<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get user ID from query parameters
$userId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($userId <= 0) {
    setFlashMessage('Invalid user ID', 'error');
    redirect(ADMIN_URL . '/users.php');
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get admin data for logging
$adminId = $_SESSION['admin_id'];
$stmt = $conn->prepare("SELECT username FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Check if user exists
$stmt = $conn->prepare("SELECT id, username, status FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    setFlashMessage('User not found', 'error');
    redirect(ADMIN_URL . '/users.php');
}

if ($user['status'] !== 'inactive') {
    setFlashMessage('User account is already active', 'info');
    redirect(ADMIN_URL . '/view_user.php?id=' . $userId);
}

// Process form submission
$reason = '';
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $confirmActivate = isset($_POST['confirm_activate']) && $_POST['confirm_activate'] === 'true';
    $reason = sanitizeInput($_POST['reason']);
    
    if (!$confirmActivate) {
        $error = 'Please confirm activation';
    } elseif (empty($reason)) {
        $error = 'Please provide a reason for activation';
    } else {
        // Begin transaction
        $conn->begin_transaction();
        
        try {
            // Update user status to active
            $status = 'active';
            $stmt = $conn->prepare("UPDATE users SET status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $userId);
            $stmt->execute();
            
            // Log this action for security and auditing
            // Check if admin_logs table exists
            $stmt = $conn->prepare("SHOW TABLES LIKE 'admin_logs'");
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $action = "Activate user";
                $details = "Admin '{$admin['username']}' (ID: {$adminId}) activated user '{$user['username']}' (ID: {$userId}). Reason: {$reason}";
                $ipAddress = $_SERVER['REMOTE_ADDR'];
                
                $stmt = $conn->prepare("
                    INSERT INTO admin_logs 
                    (admin_id, action, details, ip_address, user_id)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $stmt->bind_param("isssi", $adminId, $action, $details, $ipAddress, $userId);
                $stmt->execute();
            }
            
            // Create notification for user
            $title = 'Account Activated';
            $message = 'Your account has been reactivated by an administrator. Reason: ' . $reason . '. You can now log in and continue using our services.';
            $notifyType = 'success';
            
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, ?, 0)
            ");
            $stmt->bind_param("isss", $userId, $title, $message, $notifyType);
            $stmt->execute();
            
            // Commit transaction
            $conn->commit();
            
            $success = 'User activated successfully';
        } catch (Exception $e) {
            // Rollback transaction on error
            $conn->rollback();
            $error = 'Error: ' . $e->getMessage();
        }
    }
}

// If success and no error, redirect back to user page
if ($success && !$error) {
    setFlashMessage($success, 'success');
    redirect(ADMIN_URL . '/view_user.php?id=' . $userId);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Activate User - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-bell mr-3"></i>
                                <span>Notifications</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-ticket-alt mr-3"></i>
                                <span>Support Tickets</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cog mr-3"></i>
                                <span>General</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex items-center mb-6">
                <a href="<?php echo ADMIN_URL; ?>/view_user.php?id=<?php echo $userId; ?>" class="text-indigo-400 hover:text-indigo-300 mr-3">
                    <i class="fas fa-arrow-left"></i> Back to User
                </a>
                <h1 class="text-2xl font-bold text-white">Activate User</h1>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="admin-card rounded-lg shadow-md p-6">
                <div class="text-center mb-6">
                    <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                        <i class="fas fa-user-check text-3xl text-green-500"></i>
                    </div>
                    <h2 class="text-xl font-semibold text-white">Activate User Account</h2>
                    <p class="text-gray-400 mt-2">You are about to activate the account for <span class="text-white font-medium"><?php echo htmlspecialchars($user['username']); ?></span> (ID: <?php echo $user['id']; ?>)</p>
                </div>
                
                <div class="mb-6 p-4 bg-green-500 bg-opacity-10 border border-green-500 rounded-md">
                    <p class="text-green-300 flex items-start">
                        <i class="fas fa-info-circle mt-1 mr-2"></i>
                        <span>
                            <strong>Note:</strong> Activating this account will allow the user to log in and use all services. They will be notified about this change.
                        </span>
                    </p>
                </div>
                
                <form method="POST" action="">
                    <div class="mb-4">
                        <label for="reason" class="block text-sm font-medium text-gray-400 mb-2">Reason for Activation</label>
                        <textarea id="reason" name="reason" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo htmlspecialchars($reason); ?></textarea>
                        <p class="mt-1 text-sm text-gray-500">This reason will be visible to the user and in admin logs.</p>
                    </div>
                    
                    <div class="mb-6">
                        <div class="flex items-center mt-3">
                            <input type="checkbox" id="confirm_activate" name="confirm_activate" value="true" class="form-checkbox h-4 w-4 text-green-600 rounded focus:ring-green-500 focus:ring-offset-gray-800" required>
                            <label for="confirm_activate" class="ml-2 text-white">I confirm that I want to activate this user account</label>
                        </div>
                    </div>
                    
                    <div class="flex justify-end">
                        <a href="<?php echo ADMIN_URL; ?>/view_user.php?id=<?php echo $userId; ?>" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                            Cancel
                        </a>
                        <button type="submit" class="bg-green-600 hover:bg-green-700 py-2 px-4 rounded-md text-white">
                            Activate Account
                        </button>
                    </div>
                </form>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>