<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process form submission
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = sanitizeInput($_POST['username']);
    $email = sanitizeInput($_POST['email']);
    $phone = sanitizeInput($_POST['phone']);
    $password = sanitizeInput($_POST['password']);
    $confirmPassword = sanitizeInput($_POST['confirm_password']);
    $userType = sanitizeInput($_POST['user_type']);
    $status = sanitizeInput($_POST['status']);
    $initialBalance = isset($_POST['initial_balance']) ? (float)$_POST['initial_balance'] : 0;
    
    // Validate inputs
    if (empty($username)) {
        $error = 'Username is required';
    } elseif (empty($email)) {
        $error = 'Email is required';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = 'Invalid email format';
    } elseif (empty($password)) {
        $error = 'Password is required';
    } elseif ($password !== $confirmPassword) {
        $error = 'Passwords do not match';
    } elseif (!in_array($userType, ['smart', 'vendor', 'api'])) {
        $error = 'Invalid user type';
    } elseif (!in_array($status, ['active', 'inactive', 'pending'])) {
        $error = 'Invalid status';
    } elseif ($initialBalance < 0) {
        $error = 'Initial balance cannot be negative';
    } else {
        // Check if username or email already exists
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM users WHERE username = ? OR email = ?");
        $stmt->bind_param("ss", $username, $email);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row['count'] > 0) {
            $error = 'Username or email already exists';
        } else {
            // Hash password
            $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
            
            // Generate verification token if status is pending
            $verificationToken = null;
            if ($status === 'pending') {
                $verificationToken = md5(uniqid(rand(), true));
            }
            
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Create user
                $stmt = $conn->prepare("
                    INSERT INTO users 
                    (username, email, phone, password, user_type, status, balance, verification_token, email_verified)
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");
                
                $emailVerified = $status === 'active' ? 1 : 0;
                $stmt->bind_param("ssssssdsi", $username, $email, $phone, $hashedPassword, $userType, $status, $initialBalance, $verificationToken, $emailVerified);
                
                if (!$stmt->execute()) {
                    throw new Exception("Failed to create user: " . $conn->error);
                }
                
                $userId = $conn->insert_id;
                
                // Create initial balance transaction if balance > 0
                if ($initialBalance > 0) {
                    $txnRef = 'ADMIN_CREDIT_' . uniqid() . '_' . time();
                    $description = 'Initial balance credit by admin';
                    
                    $stmt = $conn->prepare("
                        INSERT INTO transactions 
                        (user_id, txn_ref, type, amount, fee, description, status)
                        VALUES (?, ?, 'credit', ?, 0, ?, 'successful')
                    ");
                    
                    $stmt->bind_param("isds", $userId, $txnRef, $initialBalance, $description);
                    
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create initial balance transaction: " . $conn->error);
                    }
                }
                
                // Create welcome notification
                $welcomeTitle = 'Welcome to ' . getSetting('site_name');
                $welcomeMessage = 'Your account has been created successfully. Welcome to our platform!';
                
                $stmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, 'success', 0)
                ");
                
                $stmt->bind_param("iss", $userId, $welcomeTitle, $welcomeMessage);
                
                if (!$stmt->execute()) {
                    throw new Exception("Failed to create welcome notification: " . $conn->error);
                }
                
                // Generate API key if user type is API
                if ($userType === 'api') {
                    // Use generateApiKey function if available
                    if (function_exists('generateApiKey')) {
                        $apiKey = generateApiKey();
                    } else {
                        // Fallback to manual generation
                        $apiKey = bin2hex(random_bytes(32));
                    }
                    
                    $stmt = $conn->prepare("UPDATE users SET api_key = ? WHERE id = ?");
                    $stmt->bind_param("si", $apiKey, $userId);
                    
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to set API key: " . $conn->error);
                    }
                }
                
                // Send welcome email
                if (!empty($email)) {
                    $subject = 'Welcome to ' . getSetting('site_name');
                    $emailMsg = "
                        <p>Dear {$username},</p>
                        <p>Your account has been created successfully. Welcome to " . getSetting('site_name') . "!</p>
                    ";
                    
                    // Add verification link if status is pending
                    if ($status === 'pending' && $verificationToken) {
                        $verificationLink = SITE_URL . '/verify.php?token=' . $verificationToken;
                        $emailMsg .= "
                            <p>Please click the link below to verify your email address:</p>
                            <p><a href='{$verificationLink}'>{$verificationLink}</a></p>
                        ";
                    } else {
                        $emailMsg .= "
                            <p>Your account is now active and you can start using our services.</p>
                            <p>Login Details:</p>
                            <p>Username: {$username}<br>Password: {$password}</p>
                        ";
                    }
                    
                    $emailMsg .= "
                        <p>Thank you for joining us!</p>
                        <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                    ";
                    
                    sendEmail($email, $subject, $emailMsg);
                }
                
                // Commit transaction
                $conn->commit();
                
                $success = 'User created successfully';
                
                // Clear form data after successful submission
                $_POST = [];
            } catch (Exception $e) {
                // Rollback transaction on error
                $conn->rollback();
                $error = 'Error: ' . $e->getMessage();
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add User - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700 border-l-3 border-indigo-500">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-bell mr-3"></i>
                                <span>Notifications</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-ticket-alt mr-3"></i>
                                <span>Support Tickets</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cog mr-3"></i>
                                <span>General</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex items-center mb-6">
                <a href="<?php echo ADMIN_URL; ?>/users.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                    <i class="fas fa-arrow-left"></i> Back to Users
                </a>
                <h1 class="text-2xl font-bold text-white">Add New User</h1>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="admin-card rounded-lg shadow-md p-6">
                <form method="POST" action="">
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <div>
                            <h2 class="text-lg font-semibold text-white mb-4">Account Information</h2>
                            
                            <div class="space-y-4">
                                <div>
                                    <label for="username" class="block text-sm font-medium text-gray-400 mb-1">Username <span class="text-red-500">*</span></label>
                                    <input type="text" id="username" name="username" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $_POST['username'] ?? ''; ?>" required>
                                </div>
                                
                                <div>
                                    <label for="email" class="block text-sm font-medium text-gray-400 mb-1">Email <span class="text-red-500">*</span></label>
                                    <input type="email" id="email" name="email" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $_POST['email'] ?? ''; ?>" required>
                                </div>
                                
                                <div>
                                    <label for="phone" class="block text-sm font-medium text-gray-400 mb-1">Phone</label>
                                    <input type="text" id="phone" name="phone" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $_POST['phone'] ?? ''; ?>">
                                </div>
                                
                                <div>
                                    <label for="password" class="block text-sm font-medium text-gray-400 mb-1">Password <span class="text-red-500">*</span></label>
                                    <div class="relative">
                                        <input type="password" id="password" name="password" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 pr-10" required>
                                        <button type="button" id="togglePassword" class="absolute inset-y-0 right-0 px-3 flex items-center text-gray-400 hover:text-white">
                                            <i class="fas fa-eye"></i>
                                        </button>
                                    </div>
                                </div>
                                
                                <div>
                                    <label for="confirm_password" class="block text-sm font-medium text-gray-400 mb-1">Confirm Password <span class="text-red-500">*</span></label>
                                    <div class="relative">
                                        <input type="password" id="confirm_password" name="confirm_password" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 pr-10" required>
                                        <button type="button" id="toggleConfirmPassword" class="absolute inset-y-0 right-0 px-3 flex items-center text-gray-400 hover:text-white">
                                            <i class="fas fa-eye"></i>
                                        </button>
                                    </div>
                                </div>
                                
                                <div>
                                    <button type="button" id="generatePasswordBtn" class="text-indigo-400 hover:text-indigo-300 text-sm">
                                        <i class="fas fa-magic mr-1"></i> Generate Strong Password
                                    </button>
                                </div>
                            </div>
                        </div>
                        
                        <div>
                            <h2 class="text-lg font-semibold text-white mb-4">Account Settings</h2>
                            
                            <div class="space-y-4">
                                <div>
                                    <label for="user_type" class="block text-sm font-medium text-gray-400 mb-1">Account Type <span class="text-red-500">*</span></label>
                                    <select id="user_type" name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                        <option value="smart" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'smart') ? 'selected' : ''; ?>>Standard User</option>
                                        <option value="vendor" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'vendor') ? 'selected' : ''; ?>>Vendor</option>
                                        <option value="api" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'api') ? 'selected' : ''; ?>>API User</option>
                                    </select>
                                </div>
                                
                                <div>
                                    <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status <span class="text-red-500">*</span></label>
                                    <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                        <option value="active" <?php echo (isset($_POST['status']) && $_POST['status'] === 'active') ? 'selected' : ''; ?>>Active</option>
                                        <option value="inactive" <?php echo (isset($_POST['status']) && $_POST['status'] === 'inactive') ? 'selected' : ''; ?>>Inactive</option>
                                        <option value="pending" <?php echo (isset($_POST['status']) && $_POST['status'] === 'pending') ? 'selected' : ''; ?>>Pending Verification</option>
                                    </select>
                                </div>
                                
                                <div>
                                    <label for="initial_balance" class="block text-sm font-medium text-gray-400 mb-1">Initial Wallet Balance</label>
                                    <div class="relative mt-1 rounded-md shadow-sm">
                                        <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                            <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                                        </div>
                                        <input type="number" id="initial_balance" name="initial_balance" min="0" step="0.01" class="form-input block w-full pl-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $_POST['initial_balance'] ?? '0'; ?>">
                                    </div>
                                    <p class="mt-1 text-xs text-gray-500">Optional initial wallet balance for the user</p>
                                </div>
                                
                                <div class="pt-4">
                                    <div class="bg-gray-700 p-4 rounded-md">
                                        <h3 class="text-white font-medium mb-2">Important Notes</h3>
                                        <ul class="text-gray-400 text-sm space-y-2">
                                            <li class="flex items-start">
                                                <i class="fas fa-info-circle text-indigo-400 mt-1 mr-2"></i>
                                                <span>Active users can log in immediately and use the platform.</span>
                                            </li>
                                            <li class="flex items-start">
                                                <i class="fas fa-info-circle text-indigo-400 mt-1 mr-2"></i>
                                                <span>Pending users will receive a verification email and need to verify their email before they can log in.</span>
                                            </li>
                                            <li class="flex items-start">
                                                <i class="fas fa-info-circle text-indigo-400 mt-1 mr-2"></i>
                                                <span>Inactive users cannot log in until their status is changed to active.</span>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 flex justify-end">
                        <a href="<?php echo ADMIN_URL; ?>/users.php" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                            Cancel
                        </a>
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            Create User
                        </button>
                    </div>
                </form>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Toggle password visibility
            const togglePassword = document.getElementById('togglePassword');
            const password = document.getElementById('password');
            
            togglePassword.addEventListener('click', function() {
                const type = password.getAttribute('type') === 'password' ? 'text' : 'password';
                password.setAttribute('type', type);
                this.querySelector('i').classList.toggle('fa-eye');
                this.querySelector('i').classList.toggle('fa-eye-slash');
            });
            
            // Toggle confirm password visibility
            const toggleConfirmPassword = document.getElementById('toggleConfirmPassword');
            const confirmPassword = document.getElementById('confirm_password');
            
            toggleConfirmPassword.addEventListener('click', function() {
                const type = confirmPassword.getAttribute('type') === 'password' ? 'text' : 'password';
                confirmPassword.setAttribute('type', type);
                this.querySelector('i').classList.toggle('fa-eye');
                this.querySelector('i').classList.toggle('fa-eye-slash');
            });
            
            // Generate random password
            const generatePasswordBtn = document.getElementById('generatePasswordBtn');
            
            generatePasswordBtn.addEventListener('click', function() {
                const length = 12;
                const charset = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()_-+=";
                let generatedPassword = "";
                
                for (let i = 0; i < length; i++) {
                    const randomIndex = Math.floor(Math.random() * charset.length);
                    generatedPassword += charset[randomIndex];
                }
                
                password.setAttribute('type', 'text');
                confirmPassword.setAttribute('type', 'text');
                
                password.value = generatedPassword;
                confirmPassword.value = generatedPassword;
                
                // Update toggle buttons
                togglePassword.querySelector('i').classList.remove('fa-eye');
                togglePassword.querySelector('i').classList.add('fa-eye-slash');
                toggleConfirmPassword.querySelector('i').classList.remove('fa-eye');
                toggleConfirmPassword.querySelector('i').classList.add('fa-eye-slash');
            });
        });
    </script>
</body>
</html>