<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get dashboard stats
$stats = [
    'total_users' => 0,
    'active_users' => 0,
    'suspended_users' => 0,
    'smart_users' => 0,
    'vendor_users' => 0,
    'api_users' => 0,
    'total_transactions' => 0,
    'pending_transactions' => 0,
    'successful_transactions' => 0,
    'failed_transactions' => 0,
    'total_earnings' => 0,
    'today_earnings' => 0,
    'this_month_earnings' => 0,
    'total_data_sales' => 0,
    'total_airtime_sales' => 0
];

// Total users
$result = $conn->query("SELECT COUNT(*) as total FROM users");
$row = $result->fetch_assoc();
$stats['total_users'] = $row['total'];

// Active users
$result = $conn->query("SELECT COUNT(*) as total FROM users WHERE status = 'active'");
$row = $result->fetch_assoc();
$stats['active_users'] = $row['total'];

// Suspended users
$result = $conn->query("SELECT COUNT(*) as total FROM users WHERE status = 'suspended'");
$row = $result->fetch_assoc();
$stats['suspended_users'] = $row['total'];

// User types
$result = $conn->query("SELECT user_type, COUNT(*) as total FROM users GROUP BY user_type");
while ($row = $result->fetch_assoc()) {
    $stats[$row['user_type'] . '_users'] = $row['total'];
}

// Total transactions
$result = $conn->query("SELECT COUNT(*) as total FROM transactions");
$row = $result->fetch_assoc();
$stats['total_transactions'] = $row['total'];

// Transaction status counts
$result = $conn->query("SELECT status, COUNT(*) as total FROM transactions GROUP BY status");
while ($row = $result->fetch_assoc()) {
    $stats[$row['status'] . '_transactions'] = $row['total'];
}

// Total earnings (from transaction fees)
$result = $conn->query("SELECT SUM(fee) as total FROM transactions WHERE status = 'successful'");
$row = $result->fetch_assoc();
$stats['total_earnings'] = $row['total'] ?: 0;

// Today's earnings
$today = date('Y-m-d');
$result = $conn->query("SELECT SUM(fee) as total FROM transactions WHERE status = 'successful' AND DATE(created_at) = '$today'");
$row = $result->fetch_assoc();
$stats['today_earnings'] = $row['total'] ?: 0;

// This month's earnings
$thisMonth = date('Y-m');
$result = $conn->query("SELECT SUM(fee) as total FROM transactions WHERE status = 'successful' AND created_at LIKE '$thisMonth%'");
$row = $result->fetch_assoc();
$stats['this_month_earnings'] = $row['total'] ?: 0;

// Sales by type
$result = $conn->query("SELECT type, SUM(amount) as total FROM transactions WHERE status = 'successful' GROUP BY type");
while ($row = $result->fetch_assoc()) {
    $stats['total_' . $row['type'] . '_sales'] = $row['total'] ?: 0;
}

// Get provider balances
$providerBalances = [];
$result = $conn->query("SELECT * FROM provider_balances ORDER BY provider_name");
while ($row = $result->fetch_assoc()) {
    $providerBalances[] = $row;
}

// Get recent transactions
$recentTransactions = [];
$result = $conn->query("SELECT t.*, u.username FROM transactions t JOIN users u ON t.user_id = u.id ORDER BY t.created_at DESC LIMIT 10");
while ($row = $result->fetch_assoc()) {
    $recentTransactions[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .stat-card {
            transition: transform 0.2s;
        }
        
        .stat-card:hover {
            transform: translateY(-5px);
        }
        
        .status-badge {
            padding: 0.15rem 0.5rem;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-pending {
            background-color: #facc15;
            color: #292524;
        }
        
        .status-successful {
            background-color: #22c55e;
            color: #f8fafc;
        }
        
        .status-failed {
            background-color: #ef4444;
            color: #f8fafc;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                         <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="../" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4 overflow-y-auto">
            <div class="mb-6">
                <h1 class="text-2xl font-bold text-white mb-2">Admin Dashboard</h1>
                <p class="text-gray-400">Welcome back, <?php echo htmlspecialchars($admin['full_name'] ?: $admin['username']); ?>. Here's an overview of your system.</p>
            </div>
            
            <?php if ($flashMessage): ?>
                <div class="mb-4 p-4 rounded-md <?php echo $flashMessage['type'] === 'success' ? 'bg-green-500 text-white' : 'bg-red-500 text-white'; ?>">
                    <?php echo $flashMessage['message']; ?>
                </div>
            <?php endif; ?>
            
            <!-- Stats Overview -->
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 mb-6">
                <!-- User Stats -->
                <div class="admin-card rounded-lg shadow-md p-6 stat-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Users</p>
                            <h3 class="text-2xl font-bold text-white mt-1"><?php echo number_format($stats['total_users']); ?></h3>
                        </div>
                        <div class="p-3 bg-indigo-500 bg-opacity-20 rounded-full">
                            <i class="fas fa-users text-indigo-400 text-xl"></i>
                        </div>
                    </div>
                    <div class="mt-4 pt-4 border-t border-gray-700">
                        <div class="flex justify-between items-center">
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Active</span>
                                <span class="text-green-400 font-semibold"><?php echo number_format($stats['active_users']); ?></span>
                            </div>
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Suspended</span>
                                <span class="text-red-400 font-semibold"><?php echo number_format($stats['suspended_users']); ?></span>
                            </div>
                            <a href="users.php" class="text-indigo-400 hover:text-indigo-300 text-sm">View All</a>
                        </div>
                    </div>
                </div>
                
                <!-- Transaction Stats -->
                <div class="admin-card rounded-lg shadow-md p-6 stat-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Transactions</p>
                            <h3 class="text-2xl font-bold text-white mt-1"><?php echo number_format($stats['total_transactions']); ?></h3>
                        </div>
                        <div class="p-3 bg-green-500 bg-opacity-20 rounded-full">
                            <i class="fas fa-exchange-alt text-green-400 text-xl"></i>
                        </div>
                    </div>
                    <div class="mt-4 pt-4 border-t border-gray-700">
                        <div class="flex justify-between items-center">
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Successful</span>
                                <span class="text-green-400 font-semibold"><?php echo number_format($stats['successful_transactions']); ?></span>
                            </div>
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Failed</span>
                                <span class="text-red-400 font-semibold"><?php echo number_format($stats['failed_transactions']); ?></span>
                            </div>
                            <a href="transactions.php" class="text-indigo-400 hover:text-indigo-300 text-sm">View All</a>
                        </div>
                    </div>
                </div>
                
                <!-- Earnings Stats -->
                <div class="admin-card rounded-lg shadow-md p-6 stat-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Earnings</p>
                            <h3 class="text-2xl font-bold text-white mt-1"><?php echo formatAmount($stats['total_earnings']); ?></h3>
                        </div>
                        <div class="p-3 bg-yellow-500 bg-opacity-20 rounded-full">
                            <i class="fas fa-money-bill-wave text-yellow-400 text-xl"></i>
                        </div>
                    </div>
                    <div class="mt-4 pt-4 border-t border-gray-700">
                        <div class="flex justify-between items-center">
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Today</span>
                                <span class="text-green-400 font-semibold"><?php echo formatAmount($stats['today_earnings']); ?></span>
                            </div>
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">This Month</span>
                                <span class="text-green-400 font-semibold"><?php echo formatAmount($stats['this_month_earnings']); ?></span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Sales Stats -->
                <div class="admin-card rounded-lg shadow-md p-6 stat-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Sales</p>
                            <h3 class="text-2xl font-bold text-white mt-1"><?php echo formatAmount($stats['total_data_sales'] + $stats['total_airtime_sales']); ?></h3>
                        </div>
                        <div class="p-3 bg-purple-500 bg-opacity-20 rounded-full">
                            <i class="fas fa-chart-line text-purple-400 text-xl"></i>
                        </div>
                    </div>
                    <div class="mt-4 pt-4 border-t border-gray-700">
                        <div class="flex justify-between items-center">
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Data</span>
                                <span class="text-indigo-400 font-semibold"><?php echo formatAmount($stats['total_data_sales']); ?></span>
                            </div>
                            <div class="flex flex-col">
                                <span class="text-gray-400 text-xs">Airtime</span>
                                <span class="text-indigo-400 font-semibold"><?php echo formatAmount($stats['total_airtime_sales']); ?></span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- User Type Stats -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">User Distribution</h2>
                
                <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                    <div class="p-4 bg-gray-800 rounded-lg">
                        <div class="flex items-center justify-between mb-2">
                            <h3 class="font-semibold text-white">Smart Users</h3>
                            <span class="text-white font-bold"><?php echo number_format($stats['smart_users']); ?></span>
                        </div>
                        <div class="h-2 bg-gray-700 rounded-full overflow-hidden">
                            <div class="bg-blue-500 h-full" style="width: <?php echo ($stats['total_users'] > 0) ? ($stats['smart_users'] / $stats['total_users'] * 100) : 0; ?>%"></div>
                        </div>
                        <p class="text-gray-400 text-sm mt-1"><?php echo ($stats['total_users'] > 0) ? number_format(($stats['smart_users'] / $stats['total_users'] * 100), 1) : 0; ?>% of total users</p>
                    </div>
                    
                    <div class="p-4 bg-gray-800 rounded-lg">
                        <div class="flex items-center justify-between mb-2">
                            <h3 class="font-semibold text-white">Vendor Users</h3>
                            <span class="text-white font-bold"><?php echo number_format($stats['vendor_users']); ?></span>
                        </div>
                        <div class="h-2 bg-gray-700 rounded-full overflow-hidden">
                            <div class="bg-green-500 h-full" style="width: <?php echo ($stats['total_users'] > 0) ? ($stats['vendor_users'] / $stats['total_users'] * 100) : 0; ?>%"></div>
                        </div>
                        <p class="text-gray-400 text-sm mt-1"><?php echo ($stats['total_users'] > 0) ? number_format(($stats['vendor_users'] / $stats['total_users'] * 100), 1) : 0; ?>% of total users</p>
                    </div>
                    
                    <div class="p-4 bg-gray-800 rounded-lg">
                        <div class="flex items-center justify-between mb-2">
                            <h3 class="font-semibold text-white">API Users</h3>
                            <span class="text-white font-bold"><?php echo number_format($stats['api_users']); ?></span>
                        </div>
                        <div class="h-2 bg-gray-700 rounded-full overflow-hidden">
                            <div class="bg-red-500 h-full" style="width: <?php echo ($stats['total_users'] > 0) ? ($stats['api_users'] / $stats['total_users'] * 100) : 0; ?>%"></div>
                        </div>
                        <p class="text-gray-400 text-sm mt-1"><?php echo ($stats['total_users'] > 0) ? number_format(($stats['api_users'] / $stats['total_users'] * 100), 1) : 0; ?>% of total users</p>
                    </div>
                </div>
            </div>
            
            <!-- Provider Balances -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Provider Balances</h2>
                    <a href="settings/providers.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                        <i class="fas fa-cog mr-1"></i> Manage
                    </a>
                </div>
                
                <?php if (empty($providerBalances)): ?>
                    <p class="text-gray-400">No provider balances configured yet.</p>
                <?php else: ?>
                    <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                        <?php foreach ($providerBalances as $provider): ?>
                            <div class="p-4 bg-gray-800 rounded-lg">
                                <h3 class="font-semibold text-white mb-2"><?php echo htmlspecialchars($provider['provider_name']); ?></h3>
                                <div class="flex justify-between items-center">
                                    <span class="text-gray-400">Balance:</span>
                                    <span class="text-white font-bold"><?php echo formatAmount($provider['balance']); ?></span>
                                </div>
                                <div class="flex justify-between items-center mt-2 text-sm">
                                    <span class="text-gray-400">Last Check:</span>
                                    <span class="text-gray-300">
                                        <?php echo $provider['last_checked'] ? date('M d, Y H:i', strtotime($provider['last_checked'])) : 'Never'; ?>
                                    </span>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                    
                    <div class="mt-4 text-center">
                        <button id="refreshBalancesBtn" class="accent-button py-2 px-4 rounded-md shadow-sm text-sm font-medium text-white">
                            <i class="fas fa-sync-alt mr-1"></i> Refresh All Balances
                        </button>
                        <p id="refreshStatus" class="mt-2 text-gray-400 text-sm hidden"></p>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Recent Transactions -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Recent Transactions</h2>
                    <a href="transactions.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                        View All
                    </a>
                </div>
                
                <?php if (empty($recentTransactions)): ?>
                    <p class="text-gray-400">No transactions yet.</p>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="w-full">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th class="px-4 py-2 text-left text-gray-300">ID</th>
                                    <th class="px-4 py-2 text-left text-gray-300">User</th>
                                    <th class="px-4 py-2 text-left text-gray-300">Type</th>
                                    <th class="px-4 py-2 text-left text-gray-300">Amount</th>
                                    <th class="px-4 py-2 text-left text-gray-300">Status</th>
                                    <th class="px-4 py-2 text-left text-gray-300">Date</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($recentTransactions as $transaction): ?>
                                    <tr class="border-t border-gray-700">
                                        <td class="px-4 py-3 text-gray-300"><?php echo $transaction['id']; ?></td>
                                        <td class="px-4 py-3 text-gray-300"><?php echo htmlspecialchars($transaction['username']); ?></td>
                                        <td class="px-4 py-3 text-gray-300">
                                            <?php 
                                                $typeIcon = '';
                                                switch ($transaction['type']) {
                                                    case 'funding':
                                                        $typeIcon = '<i class="fas fa-money-bill-wave text-green-500 mr-2"></i>';
                                                        break;
                                                    case 'data':
                                                        $typeIcon = '<i class="fas fa-wifi text-blue-500 mr-2"></i>';
                                                        break;
                                                    case 'airtime':
                                                        $typeIcon = '<i class="fas fa-phone text-purple-500 mr-2"></i>';
                                                        break;
                                                    case 'cable':
                                                        $typeIcon = '<i class="fas fa-tv text-red-500 mr-2"></i>';
                                                        break;
                                                    case 'electricity':
                                                        $typeIcon = '<i class="fas fa-bolt text-yellow-500 mr-2"></i>';
                                                        break;
                                                    case 'withdrawal':
                                                        $typeIcon = '<i class="fas fa-hand-holding-usd text-red-500 mr-2"></i>';
                                                        break;
                                                    case 'transfer':
                                                        $typeIcon = '<i class="fas fa-exchange-alt text-blue-500 mr-2"></i>';
                                                        break;
                                                    case 'upgrade':
                                                        $typeIcon = '<i class="fas fa-arrow-up text-indigo-500 mr-2"></i>';
                                                        break;
                                                    case 'bonus':
                                                        $typeIcon = '<i class="fas fa-gift text-pink-500 mr-2"></i>';
                                                        break;
                                                    default:
                                                        $typeIcon = '<i class="fas fa-circle text-gray-500 mr-2"></i>';
                                                }
                                                echo $typeIcon . ucfirst($transaction['type']);
                                            ?>
                                        </td>
                                        <td class="px-4 py-3 text-gray-300">
                                            <?php echo formatAmount($transaction['amount']); ?>
                                        </td>
                                        <td class="px-4 py-3">
                                            <span class="status-badge <?php echo 'status-' . $transaction['status']; ?>">
                                                <?php echo ucfirst($transaction['status']); ?>
                                            </span>
                                        </td>
                                        <td class="px-4 py-3 text-gray-300">
                                            <?php echo date('M d, H:i', strtotime($transaction['created_at'])); ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Refresh provider balances
        const refreshBalancesBtn = document.getElementById('refreshBalancesBtn');
        const refreshStatus = document.getElementById('refreshStatus');
        
        if (refreshBalancesBtn) {
            refreshBalancesBtn.addEventListener('click', async () => {
                refreshBalancesBtn.disabled = true;
                refreshBalancesBtn.innerHTML = '<i class="fas fa-spinner fa-spin mr-1"></i> Refreshing...';
                refreshStatus.classList.remove('hidden');
                refreshStatus.textContent = 'Fetching provider balances...';
                
                try {
                    // This is a placeholder - in a real implementation you would make an AJAX request to refresh balances
                    await new Promise(resolve => setTimeout(resolve, 2000)); // Simulate API call
                    
                    refreshStatus.textContent = 'Balances refreshed successfully! Page will reload shortly...';
                    setTimeout(() => {
                        window.location.reload();
                    }, 1500);
                } catch (error) {
                    refreshStatus.textContent = 'Error refreshing balances: ' + error.message;
                    refreshBalancesBtn.disabled = false;
                    refreshBalancesBtn.innerHTML = '<i class="fas fa-sync-alt mr-1"></i> Try Again';
                }
            });
        }
    </script>
</body>
</html>