<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is already logged in
if (isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/index.php');
}

$errors = [];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $username = sanitizeInput($_POST['username'] ?? '');
    $password = $_POST['password'] ?? '';
    
    // Validate form data
    if (empty($username)) {
        $errors[] = 'Username is required';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    }
    
    // If no errors, attempt to log in
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        $stmt = $conn->prepare("SELECT * FROM admins WHERE username = ?");
        $stmt->bind_param("s", $username);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $admin = $result->fetch_assoc();
            
            // Verify password
            if (password_verify($password, $admin['password'])) {
                // Log admin in
                $_SESSION['admin_id'] = $admin['id'];
                $_SESSION['admin_username'] = $admin['username'];
                
                // Redirect to admin dashboard
                redirect(ADMIN_URL . '/index.php');
            } else {
                $errors[] = 'Invalid password';
            }
        } else {
            $errors[] = 'Username not found';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Login - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .login-container {
            width: 100%;
            max-width: 450px;
            margin: 0 auto;
            padding: 2rem;
            border-radius: 8px;
            background-color: #1e1e1e;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.3);
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
            font-size: 16px; /* Prevent zooming on mobile */
            padding: 0.75rem 1rem;
            width: 100%;
            margin-bottom: 1rem;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
            box-shadow: 0 0 0 2px rgba(93, 92, 222, 0.3);
            outline: none;
        }
        .primary-button {
            background-color: #5D5CDE;
            padding: 0.75rem 1rem;
            font-size: 16px;
            font-weight: 600;
            width: 100%;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .primary-button:hover {
            background-color: #4a49b8;
            transform: translateY(-1px);
        }
        .back-link {
            display: inline-block;
            margin-top: 1rem;
            color: #5D5CDE;
            transition: color 0.3s ease;
        }
        .back-link:hover {
            color: #4a49b8;
            text-decoration: underline;
        }
        @media (max-width: 640px) {
            .login-container {
                padding: 1.5rem;
                max-width: 90%;
            }
        }
    </style>
</head>
<body>
    <div class="login-container">
        <div>
            <h2 class="text-center text-3xl font-extrabold text-white mb-6">
                Admin Login
            </h2>
            <p class="text-center text-gray-400 mb-8">
                Sign in to access the admin panel
            </p>
        </div>
        
        <?php if (!empty($errors)): ?>
            <div class="bg-red-500 text-white p-4 rounded-md mb-6" role="alert">
                <ul class="list-disc pl-5">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo $error; ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <form method="POST" action="">
            <div class="mb-4">
                <label for="username" class="block text-gray-300 mb-2">Username</label>
                <input id="username" name="username" type="text" autocomplete="username" required 
                       class="dark-input" placeholder="Enter your username" 
                       value="<?php echo isset($_POST['username']) ? htmlspecialchars($_POST['username']) : ''; ?>">
            </div>
            
            <div class="mb-6">
                <label for="password" class="block text-gray-300 mb-2">Password</label>
                <input id="password" name="password" type="password" autocomplete="current-password" 
                       required class="dark-input" placeholder="Enter your password">
            </div>

            <div>
                <button type="submit" class="primary-button text-white">
                    Sign in
                </button>
            </div>
            
            <div class="text-center mt-4">
                <a href="<?php echo SITE_URL; ?>" class="back-link">
                    Back to main site
                </a>
            </div>
        </form>
    </div>
</body>
</html>