<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize variables
$success = '';
$error = '';

// Process approval/rejection of deposit
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['approve_deposit'])) {
        $depositId = (int)$_POST['deposit_id'];
        $adminComment = sanitizeInput($_POST['admin_comment'] ?? '');
        
        // Begin transaction
        $conn->begin_transaction();
        
        try {
            // Get deposit details
            $stmt = $conn->prepare("SELECT * FROM manual_deposits WHERE id = ? AND status = 'pending'");
            $stmt->bind_param("i", $depositId);
            $stmt->execute();
            $result = $stmt->get_result();
            $deposit = $result->fetch_assoc();
            
            if (!$deposit) {
                throw new Exception('Invalid deposit or already processed');
            }
            
            // Update deposit status
            $stmt = $conn->prepare("UPDATE manual_deposits SET status = 'approved', admin_comment = ? WHERE id = ?");
            $stmt->bind_param("si", $adminComment, $depositId);
            
            if (!$stmt->execute()) {
                throw new Exception('Failed to update deposit status');
            }
            
            // Get user balance
            $stmt = $conn->prepare("SELECT balance FROM users WHERE id = ?");
            $stmt->bind_param("i", $deposit['user_id']);
            $stmt->execute();
            $result = $stmt->get_result();
            $user = $result->fetch_assoc();
            
            if (!$user) {
                throw new Exception('User not found');
            }
            
            // Calculate new balance
            $newBalance = $user['balance'] + $deposit['amount'];
            
            // Update user balance
            $stmt = $conn->prepare("UPDATE users SET balance = ? WHERE id = ?");
            $stmt->bind_param("di", $newBalance, $deposit['user_id']);
            
            if (!$stmt->execute()) {
                throw new Exception('Failed to update user balance');
            }
            
            // Create transaction record
            $description = "Manual bank transfer - " . $deposit['reference'];
            
            $stmt = $conn->prepare("
                INSERT INTO transactions 
                (user_id, txn_ref, type, amount, fee, description, status)
                VALUES (?, ?, 'fund', ?, 0, ?, 'completed')
            ");
            $stmt->bind_param("isds", $deposit['user_id'], $deposit['reference'], $deposit['amount'], $description);
            
            if (!$stmt->execute()) {
                throw new Exception('Failed to create transaction record');
            }
            
            // Commit transaction
            $conn->commit();
            
            $success = 'Deposit approved and wallet credited successfully';
        } catch (Exception $e) {
            // Rollback transaction
            $conn->rollback();
            $error = 'Error: ' . $e->getMessage();
        }
    } elseif (isset($_POST['reject_deposit'])) {
        $depositId = (int)$_POST['deposit_id'];
        $adminComment = sanitizeInput($_POST['admin_comment'] ?? '');
        
        // Update deposit status
        $stmt = $conn->prepare("UPDATE manual_deposits SET status = 'rejected', admin_comment = ? WHERE id = ? AND status = 'pending'");
        $stmt->bind_param("si", $adminComment, $depositId);
        
        if ($stmt->execute() && $stmt->affected_rows > 0) {
            $success = 'Deposit rejected successfully';
        } else {
            $error = 'Failed to reject deposit or deposit already processed';
        }
    }
}

// Get filter parameters
$status = isset($_GET['status']) ? sanitizeInput($_GET['status']) : 'all';
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$perPage = 20;
$offset = ($page - 1) * $perPage;

// Build query based on filters
$whereClause = "WHERE 1=1";
$countParams = [];
$dataParams = [];
$countTypes = "";
$dataTypes = "";

if ($status !== 'all') {
    $whereClause .= " AND status = ?";
    $countParams[] = $status;
    $dataParams[] = $status;
    $countTypes .= "s";
    $dataTypes .= "s";
}

// Construct count query
$countQuery = "SELECT COUNT(*) as total FROM manual_deposits $whereClause";

// Construct data query with proper JOIN syntax
$dataQuery = "SELECT manual_deposits.*, users.username FROM manual_deposits JOIN users ON manual_deposits.user_id = users.id $whereClause";

// Add order and limit to data query only
$dataQuery .= " ORDER BY created_at DESC LIMIT ?, ?";
$dataParams[] = $offset;
$dataParams[] = $perPage;
$dataTypes .= "ii";

// Get total count with count parameters
$stmt = $conn->prepare($countQuery);
if (!empty($countTypes)) {
    $stmt->bind_param($countTypes, ...$countParams);
}
$stmt->execute();
$totalResult = $stmt->get_result();
$totalRow = $totalResult->fetch_assoc();
$total = $totalRow['total'];

// Calculate total pages
$totalPages = ceil($total / $perPage);

// Get data for current page with data parameters
$stmt = $conn->prepare($dataQuery);
if (!empty($dataTypes)) {
    $stmt->bind_param($dataTypes, ...$dataParams);
}
$stmt->execute();
$deposits = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manual Deposits - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .filter-active {
            background-color: var(--accent-color);
            color: white;
        }
        
        /* Modal styles */
        .modal {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(0, 0, 0, 0.7);
            z-index: 1000;
            overflow-y: auto;
        }
        
        .modal-content {
            margin: 2rem auto;
            width: 90%;
            max-width: 600px;
            background-color: var(--bg-card);
            border-radius: 0.5rem;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.3);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Manual Deposits</h1>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <div class="flex flex-wrap items-center gap-2">
                    <span class="text-gray-400">Filter by status:</span>
                    <a href="?status=all" class="px-3 py-1 rounded-md text-sm <?php echo $status === 'all' ? 'filter-active' : 'bg-gray-700 text-gray-300 hover:bg-gray-600'; ?>">
                        All
                    </a>
                    <a href="?status=pending" class="px-3 py-1 rounded-md text-sm <?php echo $status === 'pending' ? 'filter-active' : 'bg-gray-700 text-gray-300 hover:bg-gray-600'; ?>">
                        Pending
                    </a>
                    <a href="?status=approved" class="px-3 py-1 rounded-md text-sm <?php echo $status === 'approved' ? 'filter-active' : 'bg-gray-700 text-gray-300 hover:bg-gray-600'; ?>">
                        Approved
                    </a>
                    <a href="?status=rejected" class="px-3 py-1 rounded-md text-sm <?php echo $status === 'rejected' ? 'filter-active' : 'bg-gray-700 text-gray-300 hover:bg-gray-600'; ?>">
                        Rejected
                    </a>
                </div>
            </div>
            
            <!-- Deposits Table -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden">
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-700">
                        <thead class="bg-gray-800">
                            <tr>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">ID</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">User</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Sender</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody class="divide-y divide-gray-700">
                            <?php if (empty($deposits)): ?>
                            <tr>
                                <td colspan="7" class="px-6 py-4 text-center text-gray-400">No deposits found</td>
                            </tr>
                            <?php else: ?>
                                <?php foreach ($deposits as $deposit): ?>
                                <tr>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium text-white"><?php echo $deposit['id']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo date('M d, Y H:i', strtotime($deposit['created_at'])); ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo htmlspecialchars($deposit['username']); ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo getSetting('currency') . number_format($deposit['amount'], 2); ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo htmlspecialchars($deposit['sender_name']); ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php if ($deposit['status'] === 'pending'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-yellow-100 text-yellow-800">
                                                Pending
                                            </span>
                                        <?php elseif ($deposit['status'] === 'approved'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">
                                                Approved
                                            </span>
                                        <?php elseif ($deposit['status'] === 'rejected'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-red-100 text-red-800">
                                                Rejected
                                            </span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                        <button 
                                            class="text-indigo-400 hover:text-indigo-300" 
                                            onclick="showDetailsModal(<?php echo $deposit['id']; ?>, '<?php echo addslashes($deposit['reference']); ?>', '<?php echo addslashes($deposit['username']); ?>', '<?php echo date('M d, Y', strtotime($deposit['transfer_date'])); ?>', '<?php echo addslashes($deposit['sender_name']); ?>', '<?php echo addslashes($deposit['sender_account']); ?>', '<?php echo addslashes($deposit['transaction_id']); ?>', '<?php echo $deposit['amount']; ?>', '<?php echo addslashes($deposit['proof_file']); ?>', '<?php echo $deposit['status']; ?>', '<?php echo addslashes($deposit['admin_comment'] ?? ''); ?>')">
                                            View Details
                                        </button>
                                        
                                        <?php if ($deposit['status'] === 'pending'): ?>
                                        <button 
                                            class="ml-3 text-green-400 hover:text-green-300" 
                                            onclick="showApproveModal(<?php echo $deposit['id']; ?>, '<?php echo addslashes($deposit['reference']); ?>', '<?php echo $deposit['amount']; ?>')">
                                            Approve
                                        </button>
                                        <button 
                                            class="ml-3 text-red-400 hover:text-red-300" 
                                            onclick="showRejectModal(<?php echo $deposit['id']; ?>, '<?php echo addslashes($deposit['reference']); ?>')">
                                            Reject
                                        </button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                
                <!-- Pagination -->
                <?php if ($totalPages > 1): ?>
                <div class="px-6 py-3 flex items-center justify-between border-t border-gray-700">
                    <div class="text-sm text-gray-400">
                        Showing <?php echo $offset + 1; ?> to <?php echo min($offset + $perPage, $total); ?> of <?php echo $total; ?> entries
                    </div>
                    <div class="flex space-x-1">
                        <?php if ($page > 1): ?>
                        <a href="?status=<?php echo $status; ?>&page=<?php echo $page - 1; ?>" class="px-3 py-1 rounded-md text-sm bg-gray-700 text-gray-300 hover:bg-gray-600">
                            Previous
                        </a>
                        <?php endif; ?>
                        
                        <?php for ($i = max(1, $page - 2); $i <= min($page + 2, $totalPages); $i++): ?>
                        <a href="?status=<?php echo $status; ?>&page=<?php echo $i; ?>" class="px-3 py-1 rounded-md text-sm <?php echo $i === $page ? 'filter-active' : 'bg-gray-700 text-gray-300 hover:bg-gray-600'; ?>">
                            <?php echo $i; ?>
                        </a>
                        <?php endfor; ?>
                        
                        <?php if ($page < $totalPages): ?>
                        <a href="?status=<?php echo $status; ?>&page=<?php echo $page + 1; ?>" class="px-3 py-1 rounded-md text-sm bg-gray-700 text-gray-300 hover:bg-gray-600">
                            Next
                        </a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Modal: View Deposit Details -->
    <div id="detailsModal" class="modal">
        <div class="modal-content">
            <div class="p-6">
                <div class="flex justify-between items-start mb-4">
                    <h2 class="text-xl font-semibold text-white">Deposit Details</h2>
                    <button class="text-gray-400 hover:text-white" onclick="closeDetailsModal()">
                        <i class="fas fa-times"></i>
                    </button>
                </div>
                
                <div class="space-y-4">
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div>
                            <p class="text-sm text-gray-400">Reference:</p>
                            <p class="text-white font-mono" id="modal-reference"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">User:</p>
                            <p class="text-white" id="modal-username"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Transfer Date:</p>
                            <p class="text-white" id="modal-transfer-date"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Amount:</p>
                            <p class="text-white font-semibold" id="modal-amount"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Sender Name:</p>
                            <p class="text-white" id="modal-sender-name"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Sender Account:</p>
                            <p class="text-white" id="modal-sender-account"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Transaction ID:</p>
                            <p class="text-white font-mono" id="modal-transaction-id"></p>
                        </div>
                        <div>
                            <p class="text-sm text-gray-400">Status:</p>
                            <p id="modal-status"></p>
                        </div>
                    </div>
                    
                    <div id="modal-comment-section">
                        <p class="text-sm text-gray-400">Admin Comment:</p>
                        <p class="text-white" id="modal-admin-comment">-</p>
                    </div>
                    
                    <div>
                        <p class="text-sm text-gray-400 mb-2">Proof of Payment:</p>
                        <div class="bg-gray-800 rounded-md p-2 text-center">
                            <a href="#" id="modal-proof-link" target="_blank" class="inline-block">
                                <img id="modal-proof-image" src="" alt="Proof of Payment" class="max-w-full h-auto max-h-64 rounded-md">
                            </a>
                            <p class="text-sm text-gray-400 mt-2">Click image to view full size</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Modal: Approve Deposit -->
    <div id="approveModal" class="modal">
        <div class="modal-content">
            <div class="p-6">
                <div class="flex justify-between items-start mb-4">
                    <h2 class="text-xl font-semibold text-white">Approve Deposit</h2>
                    <button class="text-gray-400 hover:text-white" onclick="closeApproveModal()">
                        <i class="fas fa-times"></i>
                    </button>
                </div>
                
                <form method="POST" action="">
                    <input type="hidden" id="approve-deposit-id" name="deposit_id">
                    
                    <div class="mb-4">
                        <p class="text-white">Are you sure you want to approve deposit <span id="approve-reference" class="font-mono"></span> for <span id="approve-amount" class="font-semibold"></span>?</p>
                        <p class="text-gray-400 text-sm mt-2">This will credit the user's wallet and mark the deposit as approved.</p>
                    </div>
                    
                    <div class="mb-4">
                        <label for="approve-comment" class="block text-sm font-medium text-gray-400 mb-1">Comment (Optional)</label>
                        <textarea id="approve-comment" name="admin_comment" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Add a comment or note"></textarea>
                    </div>
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" class="px-4 py-2 rounded-md bg-gray-700 text-white hover:bg-gray-600" onclick="closeApproveModal()">
                            Cancel
                        </button>
                        <button type="submit" name="approve_deposit" class="px-4 py-2 rounded-md bg-green-600 text-white hover:bg-green-700">
                            Approve Deposit
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <!-- Modal: Reject Deposit -->
    <div id="rejectModal" class="modal">
        <div class="modal-content">
            <div class="p-6">
                <div class="flex justify-between items-start mb-4">
                    <h2 class="text-xl font-semibold text-white">Reject Deposit</h2>
                    <button class="text-gray-400 hover:text-white" onclick="closeRejectModal()">
                        <i class="fas fa-times"></i>
                    </button>
                </div>
                
                <form method="POST" action="">
                    <input type="hidden" id="reject-deposit-id" name="deposit_id">
                    
                    <div class="mb-4">
                        <p class="text-white">Are you sure you want to reject deposit <span id="reject-reference" class="font-mono"></span>?</p>
                        <p class="text-gray-400 text-sm mt-2">This action cannot be undone.</p>
                    </div>
                    
                    <div class="mb-4">
                        <label for="reject-comment" class="block text-sm font-medium text-gray-400 mb-1">Reason for Rejection</label>
                        <textarea id="reject-comment" name="admin_comment" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Provide reason for rejection" required></textarea>
                    </div>
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" class="px-4 py-2 rounded-md bg-gray-700 text-white hover:bg-gray-600" onclick="closeRejectModal()">
                            Cancel
                        </button>
                        <button type="submit" name="reject_deposit" class="px-4 py-2 rounded-md bg-red-600 text-white hover:bg-red-700">
                            Reject Deposit
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        });
        
        // Modal functions for view details
        function showDetailsModal(id, reference, username, transferDate, senderName, senderAccount, transactionId, amount, proofFile, status, adminComment) {
            const modal = document.getElementById('detailsModal');
            
            // Set modal content
            document.getElementById('modal-reference').textContent = reference;
            document.getElementById('modal-username').textContent = username;
            document.getElementById('modal-transfer-date').textContent = transferDate;
            document.getElementById('modal-sender-name').textContent = senderName;
            document.getElementById('modal-sender-account').textContent = senderAccount;
            document.getElementById('modal-transaction-id').textContent = transactionId;
            document.getElementById('modal-amount').textContent = '<?php echo getSetting('currency'); ?>' + parseFloat(amount).toLocaleString(undefined, {minimumFractionDigits: 2, maximumFractionDigits: 2});
            
            // Set status with appropriate color
            const statusElement = document.getElementById('modal-status');
            if (status === 'pending') {
                statusElement.innerHTML = '<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-yellow-100 text-yellow-800">Pending</span>';
            } else if (status === 'approved') {
                statusElement.innerHTML = '<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">Approved</span>';
            } else if (status === 'rejected') {
                statusElement.innerHTML = '<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-red-100 text-red-800">Rejected</span>';
            }
            
            // Handle admin comment
            const commentSection = document.getElementById('modal-comment-section');
            const commentElement = document.getElementById('modal-admin-comment');
            
            if (status !== 'pending' && adminComment) {
                commentSection.classList.remove('hidden');
                commentElement.textContent = adminComment;
            } else if (status !== 'pending' && !adminComment) {
                commentSection.classList.remove('hidden');
                commentElement.textContent = '-';
            } else {
                commentSection.classList.add('hidden');
            }
            
            // Set proof file
            const proofImage = document.getElementById('modal-proof-image');
            const proofLink = document.getElementById('modal-proof-link');
            
            const proofPath = '<?php echo SITE_URL; ?>/uploads/proofs/' + proofFile;
            proofImage.src = proofPath;
            proofLink.href = proofPath;
            
            // Show modal
            modal.style.display = 'block';
        }
        
        function closeDetailsModal() {
            const modal = document.getElementById('detailsModal');
            modal.style.display = 'none';
        }
        
        // Modal functions for approve deposit
        function showApproveModal(id, reference, amount) {
            const modal = document.getElementById('approveModal');
            
            // Set form values
            document.getElementById('approve-deposit-id').value = id;
            document.getElementById('approve-reference').textContent = reference;
            document.getElementById('approve-amount').textContent = '<?php echo getSetting('currency'); ?>' + parseFloat(amount).toLocaleString(undefined, {minimumFractionDigits: 2, maximumFractionDigits: 2});
            
            // Show modal
            modal.style.display = 'block';
        }
        
        function closeApproveModal() {
            const modal = document.getElementById('approveModal');
            modal.style.display = 'none';
        }
        
        // Modal functions for reject deposit
        function showRejectModal(id, reference) {
            const modal = document.getElementById('rejectModal');
            
            // Set form values
            document.getElementById('reject-deposit-id').value = id;
            document.getElementById('reject-reference').textContent = reference;
            
            // Show modal
            modal.style.display = 'block';
        }
        
        function closeRejectModal() {
            const modal = document.getElementById('rejectModal');
            modal.style.display = 'none';
        }
        
        // Close modals when clicking outside of modal content
        window.onclick = function(event) {
            const modals = document.getElementsByClassName('modal');
            for (let i = 0; i < modals.length; i++) {
                if (event.target === modals[i]) {
                    modals[i].style.display = 'none';
                }
            }
        }
    </script>
</body>
</html>