<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$db = getDB();
$conn = $db->getConnection();

$adminId = $_SESSION['admin_id'] ?? 0;

$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process notification sending
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['send_notification'])) {
    $title = sanitizeInput($_POST['title']);
    $message = sanitizeInput($_POST['message']);
    $type = sanitizeInput($_POST['type']);
    $userType = isset($_POST['user_type']) ? sanitizeInput($_POST['user_type']) : '';
    $selectedUsers = isset($_POST['selected_users']) ? $_POST['selected_users'] : [];
    
    // Validate inputs
    if (empty($title)) {
        $error = 'Notification title is required';
    } elseif (empty($message)) {
        $error = 'Notification message is required';
    } elseif (!in_array($type, ['info', 'success', 'warning', 'error'])) {
        $error = 'Invalid notification type';
    } else {
        // Get target users based on filters
        $users = [];
        
        if (!empty($selectedUsers)) {
            // Send to specific users
            $placeholders = str_repeat('?,', count($selectedUsers) - 1) . '?';
            $types = str_repeat('i', count($selectedUsers));
            
            $stmt = $conn->prepare("SELECT id FROM users WHERE id IN ($placeholders)");
            $stmt->bind_param($types, ...$selectedUsers);
            $stmt->execute();
            $result = $stmt->get_result();
            
            while ($row = $result->fetch_assoc()) {
                $users[] = $row['id'];
            }
        } else if (!empty($userType)) {
            // Send to all users of a specific type
            $stmt = $conn->prepare("SELECT id FROM users WHERE user_type = ?");
            $stmt->bind_param("s", $userType);
            $stmt->execute();
            $result = $stmt->get_result();
            
            while ($row = $result->fetch_assoc()) {
                $users[] = $row['id'];
            }
        } else {
            // Send to all users
            $stmt = $conn->prepare("SELECT id FROM users");
            $stmt->execute();
            $result = $stmt->get_result();
            
            while ($row = $result->fetch_assoc()) {
                $users[] = $row['id'];
            }
        }
        
        if (empty($users)) {
            $error = 'No users found matching the selected criteria';
        } else {
            // Insert notifications
            $insertCount = 0;
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, ?, 0)
            ");
            
            foreach ($users as $userId) {
                $stmt->bind_param("isss", $userId, $title, $message, $type);
                if ($stmt->execute()) {
                    $insertCount++;
                }
            }
            
            if ($insertCount > 0) {
                $success = "Sent notification to $insertCount users successfully";
            } else {
                $error = 'Failed to send notifications';
            }
        }
    }
}

// Get users for selection
$stmt = $conn->prepare("SELECT id, username, email, user_type FROM users ORDER BY username ASC");
$stmt->execute();
$result = $stmt->get_result();
$allUsers = [];

while ($row = $result->fetch_assoc()) {
    $allUsers[] = $row;
}

// Group users by type for easier filtering
$usersByType = [
    'smart' => [],
    'vendor' => [],
    'api' => []
];

foreach ($allUsers as $user) {
    $type = $user['user_type'] ?? 'smart';
    $usersByType[$type][] = $user;
}

// Get recent sent notifications
$stmt = $conn->prepare("
    SELECT n.*, u.username, u.email, u.user_type
    FROM notifications n
    JOIN users u ON n.user_id = u.id
    ORDER BY n.created_at DESC
    LIMIT 20
");
$stmt->execute();
$result = $stmt->get_result();
$recentNotifications = [];

while ($row = $result->fetch_assoc()) {
    $recentNotifications[] = $row;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Notifications - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        /* Notification type badge styles */
        .notification-type {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .notification-type-info {
            background-color: rgba(59, 130, 246, 0.3);
            color: #93c5fd;
        }
        
        .notification-type-success {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .notification-type-warning {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .notification-type-error {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700 border-l-3 border-indigo-500">
                                <i class="fas fa-bell mr-3"></i>
                                <span>Notifications</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Notifications Management</h1>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
                <!-- Send Notification Form -->
                <div class="lg:col-span-1">
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Send Notification</h2>
                        
                        <form method="POST" action="">
                            <div class="mb-4">
                                <label for="title" class="block text-sm font-medium text-gray-400 mb-1">Title</label>
                                <input type="text" id="title" name="title" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            </div>
                            
                            <div class="mb-4">
                                <label for="message" class="block text-sm font-medium text-gray-400 mb-1">Message</label>
                                <textarea id="message" name="message" rows="4" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                            </div>
                            
                            <div class="mb-4">
                                <label for="type" class="block text-sm font-medium text-gray-400 mb-1">Type</label>
                                <select id="type" name="type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                    <option value="info">Information</option>
                                    <option value="success">Success</option>
                                    <option value="warning">Warning</option>
                                    <option value="error">Error</option>
                                </select>
                            </div>
                            
                            <div class="mb-6">
                                <label class="block text-sm font-medium text-gray-400 mb-1">Recipients</label>
                                
                                <div class="space-y-3">
                                    <div>
                                        <label class="inline-flex items-center">
                                            <input type="radio" name="recipients" value="all" class="form-radio text-indigo-600" checked>
                                            <span class="ml-2 text-gray-300">All Users</span>
                                        </label>
                                    </div>
                                    
                                    <div>
                                        <label class="inline-flex items-center">
                                            <input type="radio" name="recipients" value="by_type" class="form-radio text-indigo-600">
                                            <span class="ml-2 text-gray-300">By Account Type</span>
                                        </label>
                                        
                                        <div class="mt-2 pl-6 user-type-options hidden">
                                            <select name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                                <option value="smart">Standard Users (<?php echo count($usersByType['smart']); ?>)</option>
                                                <option value="vendor">Vendor Users (<?php echo count($usersByType['vendor']); ?>)</option>
                                                <option value="api">API Users (<?php echo count($usersByType['api']); ?>)</option>
                                            </select>
                                        </div>
                                    </div>
                                    
                                    <div>
                                        <label class="inline-flex items-center">
                                            <input type="radio" name="recipients" value="specific" class="form-radio text-indigo-600">
                                            <span class="ml-2 text-gray-300">Specific Users</span>
                                        </label>
                                        
                                        <div class="mt-2 pl-6 specific-users-options hidden">
                                            <select name="selected_users[]" multiple class="form-select block w-full h-40 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                                <?php foreach ($allUsers as $user): ?>
                                                    <option value="<?php echo $user['id']; ?>">
                                                        <?php echo htmlspecialchars($user['username']); ?> (<?php echo htmlspecialchars($user['email']); ?>) - <?php echo ucfirst($user['user_type']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                            <p class="mt-1 text-xs text-gray-500">Hold Ctrl/Cmd to select multiple users</p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="flex justify-end">
                                <button type="submit" name="send_notification" class="accent-button py-2 px-4 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                    <i class="fas fa-paper-plane mr-1"></i> Send Notification
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
                
                <!-- Recent Notifications -->
                <div class="lg:col-span-2">
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Recent Notifications</h2>
                        
                        <?php if (empty($recentNotifications)): ?>
                            <div class="text-center py-8 text-gray-400">
                                <div class="h-16 w-16 mx-auto mb-4 rounded-full bg-gray-700 flex items-center justify-center">
                                    <i class="fas fa-bell-slash text-2xl text-gray-500"></i>
                                </div>
                                <p>No notifications have been sent yet.</p>
                            </div>
                        <?php else: ?>
                            <div class="overflow-x-auto">
                                <table class="min-w-full divide-y divide-gray-700">
                                    <thead class="bg-gray-800">
                                        <tr>
                                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Sent</th>
                                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Recipient</th>
                                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Title</th>
                                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                        </tr>
                                    </thead>
                                    <tbody class="divide-y divide-gray-700">
                                        <?php foreach ($recentNotifications as $notification): ?>
                                            <tr class="hover:bg-gray-700">
                                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                                    <?php echo date('M d, Y H:i', strtotime($notification['created_at'])); ?>
                                                </td>
                                                <td class="px-6 py-4 whitespace-nowrap">
                                                    <div class="text-sm font-medium text-white"><?php echo htmlspecialchars($notification['username']); ?></div>
                                                    <div class="text-xs text-gray-400"><?php echo ucfirst($notification['user_type']); ?> User</div>
                                                </td>
                                                <td class="px-6 py-4">
                                                    <div class="text-sm font-medium text-white"><?php echo htmlspecialchars($notification['title']); ?></div>
                                                    <div class="text-xs text-gray-400 truncate max-w-xs"><?php echo htmlspecialchars($notification['message']); ?></div>
                                                </td>
                                                <td class="px-6 py-4 whitespace-nowrap">
                                                    <?php
                                                    $notificationTypeBadge = 'notification-type-info';
                                                    switch ($notification['type']) {
                                                        case 'success':
                                                            $notificationTypeBadge = 'notification-type-success';
                                                            break;
                                                        case 'warning':
                                                            $notificationTypeBadge = 'notification-type-warning';
                                                            break;
                                                        case 'error':
                                                            $notificationTypeBadge = 'notification-type-error';
                                                            break;
                                                    }
                                                    ?>
                                                    <span class="notification-type <?php echo $notificationTypeBadge; ?>">
                                                        <?php echo ucfirst($notification['type']); ?>
                                                    </span>
                                                </td>
                                                <td class="px-6 py-4 whitespace-nowrap text-sm">
                                                    <?php echo $notification['is_read'] ? '<span class="text-gray-400">Read</span>' : '<span class="text-indigo-400">Unread</span>'; ?>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Toggle recipient options
            const recipientRadios = document.querySelectorAll('input[name="recipients"]');
            const userTypeOptions = document.querySelector('.user-type-options');
            const specificUsersOptions = document.querySelector('.specific-users-options');
            
            recipientRadios.forEach(radio => {
                radio.addEventListener('change', function() {
                    if (this.value === 'by_type') {
                        userTypeOptions.classList.remove('hidden');
                        specificUsersOptions.classList.add('hidden');
                    } else if (this.value === 'specific') {
                        specificUsersOptions.classList.remove('hidden');
                        userTypeOptions.classList.add('hidden');
                    } else {
                        userTypeOptions.classList.add('hidden');
                        specificUsersOptions.classList.add('hidden');
                    }
                });
            });
        });
    </script>
</body>
</html>