<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get promo codes
$promoCodes = [];
$result = $conn->query("SELECT * FROM promo_codes ORDER BY created_at DESC");
while ($row = $result->fetch_assoc()) {
    $promoCodes[] = $row;
}

// Process promo code actions (add/edit/delete)
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_promo']) || isset($_POST['edit_promo'])) {
        // Common validation and data collection for both add and edit
        $promoId = isset($_POST['promo_id']) ? (int)$_POST['promo_id'] : 0;
        $promoCode = strtoupper(sanitizeInput($_POST['promo_code']));
        $promoType = sanitizeInput($_POST['promo_type']);
        $discount = (float)$_POST['discount'];
        $maxUses = (int)$_POST['max_uses'];
        $maxUsesPerUser = isset($_POST['max_uses_per_user']) ? (int)$_POST['max_uses_per_user'] : 1;
        $userType = sanitizeInput($_POST['user_type']);
        $expiryDate = sanitizeInput($_POST['expiry_date']);
        $applicableServices = isset($_POST['applicable_services']) ? $_POST['applicable_services'] : [];
        $minAmount = (float)$_POST['min_amount'];
        $maxAmount = (float)$_POST['max_amount'];
        $promoStatus = sanitizeInput($_POST['status']);
        $description = sanitizeInput($_POST['description']);
        
        // Validate inputs
        if (empty($promoCode)) {
            $actionError = 'Promo code is required';
        } elseif (!preg_match('/^[A-Z0-9_-]{3,20}$/', $promoCode)) {
            $actionError = 'Promo code must be 3-20 characters and contain only letters, numbers, underscores, and hyphens';
        } elseif (!in_array($promoType, ['percentage', 'fixed'])) {
            $actionError = 'Invalid promo type';
        } elseif ($discount <= 0) {
            $actionError = 'Discount must be greater than zero';
        } elseif ($promoType === 'percentage' && $discount > 100) {
            $actionError = 'Percentage discount cannot exceed 100%';
        } elseif ($maxUses < 0) {
            $actionError = 'Maximum uses cannot be negative';
        } elseif ($maxUsesPerUser < 0) {
            $actionError = 'Maximum uses per user cannot be negative';
        } elseif ($minAmount < 0) {
            $actionError = 'Minimum amount cannot be negative';
        } elseif ($maxAmount < 0 || ($maxAmount > 0 && $maxAmount < $minAmount)) {
            $actionError = 'Maximum amount must be greater than or equal to minimum amount';
        } elseif (empty($applicableServices)) {
            $actionError = 'At least one applicable service must be selected';
        } elseif (!in_array($promoStatus, ['active', 'inactive'])) {
            $actionError = 'Invalid status';
        } elseif (!in_array($userType, ['all', 'new', 'existing'])) {
            $actionError = 'Invalid user type';
        } else {
            // Check if promo code already exists (for new promo or when changing code)
            $stmt = $conn->prepare("SELECT id FROM promo_codes WHERE code = ? AND id != ?");
            $stmt->bind_param("si", $promoCode, $promoId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $actionError = 'Promo code already exists';
            }
        }
        
        if (empty($actionError)) {
            // Serialize applicable services array
            $servicesJson = json_encode($applicableServices);
            
            if (isset($_POST['add_promo'])) {
                // Add new promo
                $stmt = $conn->prepare("INSERT INTO promo_codes (code, type, discount, max_uses, current_uses, max_uses_per_user, user_type, expiry_date, applicable_services, min_amount, max_amount, status, description, created_at) VALUES (?, ?, ?, ?, 0, ?, ?, ?, ?, ?, ?, ?, ?, NOW())");
                $stmt->bind_param("ssdiissddsss", $promoCode, $promoType, $discount, $maxUses, $maxUsesPerUser, $userType, $expiryDate, $servicesJson, $minAmount, $maxAmount, $promoStatus, $description);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Promo code added successfully';
                } else {
                    $actionError = 'Failed to add promo code: ' . $conn->error;
                }
            } else {
                // Edit existing promo
                $stmt = $conn->prepare("UPDATE promo_codes SET code = ?, type = ?, discount = ?, max_uses = ?, max_uses_per_user = ?, user_type = ?, expiry_date = ?, applicable_services = ?, min_amount = ?, max_amount = ?, status = ?, description = ? WHERE id = ?");
                $stmt->bind_param("ssdiiissddsssi", $promoCode, $promoType, $discount, $maxUses, $maxUsesPerUser, $userType, $expiryDate, $servicesJson, $minAmount, $maxAmount, $promoStatus, $description, $promoId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Promo code updated successfully';
                } else {
                    $actionError = 'Failed to update promo code: ' . $conn->error;
                }
            }
            
            // Refresh promo codes list after action
            $promoCodes = [];
            $result = $conn->query("SELECT * FROM promo_codes ORDER BY created_at DESC");
            while ($row = $result->fetch_assoc()) {
                $promoCodes[] = $row;
            }
        }
    } elseif (isset($_POST['delete_promo'])) {
        $promoId = (int)$_POST['promo_id'];
        
        // Check if promo code has been used (has usage history)
        $stmt = $conn->prepare("SELECT current_uses FROM promo_codes WHERE id = ?");
        $stmt->bind_param("i", $promoId);
        $stmt->execute();
        $result = $stmt->get_result();
        $promo = $result->fetch_assoc();
        
        if ($promo && $promo['current_uses'] > 0) {
            $actionError = 'Cannot delete promo code that has been used. Consider marking it as inactive instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM promo_codes WHERE id = ?");
            $stmt->bind_param("i", $promoId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Promo code deleted successfully';
            } else {
                $actionError = 'Failed to delete promo code: ' . $conn->error;
            }
            
            // Refresh promo codes list after delete
            $promoCodes = [];
            $result = $conn->query("SELECT * FROM promo_codes ORDER BY created_at DESC");
            while ($row = $result->fetch_assoc()) {
                $promoCodes[] = $row;
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
} 
// Set current page for sidebar highlight
$currentPage = 'Promo_codes';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Promo Codes - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
        
        .promo-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
            display: inline-block;
            margin-right: 4px;
            margin-bottom: 4px;
        }
        
        .promo-percentage {
            background-color: rgba(37, 99, 235, 0.3);
            color: #93c5fd;
        }
        
        .promo-fixed {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .promo-code {
            font-family: monospace;
            letter-spacing: 0.05em;
            font-weight: 600;
        }
        
        /* Checkbox styling */
        .checkbox-label {
            display: flex;
            align-items: center;
            cursor: pointer;
            user-select: none;
        }
        
        .checkbox-label input[type="checkbox"] {
            position: absolute;
            opacity: 0;
            cursor: pointer;
            height: 0;
            width: 0;
        }
        
        .checkmark {
            height: 20px;
            width: 20px;
            background-color: #2d2d2d;
            border: 1px solid #444;
            border-radius: 4px;
            margin-right: 8px;
            position: relative;
        }
        
        .checkbox-label:hover input ~ .checkmark {
            background-color: #3d3d3d;
        }
        
        .checkbox-label input:checked ~ .checkmark {
            background-color: var(--accent-color);
            border-color: var(--accent-color);
        }
        
        .checkmark:after {
            content: "";
            position: absolute;
            display: none;
        }
        
        .checkbox-label input:checked ~ .checkmark:after {
            display: block;
        }
        
        .checkbox-label .checkmark:after {
            left: 7px;
            top: 3px;
            width: 5px;
            height: 10px;
            border: solid white;
            border-width: 0 2px 2px 0;
            transform: rotate(45deg);
        }
        
        /* User Type Badge */
        .user-type-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .user-type-all {
            background-color: rgba(139, 92, 246, 0.3);
            color: #c4b5fd;
        }
        
        .user-type-new {
            background-color: rgba(16, 185, 129, 0.3);
            color: #6ee7b7;
        }
        
        .user-type-existing {
            background-color: rgba(245, 158, 11, 0.3);
            color: #fcd34d;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Promo Codes Management</h1>
                <button id="addPromoBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                    <i class="fas fa-plus mr-2"></i> Add New Promo Code
                </button>
            </div>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Promo Codes List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($promoCodes)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-gift text-4xl mb-3"></i>
                        <p>No promo codes found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Code</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Discount</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Uses</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Eligible Users</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Expiry</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Services</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($promoCodes as $promo): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <span class="promo-code text-white"><?php echo htmlspecialchars($promo['code']); ?></span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="promo-badge <?php echo 'promo-' . $promo['type']; ?>">
                                                <?php echo ucfirst($promo['type']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-white">
                                            <?php if ($promo['type'] === 'percentage'): ?>
                                                <?php echo $promo['discount']; ?>%
                                            <?php else: ?>
                                                <?php echo formatAmount($promo['discount']); ?>
                                            <?php endif; ?>
                                        </td>
                                        <td class="py-3 px-4 text-gray-300">
                                            <?php echo $promo['current_uses']; ?> / <?php echo $promo['max_uses'] ?: '∞'; ?>
                                            <?php if (isset($promo['max_uses_per_user']) && $promo['max_uses_per_user'] > 0): ?>
                                                <br><span class="text-xs text-gray-400">(<?php echo $promo['max_uses_per_user']; ?> per user)</span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <?php 
                                                $userType = isset($promo['user_type']) ? $promo['user_type'] : 'all';
                                                $userTypeClass = 'user-type-' . $userType;
                                            ?>
                                            <span class="user-type-badge <?php echo $userTypeClass; ?>">
                                                <?php echo ucfirst($userType); ?> Users
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-gray-300">
                                            <?php echo $promo['expiry_date'] ? date('M d, Y', strtotime($promo['expiry_date'])) : 'Never'; ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <?php
                                            $services = json_decode($promo['applicable_services'], true);
                                            if (is_array($services) && !empty($services)) {
                                                foreach ($services as $service) {
                                                    echo '<span class="promo-badge bg-gray-700 text-gray-300">' . ucfirst($service) . '</span> ';
                                                }
                                            } else {
                                                echo '<span class="text-gray-500">None</span>';
                                            }
                                            ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $promo['status']; ?>">
                                                <?php echo ucfirst($promo['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-promo" 
                                                        data-id="<?php echo $promo['id']; ?>"
                                                        data-code="<?php echo htmlspecialchars($promo['code']); ?>"
                                                        data-type="<?php echo $promo['type']; ?>"
                                                        data-discount="<?php echo $promo['discount']; ?>"
                                                        data-max-uses="<?php echo $promo['max_uses']; ?>"
                                                        data-max-uses-per-user="<?php echo isset($promo['max_uses_per_user']) ? $promo['max_uses_per_user'] : 1; ?>"
                                                        data-user-type="<?php echo isset($promo['user_type']) ? $promo['user_type'] : 'all'; ?>"
                                                        data-expiry="<?php echo $promo['expiry_date']; ?>"
                                                        data-services="<?php echo htmlspecialchars($promo['applicable_services']); ?>"
                                                        data-min-amount="<?php echo $promo['min_amount']; ?>"
                                                        data-max-amount="<?php echo $promo['max_amount']; ?>"
                                                        data-status="<?php echo $promo['status']; ?>"
                                                        data-description="<?php echo htmlspecialchars($promo['description']); ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-promo" 
                                                        data-id="<?php echo $promo['id']; ?>"
                                                        data-code="<?php echo htmlspecialchars($promo['code']); ?>"
                                                        data-uses="<?php echo $promo['current_uses']; ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Promo Codes</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Promo codes are discount coupons that users can apply during checkout to get reduced prices on purchases.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Percentage vs Fixed</h3>
                            <p class="text-gray-400">
                                Percentage discounts reduce the price by a percentage of the total amount, while fixed discounts
                                reduce the price by a specific amount regardless of the total.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Usage Limits</h3>
                            <p class="text-gray-400">
                                You can limit how many times a promo code can be used overall and per user.
                                Setting overall limit to 0 means unlimited uses.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">User Eligibility</h3>
                            <p class="text-gray-400">
                                You can restrict promo codes to new users (registered after promo creation), 
                                existing users (registered before promo creation), or all users.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: Create time-limited promotions by setting an expiry date, and target specific services
                        by selecting only the applicable services.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Promo Modal -->
    <div id="promoModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Promo Code</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="promo_id" name="promo_id" value="">
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                    <div>
                        <label for="promo_code" class="block text-sm font-medium text-gray-400 mb-1">Promo Code</label>
                        <input type="text" id="promo_code" name="promo_code" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <p class="mt-1 text-sm text-gray-500">3-20 characters, letters, numbers, underscores, and hyphens only</p>
                    </div>
                    
                    <div>
                        <label for="promo_type" class="block text-sm font-medium text-gray-400 mb-1">Discount Type</label>
                        <select id="promo_type" name="promo_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="percentage">Percentage Discount</option>
                            <option value="fixed">Fixed Amount Discount</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="discount" class="block text-sm font-medium text-gray-400 mb-1">Discount Value</label>
                        <div class="flex">
                            <input type="number" id="discount" name="discount" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" step="0.01" min="0" required>
                            <span id="discount-symbol" class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                        </div>
                    </div>
                    
                    <div>
                        <label for="max_uses" class="block text-sm font-medium text-gray-400 mb-1">Maximum Uses (Total)</label>
                        <input type="number" id="max_uses" name="max_uses" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" value="0">
                        <p class="mt-1 text-sm text-gray-500">0 for unlimited uses</p>
                    </div>
                    
                    <div>
                        <label for="max_uses_per_user" class="block text-sm font-medium text-gray-400 mb-1">Maximum Uses Per User</label>
                        <input type="number" id="max_uses_per_user" name="max_uses_per_user" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" value="1">
                        <p class="mt-1 text-sm text-gray-500">How many times a single user can use this code</p>
                    </div>
                    
                    <div>
                        <label for="user_type" class="block text-sm font-medium text-gray-400 mb-1">Eligible Users</label>
                        <select id="user_type" name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="all">All Users</option>
                            <option value="new">New Users Only</option>
                            <option value="existing">Existing Users Only</option>
                        </select>
                        <p class="mt-1 text-sm text-gray-500">"New" means users who registered after this promo was created</p>
                    </div>
                    
                    <div>
                        <label for="expiry_date" class="block text-sm font-medium text-gray-400 mb-1">Expiry Date</label>
                        <input type="date" id="expiry_date" name="expiry_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        <p class="mt-1 text-sm text-gray-500">Leave empty for no expiry</p>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="active">Active</option>
                            <option value="inactive">Inactive</option>
                        </select>
                    </div>
                </div>
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                    <div>
                        <label for="min_amount" class="block text-sm font-medium text-gray-400 mb-1">Minimum Amount</label>
                        <div class="flex">
                            <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                            <input type="number" id="min_amount" name="min_amount" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" value="0">
                        </div>
                        <p class="mt-1 text-sm text-gray-500">Minimum purchase amount to use this promo</p>
                    </div>
                    
                    <div>
                        <label for="max_amount" class="block text-sm font-medium text-gray-400 mb-1">Maximum Amount</label>
                        <div class="flex">
                            <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                            <input type="number" id="max_amount" name="max_amount" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" value="0">
                        </div>
                        <p class="mt-1 text-sm text-gray-500">0 for no maximum (only for percentage discount)</p>
                    </div>
                </div>
                
                <div class="mb-4">
                    <label class="block text-sm font-medium text-gray-400 mb-2">Applicable Services</label>
                    <div class="grid grid-cols-2 md:grid-cols-4 gap-3">
                        <label class="checkbox-label">
                            <input type="checkbox" name="applicable_services[]" value="data">
                            <span class="checkmark"></span>
                            Data
                        </label>
                        <label class="checkbox-label">
                            <input type="checkbox" name="applicable_services[]" value="airtime">
                            <span class="checkmark"></span>
                            Airtime
                        </label>
                        <label class="checkbox-label">
                            <input type="checkbox" name="applicable_services[]" value="cable">
                            <span class="checkmark"></span>
                            Cable TV
                        </label>
                        <label class="checkbox-label">
                            <input type="checkbox" name="applicable_services[]" value="electricity">
                            <span class="checkmark"></span>
                            Electricity
                        </label>
                    </div>
                </div>
                
                <div class="mb-6">
                    <label for="description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                    <textarea id="description" name="description" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Optional description of this promo code"></textarea>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitPromoBtn" name="add_promo" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Promo Code
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Promo Modal -->
    <div id="deletePromoModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Promo Code</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="deletePromoWarning" class="hidden">
                <p class="text-gray-300 mb-6">Cannot delete promo code <span id="deletePromoCode1" class="font-semibold text-white promo-code"></span> because it has been used <span id="deletePromoUses" class="font-semibold text-white"></span> times. Consider marking it as inactive instead.</p>
                
                <div class="flex justify-end">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        OK
                    </button>
                </div>
            </div>
            
            <div id="deletePromoConfirmation" class="hidden">
                <p class="text-gray-300 mb-6">Are you sure you want to delete promo code <span id="deletePromoCode2" class="font-semibold text-white promo-code"></span>? This action cannot be undone.</p>
                
                <form method="POST" action="">
                    <input type="hidden" id="delete_promo_id" name="promo_id" value="">
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Cancel
                        </button>
                        <button type="submit" name="delete_promo" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                            Delete Promo
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const promoModal = document.getElementById('promoModal');
        const deletePromoModal = document.getElementById('deletePromoModal');
        const modalTitle = document.getElementById('modalTitle');
        const submitPromoBtn = document.getElementById('submitPromoBtn');
        const promoTypeSelect = document.getElementById('promo_type');
        const discountSymbol = document.getElementById('discount-symbol');
        
        // Toggle discount symbol based on promo type
        promoTypeSelect.addEventListener('change', function() {
            if (this.value === 'percentage') {
                discountSymbol.textContent = '%';
            } else {
                discountSymbol.textContent = '<?php echo getSetting('currency') ?: '₦'; ?>';
            }
        });
        
        function openPromoModal(isEdit = false, promoData = {}) {
            // Reset form
            document.querySelector('#promoModal form').reset();
            
            // Uncheck all checkboxes
            document.querySelectorAll('input[type="checkbox"]').forEach(checkbox => {
                checkbox.checked = false;
            });
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('promo_id').value = promoData.id;
                document.getElementById('promo_code').value = promoData.code;
                document.getElementById('promo_type').value = promoData.type;
                document.getElementById('discount').value = promoData.discount;
                document.getElementById('max_uses').value = promoData.maxUses;
                document.getElementById('max_uses_per_user').value = promoData.maxUsesPerUser || 1;
                document.getElementById('user_type').value = promoData.userType || 'all';
                document.getElementById('expiry_date').value = promoData.expiry;
                document.getElementById('min_amount').value = promoData.minAmount;
                document.getElementById('max_amount').value = promoData.maxAmount;
                document.getElementById('status').value = promoData.status;
                document.getElementById('description').value = promoData.description;
                
                // Set discount symbol
                if (promoData.type === 'percentage') {
                    discountSymbol.textContent = '%';
                } else {
                    discountSymbol.textContent = '<?php echo getSetting('currency') ?: '₦'; ?>';
                }
                
                // Check applicable services
                const services = JSON.parse(promoData.services);
                if (Array.isArray(services)) {
                    services.forEach(service => {
                        const checkbox = document.querySelector(`input[value="${service}"]`);
                        if (checkbox) checkbox.checked = true;
                    });
                }
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Promo Code';
                submitPromoBtn.textContent = 'Update Promo Code';
                submitPromoBtn.name = 'edit_promo';
            } else {
                // Clear values for new promo
                document.getElementById('promo_id').value = '';
                
                // Set default values
                document.getElementById('max_uses').value = '0';
                document.getElementById('max_uses_per_user').value = '1';
                document.getElementById('user_type').value = 'all';
                document.getElementById('min_amount').value = '0';
                document.getElementById('max_amount').value = '0';
                
                // Set default discount symbol
                discountSymbol.textContent = '%';
                
                // Update modal title and button
                modalTitle.textContent = 'Add New Promo Code';
                submitPromoBtn.textContent = 'Add Promo Code';
                submitPromoBtn.name = 'add_promo';
            }
            
            // Show the modal
            promoModal.classList.remove('hidden');
        }
        
        function openDeleteModal(promoId, promoCode, promoUses) {
            document.getElementById('delete_promo_id').value = promoId;
            
            if (promoUses > 0) {
                // Show warning that promo has been used
                document.getElementById('deletePromoCode1').textContent = promoCode;
                document.getElementById('deletePromoUses').textContent = promoUses;
                document.getElementById('deletePromoWarning').classList.remove('hidden');
                document.getElementById('deletePromoConfirmation').classList.add('hidden');
            } else {
                // Show delete confirmation
                document.getElementById('deletePromoCode2').textContent = promoCode;
                document.getElementById('deletePromoWarning').classList.add('hidden');
                document.getElementById('deletePromoConfirmation').classList.remove('hidden');
            }
            
            deletePromoModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            promoModal.classList.add('hidden');
            deletePromoModal.classList.add('hidden');
        }
        
        // Add event listeners
        document.getElementById('addPromoBtn').addEventListener('click', () => openPromoModal(false));
        
        document.querySelectorAll('.edit-promo').forEach(button => {
            button.addEventListener('click', function() {
                const promoData = {
                    id: this.getAttribute('data-id'),
                    code: this.getAttribute('data-code'),
                    type: this.getAttribute('data-type'),
                    discount: this.getAttribute('data-discount'),
                    maxUses: this.getAttribute('data-max-uses'),
                    maxUsesPerUser: this.getAttribute('data-max-uses-per-user'),
                    userType: this.getAttribute('data-user-type'),
                    expiry: this.getAttribute('data-expiry'),
                    services: this.getAttribute('data-services'),
                    minAmount: this.getAttribute('data-min-amount'),
                    maxAmount: this.getAttribute('data-max-amount'),
                    status: this.getAttribute('data-status'),
                    description: this.getAttribute('data-description')
                };
                openPromoModal(true, promoData);
            });
        });
        
        document.querySelectorAll('.delete-promo').forEach(button => {
            button.addEventListener('click', function() {
                const promoId = this.getAttribute('data-id');
                const promoCode = this.getAttribute('data-code');
                const promoUses = parseInt(this.getAttribute('data-uses'));
                openDeleteModal(promoId, promoCode, promoUses);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === promoModal || event.target === deletePromoModal) {
                closeAllModals();
            }
        });
        
        // Form validation
        const promoForm = document.querySelector('#promoModal form');
        const promoCodeInput = document.getElementById('promo_code');
        const discountInput = document.getElementById('discount');
        const minAmountInput = document.getElementById('min_amount');
        const maxAmountInput = document.getElementById('max_amount');
        const maxUsesPerUserInput = document.getElementById('max_uses_per_user');
        
        promoForm.addEventListener('submit', function(event) {
            let valid = true;
            const promoCode = promoCodeInput.value.trim();
            const discount = parseFloat(discountInput.value);
            const promoType = promoTypeSelect.value;
            const minAmount = parseFloat(minAmountInput.value);
            const maxAmount = parseFloat(maxAmountInput.value);
            const maxUsesPerUser = parseInt(maxUsesPerUserInput.value);
            
            // Validate promo code format
            if (!promoCode.match(/^[A-Z0-9_-]{3,20}$/)) {
                alert('Promo code must be 3-20 characters and contain only letters, numbers, underscores, and hyphens.');
                valid = false;
            }
            
            // Validate discount based on type
            if (promoType === 'percentage' && (discount <= 0 || discount > 100)) {
                alert('Percentage discount must be between 0 and 100.');
                valid = false;
            } else if (promoType === 'fixed' && discount <= 0) {
                alert('Fixed discount must be greater than 0.');
                valid = false;
            }
            
            // Validate amount range
            if (minAmount < 0) {
                alert('Minimum amount cannot be negative.');
                valid = false;
            }
            
            if (maxAmount < 0) {
                alert('Maximum amount cannot be negative.');
                valid = false;
            }
            
            if (maxAmount > 0 && maxAmount < minAmount) {
                alert('Maximum amount must be greater than or equal to minimum amount.');
                valid = false;
            }
            
            // Validate max uses per user
            if (maxUsesPerUser < 1) {
                alert('Maximum uses per user must be at least 1.');
                valid = false;
            }
            
            // Validate at least one service is selected
            const checkboxes = document.querySelectorAll('input[name="applicable_services[]"]:checked');
            if (checkboxes.length === 0) {
                alert('Please select at least one applicable service.');
                valid = false;
            }
            
            if (!valid) {
                event.preventDefault();
            }
        });
        
        // Auto-uppercase promo code
        promoCodeInput.addEventListener('input', function() {
            this.value = this.value.toUpperCase();
        });
    </script>
</body>
</html>