<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_addon']) || isset($_POST['edit_addon'])) {
        $addonId = isset($_POST['addon_id']) ? (int)$_POST['addon_id'] : 0;
        $addonName = sanitizeInput($_POST['addon_name']);
        $addonDescription = sanitizeInput($_POST['addon_description']);
        $addonPrice = (float)$_POST['addon_price'];
        $addonStatus = sanitizeInput($_POST['addon_status']);
        $isDefault = isset($_POST['is_default']) ? 1 : 0;
        
        // Validate inputs
        if (empty($addonName)) {
            $actionError = 'Add-on name is required';
        } elseif ($addonPrice < 0) {
            $actionError = 'Price cannot be negative';
        } else {
            if (isset($_POST['add_addon'])) {
                // Add new add-on
                $stmt = $conn->prepare("
                    INSERT INTO reseller_addons 
                    (name, description, price, status, is_default)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $stmt->bind_param("ssdsi", $addonName, $addonDescription, $addonPrice, $addonStatus, $isDefault);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Add-on added successfully';
                } else {
                    $actionError = 'Failed to add add-on: ' . $conn->error;
                }
            } else {
                // Edit existing add-on
                $stmt = $conn->prepare("
                    UPDATE reseller_addons 
                    SET name = ?, description = ?, price = ?, status = ?, is_default = ?
                    WHERE id = ?
                ");
                $stmt->bind_param("ssdsii", $addonName, $addonDescription, $addonPrice, $addonStatus, $isDefault, $addonId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Add-on updated successfully';
                } else {
                    $actionError = 'Failed to update add-on: ' . $conn->error;
                }
            }
        }
    } elseif (isset($_POST['delete_addon'])) {
        $addonId = (int)$_POST['addon_id'];
        
        // Check if add-on can be safely deleted (not used in any recent orders)
        $threeMonthsAgo = date('Y-m-d', strtotime('-3 months'));
        $stmt = $conn->prepare("
            SELECT COUNT(*) as count 
            FROM reseller_orders 
            WHERE JSON_CONTAINS(addons, CONCAT('[{\"id\":', ?, '}]'), '$') 
            AND created_at > ?
        ");
        $stmt->bind_param("is", $addonId, $threeMonthsAgo);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row['count'] > 0) {
            $actionError = 'Cannot delete this add-on because it is used in recent orders. Please set it to inactive instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM reseller_addons WHERE id = ?");
            $stmt->bind_param("i", $addonId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Add-on deleted successfully';
            } else {
                $actionError = 'Failed to delete add-on: ' . $conn->error;
            }
        }
    }
}

// Get all add-ons
$stmt = $conn->prepare("SELECT * FROM reseller_addons ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();
$addons = [];

while ($row = $result->fetch_assoc()) {
    $addons[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reseller Add-ons - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
        
        /* Toggle Switch */
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 48px;
            height: 24px;
        }
        
        .toggle-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }
        
        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #444;
            transition: .4s;
            border-radius: 24px;
        }
        
        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 18px;
            width: 18px;
            left: 3px;
            bottom: 3px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }
        
        input:checked + .toggle-slider {
            background-color: var(--accent-color);
        }
        
        input:focus + .toggle-slider {
            box-shadow: 0 0 1px var(--accent-color);
        }
        
        input:checked + .toggle-slider:before {
            transform: translateX(24px);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/addons.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-puzzle-piece mr-3"></i>
                                <span>Add-ons</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/domain_extensions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-globe mr-3"></i>
                                <span>Domain Extensions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Reseller Add-ons</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Add-ons Section -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Reseller Panel Add-ons</h2>
                    <button id="addAddonBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add New Add-on
                    </button>
                </div>
                
                <p class="text-gray-400 mb-4">
                    Add-ons are optional features that users can select when ordering a reseller panel.
                    Each add-on can have its own price which will be added to the total order amount.
                </p>
                
                <?php if (empty($addons)): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-puzzle-piece text-3xl mb-2"></i>
                        <p>No add-ons configured yet. Add your first add-on.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Name</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Description</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Default</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($addons as $addon): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($addon['name']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300 truncate max-w-xs">
                                            <?php echo htmlspecialchars($addon['description']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-white font-medium">
                                            <?php echo getSetting('currency') . number_format($addon['price'], 2); ?>
                                        </td>
                                        <td class="py-3 px-4 text-center">
                                            <?php if ($addon['is_default']): ?>
                                                <i class="fas fa-check text-green-500"></i>
                                            <?php else: ?>
                                                <i class="fas fa-times text-gray-500"></i>
                                            <?php endif; ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $addon['status']; ?>">
                                                <?php echo ucfirst($addon['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-addon" 
                                                        data-id="<?php echo $addon['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($addon['name']); ?>"
                                                        data-description="<?php echo htmlspecialchars($addon['description']); ?>"
                                                        data-price="<?php echo $addon['price']; ?>"
                                                        data-status="<?php echo $addon['status']; ?>"
                                                        data-default="<?php echo $addon['is_default']; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-addon" 
                                                        data-id="<?php echo $addon['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($addon['name']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Add-ons</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Add-ons allow you to offer optional services or features with your reseller panels.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Default Add-ons</h3>
                            <p class="text-gray-400">
                                Add-ons marked as "Default" will be pre-selected in the order form. This is useful for services you want most customers to include.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Common Add-on Examples</h3>
                            <ul class="text-gray-400 list-disc list-inside space-y-1">
                                <li>Premium Support</li>
                                <li>Additional Storage</li>
                                <li>WHOIS Protection</li>
                                <li>Priority Setup</li>
                                <li>Custom Branding</li>
                            </ul>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-exclamation-triangle text-yellow-400 mr-2"></i>
                        <strong>Note:</strong> If you make changes to an add-on's price, it will only affect future orders, not existing ones.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Add-on Modal -->
    <div id="addonModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Add-on</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="addon_id" name="addon_id" value="">
                
                <div class="mb-4">
                    <label for="addon_name" class="block text-sm font-medium text-gray-400 mb-1">Name</label>
                    <input type="text" id="addon_name" name="addon_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                </div>
                
                <div class="mb-4">
                    <label for="addon_description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                    <textarea id="addon_description" name="addon_description" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50"></textarea>
                </div>
                
                <div class="mb-4">
                    <label for="addon_price" class="block text-sm font-medium text-gray-400 mb-1">Price</label>
                    <div class="relative">
                        <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                            <span class="text-gray-500 sm:text-sm"><?php echo getSetting('currency'); ?></span>
                        </div>
                        <input type="number" id="addon_price" name="addon_price" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" required>
                    </div>
                </div>
                
                <div class="mb-4">
                    <label for="addon_status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="addon_status" name="addon_status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="active">Active</option>
                        <option value="inactive">Inactive</option>
                    </select>
                </div>
                
                <div class="mb-6">
                    <label class="flex items-center">
                        <input type="checkbox" id="is_default" name="is_default" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                        <span class="ml-2 text-gray-400">Pre-select by default in order form</span>
                    </label>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitAddonBtn" name="add_addon" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Add-on
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Add-on Modal -->
    <div id="deleteAddonModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Add-on</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the add-on <span id="deleteAddonName" class="font-semibold text-white"></span>? This action cannot be undone.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_addon_id" name="addon_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_addon" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Add-on
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Add-on Modal functionality
        const addonModal = document.getElementById('addonModal');
        const deleteAddonModal = document.getElementById('deleteAddonModal');
        
        const modalTitle = document.getElementById('modalTitle');
        const submitAddonBtn = document.getElementById('submitAddonBtn');
        
        function openAddonModal(isEdit = false, addonData = {}) {
            // Reset form
            document.querySelector('#addonModal form').reset();
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('addon_id').value = addonData.id;
                document.getElementById('addon_name').value = addonData.name;
                document.getElementById('addon_description').value = addonData.description;
                document.getElementById('addon_price').value = addonData.price;
                document.getElementById('addon_status').value = addonData.status;
                document.getElementById('is_default').checked = addonData.isDefault === '1';
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Add-on';
                submitAddonBtn.textContent = 'Update Add-on';
                submitAddonBtn.name = 'edit_addon';
            } else {
                // Clear values for new add-on
                document.getElementById('addon_id').value = '';
                
                // Update modal title and button
                modalTitle.textContent = 'Add New Add-on';
                submitAddonBtn.textContent = 'Add Add-on';
                submitAddonBtn.name = 'add_addon';
            }
            
            // Show the modal
            addonModal.classList.remove('hidden');
        }
        
        function openDeleteAddonModal(addonId, addonName) {
            document.getElementById('delete_addon_id').value = addonId;
            document.getElementById('deleteAddonName').textContent = addonName;
            
            deleteAddonModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            addonModal.classList.add('hidden');
            deleteAddonModal.classList.add('hidden');
        }
        
        // Add Add-on button
        document.getElementById('addAddonBtn').addEventListener('click', () => openAddonModal(false));
        
        // Edit Add-on buttons
        document.querySelectorAll('.edit-addon').forEach(button => {
            button.addEventListener('click', function() {
                const addonId = this.getAttribute('data-id');
                const addonName = this.getAttribute('data-name');
                const addonDescription = this.getAttribute('data-description');
                const addonPrice = this.getAttribute('data-price');
                const addonStatus = this.getAttribute('data-status');
                const isDefault = this.getAttribute('data-default');
                
                const addonData = {
                    id: addonId,
                    name: addonName,
                    description: addonDescription,
                    price: addonPrice,
                    status: addonStatus,
                    isDefault: isDefault
                };
                
                openAddonModal(true, addonData);
            });
        });
        
        // Delete Add-on buttons
        document.querySelectorAll('.delete-addon').forEach(button => {
            button.addEventListener('click', function() {
                const addonId = this.getAttribute('data-id');
                const addonName = this.getAttribute('data-name');
                
                openDeleteAddonModal(addonId, addonName);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === addonModal) {
                closeAllModals();
            }
            if (event.target === deleteAddonModal) {
                closeAllModals();
            }
        });
    </script>
</body>
</html>