<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_extension']) || isset($_POST['edit_extension'])) {
        $extensionId = isset($_POST['extension_id']) ? (int)$_POST['extension_id'] : 0;
        $extension = sanitizeInput($_POST['extension']);
        $price = (float)$_POST['price'];
        $whoisProtectionPrice = (float)$_POST['whois_protection_price'];
        $status = sanitizeInput($_POST['status']);
        
        // Validate inputs
        if (empty($extension)) {
            $actionError = 'Extension name is required';
        } elseif ($price < 0) {
            $actionError = 'Price cannot be negative';
        } elseif ($whoisProtectionPrice < 0) {
            $actionError = 'WHOIS protection price cannot be negative';
        } else {
            // Make sure extension starts with a dot
            if (substr($extension, 0, 1) !== '.') {
                $extension = '.' . $extension;
            }
            
            if (isset($_POST['add_extension'])) {
                // Check if extension already exists
                $stmt = $conn->prepare("SELECT id FROM domain_extensions WHERE extension = ?");
                $stmt->bind_param("s", $extension);
                $stmt->execute();
                $result = $stmt->get_result();
                
                if ($result->num_rows > 0) {
                    $actionError = 'This domain extension already exists';
                } else {
                    // Add new extension
                    $stmt = $conn->prepare("
                        INSERT INTO domain_extensions 
                        (extension, price, whois_protection_price, status)
                        VALUES (?, ?, ?, ?)
                    ");
                    $stmt->bind_param("sdds", $extension, $price, $whoisProtectionPrice, $status);
                    
                    if ($stmt->execute()) {
                        $actionSuccess = 'Domain extension added successfully';
                    } else {
                        $actionError = 'Failed to add domain extension: ' . $conn->error;
                    }
                }
            } else {
                // Check if renamed extension conflicts with existing one
                $stmt = $conn->prepare("
                    SELECT id FROM domain_extensions 
                    WHERE extension = ? AND id != ?
                ");
                $stmt->bind_param("si", $extension, $extensionId);
                $stmt->execute();
                $result = $stmt->get_result();
                
                if ($result->num_rows > 0) {
                    $actionError = 'Another domain extension with this name already exists';
                } else {
                    // Edit existing extension
                    $stmt = $conn->prepare("
                        UPDATE domain_extensions 
                        SET extension = ?, price = ?, whois_protection_price = ?, status = ?
                        WHERE id = ?
                    ");
                    $stmt->bind_param("sddsi", $extension, $price, $whoisProtectionPrice, $status, $extensionId);
                    
                    if ($stmt->execute()) {
                        $actionSuccess = 'Domain extension updated successfully';
                    } else {
                        $actionError = 'Failed to update domain extension: ' . $conn->error;
                    }
                }
            }
        }
    } elseif (isset($_POST['delete_extension'])) {
        $extensionId = (int)$_POST['extension_id'];
        
        // Check if extension is used in any orders
        $stmt = $conn->prepare("
            SELECT COUNT(*) as count 
            FROM reseller_orders 
            WHERE domain_extension = (SELECT extension FROM domain_extensions WHERE id = ?)
        ");
        $stmt->bind_param("i", $extensionId);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row['count'] > 0) {
            $actionError = 'Cannot delete this domain extension because it is used in existing orders. Please set it to inactive instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM domain_extensions WHERE id = ?");
            $stmt->bind_param("i", $extensionId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Domain extension deleted successfully';
            } else {
                $actionError = 'Failed to delete domain extension: ' . $conn->error;
            }
        }
    }
}

// Get all domain extensions
$stmt = $conn->prepare("SELECT * FROM domain_extensions ORDER BY extension ASC");
$stmt->execute();
$result = $stmt->get_result();
$extensions = [];

while ($row = $result->fetch_assoc()) {
    $extensions[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Domain Extensions - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/addons.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-puzzle-piece mr-3"></i>
                                <span>Add-ons</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/domain_extensions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-globe mr-3"></i>
                                <span>Domain Extensions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Domain Extensions</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Domain Extensions Section -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Domain Extensions</h2>
                    <button id="addExtensionBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add New Extension
                    </button>
                </div>
                
                <p class="text-gray-400 mb-4">
                    Configure domain extensions that users can register through your service.
                    Each extension can have its own price and WHOIS protection fee.
                </p>
                
                <?php if (empty($extensions)): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-globe text-3xl mb-2"></i>
                        <p>No domain extensions configured yet. Add your first extension.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Extension</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Registration Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">WHOIS Protection</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($extensions as $ext): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($ext['extension']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-white font-medium">
                                            <?php echo getSetting('currency') . number_format($ext['price'], 2); ?>
                                        </td>
                                        <td class="py-3 px-4 text-white font-medium">
                                            <?php echo getSetting('currency') . number_format($ext['whois_protection_price'], 2); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $ext['status']; ?>">
                                                <?php echo ucfirst($ext['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-extension" 
                                                        data-id="<?php echo $ext['id']; ?>"
                                                        data-extension="<?php echo htmlspecialchars($ext['extension']); ?>"
                                                        data-price="<?php echo $ext['price']; ?>"
                                                        data-whois-price="<?php echo $ext['whois_protection_price']; ?>"
                                                        data-status="<?php echo $ext['status']; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-extension" 
                                                        data-id="<?php echo $ext['id']; ?>"
                                                        data-extension="<?php echo htmlspecialchars($ext['extension']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Domain Extensions</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Domain extensions allow users to register domain names through your service when ordering a reseller panel.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Registration Prices</h3>
                            <p class="text-gray-400">
                                The price you set for each extension should cover your costs plus your markup. Remember that domain registrations typically need to be renewed annually.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">WHOIS Protection</h3>
                            <p class="text-gray-400">
                                WHOIS protection hides the domain registrant's personal information from public WHOIS records. This is an optional add-on that users can select during checkout.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-exclamation-triangle text-yellow-400 mr-2"></i>
                        <strong>Note:</strong> Be sure to set up your domain registration provider to handle these domains. You'll need to register these domains manually when users place orders.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Extension Modal -->
    <div id="extensionModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Domain Extension</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="extension_id" name="extension_id" value="">
                
                <div class="mb-4">
                    <label for="extension" class="block text-sm font-medium text-gray-400 mb-1">Domain Extension</label>
                    <input type="text" id="extension" name="extension" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder=".com" required>
                    <p class="mt-1 text-xs text-gray-500">Include the dot, e.g. .com, .net, .org</p>
                </div>
                
                <div class="mb-4">
                    <label for="price" class="block text-sm font-medium text-gray-400 mb-1">Registration Price</label>
                    <div class="relative">
                        <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                            <span class="text-gray-500 sm:text-sm"><?php echo getSetting('currency'); ?></span>
                        </div>
                        <input type="number" id="price" name="price" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" required>
                    </div>
                    <p class="mt-1 text-xs text-gray-500">Annual cost for registering this domain extension</p>
                </div>
                
                <div class="mb-4">
                    <label for="whois_protection_price" class="block text-sm font-medium text-gray-400 mb-1">WHOIS Protection Price</label>
                    <div class="relative">
                        <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                            <span class="text-gray-500 sm:text-sm"><?php echo getSetting('currency'); ?></span>
                        </div>
                        <input type="number" id="whois_protection_price" name="whois_protection_price" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" value="0.00">
                    </div>
                    <p class="mt-1 text-xs text-gray-500">Additional annual cost for WHOIS privacy protection (if applicable)</p>
                </div>
                
                <div class="mb-6">
                    <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="active">Active</option>
                        <option value="inactive">Inactive</option>
                    </select>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitExtensionBtn" name="add_extension" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Extension
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Extension Modal -->
    <div id="deleteExtensionModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Domain Extension</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the domain extension <span id="deleteExtensionName" class="font-semibold text-white"></span>? This action cannot be undone.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_extension_id" name="extension_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_extension" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Extension
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Extension Modal functionality
        const extensionModal = document.getElementById('extensionModal');
        const deleteExtensionModal = document.getElementById('deleteExtensionModal');
        
        const modalTitle = document.getElementById('modalTitle');
        const submitExtensionBtn = document.getElementById('submitExtensionBtn');
        
        function openExtensionModal(isEdit = false, extensionData = {}) {
            // Reset form
            document.querySelector('#extensionModal form').reset();
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('extension_id').value = extensionData.id;
                document.getElementById('extension').value = extensionData.extension;
                document.getElementById('price').value = extensionData.price;
                document.getElementById('whois_protection_price').value = extensionData.whoisPrice;
                document.getElementById('status').value = extensionData.status;
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Domain Extension';
                submitExtensionBtn.textContent = 'Update Extension';
                submitExtensionBtn.name = 'edit_extension';
            } else {
                // Clear values for new extension
                document.getElementById('extension_id').value = '';
                
                // Update modal title and button
                modalTitle.textContent = 'Add New Domain Extension';
                submitExtensionBtn.textContent = 'Add Extension';
                submitExtensionBtn.name = 'add_extension';
            }
            
            // Show the modal
            extensionModal.classList.remove('hidden');
        }
        
        function openDeleteExtensionModal(extensionId, extensionName) {
            document.getElementById('delete_extension_id').value = extensionId;
            document.getElementById('deleteExtensionName').textContent = extensionName;
            
            deleteExtensionModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            extensionModal.classList.add('hidden');
            deleteExtensionModal.classList.add('hidden');
        }
        
        // Add Extension button
        document.getElementById('addExtensionBtn').addEventListener('click', () => openExtensionModal(false));
        
        // Edit Extension buttons
        document.querySelectorAll('.edit-extension').forEach(button => {
            button.addEventListener('click', function() {
                const extensionId = this.getAttribute('data-id');
                const extension = this.getAttribute('data-extension');
                const price = this.getAttribute('data-price');
                const whoisPrice = this.getAttribute('data-whois-price');
                const status = this.getAttribute('data-status');
                
                const extensionData = {
                    id: extensionId,
                    extension: extension,
                    price: price,
                    whoisPrice: whoisPrice,
                    status: status
                };
                
                openExtensionModal(true, extensionData);
            });
        });
        
        // Delete Extension buttons
        document.querySelectorAll('.delete-extension').forEach(button => {
            button.addEventListener('click', function() {
                const extensionId = this.getAttribute('data-id');
                const extension = this.getAttribute('data-extension');
                
                openDeleteExtensionModal(extensionId, extension);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === extensionModal) {
                closeAllModals();
            }
            if (event.target === deleteExtensionModal) {
                closeAllModals();
            }
        });
        
        // Ensure extension starts with a dot
        document.getElementById('extension').addEventListener('blur', function() {
            let value = this.value.trim();
            if (value && !value.startsWith('.')) {
                this.value = '.' + value;
            }
        });
    </script>
</body>
</html>