<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['update_fields'])) {
        // Get field settings
        $fieldIds = $_POST['field_id'] ?? [];
        $fieldRequired = $_POST['is_required'] ?? [];
        $fieldVisible = $_POST['is_visible'] ?? [];
        $fieldLabels = $_POST['field_label'] ?? [];
        
        // Begin transaction
        $conn->begin_transaction();
        
        try {
            foreach ($fieldIds as $index => $fieldId) {
                $isRequired = isset($fieldRequired[$index]) ? 1 : 0;
                $isVisible = isset($fieldVisible[$index]) ? 1 : 0;
                $fieldLabel = isset($fieldLabels[$index]) ? sanitizeInput($fieldLabels[$index]) : '';
                
                // Update field settings
                $stmt = $conn->prepare("
                    UPDATE form_field_settings 
                    SET is_required = ?, is_visible = ?, field_label = ?
                    WHERE id = ?
                ");
                $stmt->bind_param("iisi", $isRequired, $isVisible, $fieldLabel, $fieldId);
                $stmt->execute();
            }
            
            // Commit transaction
            $conn->commit();
            $actionSuccess = 'Form field settings updated successfully';
        } catch (Exception $e) {
            // Rollback transaction
            $conn->rollback();
            $actionError = 'Failed to update form field settings: ' . $e->getMessage();
        }
    } elseif (isset($_POST['add_field'])) {
        // Add new custom field
        $formName = 'reseller_order';
        $fieldName = sanitizeInput($_POST['field_name']);
        $fieldLabel = sanitizeInput($_POST['field_label']);
        $fieldType = sanitizeInput($_POST['field_type']);
        $isRequired = isset($_POST['new_is_required']) ? 1 : 0;
        $isVisible = 1; // New fields are always visible
        
        // Validate field name - alphanumeric + underscore only
        if (!preg_match('/^[a-zA-Z0-9_]+$/', $fieldName)) {
            $actionError = 'Field name must contain only letters, numbers, and underscores';
        } else {
            // Check if field already exists
            $stmt = $conn->prepare("SELECT id FROM form_field_settings WHERE form_name = ? AND field_name = ?");
            $stmt->bind_param("ss", $formName, $fieldName);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $actionError = 'A field with this name already exists';
            } else {
                // Insert new field
                $stmt = $conn->prepare("
                    INSERT INTO form_field_settings 
                    (form_name, field_name, field_label, field_type, is_required, is_visible)
                    VALUES (?, ?, ?, ?, ?, ?)
                ");
                $stmt->bind_param("ssssii", $formName, $fieldName, $fieldLabel, $fieldType, $isRequired, $isVisible);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Custom field added successfully';
                } else {
                    $actionError = 'Failed to add custom field: ' . $conn->error;
                }
            }
        }
    } elseif (isset($_POST['delete_field'])) {
        $fieldId = (int)$_POST['field_id'];
        
        // Check if it's a core field (we don't allow deleting core fields)
        $stmt = $conn->prepare("
            SELECT field_name FROM form_field_settings 
            WHERE id = ? AND form_name = 'reseller_order'
        ");
        $stmt->bind_param("i", $fieldId);
        $stmt->execute();
        $result = $stmt->get_result();
        $field = $result->fetch_assoc();
        
        if ($field) {
            $coreFields = ['domain_name', 'company_name', 'company_email', 'company_phone', 'company_address', 'additional_info'];
            
            if (in_array($field['field_name'], $coreFields)) {
                $actionError = 'Cannot delete core fields. You can hide them instead.';
            } else {
                // Delete the custom field
                $stmt = $conn->prepare("DELETE FROM form_field_settings WHERE id = ?");
                $stmt->bind_param("i", $fieldId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Field deleted successfully';
                } else {
                    $actionError = 'Failed to delete field: ' . $conn->error;
                }
            }
        } else {
            $actionError = 'Field not found';
        }
    }
}

// Get form field settings by form name
$formFields = [];
$formNames = ['reseller_order']; // Add more form names as needed

foreach ($formNames as $formName) {
    $stmt = $conn->prepare("
        SELECT * FROM form_field_settings 
        WHERE form_name = ?
        ORDER BY id ASC
    ");
    $stmt->bind_param("s", $formName);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $formFields[$formName] = [];
    while ($row = $result->fetch_assoc()) {
        $formFields[$formName][] = $row;
    }
}

// If form_field_settings table doesn't exist or no settings found, use default fields
if (empty($formFields['reseller_order'])) {
    $formFields['reseller_order'] = [
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'domain_name',
            'field_label' => 'Domain Name',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1
        ],
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'company_name',
            'field_label' => 'Company Name',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1
        ],
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'company_email',
            'field_label' => 'Company Email',
            'field_type' => 'email',
            'is_required' => 1,
            'is_visible' => 1
        ],
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'company_phone',
            'field_label' => 'Company Phone',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1
        ],
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'company_address',
            'field_label' => 'Company Address',
            'field_type' => 'textarea',
            'is_required' => 0,
            'is_visible' => 1
        ],
        [
            'id' => 0,
            'form_name' => 'reseller_order',
            'field_name' => 'additional_info',
            'field_label' => 'Additional Information',
            'field_type' => 'textarea',
            'is_required' => 0,
            'is_visible' => 1
        ]
    ];
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Form Field Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        /* Toggle Switch */
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 48px;
            height: 24px;
        }
        
        .toggle-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }
        
        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #444;
            transition: .4s;
            border-radius: 24px;
        }
        
        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 18px;
            width: 18px;
            left: 3px;
            bottom: 3px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }
        
        input:checked + .toggle-slider {
            background-color: var(--accent-color);
        }
        
        input:focus + .toggle-slider {
            box-shadow: 0 0 1px var(--accent-color);
        }
        
        input:checked + .toggle-slider:before {
            transform: translateX(24px);
        }
        
        .core-field {
            background-color: rgba(93, 92, 222, 0.05);
        }
        
        .custom-field {
            background-color: rgba(16, 185, 129, 0.05);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/addons.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-puzzle-piece mr-3"></i>
                                <span>Add-ons</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/domain_extensions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-globe mr-3"></i>
                                <span>Domain Extensions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Form Field Settings</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Form Fields Settings -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Reseller Panel Order Form Fields</h2>
                    <button id="addFieldBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add Custom Field
                    </button>
                </div>
                
                <p class="text-gray-400 mb-6">
                    Configure which fields are required and visible in the reseller panel order form. Changes will affect all new orders.
                    <span class="inline-block mt-2 text-yellow-400"><i class="fas fa-info-circle mr-1"></i> Core fields (domain_name) are essential for system function and cannot be deleted.</span>
                </p>
                
                <?php if (empty($formFields['reseller_order'])): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-list-alt text-3xl mb-2"></i>
                        <p>No form fields configured yet. The system will use default fields until you configure them.</p>
                    </div>
                <?php else: ?>
                    <form method="POST" action="">
                        <div class="overflow-x-auto">
                            <table class="min-w-full">
                                <thead class="bg-gray-800">
                                    <tr>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Field</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Label</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Required</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Visible</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Action</th>
                                    </tr>
                                </thead>
                                <tbody class="divide-y divide-gray-700">
                                    <?php 
                                    $coreFields = ['domain_name', 'company_name', 'company_email', 'company_phone', 'company_address', 'additional_info'];
                                    foreach ($formFields['reseller_order'] as $index => $field): 
                                        $isCore = in_array($field['field_name'], $coreFields);
                                    ?>
                                        <tr class="<?php echo $isCore ? 'core-field' : 'custom-field'; ?>">
                                            <td class="py-3 px-4">
                                                <input type="hidden" name="field_id[]" value="<?php echo $field['id']; ?>">
                                                <div class="font-medium text-white flex items-center">
                                                    <?php if($isCore): ?>
                                                        <span class="bg-indigo-500 text-white text-xs px-1.5 py-0.5 rounded mr-2">Core</span>
                                                    <?php else: ?>
                                                        <span class="bg-green-500 text-white text-xs px-1.5 py-0.5 rounded mr-2">Custom</span>
                                                    <?php endif; ?>
                                                    <?php echo htmlspecialchars($field['field_name']); ?>
                                                </div>
                                            </td>
                                            <td class="py-3 px-4">
                                                <input type="text" name="field_label[]" value="<?php echo htmlspecialchars($field['field_label']); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                            </td>
                                            <td class="py-3 px-4 text-sm text-gray-300">
                                                <?php 
                                                $fieldTypeDisplay = '';
                                                switch($field['field_type']) {
                                                    case 'text': $fieldTypeDisplay = 'Text Input'; break;
                                                    case 'textarea': $fieldTypeDisplay = 'Text Area'; break;
                                                    case 'email': $fieldTypeDisplay = 'Email'; break;
                                                    case 'number': $fieldTypeDisplay = 'Number'; break;
                                                    default: $fieldTypeDisplay = ucfirst($field['field_type']); break;
                                                }
                                                echo $fieldTypeDisplay;
                                                ?>
                                            </td>
                                            <td class="py-3 px-4">
                                                <label class="toggle-switch">
                                                    <input type="checkbox" name="is_required[]" <?php echo $field['is_required'] ? 'checked' : ''; ?>>
                                                    <span class="toggle-slider"></span>
                                                </label>
                                            </td>
                                            <td class="py-3 px-4">
                                                <label class="toggle-switch">
                                                    <input type="checkbox" name="is_visible[]" <?php echo $field['is_visible'] ? 'checked' : ''; ?>>
                                                    <span class="toggle-slider"></span>
                                                </label>
                                            </td>
                                            <td class="py-3 px-4">
                                                <?php if(!$isCore): ?>
                                                <button type="button" class="text-red-500 hover:text-red-400 delete-field" 
                                                        data-id="<?php echo $field['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($field['field_name']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_fields" class="accent-button py-2 px-6 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Save Changes
                            </button>
                        </div>
                    </form>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Form Field Settings</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Form field settings allow you to customize the fields that users see when filling out forms on the website.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Core Fields</h3>
                            <p class="text-gray-400">
                                Core fields are essential for the system to function properly. You can change their labels, make them required or optional, or hide them, but they cannot be deleted.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Custom Fields</h3>
                            <p class="text-gray-400">
                                Custom fields allow you to collect additional information from users. You can add, edit, or delete custom fields as needed.
                            </p>
                        </div>
                    </div>
                    
                    <div class="p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-lg">
                        <h3 class="font-semibold text-white mb-2">Important Notes</h3>
                        <ul class="list-disc list-inside text-gray-300 space-y-1">
                            <li>The <strong>Domain Name</strong> field is automatically extended with domain extension selection and registration options.</li>
                            <li>Changing field visibility and requirements will affect new orders only.</li>
                            <li>Field data is stored and can be retrieved even if a field is hidden.</li>
                        </ul>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add Field Modal -->
    <div id="addFieldModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add Custom Field</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <div class="mb-4">
                    <label for="field_name" class="block text-sm font-medium text-gray-400 mb-1">Field Name</label>
                    <input type="text" id="field_name" name="field_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="e.g. website_url" required>
                    <p class="mt-1 text-xs text-gray-500">Use only letters, numbers, and underscores. This is the internal field name.</p>
                </div>
                
                <div class="mb-4">
                    <label for="field_label" class="block text-sm font-medium text-gray-400 mb-1">Field Label</label>
                    <input type="text" id="field_label" name="field_label" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="e.g. Website URL" required>
                    <p class="mt-1 text-xs text-gray-500">The label shown to users on the form.</p>
                </div>
                
                <div class="mb-4">
                    <label for="field_type" class="block text-sm font-medium text-gray-400 mb-1">Field Type</label>
                    <select id="field_type" name="field_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="text">Text Input</option>
                        <option value="email">Email</option>
                        <option value="number">Number</option>
                        <option value="textarea">Text Area</option>
                    </select>
                </div>
                
                <div class="mb-6">
                    <label class="flex items-center">
                        <input type="checkbox" id="new_is_required" name="new_is_required" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                        <span class="ml-2 text-gray-400">Required field</span>
                    </label>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="add_field" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Field
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Field Modal -->
    <div id="deleteFieldModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Custom Field</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the field <span id="deleteFieldName" class="font-semibold text-white"></span>? This action cannot be undone and may affect data in existing orders.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_field_id" name="field_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_field" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Field
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const addFieldModal = document.getElementById('addFieldModal');
        const deleteFieldModal = document.getElementById('deleteFieldModal');
        
        function openAddFieldModal() {
            // Reset form
            document.querySelector('#addFieldModal form').reset();
            
            // Show the modal
            addFieldModal.classList.remove('hidden');
        }
        
        function openDeleteFieldModal(fieldId, fieldName) {
            document.getElementById('delete_field_id').value = fieldId;
            document.getElementById('deleteFieldName').textContent = fieldName;
            
            deleteFieldModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            addFieldModal.classList.add('hidden');
            deleteFieldModal.classList.add('hidden');
        }
        
        // Add Field button
        document.getElementById('addFieldBtn').addEventListener('click', openAddFieldModal);
        
        // Delete Field buttons
        document.querySelectorAll('.delete-field').forEach(button => {
            button.addEventListener('click', function() {
                const fieldId = this.getAttribute('data-id');
                const fieldName = this.getAttribute('data-name');
                
                openDeleteFieldModal(fieldId, fieldName);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === addFieldModal) {
                closeAllModals();
            }
            if (event.target === deleteFieldModal) {
                closeAllModals();
            }
        });
        
        // Field name validation (allow only letters, numbers, and underscores)
        document.getElementById('field_name').addEventListener('input', function() {
            this.value = this.value.replace(/[^a-zA-Z0-9_]/g, '');
        });
    </script>
</body>
</html>