<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get active reseller panels
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE status = 'active' ORDER BY price ASC");
$stmt->execute();
$result = $stmt->get_result();
$panels = [];

while ($row = $result->fetch_assoc()) {
    $panels[] = $row;
}

// Get currency from settings
$currency = getSetting('currency', '₦');

// Check if there's a success message in session
$success = '';
if (isset($_SESSION['order_success'])) {
    $success = $_SESSION['order_success'];
    unset($_SESSION['order_success']);
}

// Check if panel_id is in URL for ordering a specific panel
$selectedPanelId = isset($_GET['panel_id']) ? (int)$_GET['panel_id'] : 0;
$selectedPanel = null;

if ($selectedPanelId > 0) {
    // Get the selected panel
    $stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $selectedPanelId);
    $stmt->execute();
    $result = $stmt->get_result();
    $selectedPanel = $result->fetch_assoc();
}

require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">Reseller Panels</h1>
        <div class="text-right">
            <p class="text-sm text-gray-400">Wallet Balance</p>
            <p class="text-lg font-semibold text-white"><?php echo $currency . number_format($user['balance'], 2); ?></p>
        </div>
    </div>
    
    <?php if ($success): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
            <p><?php echo $success; ?></p>
        </div>
    <?php endif; ?>
    
    <?php if (empty($panels)): ?>
        <div class="bg-gray-800 p-6 rounded-lg text-center">
            <i class="fas fa-store text-gray-600 text-5xl mb-4"></i>
            <h2 class="text-xl font-semibold text-white mb-2">No Reseller Panels Available</h2>
            <p class="text-gray-400">Currently, there are no reseller panels available for purchase. Please check back later.</p>
        </div>
    <?php else: ?>
        <?php if (!$selectedPanel): ?>
            <!-- Panel Selection View -->
            <div class="mb-6">
                <p class="text-gray-300 mb-4">
                    Select a reseller panel to purchase. Our panels give you the ability to run your own VTU business with your own branding.
                </p>
                
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                    <?php foreach ($panels as $panel): ?>
                        <div class="bg-gray-800 rounded-lg overflow-hidden border border-gray-700 hover:border-indigo-500 transition-all">
                            <div class="p-5">
                                <h3 class="text-xl font-semibold text-white mb-2"><?php echo htmlspecialchars($panel['name']); ?></h3>
                                <div class="mb-4">
                                    <span class="text-2xl font-bold text-white">
                                        <?php echo $currency . number_format($panel['price'], 2); ?>
                                    </span>
                                    <?php if (!empty($panel['discount_price']) && $panel['discount_price'] < $panel['price']): ?>
                                        <span class="ml-2 text-sm line-through text-gray-500">
                                            <?php echo $currency . number_format($panel['discount_price'], 2); ?>
                                        </span>
                                    <?php endif; ?>
                                </div>
                                
                                <p class="text-gray-400 mb-4"><?php echo htmlspecialchars($panel['description']); ?></p>
                                
                                <?php 
                                // Parse features if they're stored as JSON
                                $features = [];
                                if (!empty($panel['features'])) {
                                    $featuresData = json_decode($panel['features'], true);
                                    if (is_array($featuresData)) {
                                        $features = $featuresData;
                                    } else {
                                        // If not valid JSON, split by newlines
                                        $features = explode("\n", $panel['features']);
                                    }
                                }
                                ?>
                                
                                <?php if (!empty($features)): ?>
                                    <ul class="text-gray-300 mb-4 space-y-2">
                                        <?php foreach ($features as $feature): ?>
                                            <li class="flex items-start">
                                                <i class="fas fa-check text-green-500 mr-2 mt-1"></i>
                                                <span><?php echo htmlspecialchars($feature); ?></span>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif; ?>
                            </div>
                            
                            <div class="p-4 bg-gray-900 border-t border-gray-700">
                                <a href="?panel_id=<?php echo $panel['id']; ?>" class="block w-full py-2 px-4 bg-indigo-600 hover:bg-indigo-700 rounded-md text-white text-center font-medium transition-colors">
                                    Order Now
                                </a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php else: ?>
            <!-- Order Form View -->
            <div class="mb-6">
                <a href="reseller_panel.php" class="text-indigo-400 hover:text-indigo-300 mb-4 inline-flex items-center">
                    <i class="fas fa-arrow-left mr-2"></i> Back to Panels
                </a>
                
                <div class="bg-gray-800 rounded-lg p-6 mt-4">
                    <div class="flex flex-col md:flex-row">
                        <div class="md:w-1/3 mb-4 md:mb-0 md:pr-6">
                            <h2 class="text-xl font-semibold text-white mb-2"><?php echo htmlspecialchars($selectedPanel['name']); ?></h2>
                            <div class="mb-4">
                                <span class="text-2xl font-bold text-white">
                                    <?php echo $currency . number_format($selectedPanel['price'], 2); ?>
                                </span>
                            </div>
                            
                            <p class="text-gray-400 mb-4"><?php echo htmlspecialchars($selectedPanel['description']); ?></p>
                            
                            <?php 
                            // Parse features if they're stored as JSON
                            $features = [];
                            if (!empty($selectedPanel['features'])) {
                                $featuresData = json_decode($selectedPanel['features'], true);
                                if (is_array($featuresData)) {
                                    $features = $featuresData;
                                } else {
                                    // If not valid JSON, split by newlines
                                    $features = explode("\n", $selectedPanel['features']);
                                }
                            }
                            ?>
                            
                            <?php if (!empty($features)): ?>
                                <ul class="text-gray-300 mb-4 space-y-2">
                                    <?php foreach ($features as $feature): ?>
                                        <li class="flex items-start">
                                            <i class="fas fa-check text-green-500 mr-2 mt-1"></i>
                                            <span><?php echo htmlspecialchars($feature); ?></span>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php endif; ?>
                            
                            <div class="bg-gray-900 p-4 rounded-md">
                                <h3 class="text-white font-medium mb-2">Order Summary</h3>
                                <div class="flex justify-between mb-2">
                                    <span class="text-gray-400">Panel Price:</span>
                                    <span class="text-white"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></span>
                                </div>
                                <div class="flex justify-between font-semibold border-t border-gray-700 pt-2 mt-2">
                                    <span class="text-gray-400">Total:</span>
                                    <span class="text-white"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></span>
                                </div>
                            </div>
                            
                            <?php if ($user['balance'] < $selectedPanel['price']): ?>
                                <div class="mt-4 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md">
                                    <p class="text-red-400 text-sm">
                                        <i class="fas fa-exclamation-triangle mr-2"></i> Insufficient balance. Please fund your wallet before placing this order.
                                    </p>
                                    <a href="fund_wallet.php" class="mt-2 inline-block px-4 py-2 bg-red-600 text-white rounded-md hover:bg-red-700 transition-colors text-sm">
                                        Fund Wallet
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div>
                        
                        <div class="md:w-2/3 md:pl-6 md:border-l md:border-gray-700">
                            <h3 class="text-lg font-semibold text-white mb-4">Order Details</h3>
                            <form id="orderForm" action="process/order_reseller.php" method="POST">
                                <input type="hidden" name="panel_id" value="<?php echo $selectedPanel['id']; ?>">
                                
                                <div class="mb-4">
                                    <label for="domain_name" class="block text-sm font-medium text-gray-400 mb-1">Domain Name <span class="text-red-500">*</span></label>
                                    <input type="text" id="domain_name" name="domain_name" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white" placeholder="yourdomain.com" required>
                                    <p class="mt-1 text-xs text-gray-500">Enter your domain name without http:// or https://</p>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="company_name" class="block text-sm font-medium text-gray-400 mb-1">Company Name <span class="text-red-500">*</span></label>
                                    <input type="text" id="company_name" name="company_name" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white" required>
                                </div>
                                
                                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                                    <div>
                                        <label for="company_email" class="block text-sm font-medium text-gray-400 mb-1">Company Email <span class="text-red-500">*</span></label>
                                        <input type="email" id="company_email" name="company_email" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                                    </div>
                                    
                                    <div>
                                        <label for="company_phone" class="block text-sm font-medium text-gray-400 mb-1">Company Phone <span class="text-red-500">*</span></label>
                                        <input type="tel" id="company_phone" name="company_phone" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white" value="<?php echo htmlspecialchars($user['phone']); ?>" required>
                                    </div>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="company_address" class="block text-sm font-medium text-gray-400 mb-1">Company Address</label>
                                    <textarea id="company_address" name="company_address" rows="2" class="form-textarea block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white"></textarea>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="additional_info" class="block text-sm font-medium text-gray-400 mb-1">Additional Information</label>
                                    <textarea id="additional_info" name="additional_info" rows="3" class="form-textarea block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700 text-white" placeholder="Any additional requirements or information you'd like us to know"></textarea>
                                </div>
                                
                                <div class="mb-6">
                                    <div class="flex items-center">
                                        <input type="checkbox" id="agree_terms" name="agree_terms" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800 bg-gray-700 border-gray-600" required>
                                        <label for="agree_terms" class="ml-2 text-gray-300">
                                            I agree to the <a href="#" class="text-indigo-400 hover:text-indigo-300">Terms and Conditions</a>
                                        </label>
                                    </div>
                                </div>
                                
                                <div id="orderResponse" class="hidden mb-4 p-4 rounded-md"></div>
                                
                                <button type="submit" class="w-full py-2 px-4 bg-indigo-600 hover:bg-indigo-700 rounded-md text-white font-medium transition-colors" <?php echo ($user['balance'] < $selectedPanel['price']) ? 'disabled' : ''; ?>>
                                    <?php echo ($user['balance'] < $selectedPanel['price']) ? 'Insufficient Balance' : 'Place Order'; ?>
                                </button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const orderForm = document.getElementById('orderForm');
    const orderResponse = document.getElementById('orderResponse');
    
    if (orderForm) {
        orderForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Remove any previous response
            orderResponse.innerHTML = '';
            orderResponse.className = 'hidden mb-4 p-4 rounded-md';
            
            // Show loading state
            const submitButton = orderForm.querySelector('button[type="submit"]');
            const originalButtonText = submitButton.innerHTML;
            submitButton.disabled = true;
            submitButton.innerHTML = '<i class="fas fa-spinner fa-spin mr-2"></i> Processing...';
            
            // Submit form using AJAX
            const formData = new FormData(orderForm);
            
            fetch(orderForm.action, {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // Show success message
                    orderResponse.innerHTML = `
                        <div class="flex items-start">
                            <i class="fas fa-check-circle text-green-500 mr-2 mt-1"></i>
                            <div>
                                <p class="text-white">${data.message}</p>
                                <p class="text-gray-400 mt-1">Order Reference: ${data.data.reference}</p>
                            </div>
                        </div>
                    `;
                    orderResponse.className = 'mb-4 p-4 bg-green-500 bg-opacity-10 border border-green-500 rounded-md';
                    
                    // Reset the form
                    orderForm.reset();
                    
                    // Redirect to orders page after a delay
                    setTimeout(() => {
                        window.location.href = 'orders.php';
                    }, 3000);
                } else {
                    // Show error message
                    orderResponse.innerHTML = `
                        <div class="flex items-start">
                            <i class="fas fa-exclamation-circle text-red-500 mr-2 mt-1"></i>
                            <p class="text-white">${data.message}</p>
                        </div>
                    `;
                    orderResponse.className = 'mb-4 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md';
                    
                    // Reset button
                    submitButton.disabled = false;
                    submitButton.innerHTML = originalButtonText;
                }
            })
            .catch(error => {
                // Show error message
                orderResponse.innerHTML = `
                    <div class="flex items-start">
                        <i class="fas fa-exclamation-circle text-red-500 mr-2 mt-1"></i>
                        <p class="text-white">An error occurred. Please try again later.</p>
                    </div>
                `;
                orderResponse.className = 'mb-4 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md';
                
                // Reset button
                submitButton.disabled = false;
                submitButton.innerHTML = originalButtonText;
                
                console.error('Error:', error);
            });
        });
    }
});
</script>

<?php require_once './includes/footer.php'; ?>