<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['update_order'])) {
        $orderId = (int)$_POST['order_id'];
        $status = sanitizeInput($_POST['status']);
        $domainName = sanitizeInput($_POST['domain_name']);
        $startDate = $_POST['start_date'] ? date('Y-m-d', strtotime($_POST['start_date'])) : null;
        $expiryDate = $_POST['expiry_date'] ? date('Y-m-d', strtotime($_POST['expiry_date'])) : null;
        
        // Validate status
        if (!in_array($status, ['pending', 'processing', 'completed', 'cancelled'])) {
            $actionError = 'Invalid status';
        } else {
            // Update order
            $stmt = $conn->prepare("
                UPDATE reseller_orders 
                SET status = ?, domain_name = ?, start_date = ?, expiry_date = ?
                WHERE id = ?
            ");
            $stmt->bind_param("ssssi", $status, $domainName, $startDate, $expiryDate, $orderId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Order updated successfully';
                
                // Get order details for notification
                $stmt = $conn->prepare("
                    SELECT ro.*, u.username, u.email, rp.name as panel_name 
                    FROM reseller_orders ro
                    JOIN users u ON ro.user_id = u.id
                    JOIN reseller_panels rp ON ro.panel_id = rp.id
                    WHERE ro.id = ?
                ");
                $stmt->bind_param("i", $orderId);
                $stmt->execute();
                $result = $stmt->get_result();
                $order = $result->fetch_assoc();
                
                if ($order) {
                    // Create notification for user
                    $notificationTitle = "Reseller Panel Order Update";
                    $notificationMessage = "Your reseller panel order status has been updated to " . ucfirst($status) . ".";
                    
                    if ($status === 'completed') {
                        $notificationMessage = "Your reseller panel is now ready! You can access it at " . ($domainName ? $domainName . ($order['domain_extension'] ?: '') : 'your domain') . ".";
                    } elseif ($status === 'cancelled') {
                        $notificationMessage = "Your reseller panel order has been cancelled. Please contact support for more information.";
                    }
                    
                    $stmt = $conn->prepare("
                        INSERT INTO notifications 
                        (user_id, title, message, type, is_read)
                        VALUES (?, ?, ?, 'info', 0)
                    ");
                    $stmt->bind_param("iss", $order['user_id'], $notificationTitle, $notificationMessage);
                    $stmt->execute();
                    
                    // Send email to user
                    if ($order['email']) {
                        $subject = "Reseller Panel Order Update - " . $order['order_ref'];
                        $message = "
                            <p>Dear {$order['username']},</p>
                            <p>{$notificationMessage}</p>
                            <p><strong>Order Reference:</strong> {$order['order_ref']}</p>
                            <p><strong>Panel:</strong> {$order['panel_name']}</p>
                            <p><strong>Status:</strong> " . ucfirst($status) . "</p>
                        ";
                        
                        if ($status === 'completed' && $domainName) {
                            $message .= "<p><strong>Access URL:</strong> <a href='https://{$domainName}" . ($order['domain_extension'] ?: '') . "'>{$domainName}" . ($order['domain_extension'] ?: '') . "</a></p>";
                            
                            if ($expiryDate) {
                                $message .= "<p><strong>Expiry Date:</strong> " . date('F j, Y', strtotime($expiryDate)) . "</p>";
                                $message .= "<p>Your panel will be active until the expiry date. We will send you a reminder before it expires.</p>";
                            }
                        }
                        
                        $message .= "<p>If you have any questions, please contact our support team.</p>";
                        
                        sendEmail($order['email'], $subject, $message);
                    }
                }
            } else {
                $actionError = 'Failed to update order: ' . $conn->error;
            }
        }
    } elseif (isset($_POST['delete_order'])) {
        $orderId = (int)$_POST['order_id'];
        
        // Get order details
        $stmt = $conn->prepare("SELECT status FROM reseller_orders WHERE id = ?");
        $stmt->bind_param("i", $orderId);
        $stmt->execute();
        $result = $stmt->get_result();
        $order = $result->fetch_assoc();
        
        if ($order && $order['status'] !== 'completed') {
            $stmt = $conn->prepare("DELETE FROM reseller_orders WHERE id = ?");
            $stmt->bind_param("i", $orderId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Order deleted successfully';
            } else {
                $actionError = 'Failed to delete order: ' . $conn->error;
            }
        } else {
            $actionError = 'Completed orders cannot be deleted';
        }
    } elseif (isset($_POST['send_notification'])) {
        $orderId = (int)$_POST['order_id'];
        
        // Get order details
        $stmt = $conn->prepare("
            SELECT ro.*, u.id as user_id, u.username, u.email, rp.name as panel_name 
            FROM reseller_orders ro
            JOIN users u ON ro.user_id = u.id
            JOIN reseller_panels rp ON ro.panel_id = rp.id
            WHERE ro.id = ?
        ");
        $stmt->bind_param("i", $orderId);
        $stmt->execute();
        $result = $stmt->get_result();
        $order = $result->fetch_assoc();
        
        if ($order) {
            // Create notification for user
            $notificationTitle = "Reseller Panel Renewal Reminder";
            $notificationMessage = "Your reseller panel will expire on " . date('F j, Y', strtotime($order['expiry_date'])) . ". Please renew it to avoid service interruption.";
            
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'warning', 0)
            ");
            $stmt->bind_param("iss", $order['user_id'], $notificationTitle, $notificationMessage);
            $stmt->execute();
            
            // Update last notification date
            $today = date('Y-m-d');
            $stmt = $conn->prepare("
                UPDATE reseller_orders 
                SET last_notification_date = ?
                WHERE id = ?
            ");
            $stmt->bind_param("si", $today, $orderId);
            $stmt->execute();
            
            // Send email to user
            if ($order['email']) {
                $subject = "Reseller Panel Renewal Reminder";
                $message = "
                    <p>Dear {$order['username']},</p>
                    <p>This is a reminder that your reseller panel will expire on " . date('F j, Y', strtotime($order['expiry_date'])) . ".</p>
                    <p><strong>Panel:</strong> {$order['panel_name']}</p>
                    <p><strong>Domain:</strong> {$order['domain_name']}" . ($order['domain_extension'] ?: '') . "</p>
                    <p>To ensure uninterrupted service, please log in to your account and renew your panel before the expiry date.</p>
                    <p>If you have any questions, please contact our support team.</p>
                ";
                
                sendEmail($order['email'], $subject, $message);
                
                $actionSuccess = 'Renewal notification sent successfully';
            } else {
                $actionError = 'User email not found';
            }
        } else {
            $actionError = 'Order not found';
        }
    }
}

// Get orders
$status = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

$query = "
    SELECT ro.*, u.username, u.email, rp.name as panel_name 
    FROM reseller_orders ro
    JOIN users u ON ro.user_id = u.id
    JOIN reseller_panels rp ON ro.panel_id = rp.id
";

$params = [];
$types = "";

if ($status || $search) {
    $query .= " WHERE ";
    $conditions = [];
    
    if ($status) {
        $conditions[] = "ro.status = ?";
        $params[] = $status;
        $types .= "s";
    }
    
    if ($search) {
        $searchTerm = "%$search%";
        $conditions[] = "(ro.order_ref LIKE ? OR u.username LIKE ? OR ro.domain_name LIKE ? OR ro.company_name LIKE ?)";
        $params[] = $searchTerm;
        $params[] = $searchTerm;
        $params[] = $searchTerm;
        $params[] = $searchTerm;
        $types .= "ssss";
    }
    
    $query .= implode(" AND ", $conditions);
}

$query .= " ORDER BY ro.created_at DESC";

$stmt = $conn->prepare($query);

if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}

$stmt->execute();
$result = $stmt->get_result();
$orders = [];

while ($row = $result->fetch_assoc()) {
    // Decode addons if present
    if (isset($row['addons']) && !empty($row['addons'])) {
        $row['addons_decoded'] = json_decode($row['addons'], true);
    } else {
        $row['addons_decoded'] = [];
    }
    
    $orders[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reseller Orders - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .status-processing {
            background-color: rgba(59, 130, 246, 0.3);
            color: #93c5fd;
        }
        
        .status-completed {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-cancelled {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/addons.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-puzzle-piece mr-3"></i>
                                <span>Add-ons</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/domain_extensions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-globe mr-3"></i>
                                <span>Domain Extensions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Reseller Panel Orders</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="flex flex-wrap items-center space-x-0 md:space-x-4 space-y-2 md:space-y-0">
                    <div class="w-full md:w-auto">
                        <select name="status" class="form-select rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Statuses</option>
                            <option value="pending" <?php echo $status === 'pending' ? 'selected' : ''; ?>>Pending</option>
                            <option value="processing" <?php echo $status === 'processing' ? 'selected' : ''; ?>>Processing</option>
                            <option value="completed" <?php echo $status === 'completed' ? 'selected' : ''; ?>>Completed</option>
                            <option value="cancelled" <?php echo $status === 'cancelled' ? 'selected' : ''; ?>>Cancelled</option>
                        </select>
                    </div>
                    
                    <div class="flex-grow">
                        <input type="text" name="search" value="<?php echo htmlspecialchars($search); ?>" placeholder="Search by reference, username, domain, company..." class="form-input w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    </div>
                    
                    <div>
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            <i class="fas fa-search mr-2"></i> Filter
                        </button>
                    </div>
                    
                    <div>
                        <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="py-2 px-4 bg-gray-700 hover:bg-gray-600 text-white rounded-md inline-block">
                            <i class="fas fa-times mr-2"></i> Clear
                        </a>
                    </div>
                </form>
            </div>
            
            <!-- Orders Table -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Reseller Panel Orders</h2>
                
                <?php if (empty($orders)): ?>
                    <div class="text-center py-8 text-gray-400">
                        <i class="fas fa-shopping-cart text-3xl mb-2"></i>
                        <p>No orders found<?php echo $status ? ' with status: ' . ucfirst($status) : ''; ?><?php echo $search ? ' matching: "' . htmlspecialchars($search) . '"' : ''; ?></p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Order Ref</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">User</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Panel</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Domain</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Amount</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Date</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($orders as $order): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4 text-sm">
                                            <div class="font-medium text-indigo-400"><?php echo htmlspecialchars($order['order_ref']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-sm">
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($order['username']); ?></div>
                                            <div class="text-xs text-gray-400"><?php echo htmlspecialchars($order['email']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white">
                                            <?php echo htmlspecialchars($order['panel_name']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php 
                                            $domainDisplay = htmlspecialchars($order['domain_name'] ?: 'Not set');
                                            if (!empty($order['domain_extension'])) {
                                                $domainDisplay .= htmlspecialchars($order['domain_extension']);
                                            }
                                            echo $domainDisplay;
                                            ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white font-medium">
                                            <?php echo getSetting('currency') . number_format($order['amount'], 2); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $order['status']; ?>">
                                                <?php echo ucfirst($order['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo date('M d, Y', strtotime($order['created_at'])); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 view-order" data-id="<?php echo $order['id']; ?>">
                                                    <i class="fas fa-eye"></i>
                                                </button>
                                                <button class="text-green-400 hover:text-green-300 edit-order" 
                                                        data-id="<?php echo $order['id']; ?>"
                                                        data-status="<?php echo $order['status']; ?>"
                                                        data-domain="<?php echo htmlspecialchars($order['domain_name'] ?: ''); ?>"
                                                        data-start="<?php echo $order['start_date'] ?: ''; ?>"
                                                        data-expiry="<?php echo $order['expiry_date'] ?: ''; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <?php if ($order['status'] === 'pending' || $order['status'] === 'processing'): ?>
                                                    <button class="text-red-500 hover:text-red-400 delete-order" 
                                                            data-id="<?php echo $order['id']; ?>"
                                                            data-ref="<?php echo htmlspecialchars($order['order_ref']); ?>">
                                                        <i class="fas fa-trash"></i>
                                                    </button>
                                                <?php endif; ?>
                                                
                                                <?php if ($order['status'] === 'completed' && $order['expiry_date']): ?>
                                                    <?php
                                                    $expiryDays = (strtotime($order['expiry_date']) - time()) / (60 * 60 * 24);
                                                    if ($expiryDays <= 30 && $expiryDays > 0):
                                                    ?>
                                                        <button class="text-yellow-500 hover:text-yellow-400 send-notification" 
                                                                data-id="<?php echo $order['id']; ?>"
                                                                data-user="<?php echo htmlspecialchars($order['username']); ?>"
                                                                data-expiry="<?php echo date('M d, Y', strtotime($order['expiry_date'])); ?>">
                                                            <i class="fas fa-bell"></i>
                                                        </button>
                                                    <?php endif; ?>
                                                <?php endif; ?>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">Managing Reseller Panels</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        When a user orders a reseller panel, you need to:
                    </p>
                    
                    <ol class="list-decimal pl-5 space-y-2">
                        <li>Set the status to "Processing" while you prepare the panel</li>
                        <li>Set up their domain or subdomain</li>
                        <li>Install and configure the reseller panel software</li>
                        <li>Once ready, update the status to "Completed" and set the Start and Expiry dates</li>
                        <li>The system will notify the user automatically</li>
                    </ol>
                    
                    <p class="mt-4">
                        <i class="fas fa-exclamation-triangle text-yellow-400 mr-2"></i>
                        <strong>Important:</strong> The system will automatically notify users 30, 21, and 7 days before their panel expires. You can also send manual notifications using the bell icon.
                    </p>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        <strong>New Features:</strong> Users can now select domain registration, WHOIS protection, and add-ons during checkout. Check the order details to see what options they've selected.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- View Order Modal -->
    <div id="viewOrderModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-4xl w-full mx-auto p-6 max-h-screen overflow-y-auto">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Order Details</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="orderDetails" class="grid grid-cols-1 md:grid-cols-2 gap-6">
                <!-- Order Details will be loaded here -->
                <div class="text-center py-8 col-span-2">
                    <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto"></div>
                    <p class="mt-2 text-gray-400">Loading order details...</p>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Edit Order Modal -->
    <div id="editOrderModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Update Order Status</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="edit_order_id" name="order_id" value="">
                
                <div class="mb-4">
                    <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="pending">Pending</option>
                        <option value="processing">Processing</option>
                        <option value="completed">Completed</option>
                        <option value="cancelled">Cancelled</option>
                    </select>
                </div>
                
                <div class="mb-4">
                    <label for="domain_name" class="block text-sm font-medium text-gray-400 mb-1">Domain Name</label>
                    <input type="text" id="domain_name" name="domain_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="e.g. customer.yourdomain.com">
                    <p class="mt-1 text-xs text-gray-500">Enter the domain or subdomain where the reseller panel is hosted</p>
                </div>
                
                <div class="mb-4">
                    <label for="start_date" class="block text-sm font-medium text-gray-400 mb-1">Start Date</label>
                    <input type="date" id="start_date" name="start_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                
                <div class="mb-4">
                    <label for="expiry_date" class="block text-sm font-medium text-gray-400 mb-1">Expiry Date</label>
                    <input type="date" id="expiry_date" name="expiry_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    <p class="mt-1 text-xs text-gray-500">Typically 1 year from the start date</p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="update_order" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Update Order
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Order Modal -->
    <div id="deleteOrderModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Order</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the order <span id="deleteOrderRef" class="font-semibold text-white"></span>? This action cannot be undone.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_order_id" name="order_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_order" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Order
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Send Notification Modal -->
    <div id="notificationModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Send Renewal Notification</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-4">You are about to send a renewal notification to <span id="notifyUser" class="font-semibold text-white"></span>. Their panel expires on <span id="notifyExpiry" class="font-semibold text-white"></span>.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="notify_order_id" name="order_id" value="">
                
                <div class="mb-6 bg-yellow-900 bg-opacity-30 p-4 rounded-md border border-yellow-800">
                    <div class="flex items-start">
                        <i class="fas fa-exclamation-triangle text-yellow-500 mt-0.5 mr-2"></i>
                        <p class="text-sm text-yellow-200">This will send both an email and an in-app notification to remind the user about their upcoming panel expiration.</p>
                    </div>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="send_notification" class="py-2 px-4 bg-yellow-600 text-white rounded-md hover:bg-yellow-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-yellow-500">
                        Send Notification
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const viewOrderModal = document.getElementById('viewOrderModal');
        const editOrderModal = document.getElementById('editOrderModal');
        const deleteOrderModal = document.getElementById('deleteOrderModal');
        const notificationModal = document.getElementById('notificationModal');
        
        function openViewOrderModal(orderId) {
            // Show the modal
            viewOrderModal.classList.remove('hidden');
            
            // Set loading state
            document.getElementById('orderDetails').innerHTML = `
                <div class="text-center py-8 col-span-2">
                    <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto"></div>
                    <p class="mt-2 text-gray-400">Loading order details...</p>
                </div>
            `;
            
            // Fetch order details
            fetch(`${window.location.origin}/admin/ajax/get_order_details.php?id=${orderId}`)
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Render order details
                        const order = data.order;
                        let statusClass = '';
                        
                        switch (order.status) {
                            case 'pending':
                                statusClass = 'status-pending';
                                break;
                            case 'processing':
                                statusClass = 'status-processing';
                                break;
                            case 'completed':
                                statusClass = 'status-completed';
                                break;
                            case 'cancelled':
                                statusClass = 'status-cancelled';
                                break;
                        }
                        
                        // Prepare addons HTML if any
                        let addonsHtml = '';
                        if (order.addons_decoded && order.addons_decoded.length > 0) {
                            addonsHtml = `
                                <div class="mb-4">
                                    <div class="text-gray-400 mb-1">Selected Add-ons:</div>
                                    <ul class="list-disc list-inside text-white space-y-1">
                            `;
                            
                            order.addons_decoded.forEach(addon => {
                                addonsHtml += `<li>${addon.name} (${order.currency}${parseFloat(addon.price).toFixed(2)})</li>`;
                            });
                            
                            addonsHtml += `
                                    </ul>
                                </div>
                            `;
                        }
                        
                        // Prepare domain registration info if applicable
                        let domainHtml = '';
                        if (order.register_domain == 1) {
                            domainHtml = `
                                <div class="mb-4">
                                    <div class="text-gray-400 mb-1">Domain Registration:</div>
                                    <div class="flex flex-col text-white">
                                        <span>Domain: ${order.domain_name}${order.domain_extension}</span>
                                        <span>Registration Fee: ${order.currency}${parseFloat(order.domain_price).toFixed(2)}</span>
                                        ${order.whois_protection == 1 ? `<span>WHOIS Protection: Yes (${order.currency}${parseFloat(order.whois_protection_price || 0).toFixed(2)})</span>` : ''}
                                    </div>
                                </div>
                            `;
                        }
                        
                        document.getElementById('orderDetails').innerHTML = `
                            <div>
                                <h4 class="text-lg font-medium text-white mb-3">Order Information</h4>
                                <div class="bg-gray-900 rounded-md p-4 space-y-2">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Reference:</span>
                                        <span class="text-white font-medium">${order.order_ref}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Panel:</span>
                                        <span class="text-white">${order.panel_name}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Base Price:</span>
                                        <span class="text-white">${order.currency}${parseFloat(order.panel_price || 0).toFixed(2)}</span>
                                    </div>
                                    ${order.setup_fee > 0 ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Setup Fee:</span>
                                        <span class="text-white">${order.currency}${parseFloat(order.setup_fee).toFixed(2)}</span>
                                    </div>
                                    ` : ''}
                                    ${order.register_domain == 1 ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Domain Fee:</span>
                                        <span class="text-white">${order.currency}${parseFloat(order.domain_price).toFixed(2)}</span>
                                    </div>
                                    ` : ''}
                                    ${order.whois_protection == 1 ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">WHOIS Protection:</span>
                                        <span class="text-white">${order.currency}${parseFloat(order.whois_protection_price || 0).toFixed(2)}</span>
                                    </div>
                                    ` : ''}
                                    ${order.total_addons_price > 0 ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Add-ons Total:</span>
                                        <span class="text-white">${order.currency}${parseFloat(order.total_addons_price).toFixed(2)}</span>
                                    </div>
                                    ` : ''}
                                    <div class="flex justify-between pt-2 border-t border-gray-700">
                                        <span class="text-gray-300 font-medium">Total Amount:</span>
                                        <span class="text-white font-bold">${order.currency}${parseFloat(order.amount).toFixed(2)}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Date:</span>
                                        <span class="text-white">${new Date(order.created_at).toLocaleDateString()}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Status:</span>
                                        <span class="status-badge ${statusClass}">${order.status.charAt(0).toUpperCase() + order.status.slice(1)}</span>
                                    </div>
                                    ${order.start_date ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Start Date:</span>
                                        <span class="text-white">${new Date(order.start_date).toLocaleDateString()}</span>
                                    </div>
                                    ` : ''}
                                    ${order.expiry_date ? `
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Expiry Date:</span>
                                        <span class="text-white">${new Date(order.expiry_date).toLocaleDateString()}</span>
                                    </div>
                                    ` : ''}
                                </div>
                            </div>
                            
                            <div>
                                <h4 class="text-lg font-medium text-white mb-3">Customer Information</h4>
                                <div class="bg-gray-900 rounded-md p-4 space-y-2">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Username:</span>
                                        <span class="text-white">${order.username}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Email:</span>
                                        <span class="text-white">${order.email}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Company Name:</span>
                                        <span class="text-white">${order.company_name}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Company Email:</span>
                                        <span class="text-white">${order.company_email}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Company Phone:</span>
                                        <span class="text-white">${order.company_phone}</span>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="col-span-1 md:col-span-2">
                                <h4 class="text-lg font-medium text-white mb-3">Additional Information</h4>
                                <div class="bg-gray-900 rounded-md p-4">
                                    <div class="mb-4">
                                        <div class="text-gray-400 mb-1">Domain:</div>
                                        <div class="text-white">${order.domain_name}${order.domain_extension || ''}</div>
                                    </div>
                                    
                                    ${domainHtml}
                                    
                                    ${addonsHtml}
                                    
                                    <div class="mb-4">
                                        <div class="text-gray-400 mb-1">Company Address:</div>
                                        <div class="text-white">${order.company_address || 'Not provided'}</div>
                                    </div>
                                    <div>
                                        <div class="text-gray-400 mb-1">Additional Info:</div>
                                        <div class="text-white">${order.additional_info || 'Not provided'}</div>
                                    </div>
                                </div>
                            </div>
                        `;
                    } else {
                        document.getElementById('orderDetails').innerHTML = `
                            <div class="text-center py-8 col-span-2">
                                <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                                    <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
                                </div>
                                <h3 class="text-lg font-medium text-white mb-1">Error</h3>
                                <p class="text-gray-400">${data.message || 'Failed to load order details'}</p>
                            </div>
                        `;
                    }
                })
                .catch(error => {
                    console.error('Error fetching order details:', error);
                    document.getElementById('orderDetails').innerHTML = `
                        <div class="text-center py-8 col-span-2">
                            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
                            </div>
                            <h3 class="text-lg font-medium text-white mb-1">Error</h3>
                            <p class="text-gray-400">An error occurred while loading the order details. Please try again later.</p>
                        </div>
                    `;
                });
        }
        
        function openEditOrderModal(orderId, status, domain, startDate, expiryDate) {
            // Set form values
            document.getElementById('edit_order_id').value = orderId;
            document.getElementById('status').value = status;
            document.getElementById('domain_name').value = domain;
            document.getElementById('start_date').value = startDate;
            document.getElementById('expiry_date').value = expiryDate;
            
            // Show the modal
            editOrderModal.classList.remove('hidden');
        }
        
        function openDeleteOrderModal(orderId, orderRef) {
            document.getElementById('delete_order_id').value = orderId;
            document.getElementById('deleteOrderRef').textContent = orderRef;
            
            deleteOrderModal.classList.remove('hidden');
        }
        
        function openNotificationModal(orderId, username, expiryDate) {
            document.getElementById('notify_order_id').value = orderId;
            document.getElementById('notifyUser').textContent = username;
            document.getElementById('notifyExpiry').textContent = expiryDate;
            
            notificationModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            viewOrderModal.classList.add('hidden');
            editOrderModal.classList.add('hidden');
            deleteOrderModal.classList.add('hidden');
            notificationModal.classList.add('hidden');
        }
        
        // View Order buttons
        document.querySelectorAll('.view-order').forEach(button => {
            button.addEventListener('click', function() {
                const orderId = this.getAttribute('data-id');
                openViewOrderModal(orderId);
            });
        });
        
        // Edit Order buttons
        document.querySelectorAll('.edit-order').forEach(button => {
            button.addEventListener('click', function() {
                const orderId = this.getAttribute('data-id');
                const status = this.getAttribute('data-status');
                const domain = this.getAttribute('data-domain');
                const startDate = this.getAttribute('data-start');
                const expiryDate = this.getAttribute('data-expiry');
                
                openEditOrderModal(orderId, status, domain, startDate, expiryDate);
            });
        });
        
        // Delete Order buttons
        document.querySelectorAll('.delete-order').forEach(button => {
            button.addEventListener('click', function() {
                const orderId = this.getAttribute('data-id');
                const orderRef = this.getAttribute('data-ref');
                
                openDeleteOrderModal(orderId, orderRef);
            });
        });
        
        // Send Notification buttons
        document.querySelectorAll('.send-notification').forEach(button => {
            button.addEventListener('click', function() {
                const orderId = this.getAttribute('data-id');
                const username = this.getAttribute('data-user');
                const expiryDate = this.getAttribute('data-expiry');
                
                openNotificationModal(orderId, username, expiryDate);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === viewOrderModal) {
                closeAllModals();
            }
            if (event.target === editOrderModal) {
                closeAllModals();
            }
            if (event.target === deleteOrderModal) {
                closeAllModals();
            }
            if (event.target === notificationModal) {
                closeAllModals();
            }
        });
        
        // Auto-set expiry date when start date changes
        document.getElementById('start_date').addEventListener('change', function() {
            if (this.value) {
                const startDate = new Date(this.value);
                const expiryDate = new Date(startDate);
                expiryDate.setFullYear(expiryDate.getFullYear() + 1);
                
                // Format as YYYY-MM-DD
                const expiryDateStr = expiryDate.toISOString().split('T')[0];
                document.getElementById('expiry_date').value = expiryDateStr;
            }
        });
    </script>
</body>
</html>