<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_panel']) || isset($_POST['edit_panel'])) {
        // Common validation and data collection for both add and edit
        $panelId = isset($_POST['panel_id']) ? (int)$_POST['panel_id'] : 0;
        $panelName = sanitizeInput($_POST['panel_name']);
        $panelDescription = sanitizeInput($_POST['panel_description']);
        $panelPrice = (float)$_POST['panel_price'];
        $panelStatus = sanitizeInput($_POST['panel_status']);
        
        // Process features
        $features = [];
        $featureTitles = $_POST['feature_title'] ?? [];
        $featureDescriptions = $_POST['feature_description'] ?? [];
        
        foreach ($featureTitles as $index => $title) {
            if (!empty($title)) {
                $features[] = [
                    'title' => sanitizeInput($title),
                    'description' => isset($featureDescriptions[$index]) ? sanitizeInput($featureDescriptions[$index]) : ''
                ];
            }
        }
        
        $featuresJson = json_encode($features);
        
        // Validate inputs
        if (empty($panelName)) {
            $actionError = 'Panel name is required';
        } elseif ($panelPrice <= 0) {
            $actionError = 'Panel price must be greater than zero';
        } elseif (!in_array($panelStatus, ['active', 'inactive'])) {
            $actionError = 'Invalid status';
        } else {
            if (isset($_POST['add_panel'])) {
                // Add new panel
                $stmt = $conn->prepare("
                    INSERT INTO reseller_panels 
                    (name, description, price, features, status)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $stmt->bind_param("ssdss", $panelName, $panelDescription, $panelPrice, $featuresJson, $panelStatus);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Reseller panel added successfully';
                } else {
                    $actionError = 'Failed to add reseller panel: ' . $conn->error;
                }
            } else {
                // Edit existing panel
                $stmt = $conn->prepare("
                    UPDATE reseller_panels 
                    SET name = ?, description = ?, price = ?, features = ?, status = ?
                    WHERE id = ?
                ");
                $stmt->bind_param("ssdssi", $panelName, $panelDescription, $panelPrice, $featuresJson, $panelStatus, $panelId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Reseller panel updated successfully';
                } else {
                    $actionError = 'Failed to update reseller panel: ' . $conn->error;
                }
            }
        }
    } elseif (isset($_POST['delete_panel'])) {
        $panelId = (int)$_POST['panel_id'];
        
        // Check if panel can be deleted (no active orders)
        $stmt = $conn->prepare("
            SELECT COUNT(*) as count 
            FROM reseller_orders 
            WHERE panel_id = ? AND status IN ('pending', 'processing', 'completed')
        ");
        $stmt->bind_param("i", $panelId);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row['count'] > 0) {
            $actionError = 'Cannot delete this panel because it has active orders. Please change its status to inactive instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM reseller_panels WHERE id = ?");
            $stmt->bind_param("i", $panelId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Reseller panel deleted successfully';
            } else {
                $actionError = 'Failed to delete reseller panel: ' . $conn->error;
            }
        }
    }
}

// Get reseller panels
$stmt = $conn->prepare("SELECT * FROM reseller_panels ORDER BY id ASC");
$stmt->execute();
$result = $stmt->get_result();
$panels = [];

while ($row = $result->fetch_assoc()) {
    $row['features'] = json_decode($row['features'], true) ?: [];
    $panels[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reseller Panels - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/form_fields.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-list-alt mr-3"></i>
                                <span>Form Fields</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Reseller Panels</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Panels Section -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Reseller Panels</h2>
                    <button id="addPanelBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add New Panel
                    </button>
                </div>
                
                <?php if (empty($panels)): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-store text-3xl mb-2"></i>
                        <p>No reseller panels configured yet. Add your first panel.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Name</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Description</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($panels as $panel): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($panel['name']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300 truncate max-w-xs">
                                            <?php echo htmlspecialchars($panel['description']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-white font-medium">
                                            <?php echo getSetting('currency') . number_format($panel['price'], 2); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $panel['status']; ?>">
                                                <?php echo ucfirst($panel['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-panel" 
                                                        data-id="<?php echo $panel['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($panel['name']); ?>"
                                                        data-description="<?php echo htmlspecialchars($panel['description']); ?>"
                                                        data-price="<?php echo $panel['price']; ?>"
                                                        data-status="<?php echo $panel['status']; ?>"
                                                        data-features='<?php echo htmlspecialchars(json_encode($panel['features'])); ?>'>
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-panel" 
                                                        data-id="<?php echo $panel['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($panel['name']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Reseller Panels</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Reseller panels allow your users to purchase their own VTU platform with all the features and services you offer.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">User Process</h3>
                            <p class="text-gray-400">
                                Users purchase a reseller panel, provide their business information, and you set up their platform. They can then run their own VTU business using your services as the backend.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Admin Tasks</h3>
                            <p class="text-gray-400">
                                After a user purchases a panel, you need to create their account, set up their domain/subdomain, and configure their panel settings. The panel is valid for 1 year and must be renewed thereafter.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: Make sure to keep track of panel expiry dates and notify users before their panel expires.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Panel Modal -->
    <div id="panelModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-3xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Panel</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="panel_id" name="panel_id" value="">
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                    <div>
                        <label for="panel_name" class="block text-sm font-medium text-gray-400 mb-1">Panel Name</label>
                        <input type="text" id="panel_name" name="panel_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div>
                        <label for="panel_price" class="block text-sm font-medium text-gray-400 mb-1">Price</label>
                        <div class="relative">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <span class="text-gray-500 sm:text-sm"><?php echo getSetting('currency'); ?></span>
                            </div>
                            <input type="number" id="panel_price" name="panel_price" class="form-input block w-full pl-7 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="0" step="0.01" required>
                        </div>
                    </div>
                </div>
                
                <div class="mb-4">
                    <label for="panel_description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                    <textarea id="panel_description" name="panel_description" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50"></textarea>
                </div>
                
                <div class="mb-4">
                    <label for="panel_status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="panel_status" name="panel_status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="active">Active</option>
                        <option value="inactive">Inactive</option>
                    </select>
                </div>
                
                <div class="mb-4">
                    <label class="block text-sm font-medium text-gray-400 mb-1">Features</label>
                    <div id="features-container" class="space-y-3 mb-2">
                        <!-- Feature items will be added here -->
                    </div>
                    <button type="button" id="add-feature" class="mt-2 py-1 px-3 bg-gray-700 text-gray-300 rounded-md hover:bg-gray-600 text-sm">
                        <i class="fas fa-plus mr-1"></i> Add Feature
                    </button>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitPanelBtn" name="add_panel" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Panel
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Panel Modal -->
    <div id="deletePanelModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Panel</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the panel <span id="deletePanelName" class="font-semibold text-white"></span>? This action cannot be undone.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_panel_id" name="panel_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_panel" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Panel
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Panel Modal functionality
        const panelModal = document.getElementById('panelModal');
        const deletePanelModal = document.getElementById('deletePanelModal');
        
        const modalTitle = document.getElementById('modalTitle');
        const submitPanelBtn = document.getElementById('submitPanelBtn');
        const featuresContainer = document.getElementById('features-container');
        
        // Add a new feature row
        function addFeatureRow(title = '', description = '') {
            const index = document.querySelectorAll('.feature-row').length;
            const featureRow = document.createElement('div');
            featureRow.className = 'feature-row grid grid-cols-1 md:grid-cols-5 gap-2 items-start';
            featureRow.innerHTML = `
                <div class="md:col-span-2">
                    <input type="text" name="feature_title[]" placeholder="Feature Title" value="${title}" 
                           class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div class="md:col-span-2">
                    <input type="text" name="feature_description[]" placeholder="Feature Description" value="${description}" 
                           class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div class="flex justify-center">
                    <button type="button" class="remove-feature py-1 px-2 bg-red-600 hover:bg-red-700 text-white rounded">
                        <i class="fas fa-trash"></i>
                    </button>
                </div>
            `;
            
            // Add event listener to remove button
            const removeButton = featureRow.querySelector('.remove-feature');
            removeButton.addEventListener('click', function() {
                featureRow.remove();
            });
            
            featuresContainer.appendChild(featureRow);
        }
        
        // Add Feature button
        document.getElementById('add-feature').addEventListener('click', function() {
            addFeatureRow();
        });
        
        function openPanelModal(isEdit = false, panelData = {}) {
            // Reset form
            document.querySelector('#panelModal form').reset();
            
            // Clear features
            featuresContainer.innerHTML = '';
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('panel_id').value = panelData.id;
                document.getElementById('panel_name').value = panelData.name;
                document.getElementById('panel_description').value = panelData.description;
                document.getElementById('panel_price').value = panelData.price;
                document.getElementById('panel_status').value = panelData.status;
                
                // Add features
                if (panelData.features && panelData.features.length > 0) {
                    panelData.features.forEach(feature => {
                        addFeatureRow(feature.title, feature.description);
                    });
                } else {
                    // Add at least one empty feature row
                    addFeatureRow();
                }
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Reseller Panel';
                submitPanelBtn.textContent = 'Update Panel';
                submitPanelBtn.name = 'edit_panel';
            } else {
                // Clear values for new panel
                document.getElementById('panel_id').value = '';
                
                // Add default empty feature row
                addFeatureRow();
                
                // Update modal title and button
                modalTitle.textContent = 'Add New Panel';
                submitPanelBtn.textContent = 'Add Panel';
                submitPanelBtn.name = 'add_panel';
            }
            
            // Show the modal
            panelModal.classList.remove('hidden');
        }
        
        function openDeletePanelModal(panelId, panelName) {
            document.getElementById('delete_panel_id').value = panelId;
            document.getElementById('deletePanelName').textContent = panelName;
            
            deletePanelModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            panelModal.classList.add('hidden');
            deletePanelModal.classList.add('hidden');
        }
        
        // Add Panel button
        document.getElementById('addPanelBtn').addEventListener('click', () => openPanelModal(false));
        
        // Edit Panel buttons
        document.querySelectorAll('.edit-panel').forEach(button => {
            button.addEventListener('click', function() {
                const panelId = this.getAttribute('data-id');
                const panelName = this.getAttribute('data-name');
                const panelDescription = this.getAttribute('data-description');
                const panelPrice = this.getAttribute('data-price');
                const panelStatus = this.getAttribute('data-status');
                const featuresJson = this.getAttribute('data-features');
                
                let features = [];
                try {
                    features = JSON.parse(featuresJson);
                } catch (e) {
                    console.error('Error parsing features JSON:', e);
                }
                
                const panelData = {
                    id: panelId,
                    name: panelName,
                    description: panelDescription,
                    price: panelPrice,
                    status: panelStatus,
                    features: features
                };
                
                openPanelModal(true, panelData);
            });
        });
        
        // Delete Panel buttons
        document.querySelectorAll('.delete-panel').forEach(button => {
            button.addEventListener('click', function() {
                const panelId = this.getAttribute('data-id');
                const panelName = this.getAttribute('data-name');
                
                openDeletePanelModal(panelId, panelName);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === panelModal) {
                closeAllModals();
            }
            if (event.target === deletePanelModal) {
                closeAllModals();
            }
        });
    </script>
</body>
</html>