<?php
// File: admin/reward/achievement.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize messages
$success = '';
$error = '';
$formMode = 'create';
$achievementId = 0;

// Handle achievement deletion
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $deleteId = (int)$_GET['delete'];
    
    // Begin transaction
    $conn->begin_transaction();
    
    try {
        // Delete user achievement progress
        $stmt = $conn->prepare("DELETE FROM user_achievements WHERE achievement_id = ?");
        $stmt->bind_param("i", $deleteId);
        $stmt->execute();
        
        // Delete achievement
        $stmt = $conn->prepare("DELETE FROM achievements WHERE id = ?");
        $stmt->bind_param("i", $deleteId);
        $stmt->execute();
        
        if ($stmt->affected_rows > 0) {
            $conn->commit();
            $success = "Achievement deleted successfully";
        } else {
            throw new Exception("Achievement not found");
        }
    } catch (Exception $e) {
        $conn->rollback();
        $error = "Error: " . $e->getMessage();
    }
}

// Handle edit request
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $achievementId = (int)$_GET['edit'];
    $formMode = 'edit';
    
    // Fetch achievement details
    $stmt = $conn->prepare("SELECT * FROM achievements WHERE id = ?");
    $stmt->bind_param("i", $achievementId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $achievement = $result->fetch_assoc();
    } else {
        $error = "Achievement not found";
        $formMode = 'create';
    }
}

// Handle form submission for create/edit
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_achievement'])) {
    // Get form data
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $icon = trim($_POST['icon']);
    $requirementType = trim($_POST['requirement_type']);
    $requirementValue = (float)$_POST['requirement_value'];
    $requirementPeriod = isset($_POST['requirement_period']) ? trim($_POST['requirement_period']) : null;
    $rewardType = trim($_POST['reward_type']);
    $rewardAmount = (float)$_POST['reward_amount'];
    $badgeColor = trim($_POST['badge_color']);
    $isRepeatable = isset($_POST['is_repeatable']) ? 1 : 0;
    $isActive = isset($_POST['is_active']) ? 1 : 0;
    
    // Additional requirements based on type
    $requirementDetails = [];
    
    if ($requirementType === 'specific_plan') {
        $requirementDetails['plan_id'] = (int)$_POST['specific_plan_id'];
        $requirementDetails['data_type_id'] = isset($_POST['specific_data_type_id']) ? (int)$_POST['specific_data_type_id'] : null;
    } elseif ($requirementType === 'consecutive_days') {
        $requirementDetails['min_transactions'] = (int)$_POST['min_transactions_per_day'];
        $requirementDetails['consecutive_days'] = (int)$_POST['consecutive_days'];
    }
    
    // Validate inputs
    $isValid = true;
    if (empty($title)) {
        $error = "Title is required";
        $isValid = false;
    } elseif (empty($description)) {
        $error = "Description is required";
        $isValid = false;
    } elseif ($requirementValue <= 0) {
        $error = "Requirement value must be greater than zero";
        $isValid = false;
    } elseif ($rewardAmount <= 0) {
        $error = "Reward amount must be greater than zero";
        $isValid = false;
    }
    
    if ($isValid) {
        // JSON encode requirement details
        $requirementDetailsJson = !empty($requirementDetails) ? json_encode($requirementDetails) : null;
        
        if ($_POST['form_mode'] === 'create') {
            // Insert new achievement
            $stmt = $conn->prepare("
                INSERT INTO achievements 
                (title, description, icon, requirement_type, requirement_value, requirement_period, 
                requirement_details, reward_type, reward_amount, badge_color, is_repeatable, is_active) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
            ");
            
            $stmt->bind_param(
                "ssssdssdssii",
                $title,
                $description,
                $icon,
                $requirementType,
                $requirementValue,
                $requirementPeriod,
                $requirementDetailsJson,
                $rewardType,
                $rewardAmount,
                $badgeColor,
                $isRepeatable,
                $isActive
            );
            
            if ($stmt->execute()) {
                $success = "Achievement created successfully";
                
                // Clear form data for new entry
                unset($achievement);
                $formMode = 'create';
            } else {
                $error = "Error creating achievement: " . $stmt->error;
            }
        } else {
            // Update existing achievement
            $achievementId = (int)$_POST['achievement_id'];
            
            $stmt = $conn->prepare("
                UPDATE achievements SET
                title = ?, 
                description = ?, 
                icon = ?, 
                requirement_type = ?, 
                requirement_value = ?, 
                requirement_period = ?, 
                requirement_details = ?, 
                reward_type = ?, 
                reward_amount = ?, 
                badge_color = ?, 
                is_repeatable = ?,
                is_active = ?
                WHERE id = ?
            ");
            
            $stmt->bind_param(
                "ssssdssdssiis",
                $title,
                $description,
                $icon,
                $requirementType,
                $requirementValue,
                $requirementPeriod,
                $requirementDetailsJson,
                $rewardType,
                $rewardAmount,
                $badgeColor,
                $isRepeatable,
                $isActive,
                $achievementId
            );
            
            if ($stmt->execute()) {
                $success = "Achievement updated successfully";
                
                // Reset progress for all users if the achievement requirements changed
                if (
                    $_POST['original_requirement_type'] !== $requirementType ||
                    (float)$_POST['original_requirement_value'] !== $requirementValue ||
                    $_POST['original_requirement_period'] !== $requirementPeriod ||
                    $_POST['original_requirement_details'] !== $requirementDetailsJson
                ) {
                    $resetStmt = $conn->prepare("
                        UPDATE user_achievements 
                        SET progress = 0, 
                            progress_data = NULL, 
                            is_completed = 0, 
                            completed_at = NULL,
                            last_calculated_at = NOW()
                        WHERE achievement_id = ? AND is_completed = 0
                    ");
                    $resetStmt->bind_param("i", $achievementId);
                    $resetStmt->execute();
                    
                    $success .= " and user progress has been reset due to requirement changes";
                }
                
                // Redirect to list view to prevent refresh issues
                redirect(ADMIN_URL . '/reward/achievement.php');
            } else {
                $error = "Error updating achievement: " . $stmt->error;
            }
        }
    }
}

// Fetch all achievements for list view
$stmt = $conn->prepare("
    SELECT a.*, 
           (SELECT COUNT(*) FROM user_achievements ua WHERE ua.achievement_id = a.id) as user_count,
           (SELECT COUNT(*) FROM user_achievements ua WHERE ua.achievement_id = a.id AND ua.is_completed = 1) as completed_count
    FROM achievements a
    ORDER BY a.created_at DESC
");
$stmt->execute();
$result = $stmt->get_result();
$achievements = [];

while ($row = $result->fetch_assoc()) {
    $achievements[] = $row;
}

// Fetch data plans (for specific plan type)
$stmt = $conn->prepare("
    SELECT dp.id, dp.name, dp.size, dt.name as data_type, n.name as network
    FROM data_plans dp
    JOIN data_types dt ON dp.data_type_id = dt.id
    JOIN networks n ON dt.network_id = n.id
    WHERE dp.status = 'active'
    ORDER BY n.name, dt.name, dp.price
");
$stmt->execute();
$result = $stmt->get_result();
$dataPlans = [];

while ($row = $result->fetch_assoc()) {
    $dataPlans[] = $row;
}

// Fetch data types
$stmt = $conn->prepare("
    SELECT dt.id, dt.name, n.name as network
    FROM data_types dt
    JOIN networks n ON dt.network_id = n.id
    WHERE dt.status = 'active'
    ORDER BY n.name, dt.name
");
$stmt->execute();
$result = $stmt->get_result();
$dataTypes = [];

while ($row = $result->fetch_assoc()) {
    $dataTypes[] = $row;
}

// Set current page for nav highlighting
$currentPage = 'achievements';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Achievement Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .badge {
            display: inline-flex;
            align-items: center;
            padding: 0.25rem 0.5rem;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .badge-blue {
            background-color: rgba(59, 130, 246, 0.2);
            color: #93c5fd;
        }
        
        .badge-green {
            background-color: rgba(16, 185, 129, 0.2);
            color: #6ee7b7;
        }
        
        .badge-red {
            background-color: rgba(239, 68, 68, 0.2);
            color: #fca5a5;
        }
        
        .badge-yellow {
            background-color: rgba(245, 158, 11, 0.2);
            color: #fcd34d;
        }
        
        .badge-purple {
            background-color: rgba(139, 92, 246, 0.2);
            color: #c4b5fd;
        }
        
        .badge-pink {
            background-color: rgba(236, 72, 153, 0.2);
            color: #f9a8d4;
        }
        
        .badge-indigo {
            background-color: rgba(79, 70, 229, 0.2);
            color: #a5b4fc;
        }
        
        .tab-button {
            padding: 0.5rem 1rem;
            font-weight: 500;
            border-bottom: 2px solid transparent;
        }
        
        .tab-button.active {
            color: var(--accent-color);
            border-bottom-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <!-- Tabs -->
            <div class="border-b border-gray-700 mb-4">
                <div class="flex space-x-4">
                    <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="tab-button active">
                        <i class="fas fa-trophy mr-2"></i> Achievements
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/referral.php" class="tab-button">
                        <i class="fas fa-user-plus mr-2"></i> Referrals
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="tab-button">
                        <i class="fas fa-award mr-2"></i> Referral Contests
                    </a>
                </div>
            </div>
            
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">
                    <?php echo $formMode === 'create' ? 'Create Achievement' : 'Edit Achievement'; ?>
                </h1>
                
                <?php if ($formMode === 'edit'): ?>
                <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="accent-button py-2 px-4 rounded-md text-white">
                    <i class="fas fa-plus mr-2"></i> New Achievement
                </a>
                <?php endif; ?>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Create/Edit Achievement Form -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <form method="POST" action="">
                    <input type="hidden" name="form_mode" value="<?php echo $formMode; ?>">
                    
                    <?php if ($formMode === 'edit'): ?>
                    <input type="hidden" name="achievement_id" value="<?php echo $achievement['id']; ?>">
                    <input type="hidden" name="original_requirement_type" value="<?php echo $achievement['requirement_type']; ?>">
                    <input type="hidden" name="original_requirement_value" value="<?php echo $achievement['requirement_value']; ?>">
                    <input type="hidden" name="original_requirement_period" value="<?php echo $achievement['requirement_period']; ?>">
                    <input type="hidden" name="original_requirement_details" value="<?php echo $achievement['requirement_details']; ?>">
                    <?php endif; ?>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <!-- Basic Information -->
                        <div>
                            <h3 class="text-lg font-medium text-white mb-4">Basic Information</h3>
                            
                            <div class="mb-4">
                                <label for="title" class="block text-sm font-medium text-gray-400 mb-1">Achievement Title</label>
                                <input type="text" id="title" name="title" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($achievement) ? htmlspecialchars($achievement['title']) : ''; ?>" required>
                            </div>
                            
                            <div class="mb-4">
                                <label for="description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                                <textarea id="description" name="description" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo isset($achievement) ? htmlspecialchars($achievement['description']) : ''; ?></textarea>
                                <p class="text-sm text-gray-500 mt-1">Explain what users need to do to earn this achievement</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="icon" class="block text-sm font-medium text-gray-400 mb-1">Icon</label>
                                <div class="flex">
                                    <select id="icon" name="icon" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="trophy" <?php echo (isset($achievement) && $achievement['icon'] === 'trophy') ? 'selected' : ''; ?>>Trophy</option>
                                        <option value="star" <?php echo (isset($achievement) && $achievement['icon'] === 'star') ? 'selected' : ''; ?>>Star</option>
                                        <option value="medal" <?php echo (isset($achievement) && $achievement['icon'] === 'medal') ? 'selected' : ''; ?>>Medal</option>
                                        <option value="badge" <?php echo (isset($achievement) && $achievement['icon'] === 'badge') ? 'selected' : ''; ?>>Badge</option>
                                        <option value="award" <?php echo (isset($achievement) && $achievement['icon'] === 'award') ? 'selected' : ''; ?>>Award</option>
                                        <option value="crown" <?php echo (isset($achievement) && $achievement['icon'] === 'crown') ? 'selected' : ''; ?>>Crown</option>
                                        <option value="certificate" <?php echo (isset($achievement) && $achievement['icon'] === 'certificate') ? 'selected' : ''; ?>>Certificate</option>
                                        <option value="gift" <?php echo (isset($achievement) && $achievement['icon'] === 'gift') ? 'selected' : ''; ?>>Gift</option>
                                        <option value="coin" <?php echo (isset($achievement) && $achievement['icon'] === 'coin') ? 'selected' : ''; ?>>Coin</option>
                                        <option value="money" <?php echo (isset($achievement) && $achievement['icon'] === 'money') ? 'selected' : ''; ?>>Money</option>
                                        <option value="wallet" <?php echo (isset($achievement) && $achievement['icon'] === 'wallet') ? 'selected' : ''; ?>>Wallet</option>
                                        <option value="phone" <?php echo (isset($achievement) && $achievement['icon'] === 'phone') ? 'selected' : ''; ?>>Phone</option>
                                        <option value="wifi" <?php echo (isset($achievement) && $achievement['icon'] === 'wifi') ? 'selected' : ''; ?>>WiFi</option>
                                    </select>
                                    <div class="ml-2 w-10 h-10 rounded-full bg-gray-700 flex items-center justify-center">
                                        <i id="iconPreview" class="fas fa-trophy text-yellow-400"></i>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="badge_color" class="block text-sm font-medium text-gray-400 mb-1">Badge Color</label>
                                <div class="flex">
                                    <select id="badge_color" name="badge_color" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="blue" <?php echo (isset($achievement) && $achievement['badge_color'] === 'blue') ? 'selected' : ''; ?>>Blue</option>
                                        <option value="green" <?php echo (isset($achievement) && $achievement['badge_color'] === 'green') ? 'selected' : ''; ?>>Green</option>
                                        <option value="red" <?php echo (isset($achievement) && $achievement['badge_color'] === 'red') ? 'selected' : ''; ?>>Red</option>
                                        <option value="yellow" <?php echo (isset($achievement) && $achievement['badge_color'] === 'yellow') ? 'selected' : ''; ?>>Yellow</option>
                                        <option value="purple" <?php echo (isset($achievement) && $achievement['badge_color'] === 'purple') ? 'selected' : ''; ?>>Purple</option>
                                        <option value="pink" <?php echo (isset($achievement) && $achievement['badge_color'] === 'pink') ? 'selected' : ''; ?>>Pink</option>
                                        <option value="indigo" <?php echo (isset($achievement) && $achievement['badge_color'] === 'indigo') ? 'selected' : ''; ?>>Indigo</option>
                                    </select>
                                    <div class="ml-2">
                                        <span id="badgePreview" class="badge badge-blue">Preview</span>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <div class="flex items-center">
                                    <input type="checkbox" id="is_active" name="is_active" class="form-checkbox h-4 w-4 text-indigo-600 rounded border-gray-700 focus:ring-indigo-500" 
                                           <?php echo (!isset($achievement) || $achievement['is_active'] == 1) ? 'checked' : ''; ?>>
                                    <label for="is_active" class="ml-2 text-gray-300">Active</label>
                                </div>
                                <p class="text-sm text-gray-500 mt-1">Inactive achievements won't be visible to users</p>
                            </div>
                        </div>
                        
                        <!-- Requirements & Rewards -->
                        <div>
                            <h3 class="text-lg font-medium text-white mb-4">Requirements & Rewards</h3>
                            
                            <div class="mb-4">
                                <label for="requirement_type" class="block text-sm font-medium text-gray-400 mb-1">Requirement Type</label>
                                <select id="requirement_type" name="requirement_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                    <option value="">Select a requirement type...</option>
                                    <option value="transaction_count" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'transaction_count') ? 'selected' : ''; ?>>Transaction Count</option>
                                    <option value="airtime_purchase" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'airtime_purchase') ? 'selected' : ''; ?>>Airtime Purchase</option>
                                    <option value="data_purchase" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'data_purchase') ? 'selected' : ''; ?>>Data Purchase</option>
                                    <option value="wallet_balance" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'wallet_balance') ? 'selected' : ''; ?>>Wallet Balance</option>
                                    <option value="funding_total" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'funding_total') ? 'selected' : ''; ?>>Total Funding</option>
                                    <option value="specific_plan" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'specific_plan') ? 'selected' : ''; ?>>Specific Data Plan</option>
                                    <option value="consecutive_days" <?php echo (isset($achievement) && $achievement['requirement_type'] === 'consecutive_days') ? 'selected' : ''; ?>>Consecutive Days</option>
                                </select>
                            </div>
                            
                            <!-- Dynamic fields based on requirement type -->
                            <div id="transaction_count_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Number of Transactions</label>
                                    <input type="number" id="requirement_value_transaction" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                    <p class="text-sm text-gray-500 mt-1">Required number of transactions</p>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_period" class="block text-sm font-medium text-gray-400 mb-1">Time Period</label>
                                    <select id="requirement_period_transaction" data-target="requirement_period" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="day">Day</option>
                                        <option value="week">Week</option>
                                        <option value="month">Month</option>
                                        <option value="year">Year</option>
                                        <option value="all_time">All Time</option>
                                    </select>
                                </div>
                            </div>
                            
                            <div id="airtime_purchase_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Airtime Amount</label>
                                    <input type="number" id="requirement_value_airtime" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                    <p class="text-sm text-gray-500 mt-1">Amount in naira (₦)</p>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_period" class="block text-sm font-medium text-gray-400 mb-1">Time Period</label>
                                    <select id="requirement_period_airtime" data-target="requirement_period" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="single">Single Transaction</option>
                                        <option value="day">Day</option>
                                        <option value="week">Week</option>
                                        <option value="month">Month</option>
                                        <option value="all_time">All Time</option>
                                    </select>
                                </div>
                            </div>
                            
                            <div id="data_purchase_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Number of Data Purchases</label>
                                    <input type="number" id="requirement_value_data" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_period" class="block text-sm font-medium text-gray-400 mb-1">Time Period</label>
                                    <select id="requirement_period_data" data-target="requirement_period" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="day">Day</option>
                                        <option value="week">Week</option>
                                        <option value="month">Month</option>
                                        <option value="year">Year</option>
                                        <option value="all_time">All Time</option>
                                    </select>
                                </div>
                            </div>
                            
                            <div id="wallet_balance_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Minimum Balance</label>
                                    <input type="number" id="requirement_value_balance" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                    <p class="text-sm text-gray-500 mt-1">Amount in naira (₦)</p>
                                </div>
                            </div>
                            
                            <div id="funding_total_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Total Funding Amount</label>
                                    <input type="number" id="requirement_value_funding" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                    <p class="text-sm text-gray-500 mt-1">Amount in naira (₦)</p>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_period" class="block text-sm font-medium text-gray-400 mb-1">Time Period</label>
                                    <select id="requirement_period_funding" data-target="requirement_period" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="day">Day</option>
                                        <option value="week">Week</option>
                                        <option value="month">Month</option>
                                        <option value="year">Year</option>
                                        <option value="all_time">All Time</option>
                                    </select>
                                </div>
                            </div>
                            
                            <div id="specific_plan_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="specific_data_type_id" class="block text-sm font-medium text-gray-400 mb-1">Data Type (Optional)</label>
                                    <select id="specific_data_type_id" name="specific_data_type_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="">Any Data Type</option>
                                        <?php foreach ($dataTypes as $dataType): ?>
                                            <option value="<?php echo $dataType['id']; ?>" 
                                                <?php 
                                                    if (isset($achievement) && $achievement['requirement_type'] === 'specific_plan') {
                                                        $details = json_decode($achievement['requirement_details'], true);
                                                        if (isset($details['data_type_id']) && $details['data_type_id'] == $dataType['id']) {
                                                            echo 'selected';
                                                        }
                                                    }
                                                ?>>
                                                <?php echo htmlspecialchars($dataType['network'] . ' - ' . $dataType['name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="specific_plan_id" class="block text-sm font-medium text-gray-400 mb-1">Data Plan</label>
                                    <select id="specific_plan_id" name="specific_plan_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="">Select a data plan...</option>
                                        <?php foreach ($dataPlans as $plan): ?>
                                            <option value="<?php echo $plan['id']; ?>" 
                                                <?php 
                                                    if (isset($achievement) && $achievement['requirement_type'] === 'specific_plan') {
                                                        $details = json_decode($achievement['requirement_details'], true);
                                                        if (isset($details['plan_id']) && $details['plan_id'] == $plan['id']) {
                                                            echo 'selected';
                                                        }
                                                    }
                                                ?>>
                                                <?php echo htmlspecialchars($plan['network'] . ' - ' . $plan['data_type'] . ' - ' . $plan['name'] . ' (' . $plan['size'] . ')'); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1">Number of Purchases</label>
                                    <input type="number" id="requirement_value_specific" data-target="requirement_value" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1">
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_period" class="block text-sm font-medium text-gray-400 mb-1">Time Period</label>
                                    <select id="requirement_period_specific" data-target="requirement_period" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="all_time">All Time</option>
                                        <option value="day">Day</option>
                                        <option value="week">Week</option>
                                        <option value="month">Month</option>
                                        <option value="year">Year</option>
                                    </select>
                                </div>
                            </div>
                            
                            <div id="consecutive_days_fields" class="requirement-fields hidden">
                                <div class="mb-4">
                                    <label for="consecutive_days" class="block text-sm font-medium text-gray-400 mb-1">Number of Consecutive Days</label>
                                    <input type="number" id="consecutive_days" name="consecutive_days" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1" value="<?php 
                                        if (isset($achievement) && $achievement['requirement_type'] === 'consecutive_days') {
                                            $details = json_decode($achievement['requirement_details'], true);
                                            echo isset($details['consecutive_days']) ? $details['consecutive_days'] : 5;
                                        } else {
                                            echo 5;
                                        }
                                    ?>">
                                </div>
                                
                                <div class="mb-4">
                                    <label for="min_transactions_per_day" class="block text-sm font-medium text-gray-400 mb-1">Minimum Transactions Per Day</label>
                                    <input type="number" id="min_transactions_per_day" name="min_transactions_per_day" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1" value="<?php 
                                        if (isset($achievement) && $achievement['requirement_type'] === 'consecutive_days') {
                                            $details = json_decode($achievement['requirement_details'], true);
                                            echo isset($details['min_transactions']) ? $details['min_transactions'] : 1;
                                        } else {
                                            echo 1;
                                        }
                                    ?>">
                                </div>
                                
                                <div class="mb-4">
                                    <label for="requirement_value" class="block text-sm font-medium text-gray-400 mb-1 hidden">Requirement Value (Hidden)</label>
                                    <input type="hidden" id="requirement_value_consecutive" data-target="requirement_value" class="form-input" value="1">
                                </div>
                            </div>
                            
                            <!-- Hidden fields to store actual values -->
                            <input type="hidden" id="requirement_value" name="requirement_value" value="<?php echo isset($achievement) ? $achievement['requirement_value'] : ''; ?>">
                            <input type="hidden" id="requirement_period" name="requirement_period" value="<?php echo isset($achievement) ? $achievement['requirement_period'] : ''; ?>">
                            
                            <hr class="my-6 border-gray-700">
                            
                            <div class="mb-4">
                                <label for="reward_type" class="block text-sm font-medium text-gray-400 mb-1">Reward Type</label>
                                <select id="reward_type" name="reward_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                    <option value="cash" <?php echo (isset($achievement) && $achievement['reward_type'] === 'cash') ? 'selected' : ''; ?>>Cash Reward</option>
                                    <option value="discount" <?php echo (isset($achievement) && $achievement['reward_type'] === 'discount') ? 'selected' : ''; ?>>Discount Coupon</option>
                                    <option value="point" <?php echo (isset($achievement) && $achievement['reward_type'] === 'point') ? 'selected' : ''; ?>>Reward Points</option>
                                </select>
                            </div>
                            
                            <div class="mb-4">
                                <label for="reward_amount" class="block text-sm font-medium text-gray-400 mb-1">Reward Amount</label>
                                <div class="flex">
                                    <span class="inline-flex items-center px-3 py-2 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400" id="reward_currency">₦</span>
                                    <input type="number" id="reward_amount" name="reward_amount" class="form-input block w-full rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" step="1" 
                                           value="<?php echo isset($achievement) ? $achievement['reward_amount'] : ''; ?>" required>
                                </div>
                                <p class="text-sm text-gray-500 mt-1" id="reward_description">Amount to credit to user's wallet</p>
                            </div>
                            
                            <div class="mb-4">
                                <div class="flex items-center">
                                    <input type="checkbox" id="is_repeatable" name="is_repeatable" class="form-checkbox h-4 w-4 text-indigo-600 rounded border-gray-700 focus:ring-indigo-500" 
                                           <?php echo (isset($achievement) && $achievement['is_repeatable'] == 1) ? 'checked' : ''; ?>>
                                    <label for="is_repeatable" class="ml-2 text-gray-300">Repeatable</label>
                                </div>
                                <p class="text-sm text-gray-500 mt-1">Users can earn this achievement multiple times</p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="flex justify-end mt-6">
                        <?php if ($formMode === 'edit'): ?>
                        <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                            Cancel
                        </a>
                        <?php endif; ?>
                        
                        <button type="submit" name="save_achievement" class="accent-button py-2 px-4 rounded-md text-white">
                            <?php echo $formMode === 'create' ? 'Create Achievement' : 'Update Achievement'; ?>
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Achievements List -->
            <div class="mt-10">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-white">All Achievements</h2>
                    <span class="text-gray-400"><?php echo count($achievements); ?> achievements</span>
                </div>
                
                <?php if (empty($achievements)): ?>
                    <div class="admin-card rounded-lg shadow-md p-6 text-center">
                        <i class="fas fa-trophy text-4xl text-gray-600 mb-3"></i>
                        <p class="text-gray-400">No achievements yet. Create your first achievement above.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full border-collapse">
                            <thead>
                                <tr class="bg-gray-800">
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Title</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Requirement</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Reward</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Completions</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-800">
                                <?php foreach ($achievements as $item): ?>
                                    <tr class="hover:bg-gray-800">
                                        <td class="px-4 py-4">
                                            <div class="flex items-center">
                                                <div class="w-10 h-10 rounded-full bg-<?php echo $item['badge_color']; ?>-700 bg-opacity-20 flex items-center justify-center mr-3">
                                                    <i class="fas fa-<?php echo $item['icon']; ?> text-<?php echo $item['badge_color']; ?>-400"></i>
                                                </div>
                                                <div>
                                                    <div class="font-medium text-white"><?php echo htmlspecialchars($item['title']); ?></div>
                                                    <div class="text-sm text-gray-400"><?php echo htmlspecialchars(substr($item['description'], 0, 60) . (strlen($item['description']) > 60 ? '...' : '')); ?></div>
                                                </div>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white">
                                                <?php
                                                    $requirementText = '';
                                                    switch ($item['requirement_type']) {
                                                        case 'transaction_count':
                                                            $period = $item['requirement_period'] !== 'all_time' ? ' per ' . $item['requirement_period'] : '';
                                                            $requirementText = number_format($item['requirement_value']) . ' transactions' . $period;
                                                            break;
                                                        case 'airtime_purchase':
                                                            if ($item['requirement_period'] === 'single') {
                                                                $requirementText = '₦' . number_format($item['requirement_value']) . ' in a single purchase';
                                                            } else {
                                                                $period = $item['requirement_period'] !== 'all_time' ? ' per ' . $item['requirement_period'] : '';
                                                                $requirementText = '₦' . number_format($item['requirement_value']) . ' in airtime' . $period;
                                                            }
                                                            break;
                                                        case 'data_purchase':
                                                            $period = $item['requirement_period'] !== 'all_time' ? ' per ' . $item['requirement_period'] : '';
                                                            $requirementText = number_format($item['requirement_value']) . ' data purchases' . $period;
                                                            break;
                                                        case 'wallet_balance':
                                                            $requirementText = '₦' . number_format($item['requirement_value']) . ' wallet balance';
                                                            break;
                                                        case 'funding_total':
                                                            $period = $item['requirement_period'] !== 'all_time' ? ' per ' . $item['requirement_period'] : ' total';
                                                            $requirementText = '₦' . number_format($item['requirement_value']) . ' funding' . $period;
                                                            break;
                                                        case 'specific_plan':
                                                            $details = json_decode($item['requirement_details'], true);
                                                            $planId = $details['plan_id'] ?? 0;
                                                            $plan = '';
                                                            
                                                            // Find plan name
                                                            foreach ($dataPlans as $dataItem) {
                                                                if ($dataItem['id'] == $planId) {
                                                                    $plan = $dataItem['network'] . ' ' . $dataItem['size'];
                                                                    break;
                                                                }
                                                            }
                                                            
                                                            $period = $item['requirement_period'] !== 'all_time' ? ' per ' . $item['requirement_period'] : '';
                                                            $requirementText = number_format($item['requirement_value']) . ' purchases of ' . $plan . $period;
                                                            break;
                                                        case 'consecutive_days':
                                                            $details = json_decode($item['requirement_details'], true);
                                                            $days = $details['consecutive_days'] ?? 5;
                                                            $minTx = $details['min_transactions'] ?? 1;
                                                            $txText = $minTx > 1 ? $minTx . ' transactions' : '1 transaction';
                                                            $requirementText = 'At least ' . $txText . ' every day for ' . $days . ' consecutive days';
                                                            break;
                                                    }
                                                    echo $requirementText;
                                                ?>
                                            </div>
                                            <div class="text-xs text-gray-500 mt-1">
                                                <?php echo ucwords(str_replace('_', ' ', $item['requirement_type'])); ?>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white">
                                                <?php 
                                                    $rewardText = '';
                                                    switch ($item['reward_type']) {
                                                        case 'cash':
                                                            $rewardText = '₦' . number_format($item['reward_amount']);
                                                            break;
                                                        case 'discount':
                                                            $rewardText = number_format($item['reward_amount']) . '% discount';
                                                            break;
                                                        case 'point':
                                                            $rewardText = number_format($item['reward_amount']) . ' points';
                                                            break;
                                                    }
                                                    echo $rewardText;
                                                ?>
                                            </div>
                                            <div class="text-xs text-gray-500 mt-1">
                                                <?php echo $item['is_repeatable'] ? 'Repeatable' : 'One-time'; ?>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white">
                                                <?php echo number_format($item['completed_count']); ?> / <?php echo number_format($item['user_count']); ?>
                                            </div>
                                            <div class="text-xs text-gray-500 mt-1">
                                                <?php 
                                                    if ($item['user_count'] > 0) {
                                                        $completionRate = ($item['completed_count'] / $item['user_count']) * 100;
                                                        echo number_format($completionRate, 1) . '% completion rate';
                                                    } else {
                                                        echo 'No users yet';
                                                    }
                                                ?>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium <?php echo $item['is_active'] ? 'bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300' : 'bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300'; ?>">
                                                <?php echo $item['is_active'] ? 'Active' : 'Inactive'; ?>
                                            </span>
                                        </td>
                                        <td class="px-4 py-4 text-sm font-medium">
                                            <div class="flex space-x-2">
                                                <a href="?edit=<?php echo $item['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                    <i class="fas fa-edit"></i> Edit
                                                </a>
                                                <a href="javascript:void(0)" onclick="confirmDelete(<?php echo $item['id']; ?>, '<?php echo addslashes($item['title']); ?>')" class="text-red-400 hover:text-red-300">
                                                    <i class="fas fa-trash"></i> Delete
                                                </a>
                                                <a href="<?php echo ADMIN_URL; ?>/reward/achievement_stats.php?id=<?php echo $item['id']; ?>" class="text-blue-400 hover:text-blue-300">
                                                    <i class="fas fa-chart-bar"></i> Stats
                                                </a>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Delete Confirmation Modal -->
    <div id="deleteModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg p-6 max-w-md w-full relative z-10">
            <h3 class="text-xl font-semibold text-white mb-4">Confirm Deletion</h3>
            <p class="text-gray-300 mb-6">Are you sure you want to delete the achievement "<span id="deleteAchievementName"></span>"? This action cannot be undone.</p>
            <div class="flex justify-end space-x-3">
                <button id="cancelDelete" class="px-4 py-2 bg-gray-700 text-white rounded-md">Cancel</button>
                <a id="confirmDeleteBtn" href="#" class="px-4 py-2 bg-red-600 text-white rounded-md">Delete</a>
            </div>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', function() {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', function(e) {
            if (!profileButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Icon Preview
        const iconSelect = document.getElementById('icon');
        const iconPreview = document.getElementById('iconPreview');
        
        iconSelect.addEventListener('change', function() {
            iconPreview.className = 'fas fa-' + this.value + ' text-yellow-400';
        });
        
        // Badge Color Preview
        const badgeColorSelect = document.getElementById('badge_color');
        const badgePreview = document.getElementById('badgePreview');
        
        badgeColorSelect.addEventListener('change', function() {
            badgePreview.className = 'badge badge-' + this.value;
        });
        
        // Reward Type
        const rewardTypeSelect = document.getElementById('reward_type');
        const rewardCurrency = document.getElementById('reward_currency');
        const rewardDescription = document.getElementById('reward_description');
        
        rewardTypeSelect.addEventListener('change', function() {
            switch (this.value) {
                case 'cash':
                    rewardCurrency.textContent = '₦';
                    rewardDescription.textContent = 'Amount to credit to user\'s wallet';
                    break;
                case 'discount':
                    rewardCurrency.textContent = '%';
                    rewardDescription.textContent = 'Discount percentage for next purchase';
                    break;
                case 'point':
                    rewardCurrency.textContent = 'pts';
                    rewardDescription.textContent = 'Reward points to credit to user';
                    break;
            }
        });
        
        // Requirement Type Fields
        const requirementTypeSelect = document.getElementById('requirement_type');
        const requirementFields = document.querySelectorAll('.requirement-fields');
        const mainRequirementValue = document.getElementById('requirement_value');
        const mainRequirementPeriod = document.getElementById('requirement_period');
        
        requirementTypeSelect.addEventListener('change', function() {
            // Hide all requirement fields
            requirementFields.forEach(field => {
                field.classList.add('hidden');
            });
            
            // Show the relevant fields based on selected type
            const selectedFields = document.getElementById(this.value + '_fields');
            if (selectedFields) {
                selectedFields.classList.remove('hidden');
                
                // Set values from hidden fields to visible fields
                const valueField = selectedFields.querySelector('[data-target="requirement_value"]');
                if (valueField && mainRequirementValue.value) {
                    valueField.value = mainRequirementValue.value;
                }
                
                const periodField = selectedFields.querySelector('[data-target="requirement_period"]');
                if (periodField && mainRequirementPeriod.value) {
                    periodField.value = mainRequirementPeriod.value;
                }
            }
        });
        
        // Update hidden fields when visible fields change
        document.querySelectorAll('[data-target]').forEach(field => {
            field.addEventListener('input', function() {
                const target = this.dataset.target;
                document.getElementById(target).value = this.value;
            });
            
            field.addEventListener('change', function() {
                const target = this.dataset.target;
                document.getElementById(target).value = this.value;
            });
        });
        
        // Delete confirmation
        const deleteModal = document.getElementById('deleteModal');
        const deleteAchievementName = document.getElementById('deleteAchievementName');
        const confirmDeleteBtn = document.getElementById('confirmDeleteBtn');
        const cancelDelete = document.getElementById('cancelDelete');
        
        function confirmDelete(id, name) {
            deleteAchievementName.textContent = name;
            confirmDeleteBtn.href = '?delete=' + id;
            deleteModal.classList.remove('hidden');
        }
        
        cancelDelete.addEventListener('click', function() {
            deleteModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        deleteModal.addEventListener('click', function(e) {
            if (e.target === deleteModal) {
                deleteModal.classList.add('hidden');
            }
        });
        
        // Initialize fields based on current values
        window.addEventListener('DOMContentLoaded', function() {
            // Set icon preview
            iconPreview.className = 'fas fa-' + iconSelect.value + ' text-yellow-400';
            
            // Set badge preview
            badgePreview.className = 'badge badge-' + badgeColorSelect.value;
            
            // Set reward type display
            switch (rewardTypeSelect.value) {
                case 'cash':
                    rewardCurrency.textContent = '₦';
                    rewardDescription.textContent = 'Amount to credit to user\'s wallet';
                    break;
                case 'discount':
                    rewardCurrency.textContent = '%';
                    rewardDescription.textContent = 'Discount percentage for next purchase';
                    break;
                case 'point':
                    rewardCurrency.textContent = 'pts';
                    rewardDescription.textContent = 'Reward points to credit to user';
                    break;
            }
            
            // Show correct requirement fields
            if (requirementTypeSelect.value) {
                requirementTypeSelect.dispatchEvent(new Event('change'));
            }
        });
    </script>
</body>
</html>