<?php
// File: admin/reward/contest.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize messages
$success = '';
$error = '';
$formMode = 'create';
$contestId = 0;

// Handle contest deletion
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $deleteId = (int)$_GET['delete'];
    
    // Check if the contest has entries
    $stmt = $conn->prepare("SELECT COUNT(*) as entry_count FROM contest_entries WHERE contest_id = ?");
    $stmt->bind_param("i", $deleteId);
    $stmt->execute();
    $result = $stmt->get_result();
    $entryCount = $result->fetch_assoc()['entry_count'];
    
    if ($entryCount > 0) {
        $error = "Cannot delete contest with existing entries. Deactivate it instead.";
    } else {
        // Delete contest
        $stmt = $conn->prepare("DELETE FROM referral_contests WHERE id = ?");
        $stmt->bind_param("i", $deleteId);
        $stmt->execute();
        
        if ($stmt->affected_rows > 0) {
            $success = "Contest deleted successfully";
        } else {
            $error = "Contest not found";
        }
    }
}

// Handle contest elimination
if (isset($_GET['eliminate']) && is_numeric($_GET['eliminate'])) {
    $contestId = (int)$_GET['eliminate'];
    
    // Get contest info
    $stmt = $conn->prepare("SELECT * FROM referral_contests WHERE id = ?");
    $stmt->bind_param("i", $contestId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = "Contest not found";
    } else {
        $contest = $result->fetch_assoc();
        
        // Check if contest has elimination_threshold set
        if (empty($contest['elimination_threshold'])) {
            $error = "This contest doesn't have an elimination threshold set";
        } else {
            try {
                // Start transaction
                $conn->begin_transaction();
                
                // Find entries to eliminate
                $stmt = $conn->prepare("
                    SELECT ce.id, ce.user_id, ce.referral_count, u.username
                    FROM contest_entries ce
                    JOIN users u ON ce.user_id = u.id
                    WHERE ce.contest_id = ? 
                    AND ce.is_disqualified = 0
                    ORDER BY ce.referral_count ASC, ce.created_at DESC
                ");
                $stmt->bind_param("i", $contestId);
                $stmt->execute();
                $result = $stmt->get_result();
                
                $entries = [];
                while ($row = $result->fetch_assoc()) {
                    $entries[] = $row;
                }
                
                // Calculate how many to eliminate
                $totalEntries = count($entries);
                $threshold = $contest['elimination_threshold'];
                $toEliminate = min($threshold, $totalEntries);
                $eliminatedCount = 0;
                
                if ($toEliminate > 0) {
                    // Eliminate bottom entries
                    for ($i = 0; $i < $toEliminate; $i++) {
                        $entry = $entries[$i];
                        
                        $stmt = $conn->prepare("
                            UPDATE contest_entries
                            SET is_disqualified = 1,
                                disqualification_reason = ?
                            WHERE id = ?
                        ");
                        $reason = "Eliminated in contest round on " . date('M d, Y') . " (bottom performer)";
                        $stmt->bind_param("si", $reason, $entry['id']);
                        $stmt->execute();
                        
                        // Create notification for user
                        $userId = $entry['user_id'];
                        $notifyTitle = "Contest Elimination";
                        $notifyMessage = "You have been eliminated from the contest: " . $contest['title'] . ". Your final position: " . ($totalEntries - $i) . "/" . $totalEntries . ".";
                        
                        $stmt = $conn->prepare("
                            INSERT INTO notifications
                            (user_id, title, message, type, is_read)
                            VALUES (?, ?, ?, 'warning', 0)
                        ");
                        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
                        $stmt->execute();
                        
                        $eliminatedCount++;
                    }
                    
                    // Create elimination log
                    $stmt = $conn->prepare("
                        INSERT INTO contest_elimination_logs
                        (contest_id, elimination_date, elimination_threshold, users_eliminated)
                        VALUES (?, NOW(), ?, ?)
                    ");
                    $stmt->bind_param("iii", $contestId, $threshold, $eliminatedCount);
                    $stmt->execute();
                    
                    $conn->commit();
                    $success = "Successfully eliminated " . $eliminatedCount . " participants from the contest";
                } else {
                    $error = "No participants to eliminate";
                    $conn->rollback();
                }
            } catch (Exception $e) {
                $conn->rollback();
                $error = "Error during elimination: " . $e->getMessage();
            }
        }
    }
}

// Handle manual disqualification
if (isset($_POST['disqualify_user']) && isset($_POST['entry_id']) && isset($_POST['disqualification_reason'])) {
    $entryId = (int)$_POST['entry_id'];
    $reason = sanitizeInput($_POST['disqualification_reason']);
    
    if (empty($reason)) {
        $error = "Disqualification reason is required";
    } else {
        try {
            // Start transaction
            $conn->begin_transaction();
            
            // Get entry info
            $stmt = $conn->prepare("
                SELECT ce.*, c.title as contest_title, u.id as user_id, u.username
                FROM contest_entries ce
                JOIN referral_contests c ON ce.contest_id = c.id
                JOIN users u ON ce.user_id = u.id
                WHERE ce.id = ?
            ");
            $stmt->bind_param("i", $entryId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows === 0) {
                throw new Exception("Entry not found");
            }
            
            $entry = $result->fetch_assoc();
            
            // Update entry
            $stmt = $conn->prepare("
                UPDATE contest_entries
                SET is_disqualified = 1,
                    disqualification_reason = ?
                WHERE id = ?
            ");
            $stmt->bind_param("si", $reason, $entryId);
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to update entry");
            }
            
            // Create notification for user
            $userId = $entry['user_id'];
            $notifyTitle = "Contest Disqualification";
            $notifyMessage = "You have been disqualified from the contest: " . $entry['contest_title'] . ". Reason: " . $reason;
            
            $stmt = $conn->prepare("
                INSERT INTO notifications
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'error', 0)
            ");
            $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
            $stmt->execute();
            
            // Commit transaction
            $conn->commit();
            
            $success = "User " . $entry['username'] . " has been disqualified from the contest";
        } catch (Exception $e) {
            $conn->rollback();
            $error = $e->getMessage();
        }
    }
}

// Handle manual referral count adjustment
if (isset($_POST['adjust_referrals']) && isset($_POST['entry_id']) && isset($_POST['adjustment'])) {
    $entryId = (int)$_POST['entry_id'];
    $adjustment = (int)$_POST['adjustment'];
    
    try {
        // Start transaction
        $conn->begin_transaction();
        
        // Get entry info
        $stmt = $conn->prepare("
            SELECT ce.*, u.username 
            FROM contest_entries ce
            JOIN users u ON ce.user_id = u.id
            WHERE ce.id = ?
        ");
        $stmt->bind_param("i", $entryId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            throw new Exception("Entry not found");
        }
        
        $entry = $result->fetch_assoc();
        
        // Update manual adjustment
        $stmt = $conn->prepare("
            UPDATE contest_entries
            SET manual_adjustment = ?
            WHERE id = ?
        ");
        $stmt->bind_param("ii", $adjustment, $entryId);
        
        if (!$stmt->execute()) {
            throw new Exception("Failed to update entry");
        }
        
        // Commit transaction
        $conn->commit();
        
        $success = "Referral count for " . $entry['username'] . " has been adjusted by " . $adjustment;
    } catch (Exception $e) {
        $conn->rollback();
        $error = $e->getMessage();
    }
}

// Handle edit request
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $contestId = (int)$_GET['edit'];
    $formMode = 'edit';
    
    // Fetch contest details
    $stmt = $conn->prepare("SELECT * FROM referral_contests WHERE id = ?");
    $stmt->bind_param("i", $contestId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $contest = $result->fetch_assoc();
    } else {
        $error = "Contest not found";
        $formMode = 'create';
    }
}

// Handle viewing contest results
if (isset($_GET['view']) && is_numeric($_GET['view'])) {
    $viewId = (int)$_GET['view'];
    redirect(ADMIN_URL . '/reward/contest_results.php?id=' . $viewId);
}

// Handle form submission for create/edit
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_contest'])) {
    // Get form data
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $startDate = $_POST['start_date'];
    $endDate = $_POST['end_date'];
    $prefix = trim($_POST['prefix'] ?? '');
    $suffix = trim($_POST['suffix'] ?? '');
    $minReferrals = (int)$_POST['min_referrals'];
    $entryFee = (float)$_POST['entry_fee'];
    $prizePool = (float)$_POST['prize_pool'];
    $firstPrize = (float)$_POST['first_prize'];
    $secondPrize = (float)($_POST['second_prize'] ?? 0);
    $thirdPrize = (float)($_POST['third_prize'] ?? 0);
    $participationReward = (float)($_POST['participation_reward'] ?? 0);
    $perReferralReward = (float)($_POST['per_referral_reward'] ?? 0);
    $groupLink = trim($_POST['group_link'] ?? '');
    $isElimination = isset($_POST['is_elimination']) ? 1 : 0;
    $eliminationFrequency = $isElimination ? sanitizeInput($_POST['elimination_frequency']) : null;
    $eliminationThreshold = $isElimination ? (int)$_POST['elimination_threshold'] : null;
    $isActive = isset($_POST['is_active']) ? 1 : 0;
    
    // Validate inputs
    $isValid = true;
    if (empty($title)) {
        $error = "Title is required";
        $isValid = false;
    } elseif (empty($description)) {
        $error = "Description is required";
        $isValid = false;
    } elseif (empty($startDate) || empty($endDate)) {
        $error = "Start and end dates are required";
        $isValid = false;
    } elseif (strtotime($startDate) >= strtotime($endDate)) {
        $error = "End date must be after start date";
        $isValid = false;
    } elseif ($minReferrals < 1) {
        $error = "Minimum referrals must be at least 1";
        $isValid = false;
    } elseif ($entryFee < 0) {
        $error = "Entry fee cannot be negative";
        $isValid = false;
    } elseif ($firstPrize <= 0) {
        $error = "First prize must be greater than zero";
        $isValid = false;
    }
    
    // Check if prefix and suffix are valid
    if (!empty($prefix) && !ctype_alnum($prefix)) {
        $error = "Prefix must contain only letters and numbers";
        $isValid = false;
    } elseif (!empty($suffix) && !ctype_alnum($suffix)) {
        $error = "Suffix must contain only letters and numbers";
        $isValid = false;
    }
    
    // Validate elimination settings
    if ($isElimination) {
        if (empty($eliminationFrequency)) {
            $error = "Elimination frequency is required for elimination contests";
            $isValid = false;
        } elseif ($eliminationThreshold <= 0) {
            $error = "Elimination threshold must be greater than zero";
            $isValid = false;
        }
    }
    
    if ($isValid) {
        if ($_POST['form_mode'] === 'create') {
            // Insert new contest
            $stmt = $conn->prepare("
                INSERT INTO referral_contests 
                (title, description, start_date, end_date, prefix, suffix, min_referrals, 
                entry_fee, prize_pool, first_prize, second_prize, third_prize, 
                participation_reward, per_referral_reward, group_link,
                is_elimination, elimination_frequency, elimination_threshold, is_active) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
            ");
            
            $stmt->bind_param(
                "ssssssiiddddddssiii",
                $title,
                $description,
                $startDate,
                $endDate,
                $prefix,
                $suffix,
                $minReferrals,
                $entryFee,
                $prizePool,
                $firstPrize,
                $secondPrize,
                $thirdPrize,
                $participationReward,
                $perReferralReward,
                $groupLink,
                $isElimination,
                $eliminationFrequency,
                $eliminationThreshold,
                $isActive
            );
            
            if ($stmt->execute()) {
                $success = "Contest created successfully";
                
                // Clear form data for new entry
                unset($contest);
                $formMode = 'create';
            } else {
                $error = "Error creating contest: " . $stmt->error;
            }
        } else {
            // Update existing contest
            $contestId = (int)$_POST['contest_id'];
            
            $stmt = $conn->prepare("
                UPDATE referral_contests SET
                title = ?, 
                description = ?, 
                start_date = ?, 
                end_date = ?, 
                prefix = ?, 
                suffix = ?, 
                min_referrals = ?, 
                entry_fee = ?,
                prize_pool = ?,
                first_prize = ?, 
                second_prize = ?, 
                third_prize = ?, 
                participation_reward = ?, 
                per_referral_reward = ?,
                group_link = ?,
                is_elimination = ?,
                elimination_frequency = ?,
                elimination_threshold = ?,
                is_active = ?
                WHERE id = ?
            ");
            
            $stmt->bind_param(
                "ssssssiiddddddssiiii",
                $title,
                $description,
                $startDate,
                $endDate,
                $prefix,
                $suffix,
                $minReferrals,
                $entryFee,
                $prizePool,
                $firstPrize,
                $secondPrize,
                $thirdPrize,
                $participationReward,
                $perReferralReward,
                $groupLink,
                $isElimination,
                $eliminationFrequency,
                $eliminationThreshold,
                $isActive,
                $contestId
            );
            
            if ($stmt->execute()) {
                $success = "Contest updated successfully";
                
                // Redirect to list view to prevent refresh issues
                redirect(ADMIN_URL . '/reward/contest.php');
            } else {
                $error = "Error updating contest: " . $stmt->error;
            }
        }
    }
}

// Fetch all contests for list view
$stmt = $conn->prepare("
    SELECT c.*, 
           (SELECT COUNT(*) FROM contest_entries ce WHERE ce.contest_id = c.id) as entry_count,
           (SELECT SUM(referral_count) FROM contest_entries ce WHERE ce.contest_id = c.id) as total_referrals,
           (SELECT COUNT(*) FROM contest_entries ce WHERE ce.contest_id = c.id AND ce.is_disqualified = 1) as disqualified_count
    FROM referral_contests c
    ORDER BY 
        CASE 
            WHEN c.is_active = 1 AND c.start_date <= NOW() AND c.end_date >= NOW() THEN 1
            WHEN c.is_active = 1 AND c.start_date > NOW() THEN 2
            WHEN c.is_active = 1 AND c.end_date < NOW() THEN 3
            ELSE 4
        END,
        c.start_date DESC
");
$stmt->execute();
$result = $stmt->get_result();
$contests = [];

while ($row = $result->fetch_assoc()) {
    $contests[] = $row;
}

// Set current page for nav highlighting
$currentPage = 'contests';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Referral Contests - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .tab-button {
            padding: 0.5rem 1rem;
            font-weight: 500;
            border-bottom: 2px solid transparent;
        }
        
        .tab-button.active {
            color: var(--accent-color);
            border-bottom-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <!-- Tabs -->
            <div class="border-b border-gray-700 mb-4">
                <div class="flex space-x-4">
                    <a href="<?php echo ADMIN_URL; ?>/reward/achievement.php" class="tab-button">
                        <i class="fas fa-trophy mr-2"></i> Achievements
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/referral.php" class="tab-button">
                        <i class="fas fa-user-plus mr-2"></i> Referrals
                    </a>
                    <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="tab-button active">
                        <i class="fas fa-award mr-2"></i> Referral Contests
                    </a>
                </div>
            </div>
            
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">
                    <?php echo $formMode === 'create' ? 'Create Referral Contest' : 'Edit Referral Contest'; ?>
                </h1>
                
                <?php if ($formMode === 'edit'): ?>
                <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="accent-button py-2 px-4 rounded-md text-white">
                    <i class="fas fa-plus mr-2"></i> New Contest
                </a>
                <?php endif; ?>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Create/Edit Contest Form -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <form method="POST" action="">
                    <input type="hidden" name="form_mode" value="<?php echo $formMode; ?>">
                    
                    <?php if ($formMode === 'edit'): ?>
                    <input type="hidden" name="contest_id" value="<?php echo $contest['id']; ?>">
                    <?php endif; ?>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <!-- Basic Contest Information -->
                        <div>
                            <h3 class="text-lg font-medium text-white mb-4">Contest Details</h3>
                            
                            <div class="mb-4">
                                <label for="title" class="block text-sm font-medium text-gray-400 mb-1">Contest Title</label>
                                <input type="text" id="title" name="title" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? htmlspecialchars($contest['title']) : ''; ?>" required>
                            </div>
                            
                            <div class="mb-4">
                                <label for="description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                                <textarea id="description" name="description" rows="4" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo isset($contest) ? htmlspecialchars($contest['description']) : ''; ?></textarea>
                                <p class="text-sm text-gray-500 mt-1">Explain contest rules and prizes to users</p>
                            </div>
                            
                            <div class="grid grid-cols-1 sm:grid-cols-2 gap-4 mb-4">
                                <div>
                                    <label for="start_date" class="block text-sm font-medium text-gray-400 mb-1">Start Date</label>
                                    <input type="datetime-local" id="start_date" name="start_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                           value="<?php echo isset($contest) ? date('Y-m-d\TH:i', strtotime($contest['start_date'])) : date('Y-m-d\TH:i'); ?>" required>
                                </div>
                                
                                <div>
                                    <label for="end_date" class="block text-sm font-medium text-gray-400 mb-1">End Date</label>
                                    <input type="datetime-local" id="end_date" name="end_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                           value="<?php echo isset($contest) ? date('Y-m-d\TH:i', strtotime($contest['end_date'])) : date('Y-m-d\TH:i', strtotime('+7 days')); ?>" required>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="min_referrals" class="block text-sm font-medium text-gray-400 mb-1">Minimum Referrals to Qualify</label>
                                <input type="number" id="min_referrals" name="min_referrals" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['min_referrals'] : 1; ?>" min="1" step="1" required>
                                <p class="text-sm text-gray-500 mt-1">Number of referrals required to be eligible for rewards</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="entry_fee" class="block text-sm font-medium text-gray-400 mb-1">Entry Fee (₦)</label>
                                <input type="number" id="entry_fee" name="entry_fee" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['entry_fee'] : 0; ?>" min="0" step="1">
                                <p class="text-sm text-gray-500 mt-1">Fee to join the contest (0 for free entry)</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="group_link" class="block text-sm font-medium text-gray-400 mb-1">Group Link (Optional)</label>
                                <input type="url" id="group_link" name="group_link" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? htmlspecialchars($contest['group_link']) : ''; ?>" placeholder="https://chat.whatsapp.com/...">
                                <p class="text-sm text-gray-500 mt-1">Link to WhatsApp, Telegram, or other group for contest participants</p>
                            </div>
                            
                            <div class="mb-4">
                                <div class="flex items-center">
                                    <input type="checkbox" id="is_elimination" name="is_elimination" class="form-checkbox h-4 w-4 text-indigo-600 rounded border-gray-700 focus:ring-indigo-500" 
                                           <?php echo (isset($contest) && $contest['is_elimination'] == 1) ? 'checked' : ''; ?>>
                                    <label for="is_elimination" class="ml-2 text-gray-300">Elimination Contest</label>
                                </div>
                                <p class="text-sm text-gray-500 mt-1">Periodically eliminate participants with the lowest referral counts</p>
                            </div>
                            
                            <div id="elimination_settings" class="p-4 bg-gray-800 rounded-md mb-4 <?php echo (isset($contest) && $contest['is_elimination'] == 1) ? '' : 'hidden'; ?>">
                                <div class="mb-4">
                                    <label for="elimination_frequency" class="block text-sm font-medium text-gray-400 mb-1">Elimination Frequency</label>
                                    <select id="elimination_frequency" name="elimination_frequency" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        <option value="daily" <?php echo (isset($contest) && $contest['elimination_frequency'] === 'daily') ? 'selected' : ''; ?>>Daily</option>
                                        <option value="weekly" <?php echo (isset($contest) && $contest['elimination_frequency'] === 'weekly') ? 'selected' : ''; ?>>Weekly</option>
                                    </select>
                                </div>
                                
                                <div class="mb-2">
                                    <label for="elimination_threshold" class="block text-sm font-medium text-gray-400 mb-1">Elimination Threshold</label>
                                    <input type="number" id="elimination_threshold" name="elimination_threshold" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                           value="<?php echo isset($contest) ? $contest['elimination_threshold'] : 5; ?>" min="1" step="1">
                                    <p class="text-sm text-gray-500 mt-1">Number of participants to eliminate in each round</p>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <div class="flex items-center">
                                    <input type="checkbox" id="is_active" name="is_active" class="form-checkbox h-4 w-4 text-indigo-600 rounded border-gray-700 focus:ring-indigo-500" 
                                           <?php echo (!isset($contest) || $contest['is_active'] == 1) ? 'checked' : ''; ?>>
                                    <label for="is_active" class="ml-2 text-gray-300">Active</label>
                                </div>
                                <p class="text-sm text-gray-500 mt-1">Inactive contests won't be visible to users</p>
                            </div>
                        </div>
                        
                        <!-- Referral Code & Prizes -->
                        <div>
                            <h3 class="text-lg font-medium text-white mb-4">Referral Code & Prizes</h3>
                            
                            <div class="mb-4">
                                <label for="prefix" class="block text-sm font-medium text-gray-400 mb-1">Referral Code Prefix (Optional)</label>
                                <input type="text" id="prefix" name="prefix" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? htmlspecialchars($contest['prefix']) : ''; ?>" placeholder="e.g. SUMMER23_">
                                <p class="text-sm text-gray-500 mt-1">Will be added before username in referral links</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="suffix" class="block text-sm font-medium text-gray-400 mb-1">Referral Code Suffix (Optional)</label>
                                <input type="text" id="suffix" name="suffix" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? htmlspecialchars($contest['suffix']) : ''; ?>" placeholder="e.g. _PROMO">
                                <p class="text-sm text-gray-500 mt-1">Will be added after username in referral links</p>
                            </div>
                            
                            <div id="referral_example" class="mb-6 p-3 bg-gray-800 rounded-md text-sm">
                                <p class="mb-1 text-gray-400">Example Referral Link:</p>
                                <p class="font-mono text-indigo-400 break-all" id="example_link"></p>
                            </div>
                            
                            <h4 class="font-medium text-white mb-3">Prize Structure</h4>
                            
                            <div class="mb-4">
                                <label for="prize_pool" class="block text-sm font-medium text-gray-400 mb-1">Total Prize Pool (₦)</label>
                                <input type="number" id="prize_pool" name="prize_pool" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['prize_pool'] : 20000; ?>" min="0" step="1">
                                <p class="text-sm text-gray-500 mt-1">Total amount allocated for all prizes (informational)</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="first_prize" class="block text-sm font-medium text-gray-400 mb-1">First Place Prize (₦)</label>
                                <input type="number" id="first_prize" name="first_prize" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['first_prize'] : 10000; ?>" min="1" step="1" required>
                            </div>
                            
                            <div class="mb-4">
                                <label for="second_prize" class="block text-sm font-medium text-gray-400 mb-1">Second Place Prize (₦)</label>
                                <input type="number" id="second_prize" name="second_prize" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['second_prize'] : 5000; ?>" min="0" step="1">
                            </div>
                            
                            <div class="mb-4">
                                <label for="third_prize" class="block text-sm font-medium text-gray-400 mb-1">Third Place Prize (₦)</label>
                                <input type="number" id="third_prize" name="third_prize" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['third_prize'] : 3000; ?>" min="0" step="1">
                            </div>
                            
                            <div class="mb-4">
                                <label for="participation_reward" class="block text-sm font-medium text-gray-400 mb-1">Participation Reward (₦)</label>
                                <input type="number" id="participation_reward" name="participation_reward" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['participation_reward'] : 1000; ?>" min="0" step="1">
                                <p class="text-sm text-gray-500 mt-1">Given to all participants who meet minimum referrals</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="per_referral_reward" class="block text-sm font-medium text-gray-400 mb-1">Per Referral Reward (₦)</label>
                                <input type="number" id="per_referral_reward" name="per_referral_reward" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                       value="<?php echo isset($contest) ? $contest['per_referral_reward'] : 0; ?>" min="0" step="1">
                                <p class="text-sm text-gray-500 mt-1">Additional reward per successful referral</p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="flex justify-end mt-6">
                        <?php if ($formMode === 'edit'): ?>
                        <a href="<?php echo ADMIN_URL; ?>/reward/contest.php" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                            Cancel
                        </a>
                        <?php endif; ?>
                        
                        <button type="submit" name="save_contest" class="accent-button py-2 px-4 rounded-md text-white">
                            <?php echo $formMode === 'create' ? 'Create Contest' : 'Update Contest'; ?>
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Contests List -->
            <div class="mt-10">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-white">All Referral Contests</h2>
                    <span class="text-gray-400"><?php echo count($contests); ?> contests</span>
                </div>
                
                <?php if (empty($contests)): ?>
                    <div class="admin-card rounded-lg shadow-md p-6 text-center">
                        <i class="fas fa-award text-4xl text-gray-600 mb-3"></i>
                        <p class="text-gray-400">No contests yet. Create your first contest above.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full border-collapse">
                            <thead>
                                <tr class="bg-gray-800">
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Title</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Period</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Entry Fee</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Prizes</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Entries</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="px-4 py-3 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-800">
                                <?php foreach ($contests as $item): 
                                    $isActive = $item['is_active'] == 1;
                                    $hasStarted = strtotime($item['start_date']) <= time();
                                    $hasEnded = strtotime($item['end_date']) < time();
                                    
                                    $status = 'inactive';
                                    if ($isActive) {
                                        if (!$hasStarted) {
                                            $status = 'upcoming';
                                        } elseif ($hasEnded) {
                                            $status = 'ended';
                                        } else {
                                            $status = 'active';
                                        }
                                    }
                                ?>
                                    <tr class="hover:bg-gray-800">
                                        <td class="px-4 py-4">
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($item['title']); ?></div>
                                            <div class="text-sm text-gray-400"><?php echo htmlspecialchars(substr($item['description'], 0, 60) . (strlen($item['description']) > 60 ? '...' : '')); ?></div>
                                            
                                            <?php if ($item['is_elimination']): ?>
                                                <span class="inline-flex items-center px-2 py-0.5 rounded text-xs font-medium bg-red-900 text-red-200 mt-1">
                                                    <i class="fas fa-fire-alt mr-1"></i> Elimination (<?php echo ucfirst($item['elimination_frequency']); ?>)
                                                </span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white"><?php echo date('M d, Y', strtotime($item['start_date'])); ?></div>
                                            <div class="text-sm text-gray-400">to <?php echo date('M d, Y', strtotime($item['end_date'])); ?></div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white">
                                                <?php 
                                                    if ($item['entry_fee'] > 0) {
                                                        echo formatAmount($item['entry_fee']);
                                                    } else {
                                                        echo '<span class="text-green-400">Free</span>';
                                                    }
                                                ?>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white">
                                                <div>Pool: <?php echo formatAmount($item['prize_pool']); ?></div>
                                                <div class="text-xs text-gray-400">
                                                    1st: <?php echo formatAmount($item['first_prize']); ?>
                                                    <?php if ($item['second_prize'] > 0): ?>, 2nd: <?php echo formatAmount($item['second_prize']); ?><?php endif; ?>
                                                </div>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <div class="text-sm text-white"><?php echo $item['entry_count']; ?> participants</div>
                                            <div class="text-xs text-gray-400">
                                                <?php echo $item['total_referrals'] ? $item['total_referrals'] : 0; ?> total referrals
                                                <?php if ($item['disqualified_count'] > 0): ?>
                                                    <span class="text-red-400">(<?php echo $item['disqualified_count']; ?> disqualified)</span>
                                                <?php endif; ?>
                                            </div>
                                        </td>
                                        <td class="px-4 py-4">
                                            <?php if ($status === 'active'): ?>
                                                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300">
                                                    Active
                                                </span>
                                            <?php elseif ($status === 'upcoming'): ?>
                                                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-300">
                                                    Upcoming
                                                </span>
                                            <?php elseif ($status === 'ended'): ?>
                                                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-100 text-gray-800 dark:bg-gray-700 dark:text-gray-300">
                                                    Ended
                                                </span>
                                            <?php else: ?>
                                                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300">
                                                    Inactive
                                                </span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="px-4 py-4 text-sm font-medium">
                                            <div class="flex flex-col space-y-2">
                                                <div class="flex space-x-2">
                                                    <a href="?edit=<?php echo $item['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                        <i class="fas fa-edit"></i> Edit
                                                    </a>
                                                    <?php if ($item['entry_count'] == 0): ?>
                                                        <a href="javascript:void(0)" onclick="confirmDelete(<?php echo $item['id']; ?>, '<?php echo addslashes($item['title']); ?>')" class="text-red-400 hover:text-red-300">
                                                            <i class="fas fa-trash"></i> Delete
                                                        </a>
                                                    <?php endif; ?>
                                                </div>
                                                
                                                <div class="flex space-x-2">
                                                    <a href="?view=<?php echo $item['id']; ?>" class="text-blue-400 hover:text-blue-300">
                                                        <i class="fas fa-chart-bar"></i> Results
                                                    </a>
                                                    
                                                    <?php if ($status === 'active' && $item['is_elimination'] && $item['entry_count'] > 0): ?>
                                                        <a href="javascript:void(0)" onclick="confirmElimination(<?php echo $item['id']; ?>, '<?php echo addslashes($item['title']); ?>')" class="text-yellow-400 hover:text-yellow-300">
                                                            <i class="fas fa-fire"></i> Run Elimination
                                                        </a>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Delete Confirmation Modal -->
    <div id="deleteModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg p-6 max-w-md w-full relative z-10">
            <h3 class="text-xl font-semibold text-white mb-4">Confirm Deletion</h3>
            <p class="text-gray-300 mb-6">Are you sure you want to delete the contest "<span id="deleteContestName"></span>"? This action cannot be undone.</p>
            <div class="flex justify-end space-x-3">
                <button id="cancelDelete" class="px-4 py-2 bg-gray-700 text-white rounded-md">Cancel</button>
                <a id="confirmDeleteBtn" href="#" class="px-4 py-2 bg-red-600 text-white rounded-md">Delete</a>
            </div>
        </div>
    </div>
    
    <!-- Elimination Confirmation Modal -->
    <div id="eliminationModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg p-6 max-w-md w-full relative z-10">
            <h3 class="text-xl font-semibold text-white mb-4">Confirm Elimination Round</h3>
            <p class="text-gray-300 mb-6">Are you sure you want to run an elimination round for "<span id="eliminationContestName"></span>"? Participants with the lowest referral counts will be eliminated.</p>
            <div class="flex justify-end space-x-3">
                <button id="cancelElimination" class="px-4 py-2 bg-gray-700 text-white rounded-md">Cancel</button>
                <a id="confirmEliminationBtn" href="#" class="px-4 py-2 bg-yellow-600 text-white rounded-md">Run Elimination</a>
            </div>
        </div>
    </div>
    
    <!-- Disqualify User Modal -->
    <div id="disqualifyModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg p-6 max-w-md w-full relative z-10">
            <h3 class="text-xl font-semibold text-white mb-4">Disqualify User</h3>
            <form id="disqualifyForm" method="POST" action="">
                <input type="hidden" id="entry_id" name="entry_id" value="">
                
                <div class="mb-4">
                    <label for="disqualification_reason" class="block text-sm font-medium text-gray-400 mb-1">Reason for Disqualification</label>
                    <textarea id="disqualification_reason" name="disqualification_reason" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" id="cancelDisqualify" class="px-4 py-2 bg-gray-700 text-white rounded-md">Cancel</button>
                    <button type="submit" name="disqualify_user" class="px-4 py-2 bg-red-600 text-white rounded-md">Disqualify</button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Adjust Referrals Modal -->
    <div id="adjustModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg p-6 max-w-md w-full relative z-10">
            <h3 class="text-xl font-semibold text-white mb-4">Adjust Referral Count</h3>
            <form id="adjustForm" method="POST" action="">
                <input type="hidden" id="adjust_entry_id" name="entry_id" value="">
                
                <div class="mb-4">
                    <label for="adjustment" class="block text-sm font-medium text-gray-400 mb-1">Manual Adjustment</label>
                    <input type="number" id="adjustment" name="adjustment" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    <p class="text-sm text-gray-500 mt-1">Positive or negative number to adjust the referral count</p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" id="cancelAdjust" class="px-4 py-2 bg-gray-700 text-white rounded-md">Cancel</button>
                    <button type="submit" name="adjust_referrals" class="px-4 py-2 bg-blue-600 text-white rounded-md">Save Adjustment</button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', function() {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', function(e) {
            if (!profileButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Delete confirmation
        const deleteModal = document.getElementById('deleteModal');
        const deleteContestName = document.getElementById('deleteContestName');
        const confirmDeleteBtn = document.getElementById('confirmDeleteBtn');
        const cancelDelete = document.getElementById('cancelDelete');
        
        function confirmDelete(id, name) {
            deleteContestName.textContent = name;
            confirmDeleteBtn.href = '?delete=' + id;
            deleteModal.classList.remove('hidden');
        }
        
        cancelDelete.addEventListener('click', function() {
            deleteModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        deleteModal.addEventListener('click', function(e) {
            if (e.target === deleteModal) {
                deleteModal.classList.add('hidden');
            }
        });
        
        // Elimination confirmation
        const eliminationModal = document.getElementById('eliminationModal');
        const eliminationContestName = document.getElementById('eliminationContestName');
        const confirmEliminationBtn = document.getElementById('confirmEliminationBtn');
        const cancelElimination = document.getElementById('cancelElimination');
        
        function confirmElimination(id, name) {
            eliminationContestName.textContent = name;
            confirmEliminationBtn.href = '?eliminate=' + id;
            eliminationModal.classList.remove('hidden');
        }
        
        cancelElimination.addEventListener('click', function() {
            eliminationModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        eliminationModal.addEventListener('click', function(e) {
            if (e.target === eliminationModal) {
                eliminationModal.classList.add('hidden');
            }
        });
        
        // Disqualify user modal
        const disqualifyModal = document.getElementById('disqualifyModal');
        const disqualifyForm = document.getElementById('disqualifyForm');
        const entryIdInput = document.getElementById('entry_id');
        const cancelDisqualify = document.getElementById('cancelDisqualify');
        
        function openDisqualifyModal(entryId) {
            entryIdInput.value = entryId;
            disqualifyModal.classList.remove('hidden');
        }
        
        cancelDisqualify.addEventListener('click', function() {
            disqualifyModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        disqualifyModal.addEventListener('click', function(e) {
            if (e.target === disqualifyModal) {
                disqualifyModal.classList.add('hidden');
            }
        });
        
        // Adjust referrals modal
        const adjustModal = document.getElementById('adjustModal');
        const adjustForm = document.getElementById('adjustForm');
        const adjustEntryIdInput = document.getElementById('adjust_entry_id');
        const cancelAdjust = document.getElementById('cancelAdjust');
        
        function openAdjustModal(entryId, currentAdjustment) {
            adjustEntryIdInput.value = entryId;
            document.getElementById('adjustment').value = currentAdjustment || 0;
            adjustModal.classList.remove('hidden');
        }
        
        cancelAdjust.addEventListener('click', function() {
            adjustModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        adjustModal.addEventListener('click', function(e) {
            if (e.target === adjustModal) {
                adjustModal.classList.add('hidden');
            }
        });
        
        // Update example referral link
        function updateExampleLink() {
            const prefix = document.getElementById('prefix').value;
            const suffix = document.getElementById('suffix').value;
            const username = 'username';
            const siteUrl = "<?php echo SITE_URL; ?>";
            
            let refCode = username;
            if (prefix) refCode = prefix + username;
            if (suffix) refCode = refCode + suffix;
            
            const exampleLink = `${siteUrl}/register?ref=${refCode}`;
            document.getElementById('example_link').textContent = exampleLink;
        }
        
        document.getElementById('prefix').addEventListener('input', updateExampleLink);
        document.getElementById('suffix').addEventListener('input', updateExampleLink);
        
        // Show/hide elimination settings
        document.getElementById('is_elimination').addEventListener('change', function() {
            const eliminationSettings = document.getElementById('elimination_settings');
            if (this.checked) {
                eliminationSettings.classList.remove('hidden');
            } else {
                eliminationSettings.classList.add('hidden');
            }
        });
        
        // Initialize on page load
        updateExampleLink();
    </script>
</body>
</html>