<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize variables
$userId = isset($_GET['user_id']) ? (int)$_GET['user_id'] : 0;
$title = '';
$message = '';
$type = 'info';
$sendEmail = false;
$success = '';
$error = '';

// Get user data if user_id is provided
$user = null;
if ($userId > 0) {
    $stmt = $conn->prepare("SELECT id, username, email, status FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
    
    if (!$user) {
        $error = 'User not found';
        $userId = 0;
    }
}

// Get user list for selector
$stmt = $conn->prepare("SELECT id, username, email FROM users ORDER BY username ASC");
$stmt->execute();
$result = $stmt->get_result();
$users = [];

while ($row = $result->fetch_assoc()) {
    $users[] = $row;
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = sanitizeInput($_POST['title']);
    $message = sanitizeInput($_POST['message']);
    $type = sanitizeInput($_POST['type']);
    $sendEmail = isset($_POST['send_email']);
    
    // Validate the form
    if (empty($title)) {
        $error = 'Title is required';
    } elseif (empty($message)) {
        $error = 'Message is required';
    } elseif (!in_array($type, ['info', 'success', 'warning', 'error'])) {
        $error = 'Invalid notification type';
    } else {
        $recipientType = sanitizeInput($_POST['recipient_type']);
        
        if ($recipientType === 'all') {
            // Send to all users
            $stmt = $conn->prepare("SELECT id, username, email FROM users WHERE status = 'active'");
            $stmt->execute();
            $result = $stmt->get_result();
            $recipients = [];
            
            while ($row = $result->fetch_assoc()) {
                $recipients[] = $row;
            }
            
            if (empty($recipients)) {
                $error = 'No active users found';
            } else {
                $notificationsSent = 0;
                $emailsSent = 0;
                
                foreach ($recipients as $recipient) {
                    // Insert notification
                    $stmt = $conn->prepare("
                        INSERT INTO notifications 
                        (user_id, title, message, type, is_read, admin_id)
                        VALUES (?, ?, ?, ?, 0, ?)
                    ");
                    $stmt->bind_param("isssi", $recipient['id'], $title, $message, $type, $adminId);
                    
                    if ($stmt->execute()) {
                        $notificationsSent++;
                        
                        // Send email if requested
                        if ($sendEmail && !empty($recipient['email'])) {
                            $subject = "New Notification from " . getSetting('site_name');
                            $emailMessage = "
                                <p>Hello {$recipient['username']},</p>
                                <p><strong>{$title}</strong></p>
                                <p>{$message}</p>
                                <p>You can log in to your account to view this notification and manage your preferences.</p>
                                <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                            ";
                            
                            if (sendEmail($recipient['email'], $subject, $emailMessage)) {
                                $emailsSent++;
                            }
                        }
                    }
                }
                
                if ($notificationsSent > 0) {
                    $success = "{$notificationsSent} notifications sent successfully" . ($emailsSent > 0 ? " and {$emailsSent} emails sent" : "");
                    
                    // Clear form after successful submission
                    $title = '';
                    $message = '';
                    $type = 'info';
                    $sendEmail = false;
                } else {
                    $error = 'Failed to send notifications';
                }
            }
        } elseif ($recipientType === 'specific') {
            // Send to specific user
            $singleUserId = (int)$_POST['user_id'];
            
            if ($singleUserId <= 0) {
                $error = 'Please select a user';
            } else {
                // Check if user exists
                $stmt = $conn->prepare("SELECT id, username, email FROM users WHERE id = ?");
                $stmt->bind_param("i", $singleUserId);
                $stmt->execute();
                $result = $stmt->get_result();
                $specificUser = $result->fetch_assoc();
                
                if (!$specificUser) {
                    $error = 'Selected user not found';
                } else {
                    // Insert notification
                    $stmt = $conn->prepare("
                        INSERT INTO notifications 
                        (user_id, title, message, type, is_read, admin_id)
                        VALUES (?, ?, ?, ?, 0, ?)
                    ");
                    $stmt->bind_param("isssi", $singleUserId, $title, $message, $type, $adminId);
                    
                    if ($stmt->execute()) {
                        $success = "Notification sent successfully to " . htmlspecialchars($specificUser['username']);
                        
                        // Send email if requested
                        if ($sendEmail && !empty($specificUser['email'])) {
                            $subject = "New Notification from " . getSetting('site_name');
                            $emailMessage = "
                                <p>Hello {$specificUser['username']},</p>
                                <p><strong>{$title}</strong></p>
                                <p>{$message}</p>
                                <p>You can log in to your account to view this notification and manage your preferences.</p>
                                <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                            ";
                            
                            if (sendEmail($specificUser['email'], $subject, $emailMessage)) {
                                $success .= " and email sent";
                            }
                        }
                        
                        // Clear form after successful submission
                        $title = '';
                        $message = '';
                        $type = 'info';
                        $sendEmail = false;
                    } else {
                        $error = 'Failed to send notification';
                    }
                }
            }
        } elseif ($recipientType === 'user_type') {
            // Send to users of a specific type
            $userType = sanitizeInput($_POST['user_type']);
            
            if (!in_array($userType, ['smart', 'vendor', 'api'])) {
                $error = 'Invalid user type selected';
            } else {
                // Get all active users of this type
                $stmt = $conn->prepare("SELECT id, username, email FROM users WHERE user_type = ? AND status = 'active'");
                $stmt->bind_param("s", $userType);
                $stmt->execute();
                $result = $stmt->get_result();
                $typeUsers = [];
                
                while ($row = $result->fetch_assoc()) {
                    $typeUsers[] = $row;
                }
                
                if (empty($typeUsers)) {
                    $error = 'No active users found with the selected user type';
                } else {
                    $notificationsSent = 0;
                    $emailsSent = 0;
                    
                    foreach ($typeUsers as $recipient) {
                        // Insert notification
                        $stmt = $conn->prepare("
                            INSERT INTO notifications 
                            (user_id, title, message, type, is_read, admin_id)
                            VALUES (?, ?, ?, ?, 0, ?)
                        ");
                        $stmt->bind_param("isssi", $recipient['id'], $title, $message, $type, $adminId);
                        
                        if ($stmt->execute()) {
                            $notificationsSent++;
                            
                            // Send email if requested
                            if ($sendEmail && !empty($recipient['email'])) {
                                $subject = "New Notification from " . getSetting('site_name');
                                $emailMessage = "
                                    <p>Hello {$recipient['username']},</p>
                                    <p><strong>{$title}</strong></p>
                                    <p>{$message}</p>
                                    <p>You can log in to your account to view this notification and manage your preferences.</p>
                                    <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                                ";
                                
                                if (sendEmail($recipient['email'], $subject, $emailMessage)) {
                                    $emailsSent++;
                                }
                            }
                        }
                    }
                    
                    if ($notificationsSent > 0) {
                        $success = "{$notificationsSent} notifications sent successfully to " . ucfirst($userType) . " users" . ($emailsSent > 0 ? " and {$emailsSent} emails sent" : "");
                        
                        // Clear form after successful submission
                        $title = '';
                        $message = '';
                        $type = 'info';
                        $sendEmail = false;
                    } else {
                        $error = 'Failed to send notifications';
                    }
                }
            }
        } else {
            $error = 'Please select a recipient type';
        }
    }
}
// Set current page for sidebar highlight
$currentPage = 'send_notification';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Send Notification - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .type-badge {
            display: inline-block;
            padding: 0.25rem 0.5rem;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .type-info {
            background-color: rgba(59, 130, 246, 0.2);
            color: #93c5fd;
        }
        
        .type-success {
            background-color: rgba(16, 185, 129, 0.2);
            color: #6ee7b7;
        }
        
        .type-warning {
            background-color: rgba(245, 158, 11, 0.2);
            color: #fcd34d;
        }
        
        .type-error {
            background-color: rgba(239, 68, 68, 0.2);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
               <!-- Include Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex items-center mb-6">
                <?php if ($userId > 0 && $user): ?>
                    <a href="<?php echo ADMIN_URL; ?>/view_user.php?id=<?php echo $userId; ?>" class="text-indigo-400 hover:text-indigo-300 mr-3">
                        <i class="fas fa-arrow-left"></i> Back to User
                    </a>
                    <h1 class="text-2xl font-bold text-white">Send Notification to <?php echo htmlspecialchars($user['username']); ?></h1>
                <?php else: ?>
                    <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                        <i class="fas fa-arrow-left"></i> Back to Notifications
                    </a>
                    <h1 class="text-2xl font-bold text-white">Send Notification</h1>
                <?php endif; ?>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="admin-card rounded-lg shadow-md p-6">
                <form method="POST" action="">
                    <div class="mb-4">
                        <label class="block text-sm font-medium text-gray-400 mb-2">Recipient</label>
                        <div class="space-y-3">
                            <div class="flex items-center">
                                <input type="radio" id="recipient_specific" name="recipient_type" value="specific" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($userId > 0 || (isset($_POST['recipient_type']) && $_POST['recipient_type'] === 'specific')) ? 'checked' : ''; ?>>
                                <label for="recipient_specific" class="ml-2 text-gray-300">Specific User</label>
                            </div>
                            
                            <div id="user_select_container" class="pl-6 <?php echo ($userId > 0 || (isset($_POST['recipient_type']) && $_POST['recipient_type'] === 'specific')) ? '' : 'hidden'; ?>">
                                <select id="user_id" name="user_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                    <option value="">Select a user...</option>
                                    <?php foreach ($users as $userOption): ?>
                                        <option value="<?php echo $userOption['id']; ?>" <?php echo ($userId > 0 && $userId == $userOption['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($userOption['username']); ?> (<?php echo htmlspecialchars($userOption['email']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            
                            <!-- New option: By User Type -->
                            <div class="flex items-center">
                                <input type="radio" id="recipient_user_type" name="recipient_type" value="user_type" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo (isset($_POST['recipient_type']) && $_POST['recipient_type'] === 'user_type') ? 'checked' : ''; ?>>
                                <label for="recipient_user_type" class="ml-2 text-gray-300">By User Type</label>
                            </div>
                            
                            <div id="user_type_container" class="pl-6 <?php echo (isset($_POST['recipient_type']) && $_POST['recipient_type'] === 'user_type') ? '' : 'hidden'; ?>">
                                <select id="user_type" name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                    <option value="smart" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'smart') ? 'selected' : ''; ?>>Smart Users</option>
                                    <option value="vendor" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'vendor') ? 'selected' : ''; ?>>Vendor Users</option>
                                    <option value="api" <?php echo (isset($_POST['user_type']) && $_POST['user_type'] === 'api') ? 'selected' : ''; ?>>API Users</option>
                                </select>
                                <p class="text-gray-500 text-xs mt-1">Send notification to all active users of the selected type.</p>
                            </div>
                            
                            <div class="flex items-center">
                                <input type="radio" id="recipient_all" name="recipient_type" value="all" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($userId == 0 && (!isset($_POST['recipient_type']) || $_POST['recipient_type'] === 'all')) ? 'checked' : ''; ?>>
                                <label for="recipient_all" class="ml-2 text-gray-300">All Active Users</label>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="type" class="block text-sm font-medium text-gray-400 mb-2">Notification Type</label>
                        <div class="flex space-x-4">
                            <div class="flex items-center">
                                <input type="radio" id="type_info" name="type" value="info" class="form-radio h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($type === 'info') ? 'checked' : ''; ?>>
                                <label for="type_info" class="ml-2 flex items-center">
                                    <span class="type-badge type-info mr-2">Info</span>
                                    <span class="text-gray-300">General information</span>
                                </label>
                            </div>
                            
                            <div class="flex items-center">
                                <input type="radio" id="type_success" name="type" value="success" class="form-radio h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($type === 'success') ? 'checked' : ''; ?>>
                                <label for="type_success" class="ml-2 flex items-center">
                                    <span class="type-badge type-success mr-2">Success</span>
                                    <span class="text-gray-300">Positive news</span>
                                </label>
                            </div>
                            
                            <div class="flex items-center">
                                <input type="radio" id="type_warning" name="type" value="warning" class="form-radio h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($type === 'warning') ? 'checked' : ''; ?>>
                                <label for="type_warning" class="ml-2 flex items-center">
                                    <span class="type-badge type-warning mr-2">Warning</span>
                                    <span class="text-gray-300">Attention needed</span>
                                </label>
                            </div>
                            
                            <div class="flex items-center">
                                <input type="radio" id="type_error" name="type" value="error" class="form-radio h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo ($type === 'error') ? 'checked' : ''; ?>>
                                <label for="type_error" class="ml-2 flex items-center">
                                    <span class="type-badge type-error mr-2">Error</span>
                                    <span class="text-gray-300">Important alert</span>
                                </label>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="title" class="block text-sm font-medium text-gray-400 mb-2">Notification Title</label>
                        <input type="text" id="title" name="title" value="<?php echo htmlspecialchars($title); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div class="mb-4">
                        <label for="message" class="block text-sm font-medium text-gray-400 mb-2">Message</label>
                        <textarea id="message" name="message" rows="4" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo htmlspecialchars($message); ?></textarea>
                    </div>
                    
                    <div class="mb-6">
                        <div class="flex items-center">
                            <input type="checkbox" id="send_email" name="send_email" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800" <?php echo $sendEmail ? 'checked' : ''; ?>>
                            <label for="send_email" class="ml-2 text-gray-300">Also send as an email</label>
                        </div>
                        <p class="text-gray-500 text-xs mt-1">The notification will be sent via email in addition to appearing in the user's dashboard.</p>
                    </div>
                    
                    <div class="flex justify-end">
                        <a href="<?php echo $userId > 0 ? ADMIN_URL . '/view_user.php?id=' . $userId : ADMIN_URL . '/notifications.php'; ?>" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                            Cancel
                        </a>
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            Send Notification
                        </button>
                    </div>
                </form>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Toggle container visibility based on recipient type
            const recipientSpecific = document.getElementById('recipient_specific');
            const recipientUserType = document.getElementById('recipient_user_type');
            const recipientAll = document.getElementById('recipient_all');
            const userSelectContainer = document.getElementById('user_select_container');
            const userTypeContainer = document.getElementById('user_type_container');
            
            recipientSpecific.addEventListener('change', function() {
                if (this.checked) {
                    userSelectContainer.classList.remove('hidden');
                    userTypeContainer.classList.add('hidden');
                }
            });
            
            recipientUserType.addEventListener('change', function() {
                if (this.checked) {
                    userTypeContainer.classList.remove('hidden');
                    userSelectContainer.classList.add('hidden');
                }
            });
            
            recipientAll.addEventListener('change', function() {
                if (this.checked) {
                    userSelectContainer.classList.add('hidden');
                    userTypeContainer.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>