<?php
// File: /admin/services/airtime_networks.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize variables
$network_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
$action = isset($_GET['action']) ? $_GET['action'] : '';
$success = '';
$error = '';

// Get airtime providers
$providers = [];
$stmt = $conn->prepare("SELECT id, name FROM providers WHERE (type = 'airtime' OR type = 'general') AND status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $providers[] = $row;
}

// Process delete action
if ($action == 'delete-mapping' && isset($_GET['mapping_id'])) {
    $mappingId = (int)$_GET['mapping_id'];
    
    $stmt = $conn->prepare("DELETE FROM network_providers WHERE id = ?");
    $stmt->bind_param("i", $mappingId);
    
    if ($stmt->execute()) {
        $success = "Provider mapping deleted successfully";
    } else {
        $error = "Failed to delete provider mapping";
    }
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_mapping'])) {
        $networkId = (int)$_POST['network_id'];
        $providerId = (int)$_POST['provider_id'];
        $providerNetworkId = sanitizeInput($_POST['provider_network_id']);
        $isDefault = isset($_POST['is_default']) ? 1 : 0;
        
        // Validate input
        if ($networkId <= 0) {
            $error = "Please select a network";
        } elseif ($providerId <= 0) {
            $error = "Please select a provider";
        } else {
            // Check if mapping already exists
            $stmt = $conn->prepare("
                SELECT COUNT(*) as count FROM network_providers 
                WHERE network_id = ? AND provider_id = ? AND service_type = 'airtime'
            ");
            $stmt->bind_param("ii", $networkId, $providerId);
            $stmt->execute();
            $result = $stmt->get_result();
            $row = $result->fetch_assoc();
            
            if ($row['count'] > 0) {
                // Update existing mapping
                $stmt = $conn->prepare("
                    UPDATE network_providers 
                    SET provider_network_id = ?, is_default = ? 
                    WHERE network_id = ? AND provider_id = ? AND service_type = 'airtime'
                ");
                $stmt->bind_param("siis", $providerNetworkId, $isDefault, $networkId, $providerId);
            } else {
                // Add new mapping
                $stmt = $conn->prepare("
                    INSERT INTO network_providers (network_id, provider_id, provider_network_id, service_type, is_default) 
                    VALUES (?, ?, ?, 'airtime', ?)
                ");
                $stmt->bind_param("iisi", $networkId, $providerId, $providerNetworkId, $isDefault);
            }
            
            if ($stmt->execute()) {
                // If this is set as default, unset default flag for other mappings
                if ($isDefault) {
                    $stmt = $conn->prepare("
                        UPDATE network_providers 
                        SET is_default = 0 
                        WHERE network_id = ? AND provider_id != ? AND service_type = 'airtime'
                    ");
                    $stmt->bind_param("ii", $networkId, $providerId);
                    $stmt->execute();
                }
                
                $success = "Provider mapping saved successfully";
            } else {
                $error = "Failed to save provider mapping";
            }
        }
    }
}

// Get all networks
$networks = [];
$stmt = $conn->query("SELECT * FROM networks ORDER BY name ASC");
while ($row = $stmt->fetch_assoc()) {
    $networks[] = $row;
}

// Get network provider mappings
$mappings = [];
$stmt = $conn->query("
    SELECT np.*, n.name as network_name, p.name as provider_name 
    FROM network_providers np
    JOIN networks n ON np.network_id = n.id
    JOIN providers p ON np.provider_id = p.id
    WHERE np.service_type = 'airtime'
    ORDER BY n.name ASC, np.is_default DESC
");

while ($row = $stmt->fetch_assoc()) {
    $mappings[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $error = $flashMessage['message'];
    }
}
// Set current page for sidebar highlight
$currentPage = 'airtime';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Airtime Network Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }

        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 44px;
            height: 24px;
        }

        .toggle-switch input { 
            opacity: 0;
            width: 0;
            height: 0;
        }

        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #555;
            transition: .4s;
            border-radius: 24px;
        }

        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 18px;
            width: 18px;
            left: 3px;
            bottom: 3px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }

        input:checked + .toggle-slider {
            background-color: var(--accent-color);
        }

        input:checked + .toggle-slider:before {
            transform: translateX(20px);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
              <!-- Include Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Airtime Network Management</h1>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Provider Mapping Form -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Add Network Provider Mapping</h2>
                
                <form method="POST" action="">
                    <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4 mb-4">
                        <div>
                            <label for="network_id" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                            <select id="network_id" name="network_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                <option value="">Select Network</option>
                                <?php foreach ($networks as $network): ?>
                                    <option value="<?php echo $network['id']; ?>">
                                        <?php echo htmlspecialchars($network['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div>
                            <label for="provider_id" class="block text-sm font-medium text-gray-400 mb-1">Provider</label>
                            <select id="provider_id" name="provider_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                <option value="">Select Provider</option>
                                <?php foreach ($providers as $provider): ?>
                                    <option value="<?php echo $provider['id']; ?>">
                                        <?php echo htmlspecialchars($provider['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div>
                            <label for="provider_network_id" class="block text-sm font-medium text-gray-400 mb-1">Provider Network ID</label>
                            <input type="text" id="provider_network_id" name="provider_network_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="e.g. MTN, GLO, 1, etc." required>
                            <p class="mt-1 text-xs text-gray-500">The network identifier used by the provider's API</p>
                        </div>
                        
                        <div class="flex items-end">
                            <div>
                                <label class="block text-sm font-medium text-gray-400 mb-1">Default Provider</label>
                                <label class="toggle-switch mt-1">
                                    <input type="checkbox" name="is_default" checked>
                                    <span class="toggle-slider"></span>
                                </label>
                                <span class="ml-2 text-sm text-gray-400">Use as default</span>
                            </div>
                        </div>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="add_mapping" class="accent-button py-2 px-4 rounded-md text-white">
                            Add Mapping
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Provider Mappings List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden">
                <h2 class="text-xl font-semibold text-white p-6 pb-4">Network Provider Mappings</h2>
                
                <?php if (empty($mappings)): ?>
                    <div class="p-6 text-center">
                        <p class="text-gray-400">No network provider mappings found. Use the form above to add one.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-700">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Network
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Provider
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Provider Network ID
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Default
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Actions
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-700">
                                <?php foreach ($mappings as $mapping): ?>
                                    <tr>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($mapping['network_name']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($mapping['provider_name']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($mapping['provider_network_id']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php if ($mapping['is_default']): ?>
                                                <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-500 bg-opacity-20 text-green-300">
                                                    Yes
                                                </span>
                                            <?php else: ?>
                                                <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full bg-gray-500 bg-opacity-20 text-gray-300">
                                                    No
                                                </span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                            <a href="?action=delete-mapping&mapping_id=<?php echo $mapping['id']; ?>" class="text-red-400 hover:text-red-300" 
                                               onclick="return confirm('Are you sure you want to delete this mapping?');">
                                                <i class="fas fa-trash-alt"></i> Delete
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>