<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get available API provider classes
$providerClasses = [];
$apiDirectory = __DIR__ . '/../../includes/api/';
$files = scandir($apiDirectory);

foreach ($files as $file) {
    if (preg_match('/^([A-Za-z0-9]+Provider)\.php$/', $file, $matches) && $file !== 'BaseAPIProvider.php') {
        $providerClasses[] = $matches[1];
    }
}

// Get networks for dropdown
$networks = [];
$result = $conn->query("SELECT * FROM networks WHERE status = 'active' ORDER BY name");
while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Get providers
$providers = [];
$result = $conn->query("SELECT * FROM api_providers ORDER BY priority, name");
while ($row = $result->fetch_assoc()) {
    $providers[] = $row;
}

// Process action
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_provider']) || isset($_POST['edit_provider'])) {
        // Common validation and data collection for both add and edit
        $providerId = isset($_POST['provider_id']) ? (int)$_POST['provider_id'] : 0;
        $providerName = sanitizeInput($_POST['provider_name']);
        $providerClass = sanitizeInput($_POST['provider_class']);
        $apiKey = sanitizeInput($_POST['api_key']);
        $apiUrl = sanitizeInput($_POST['api_url']);
        $status = sanitizeInput($_POST['status']);
        $isPrimary = isset($_POST['is_primary']) ? 1 : 0;
        $priority = (int)$_POST['priority'];
        
        // Get services
        $services = isset($_POST['services']) ? $_POST['services'] : [];
        
        // Validate inputs
        if (empty($providerName)) {
            $actionError = 'Provider name is required';
        } elseif (empty($providerClass)) {
            $actionError = 'Provider class is required';
        } elseif (empty($apiKey)) {
            $actionError = 'API key is required';
        } elseif (empty($apiUrl)) {
            $actionError = 'API URL is required';
        } elseif (!in_array($status, ['active', 'inactive'])) {
            $actionError = 'Invalid status';
        } elseif ($priority < 1) {
            $actionError = 'Priority must be at least 1';
        } else {
            // If setting this provider as primary, update all others to non-primary
            if ($isPrimary) {
                $conn->query("UPDATE api_providers SET is_primary = 0");
            } elseif (!$providerId) {
                // Check if no primary provider exists
                $result = $conn->query("SELECT COUNT(*) as count FROM api_providers WHERE is_primary = 1");
                $row = $result->fetch_assoc();
                if ($row['count'] == 0) {
                    $isPrimary = 1; // Make this the primary if no other provider is primary
                }
            }
            
            if (isset($_POST['add_provider'])) {
                // Add new provider
                $stmt = $conn->prepare("INSERT INTO api_providers (name, provider_class, api_key, api_url, status, is_primary, priority) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $stmt->bind_param("sssssii", $providerName, $providerClass, $apiKey, $apiUrl, $status, $isPrimary, $priority);
                
                if ($stmt->execute()) {
                    $providerId = $conn->insert_id;
                    $actionSuccess = 'API provider added successfully';
                    
                    // Save service mappings
                    if (!empty($services)) {
                        saveProviderServices($providerId, $services);
                    }
                } else {
                    $actionError = 'Failed to add API provider: ' . $conn->error;
                }
            } else {
                // Edit existing provider
                $stmt = $conn->prepare("UPDATE api_providers SET name = ?, provider_class = ?, api_key = ?, api_url = ?, status = ?, is_primary = ?, priority = ? WHERE id = ?");
                $stmt->bind_param("sssssiii", $providerName, $providerClass, $apiKey, $apiUrl, $status, $isPrimary, $priority, $providerId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'API provider updated successfully';
                    
                    // Delete existing service mappings
                    $conn->query("DELETE FROM api_provider_services WHERE provider_id = " . $providerId);
                    
                    // Save new service mappings
                    if (!empty($services)) {
                        saveProviderServices($providerId, $services);
                    }
                } else {
                    $actionError = 'Failed to update API provider: ' . $conn->error;
                }
            }
            
            // Refresh providers list after action
            $providers = [];
            $result = $conn->query("SELECT * FROM api_providers ORDER BY priority, name");
            while ($row = $result->fetch_assoc()) {
                $providers[] = $row;
            }
        }
    } elseif (isset($_POST['delete_provider'])) {
        $providerId = (int)$_POST['provider_id'];
        
        // Check if provider is primary
        $stmt = $conn->prepare("SELECT is_primary FROM api_providers WHERE id = ?");
        $stmt->bind_param("i", $providerId);
        $stmt->execute();
        $result = $stmt->get_result();
        $provider = $result->fetch_assoc();
        
        if ($provider && $provider['is_primary']) {
            $actionError = 'Cannot delete the primary API provider. Please set another provider as primary first.';
        } else {
            $stmt = $conn->prepare("DELETE FROM api_providers WHERE id = ?");
            $stmt->bind_param("i", $providerId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'API provider deleted successfully';
                
                // Refresh providers list after delete
                $providers = [];
                $result = $conn->query("SELECT * FROM api_providers ORDER BY priority, name");
                while ($row = $result->fetch_assoc()) {
                    $providers[] = $row;
                }
            } else {
                $actionError = 'Failed to delete API provider: ' . $conn->error;
            }
        }
    } elseif (isset($_POST['add_mapping'])) {
        $networkId = (int)$_POST['network_id'];
        $providerId = (int)$_POST['provider_id'];
        $apiId = sanitizeInput($_POST['api_id']);
        
        if (empty($networkId)) {
            $actionError = 'Please select a network';
        } elseif (empty($providerId)) {
            $actionError = 'Please select a provider';
        } elseif (empty($apiId)) {
            $actionError = 'API ID is required';
        } else {
            // Check if mapping already exists
            $stmt = $conn->prepare("SELECT id FROM network_api_mappings WHERE network_id = ? AND provider_id = ?");
            $stmt->bind_param("ii", $networkId, $providerId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                // Update existing mapping
                $stmt = $conn->prepare("UPDATE network_api_mappings SET api_id = ? WHERE network_id = ? AND provider_id = ?");
                $stmt->bind_param("sii", $apiId, $networkId, $providerId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Network-API mapping updated successfully';
                } else {
                    $actionError = 'Failed to update mapping: ' . $conn->error;
                }
            } else {
                // Add new mapping
                $stmt = $conn->prepare("INSERT INTO network_api_mappings (network_id, provider_id, api_id) VALUES (?, ?, ?)");
                $stmt->bind_param("iis", $networkId, $providerId, $apiId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Network-API mapping added successfully';
                } else {
                    $actionError = 'Failed to add mapping: ' . $conn->error;
                }
            }
        }
    } elseif (isset($_POST['delete_mapping'])) {
        $mappingId = (int)$_POST['mapping_id'];
        
        $stmt = $conn->prepare("DELETE FROM network_api_mappings WHERE id = ?");
        $stmt->bind_param("i", $mappingId);
        
        if ($stmt->execute()) {
            $actionSuccess = 'Network-API mapping deleted successfully';
        } else {
            $actionError = 'Failed to delete mapping: ' . $conn->error;
        }
    }
}

// Get network-API mappings
$mappings = [];
$query = "
    SELECT m.*, n.name as network_name, p.name as provider_name 
    FROM network_api_mappings m
    JOIN networks n ON m.network_id = n.id
    JOIN api_providers p ON m.provider_id = p.id
    ORDER BY n.name, p.name
";
$result = $conn->query($query);
while ($row = $result->fetch_assoc()) {
    $mappings[] = $row;
}

// Get provider service mappings
function getProviderServices($providerId) {
    global $conn;
    
    $services = [];
    $stmt = $conn->prepare("
        SELECT * FROM api_provider_services 
        WHERE provider_id = ?
    ");
    $stmt->bind_param("i", $providerId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $serviceKey = $row['service_type'];
        if ($row['network_id']) {
            $serviceKey .= '_' . $row['network_id'];
        }
        $services[$serviceKey] = $row;
    }
    
    return $services;
}

// Save provider services
function saveProviderServices($providerId, $services) {
    global $conn;
    
    foreach ($services as $service) {
        $parts = explode('_', $service);
        $serviceType = $parts[0];
        $networkId = isset($parts[1]) ? (int)$parts[1] : null;
        
        $stmt = $conn->prepare("
            INSERT INTO api_provider_services (provider_id, service_type, network_id)
            VALUES (?, ?, ?)
        ");
        $stmt->bind_param("isi", $providerId, $serviceType, $networkId);
        $stmt->execute();
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>API Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
        
        .primary-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        /* Checkbox styling */
        .checkbox-label {
            display: flex;
            align-items: center;
            cursor: pointer;
            user-select: none;
        }
        
        .checkbox-label input[type="checkbox"] {
            position: absolute;
            opacity: 0;
            cursor: pointer;
            height: 0;
            width: 0;
        }
        
        .checkmark {
            height: 20px;
            width: 20px;
            background-color: #2d2d2d;
            border: 1px solid #444;
            border-radius: 4px;
            margin-right: 8px;
            position: relative;
        }
        
        .checkbox-label:hover input ~ .checkmark {
            background-color: #3d3d3d;
        }
        
        .checkbox-label input:checked ~ .checkmark {
            background-color: var(--accent-color);
            border-color: var(--accent-color);
        }
        
        .checkmark:after {
            content: "";
            position: absolute;
            display: none;
        }
        
        .checkbox-label input:checked ~ .checkmark:after {
            display: block;
        }
        
        .checkbox-label .checkmark:after {
            left: 7px;
            top: 3px;
            width: 5px;
            height: 10px;
            border: solid white;
            border-width: 0 2px 2px 0;
            transform: rotate(45deg);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">API Providers Settings</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- API Providers Section -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">API Providers</h2>
                    <button id="addProviderBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add New Provider
                    </button>
                </div>
                
                <?php if (empty($providers)): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-plug text-3xl mb-2"></i>
                        <p>No API providers configured yet. Add your first provider to connect to API services.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Name</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Class</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">API URL</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Priority</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($providers as $provider): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="flex items-center">
                                                <div class="h-8 w-8 rounded-full bg-gray-600 flex items-center justify-center mr-3 text-white">
                                                    <i class="fas fa-plug"></i>
                                                </div>
                                                <div>
                                                    <div class="font-medium text-white"><?php echo htmlspecialchars($provider['name']); ?></div>
                                                    <?php if ($provider['is_primary']): ?>
                                                        <span class="primary-badge">Primary</span>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        </td>
                                        <td class="py-3 px-4 font-mono text-sm text-gray-300"><?php echo htmlspecialchars($provider['provider_class']); ?></td>
                                        <td class="py-3 px-4 text-gray-300 truncate max-w-xs"><?php echo htmlspecialchars($provider['api_url']); ?></td>
                                        <td class="py-3 px-4 text-gray-300"><?php echo $provider['priority']; ?></td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $provider['status']; ?>">
                                                <?php echo ucfirst($provider['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-provider" 
                                                        data-id="<?php echo $provider['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($provider['name']); ?>"
                                                        data-class="<?php echo htmlspecialchars($provider['provider_class']); ?>"
                                                        data-url="<?php echo htmlspecialchars($provider['api_url']); ?>"
                                                        data-key="<?php echo htmlspecialchars($provider['api_key']); ?>"
                                                        data-status="<?php echo $provider['status']; ?>"
                                                        data-primary="<?php echo $provider['is_primary']; ?>"
                                                        data-priority="<?php echo $provider['priority']; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-indigo-400 hover:text-indigo-300 test-provider" data-id="<?php echo $provider['id']; ?>">
                                                    <i class="fas fa-vial"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-provider" 
                                                        data-id="<?php echo $provider['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($provider['name']); ?>"
                                                        data-primary="<?php echo $provider['is_primary']; ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Network-API Mappings Section -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Network-API Mappings</h2>
                    <button id="addMappingBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                        <i class="fas fa-plus mr-2"></i> Add New Mapping
                    </button>
                </div>
                
                <p class="text-gray-400 mb-4">
                    <i class="fas fa-info-circle mr-1"></i>
                    Network-API mappings allow you to specify which network ID to use for each provider, as different providers may use different IDs for the same network.
                </p>
                
                <?php if (empty($mappings)): ?>
                    <div class="text-center py-6 text-gray-400">
                        <i class="fas fa-link text-3xl mb-2"></i>
                        <p>No network-API mappings configured yet.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Network</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">API Provider</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">API ID</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($mappings as $mapping): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4 text-white"><?php echo htmlspecialchars($mapping['network_name']); ?></td>
                                        <td class="py-3 px-4 text-white"><?php echo htmlspecialchars($mapping['provider_name']); ?></td>
                                        <td class="py-3 px-4 font-mono text-gray-300"><?php echo htmlspecialchars($mapping['api_id']); ?></td>
                                        <td class="py-3 px-4">
                                            <button class="text-red-500 hover:text-red-400 delete-mapping" 
                                                    data-id="<?php echo $mapping['id']; ?>"
                                                    data-network="<?php echo htmlspecialchars($mapping['network_name']); ?>"
                                                    data-provider="<?php echo htmlspecialchars($mapping['provider_name']); ?>">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About API Providers</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        API providers connect your VTU platform to external services for data, airtime, cable, and electricity transactions.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Multiple Providers</h3>
                            <p class="text-gray-400">
                                You can configure multiple API providers and prioritize them. If one provider fails, the system can automatically fall back to the next provider.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Network Mappings</h3>
                            <p class="text-gray-400">
                                Different providers may use different IDs for the same network. Network mappings allow you to specify the correct ID for each provider.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: Always test your API settings after configuration. You can use the Test button to verify connectivity with the provider.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Provider Modal -->
    <div id="providerModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content relative rounded-lg shadow-lg max-w-3xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New API Provider</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="provider_id" name="provider_id" value="">
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                    <div>
                        <label for="provider_name" class="block text-sm font-medium text-gray-400 mb-1">Provider Name</label>
                        <input type="text" id="provider_name" name="provider_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div>
                        <label for="provider_class" class="block text-sm font-medium text-gray-400 mb-1">Provider Class</label>
                        <select id="provider_class" name="provider_class" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="">-- Select Provider Class --</option>
                            <?php foreach ($providerClasses as $class): ?>
                                <option value="<?php echo $class; ?>"><?php echo $class; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div>
                        <label for="api_key" class="block text-sm font-medium text-gray-400 mb-1">API Key/Token</label>
                        <input type="text" id="api_key" name="api_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div>
                        <label for="api_url" class="block text-sm font-medium text-gray-400 mb-1">API URL</label>
                        <input type="text" id="api_url" name="api_url" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div>
                        <label for="priority" class="block text-sm font-medium text-gray-400 mb-1">Priority</label>
                        <input type="number" id="priority" name="priority" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" value="10" required>
                        <p class="mt-1 text-xs text-gray-500">Lower number = higher priority</p>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="active">Active</option>
                            <option value="inactive">Inactive</option>
                        </select>
                    </div>
                </div>
                
                <div class="mb-4">
                    <label class="inline-flex items-center cursor-pointer">
                        <input type="checkbox" id="is_primary" name="is_primary" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                        <span class="ml-2 text-gray-400">Set as Primary Provider</span>
                    </label>
                    <p class="mt-1 text-xs text-gray-500 ml-6">The primary provider will be used by default for all services.</p>
                </div>
                
                <!-- Services Section -->
                <div class="mb-6">
                    <label class="block text-sm font-medium text-gray-400 mb-2">Services</label>
                    <p class="text-xs text-gray-500 mb-2">Select which services this provider should handle</p>
                    
                    <div id="services-container" class="grid grid-cols-1 sm:grid-cols-2 gap-y-4 gap-x-6">
                        <div class="bg-gray-800 p-3 rounded-md">
                            <h4 class="font-medium text-white mb-2">Data</h4>
                            <div>
                                <label class="checkbox-label mb-2">
                                    <input type="checkbox" name="services[]" value="data">
                                    <span class="checkmark"></span>
                                    All Networks
                                </label>
                            </div>
                            
                            <div class="ml-6 space-y-2 pt-1 border-t border-gray-700 mt-1">
                                <?php foreach ($networks as $network): ?>
                                    <label class="checkbox-label">
                                        <input type="checkbox" name="services[]" value="data_<?php echo $network['id']; ?>">
                                        <span class="checkmark"></span>
                                        <?php echo htmlspecialchars($network['name']); ?>
                                    </label>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        
                        <div class="bg-gray-800 p-3 rounded-md">
                            <h4 class="font-medium text-white mb-2">Airtime</h4>
                            <div>
                                <label class="checkbox-label mb-2">
                                    <input type="checkbox" name="services[]" value="airtime">
                                    <span class="checkmark"></span>
                                    All Networks
                                </label>
                            </div>
                            
                            <div class="ml-6 space-y-2 pt-1 border-t border-gray-700 mt-1">
                                <?php foreach ($networks as $network): ?>
                                    <label class="checkbox-label">
                                        <input type="checkbox" name="services[]" value="airtime_<?php echo $network['id']; ?>">
                                        <span class="checkmark"></span>
                                        <?php echo htmlspecialchars($network['name']); ?>
                                    </label>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        
                        <div class="bg-gray-800 p-3 rounded-md">
                            <h4 class="font-medium text-white mb-2">Cable TV</h4>
                            <div>
                                <label class="checkbox-label">
                                    <input type="checkbox" name="services[]" value="cable">
                                    <span class="checkmark"></span>
                                    All Cable TV Services
                                </label>
                            </div>
                        </div>
                        
                        <div class="bg-gray-800 p-3 rounded-md">
                            <h4 class="font-medium text-white mb-2">Electricity</h4>
                            <div>
                                <label class="checkbox-label">
                                    <input type="checkbox" name="services[]" value="electricity">
                                    <span class="checkmark"></span>
                                    All Electricity Services
                                </label>
                            </div>
                        </div>
                    </div>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitProviderBtn" name="add_provider" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Provider
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Add Mapping Modal -->
    <div id="mappingModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content relative rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Add Network-API Mapping</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <div class="mb-4">
                    <label for="network_id" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                    <select id="network_id" name="network_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="">-- Select Network --</option>
                        <?php foreach ($networks as $network): ?>
                            <option value="<?php echo $network['id']; ?>"><?php echo htmlspecialchars($network['name']); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="mb-4">
                    <label for="provider_id" class="block text-sm font-medium text-gray-400 mb-1">API Provider</label>
                    <select id="provider_id" name="provider_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="">-- Select Provider --</option>
                        <?php foreach ($providers as $provider): ?>
                            <option value="<?php echo $provider['id']; ?>"><?php echo htmlspecialchars($provider['name']); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="mb-6">
                    <label for="api_id" class="block text-sm font-medium text-gray-400 mb-1">API ID</label>
                    <input type="text" id="api_id" name="api_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    <p class="mt-1 text-xs text-gray-500">The ID that the API provider uses for this network</p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="add_mapping" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Mapping
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Provider Modal -->
    <div id="deleteProviderModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content relative rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete API Provider</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="deletePrimaryWarning" class="hidden">
                <p class="text-gray-300 mb-6">Cannot delete <span id="deletePrimaryName" class="font-semibold text-white"></span> because it is set as the primary provider. Please set another provider as primary first.</p>
                
                <div class="flex justify-end">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        OK
                    </button>
                </div>
            </div>
            
            <div id="deleteProviderConfirmation" class="hidden">
                <p class="text-gray-300 mb-6">Are you sure you want to delete the provider <span id="deleteProviderName" class="font-semibold text-white"></span>? This will also remove all service mappings for this provider.</p>
                
                <form method="POST" action="">
                    <input type="hidden" id="delete_provider_id" name="provider_id" value="">
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Cancel
                        </button>
                        <button type="submit" name="delete_provider" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                            Delete Provider
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <!-- Delete Mapping Modal -->
    <div id="deleteMappingModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content relative rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Network-API Mapping</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete the mapping for <span id="deleteMappingNetwork" class="font-semibold text-white"></span> and <span id="deleteMappingProvider" class="font-semibold text-white"></span>?</p>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_mapping_id" name="mapping_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_mapping" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Mapping
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Test Results Modal -->
    <div id="testResultsModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content relative rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">API Test Results</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="testLoading" class="py-8 text-center">
                <div class="animate-spin rounded-full h-8 w-8 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
                <p class="text-gray-300">Testing API connection...</p>
            </div>
            
            <div id="testSuccess" class="hidden py-4">
                <div class="flex justify-center mb-4">
                    <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center">
                        <i class="fas fa-check-circle text-3xl text-green-500"></i>
                    </div>
                </div>
                <p class="text-center text-gray-300 mb-4">
                    API connection successful! The provider is properly configured.
                </p>
                <div class="bg-gray-800 p-4 rounded-md mb-4">
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Balance:</span>
                        <span id="balanceAmount" class="text-white font-medium"></span>
                    </div>
                    <div class="flex justify-between">
                        <span class="text-gray-400">Status:</span>
                        <span class="text-green-400">Connected</span>
                    </div>
                </div>
            </div>
            
            <div id="testError" class="hidden py-4">
                <div class="flex justify-center mb-4">
                    <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center">
                        <i class="fas fa-times-circle text-3xl text-red-500"></i>
                    </div>
                </div>
                <p class="text-center text-gray-300 mb-4">
                    API connection failed. Please check your configuration.
                </p>
                <div class="bg-gray-800 p-4 rounded-md">
                    <h4 class="text-white mb-2">Error Message:</h4>
                    <div id="errorMessage" class="text-red-400 text-sm font-mono overflow-auto max-h-32"></div>
                </div>
            </div>
            
            <div class="flex justify-end mt-4">
                <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                    Close
                </button>
            </div>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const providerModal = document.getElementById('providerModal');
        const mappingModal = document.getElementById('mappingModal');
        const deleteProviderModal = document.getElementById('deleteProviderModal');
        const deleteMappingModal = document.getElementById('deleteMappingModal');
        const testResultsModal = document.getElementById('testResultsModal');
        
        const modalTitle = document.getElementById('modalTitle');
        const submitProviderBtn = document.getElementById('submitProviderBtn');
        
        function openProviderModal(isEdit = false, providerData = {}) {
            // Reset form
            document.querySelector('#providerModal form').reset();
            
            // Uncheck all checkboxes
            document.querySelectorAll('#services-container input[type="checkbox"]').forEach(checkbox => {
                checkbox.checked = false;
            });
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('provider_id').value = providerData.id;
                document.getElementById('provider_name').value = providerData.name;
                document.getElementById('provider_class').value = providerData.class;
                document.getElementById('api_key').value = providerData.key;
                document.getElementById('api_url').value = providerData.url;
                document.getElementById('status').value = providerData.status;
                document.getElementById('is_primary').checked = providerData.primary === '1';
                document.getElementById('priority').value = providerData.priority;
                
                // Load provider services
                if (providerData.services) {
                    providerData.services.forEach(service => {
                        const checkbox = document.querySelector(`input[name="services[]"][value="${service}"]`);
                        if (checkbox) checkbox.checked = true;
                    });
                }
                
                // Update modal title and button
                modalTitle.textContent = 'Edit API Provider';
                submitProviderBtn.textContent = 'Update Provider';
                submitProviderBtn.name = 'edit_provider';
            } else {
                // Clear values for new provider
                document.getElementById('provider_id').value = '';
                
                // Update modal title and button
                modalTitle.textContent = 'Add New API Provider';
                submitProviderBtn.textContent = 'Add Provider';
                submitProviderBtn.name = 'add_provider';
            }
            
            // Show the modal
            providerModal.classList.remove('hidden');
        }
        
        function openMappingModal() {
            // Reset form
            document.querySelector('#mappingModal form').reset();
            
            // Show the modal
            mappingModal.classList.remove('hidden');
        }
        
        function openDeleteProviderModal(providerId, providerName, isPrimary) {
            document.getElementById('delete_provider_id').value = providerId;
            
            if (isPrimary === '1') {
                // Show warning that provider is primary
                document.getElementById('deletePrimaryName').textContent = providerName;
                document.getElementById('deletePrimaryWarning').classList.remove('hidden');
                document.getElementById('deleteProviderConfirmation').classList.add('hidden');
            } else {
                // Show delete confirmation
                document.getElementById('deleteProviderName').textContent = providerName;
                document.getElementById('deletePrimaryWarning').classList.add('hidden');
                document.getElementById('deleteProviderConfirmation').classList.remove('hidden');
            }
            
            deleteProviderModal.classList.remove('hidden');
        }
        
        function openDeleteMappingModal(mappingId, networkName, providerName) {
            document.getElementById('delete_mapping_id').value = mappingId;
            document.getElementById('deleteMappingNetwork').textContent = networkName;
            document.getElementById('deleteMappingProvider').textContent = providerName;
            
            deleteMappingModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            providerModal.classList.add('hidden');
            mappingModal.classList.add('hidden');
            deleteProviderModal.classList.add('hidden');
            deleteMappingModal.classList.add('hidden');
            testResultsModal.classList.add('hidden');
        }
        
        // Test API connection
        function testAPIConnection(providerId) {
            // Show loading state
            document.getElementById('testLoading').classList.remove('hidden');
            document.getElementById('testSuccess').classList.add('hidden');
            document.getElementById('testError').classList.add('hidden');
            testResultsModal.classList.remove('hidden');
            
            // Make the API test request
            fetch(`${window.location.origin}/admin/ajax/test_api.php?provider_id=${providerId}`)
                .then(response => response.json())
                .then(data => {
                    // Hide loading state
                    document.getElementById('testLoading').classList.add('hidden');
                    
                    if (data.success) {
                        // Show success state
                        document.getElementById('testSuccess').classList.remove('hidden');
                        document.getElementById('balanceAmount').textContent = data.balance;
                    } else {
                        // Show error state
                        document.getElementById('testError').classList.remove('hidden');
                        document.getElementById('errorMessage').textContent = data.message;
                    }
                })
                .catch(error => {
                    // Hide loading state and show error
                    document.getElementById('testLoading').classList.add('hidden');
                    document.getElementById('testError').classList.remove('hidden');
                    document.getElementById('errorMessage').textContent = 'Network error: ' + error.message;
                });
        }
        
        // Add event listeners
        document.getElementById('addProviderBtn').addEventListener('click', () => openProviderModal(false));
        document.getElementById('addMappingBtn').addEventListener('click', openMappingModal);
        
        document.querySelectorAll('.edit-provider').forEach(button => {
            button.addEventListener('click', function() {
                const providerId = this.getAttribute('data-id');
                const providerData = {
                    id: providerId,
                    name: this.getAttribute('data-name'),
                    class: this.getAttribute('data-class'),
                    url: this.getAttribute('data-url'),
                    key: this.getAttribute('data-key'),
                    status: this.getAttribute('data-status'),
                    primary: this.getAttribute('data-primary'),
                    priority: this.getAttribute('data-priority')
                };
                
                // Fetch provider services
                fetch(`${window.location.origin}/admin/ajax/get_provider_services.php?provider_id=${providerId}`)
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            providerData.services = data.services;
                        }
                        openProviderModal(true, providerData);
                    })
                    .catch(error => {
                        console.error('Error fetching provider services:', error);
                        openProviderModal(true, providerData);
                    });
            });
        });
        
        document.querySelectorAll('.delete-provider').forEach(button => {
            button.addEventListener('click', function() {
                const providerId = this.getAttribute('data-id');
                const providerName = this.getAttribute('data-name');
                const isPrimary = this.getAttribute('data-primary');
                openDeleteProviderModal(providerId, providerName, isPrimary);
            });
        });
        
        document.querySelectorAll('.delete-mapping').forEach(button => {
            button.addEventListener('click', function() {
                const mappingId = this.getAttribute('data-id');
                const networkName = this.getAttribute('data-network');
                const providerName = this.getAttribute('data-provider');
                openDeleteMappingModal(mappingId, networkName, providerName);
            });
        });
        
        document.querySelectorAll('.test-provider').forEach(button => {
            button.addEventListener('click', function() {
                const providerId = this.getAttribute('data-id');
                testAPIConnection(providerId);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === providerModal) {
                closeAllModals();
            }
            if (event.target === mappingModal) {
                closeAllModals();
            }
            if (event.target === deleteProviderModal) {
                closeAllModals();
            }
            if (event.target === deleteMappingModal) {
                closeAllModals();
            }
            if (event.target === testResultsModal) {
                closeAllModals();
            }
        });
        
        // Handle "All Networks" checkbox for data
        document.querySelector('input[value="data"]').addEventListener('change', function() {
            const checked = this.checked;
            document.querySelectorAll('input[value^="data_"]').forEach(checkbox => {
                checkbox.checked = checked;
                checkbox.disabled = checked;
            });
        });
        
        // Handle "All Networks" checkbox for airtime
        document.querySelector('input[value="airtime"]').addEventListener('change', function() {
            const checked = this.checked;
            document.querySelectorAll('input[value^="airtime_"]').forEach(checkbox => {
                checkbox.checked = checked;
                checkbox.disabled = checked;
            });
        });
    </script>
</body>
</html>