<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get networks for dropdown
$networks = [];
$result = $conn->query("SELECT * FROM networks WHERE status = 'active' ORDER BY name");
while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Initialize variables
$network_id = isset($_POST['network_id']) ? (int)$_POST['network_id'] : 0;
$data_type_id = isset($_POST['data_type_id']) ? (int)$_POST['data_type_id'] : 0;

// Get all data types for the selected network
$data_types = [];
if ($network_id > 0) {
    $stmt = $conn->prepare("SELECT id, name FROM data_types WHERE network_id = ? AND status = 'active' ORDER BY sort_order ASC, name ASC");
    $stmt->bind_param("i", $network_id);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $data_types[$row['id']] = $row['name'];
    }
}

// Pagination settings
$perPage = 20;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $perPage;

// Filter settings
$networkFilter = isset($_GET['network']) ? (int)$_GET['network'] : 0;
$dataTypeFilter = isset($_GET['data_type']) ? (int)$_GET['data_type'] : 0;
$statusFilter = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Build query
$query = "SELECT dp.*, n.name as network_name, dt.name as data_type_name
          FROM data_plans dp
          JOIN networks n ON dp.network_id = n.id
          JOIN data_types dt ON dp.data_type_id = dt.id
          WHERE 1=1";
$countQuery = "SELECT COUNT(*) as total 
               FROM data_plans dp
               JOIN networks n ON dp.network_id = n.id
               JOIN data_types dt ON dp.data_type_id = dt.id
               WHERE 1=1";
$params = [];
$types = "";

if ($networkFilter) {
    $query .= " AND dp.network_id = ?";
    $countQuery .= " AND dp.network_id = ?";
    $params[] = $networkFilter;
    $types .= "i";
    
    // If network filter is set, load data types for this network
    if ($networkFilter > 0) {
        $dataTypesForFilter = [];
        $stmt = $conn->prepare("SELECT id, name FROM data_types WHERE network_id = ? AND status = 'active' ORDER BY sort_order ASC, name ASC");
        $stmt->bind_param("i", $networkFilter);
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $dataTypesForFilter[$row['id']] = $row['name'];
        }
    }
}

if ($dataTypeFilter) {
    $query .= " AND dp.data_type_id = ?";
    $countQuery .= " AND dp.data_type_id = ?";
    $params[] = $dataTypeFilter;
    $types .= "i";
}

if ($statusFilter) {
    $query .= " AND dp.status = ?";
    $countQuery .= " AND dp.status = ?";
    $params[] = $statusFilter;
    $types .= "s";
}

if ($search) {
    $searchParam = "%$search%";
    $query .= " AND (dp.name LIKE ? OR dp.size LIKE ? OR dp.validity LIKE ? OR n.name LIKE ? OR dt.name LIKE ?)";
    $countQuery .= " AND (dp.name LIKE ? OR dp.size LIKE ? OR dp.validity LIKE ? OR n.name LIKE ? OR dt.name LIKE ?)";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "sssss";
}

// Order by network, data type, and name
$query .= " ORDER BY n.name ASC, dt.name ASC, dp.name ASC LIMIT ?, ?";
$params[] = $offset;
$params[] = $perPage;
$types .= "ii";

// Prepare and execute query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();
$dataPlans = [];

while ($row = $result->fetch_assoc()) {
    $dataPlans[] = $row;
}

// Get total records for pagination
$countStmt = $conn->prepare($countQuery);
if (!empty($params)) {
    // Remove limit parameters which are the last two
    $countParams = array_slice($params, 0, -2);
    $countTypes = substr($types, 0, -2);
    if (!empty($countParams)) {
        $countStmt->bind_param($countTypes, ...$countParams);
    }
}
$countStmt->execute();
$countResult = $countStmt->get_result();
$totalRecords = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $perPage);

// Find the next suggested plan ID (max plan_id + 1)
$nextPlanIdStmt = $conn->query("SELECT IFNULL(MAX(plan_id), 0) + 1 AS next_plan_id FROM data_plans");
$nextPlanIdResult = $nextPlanIdStmt->fetch_assoc();
$suggestedPlanId = $nextPlanIdResult['next_plan_id'];

// Process data plan actions (add/edit/delete)
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_plan']) || isset($_POST['edit_plan'])) {
        // Common validation and data collection for both add and edit
        $planId = isset($_POST['plan_id']) ? (int)$_POST['plan_id'] : 0;
        $networkId = (int)$_POST['network_id'];
        $dataTypeId = (int)$_POST['data_type_id'];
        $planName = sanitizeInput($_POST['plan_name']);
        $planSize = sanitizeInput($_POST['plan_size']);
        $planValidity = sanitizeInput($_POST['plan_validity']);
        $planApiId = sanitizeInput($_POST['plan_api_id']);
        $costPrice = (float)$_POST['cost_price'];
        $amountSmart = (float)$_POST['amount_smart'];
        $amountVendor = (float)$_POST['amount_vendor'];
        $amountApi = (float)$_POST['amount_api'];
        $planStatus = sanitizeInput($_POST['status']);
        $manualPlanId = isset($_POST['manual_plan_id']) ? (int)$_POST['manual_plan_id'] : 0;
        
        // Validate inputs
        if (empty($networkId)) {
            $actionError = 'Please select a network';
        } elseif (empty($dataTypeId)) {
            $actionError = 'Please select a data type';
        } elseif (empty($planName)) {
            $actionError = 'Plan name is required';
        } elseif (empty($planSize)) {
            $actionError = 'Plan size is required';
        } elseif (empty($planValidity)) {
            $actionError = 'Plan validity is required';
        } elseif ($costPrice < 0) {
            $actionError = 'Cost price cannot be negative';
        } elseif ($amountSmart < 0) {
            $actionError = 'Smart user price cannot be negative';
        } elseif ($amountVendor < 0) {
            $actionError = 'Vendor price cannot be negative';
        } elseif ($amountApi < 0) {
            $actionError = 'API user price cannot be negative';
        } elseif ($amountVendor > $amountSmart) {
            $actionError = 'Vendor price should be less than or equal to smart user price';
        } elseif ($amountApi > $amountVendor) {
            $actionError = 'API price should be less than or equal to vendor price';
        } elseif (!in_array($planStatus, ['active', 'inactive'])) {
            $actionError = 'Invalid status';
        } elseif (empty($manualPlanId)) {
            $actionError = 'Plan ID is required';
        }
        
        // Check if plan_id already exists (for new plans or when changing plan_id)
        if (empty($actionError)) {
            $checkStmt = $conn->prepare("SELECT id FROM data_plans WHERE plan_id = ? AND id != ?");
            $checkStmt->bind_param("ii", $manualPlanId, $planId);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();
            
            if ($checkResult->num_rows > 0) {
                $actionError = 'Plan ID already exists. Please use a different Plan ID.';
            }
        }
        
        if (empty($actionError)) {
            if (isset($_POST['add_plan'])) {
                // Add new plan
                $stmt = $conn->prepare("INSERT INTO data_plans (network_id, data_type_id, name, size, validity, api_plan_id, cost_price, amount_smart, amount_vendor, amount_api, status, plan_id) 
                                      VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                $stmt->bind_param("iissssddddsi", $networkId, $dataTypeId, $planName, $planSize, $planValidity, $planApiId, $costPrice, $amountSmart, $amountVendor, $amountApi, $planStatus, $manualPlanId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Data plan added successfully';
                } else {
                    $actionError = 'Failed to add data plan: ' . $conn->error;
                }
            } else {
                // Edit existing plan
                $stmt = $conn->prepare("UPDATE data_plans SET 
                                      network_id = ?, 
                                      data_type_id = ?, 
                                      name = ?, 
                                      size = ?, 
                                      validity = ?, 
                                      api_plan_id = ?, 
                                      cost_price = ?, 
                                      amount_smart = ?, 
                                      amount_vendor = ?, 
                                      amount_api = ?, 
                                      status = ?,
                                      plan_id = ? 
                                      WHERE id = ?");
                $stmt->bind_param("iissssddddsii", $networkId, $dataTypeId, $planName, $planSize, $planValidity, $planApiId, $costPrice, $amountSmart, $amountVendor, $amountApi, $planStatus, $manualPlanId, $planId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Data plan updated successfully';
                } else {
                    $actionError = 'Failed to update data plan: ' . $conn->error;
                }
            }
            
            // Refresh data plans list after action
            $stmt = $conn->prepare($query);
            if (!empty($params)) {
                $stmt->bind_param($types, ...$params);
            }
            $stmt->execute();
            $result = $stmt->get_result();
            $dataPlans = [];
            
            while ($row = $result->fetch_assoc()) {
                $dataPlans[] = $row;
            }
            
            // Update the next suggested plan ID
            $nextPlanIdStmt = $conn->query("SELECT IFNULL(MAX(plan_id), 0) + 1 AS next_plan_id FROM data_plans");
            $nextPlanIdResult = $nextPlanIdStmt->fetch_assoc();
            $suggestedPlanId = $nextPlanIdResult['next_plan_id'];
        }
    } elseif (isset($_POST['delete_plan'])) {
        $planId = (int)$_POST['plan_id'];
        
        // Check if data plan has been used in transactions
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"plan_id":"' . $planId . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        $result = $stmt->get_result();
        $transactionCount = $result->fetch_assoc()['count'];
        
        if ($transactionCount > 0) {
            $actionError = 'Cannot delete data plan that has been used in transactions. Consider marking it as inactive instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM data_plans WHERE id = ?");
            $stmt->bind_param("i", $planId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'Data plan deleted successfully';
            } else {
                $actionError = 'Failed to delete data plan: ' . $conn->error;
            }
            
            // Refresh data plans list after delete
            $stmt = $conn->prepare($query);
            if (!empty($params)) {
                $stmt->bind_param($types, ...$params);
            }
            $stmt->execute();
            $result = $stmt->get_result();
            $dataPlans = [];
            
            while ($row = $result->fetch_assoc()) {
                $dataPlans[] = $row;
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
// Set current page for sidebar highlight
$currentPage = 'data_plans';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Data Plans - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
               <!-- Include Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Data Plans Management</h1>
                <button id="addPlanBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                    <i class="fas fa-plus mr-2"></i> Add New Plan
                </button>
            </div>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="flex flex-col md:flex-row md:items-end space-y-4 md:space-y-0 md:space-x-4">
                    <div class="flex-1">
                        <label for="search" class="block text-sm font-medium text-gray-400 mb-1">Search</label>
                        <input type="text" id="search" name="search" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Search by name, size, validity" value="<?php echo htmlspecialchars($search); ?>">
                    </div>
                    
                    <div>
                        <label for="network" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                        <select id="network" name="network" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Networks</option>
                            <?php foreach ($networks as $network): ?>
                                <option value="<?php echo $network['id']; ?>" <?php echo $networkFilter == $network['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($network['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div>
                        <label for="data_type" class="block text-sm font-medium text-gray-400 mb-1">Data Type</label>
                        <select id="data_type" name="data_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Data Types</option>
                            <?php if (isset($dataTypesForFilter) && !empty($dataTypesForFilter)): ?>
                                <?php foreach ($dataTypesForFilter as $id => $name): ?>
                                    <option value="<?php echo $id; ?>" <?php echo $dataTypeFilter == $id ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($name); ?>
                                    </option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Statuses</option>
                            <option value="active" <?php echo $statusFilter === 'active' ? 'selected' : ''; ?>>Active</option>
                            <option value="inactive" <?php echo $statusFilter === 'inactive' ? 'selected' : ''; ?>>Inactive</option>
                        </select>
                    </div>
                    
                    <div class="md:flex-none">
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white w-full">Filter</button>
                    </div>
                </form>
            </div>
            
            <!-- Data Plans List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($dataPlans)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-wifi text-4xl mb-3"></i>
                        <p>No data plans found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Network</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Data Type</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Name</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Size</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Validity</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Plan ID</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Smart Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Vendor Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">API Price</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($dataPlans as $plan): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4 text-gray-300"><?php echo htmlspecialchars($plan['network_name']); ?></td>
                                        <td class="py-3 px-4 text-gray-300"><?php echo htmlspecialchars($plan['data_type_name']); ?></td>
                                        <td class="py-3 px-4 text-white"><?php echo htmlspecialchars($plan['name']); ?></td>
                                        <td class="py-3 px-4 text-gray-300"><?php echo htmlspecialchars($plan['size']); ?></td>
                                        <td class="py-3 px-4 text-gray-300"><?php echo htmlspecialchars($plan['validity']); ?></td>
                                        <td class="py-3 px-4 text-white font-medium"><?php echo $plan['plan_id']; ?></td>
                                        <td class="py-3 px-4 font-medium text-white"><?php echo formatAmount($plan['amount_smart']); ?></td>
                                        <td class="py-3 px-4 font-medium text-white"><?php echo formatAmount($plan['amount_vendor']); ?></td>
                                        <td class="py-3 px-4 font-medium text-white"><?php echo formatAmount($plan['amount_api']); ?></td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $plan['status']; ?>">
                                                <?php echo ucfirst($plan['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-plan" 
                                                        data-id="<?php echo $plan['id']; ?>"
                                                        data-network="<?php echo $plan['network_id']; ?>"
                                                        data-datatype="<?php echo $plan['data_type_id']; ?>"
                                                        data-datatypename="<?php echo htmlspecialchars($plan['data_type_name']); ?>"
                                                        data-name="<?php echo htmlspecialchars($plan['name']); ?>"
                                                        data-size="<?php echo htmlspecialchars($plan['size']); ?>"
                                                        data-validity="<?php echo htmlspecialchars($plan['validity']); ?>"
                                                        data-api-id="<?php echo htmlspecialchars($plan['api_plan_id']); ?>"
                                                        data-cost="<?php echo $plan['cost_price']; ?>"
                                                        data-smart="<?php echo $plan['amount_smart']; ?>"
                                                        data-vendor="<?php echo $plan['amount_vendor']; ?>"
                                                        data-api="<?php echo $plan['amount_api']; ?>"
                                                        data-status="<?php echo $plan['status']; ?>"
                                                        data-plan-id="<?php echo $plan['plan_id']; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-plan" 
                                                        data-id="<?php echo $plan['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($plan['name']); ?>"
                                                        data-network="<?php echo htmlspecialchars($plan['network_name']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <!-- Pagination -->
                    <?php if ($totalPages > 1): ?>
                        <div class="px-4 py-3 flex items-center justify-between border-t border-gray-700">
                            <div class="hidden sm:block">
                                <p class="text-sm text-gray-400">
                                    Showing <span class="font-medium"><?php echo $offset + 1; ?></span> to <span class="font-medium"><?php echo min($offset + $perPage, $totalRecords); ?></span> of <span class="font-medium"><?php echo $totalRecords; ?></span> results
                                </p>
                            </div>
                            <div class="flex-1 flex justify-between sm:justify-end">
                                <?php if ($page > 1): ?>
                                    <a href="?page=<?php echo $page - 1; ?><?php echo $networkFilter ? '&network=' . $networkFilter : ''; ?><?php echo $dataTypeFilter ? '&data_type=' . $dataTypeFilter : ''; ?><?php echo $statusFilter ? '&status=' . $statusFilter : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Previous
                                    </a>
                                <?php endif; ?>
                                
                                <?php if ($page < $totalPages): ?>
                                    <a href="?page=<?php echo $page + 1; ?><?php echo $networkFilter ? '&network=' . $networkFilter : ''; ?><?php echo $dataTypeFilter ? '&data_type=' . $dataTypeFilter : ''; ?><?php echo $statusFilter ? '&status=' . $statusFilter : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="ml-3 relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Next
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Plan Modal -->
    <div id="planModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Data Plan</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="plan_id" name="plan_id" value="">
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                    <!-- Plan ID Field (New) -->
                    <div>
                        <label for="manual_plan_id" class="block text-sm font-medium text-gray-400 mb-1">Plan ID *</label>
                        <div class="flex">
                            <input type="number" id="manual_plan_id" name="manual_plan_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" min="1" value="<?php echo $suggestedPlanId; ?>" required>
                        </div>
                        <p class="mt-1 text-xs text-gray-500">Unique identifier for API reference. Suggested value: <?php echo $suggestedPlanId; ?></p>
                    </div>
                    
                    <div>
                        <label for="network_id" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                        <select id="network_id" name="network_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="">-- Select Network --</option>
                            <?php foreach ($networks as $network): ?>
                                <option value="<?php echo $network['id']; ?>"><?php echo htmlspecialchars($network['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div>
                        <label for="data_type_id" class="block text-sm font-medium text-gray-400 mb-1">Data Type</label>
                        <select id="data_type_id" name="data_type_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="">-- Select Data Type --</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="plan_name" class="block text-sm font-medium text-gray-400 mb-1">Plan Name</label>
                        <input type="text" id="plan_name" name="plan_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div>
                        <label for="plan_size" class="block text-sm font-medium text-gray-400 mb-1">Plan Size</label>
                        <input type="text" id="plan_size" name="plan_size" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required placeholder="e.g. 1GB, 2.5GB">
                    </div>
                    
                    <div>
                        <label for="plan_validity" class="block text-sm font-medium text-gray-400 mb-1">Validity</label>
                        <input type="text" id="plan_validity" name="plan_validity" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required placeholder="e.g. 30 Days, 7 Days">
                    </div>
                    
                    <div>
                        <label for="plan_api_id" class="block text-sm font-medium text-gray-400 mb-1">API Plan ID</label>
                        <input type="text" id="plan_api_id" name="plan_api_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="API provider's plan ID">
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            <option value="active">Active</option>
                            <option value="inactive">Inactive</option>
                        </select>
                    </div>
                </div>
                
                <div class="border-t border-gray-700 pt-4 mb-4">
                    <h4 class="text-lg font-medium text-white mb-3">Pricing</h4>
                    
                    <div class="grid grid-cols-1 md:grid-cols-4 gap-4">
                        <div>
                            <label for="cost_price" class="block text-sm font-medium text-gray-400 mb-1">Cost Price</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                                <input type="number" id="cost_price" name="cost_price" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" step="0.01" min="0" required>
                            </div>
                            <p class="mt-1 text-xs text-gray-500">Your cost from provider</p>
                        </div>
                        
                        <div>
                            <label for="amount_smart" class="block text-sm font-medium text-gray-400 mb-1">Smart User Price</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                                <input type="number" id="amount_smart" name="amount_smart" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" step="0.01" min="0" required>
                            </div>
                            <p class="mt-1 text-xs text-gray-500">Price for Smart users</p>
                        </div>
                        
                        <div>
                            <label for="amount_vendor" class="block text-sm font-medium text-gray-400 mb-1">Vendor Price</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                                <input type="number" id="amount_vendor" name="amount_vendor" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" step="0.01" min="0" required>
                            </div>
                            <p class="mt-1 text-xs text-gray-500">Price for Vendor users</p>
                        </div>
                        
                        <div>
                            <label for="amount_api" class="block text-sm font-medium text-gray-400 mb-1">API User Price</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                                <input type="number" id="amount_api" name="amount_api" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" step="0.01" min="0" required>
                            </div>
                            <p class="mt-1 text-xs text-gray-500">Price for API users</p>
                        </div>
                    </div>
                </div>
                
                <div class="p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md mb-6">
                    <p class="text-indigo-300 text-sm">
                        <i class="fas fa-info-circle mr-2"></i>
                        Set appropriate pricing for each user type. API users should have the lowest price, followed by Vendors, then Smart users.
                    </p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitPlanBtn" name="add_plan" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Plan
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Plan Modal -->
    <div id="deletePlanModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Data Plan</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete <span id="deletePlanName" class="font-semibold text-white"></span> on <span id="deletePlanNetwork" class="font-semibold text-white"></span>? This action cannot be undone.</p>
            
            <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-6">
                <p class="text-yellow-300 text-sm">
                    <i class="fas fa-exclamation-triangle mr-2"></i>
                    Note: Plans that have been used in transactions cannot be deleted. Consider marking them as inactive instead.
                </p>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_plan_id" name="plan_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_plan" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete Plan
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const planModal = document.getElementById('planModal');
        const deletePlanModal = document.getElementById('deletePlanModal');
        const modalTitle = document.getElementById('modalTitle');
        const submitPlanBtn = document.getElementById('submitPlanBtn');
        
        // Load data types based on network selection
        const networkIdSelect = document.getElementById('network_id');
        const dataTypeIdSelect = document.getElementById('data_type_id');
        
        // Filter form network change
        const filterNetworkSelect = document.getElementById('network');
        const filterDataTypeSelect = document.getElementById('data_type');
        
        filterNetworkSelect.addEventListener('change', function() {
            const networkId = this.value;
            filterDataTypeSelect.innerHTML = '<option value="">All Data Types</option>';
            
            if (networkId) {
                // Fetch data types for this network
                fetch(`get_data_types.php?network_id=${networkId}`)
                    .then(response => response.json())
                    .then(data => {
                        if (data.success && data.data_types.length > 0) {
                            data.data_types.forEach(type => {
                                const option = document.createElement('option');
                                option.value = type.id;
                                option.textContent = type.name;
                                filterDataTypeSelect.appendChild(option);
                            });
                        }
                    })
                    .catch(error => console.error('Error fetching data types:', error));
            }
        });
        
        // Modal form network change
        networkIdSelect.addEventListener('change', function() {
            const networkId = this.value;
            dataTypeIdSelect.innerHTML = '<option value="">-- Select Data Type --</option>';
            dataTypeIdSelect.disabled = true;
            
            if (networkId) {
                // Fetch data types for this network
                fetch(`get_data_types.php?network_id=${networkId}`)
                    .then(response => response.json())
                    .then(data => {
                        if (data.success && data.data_types.length > 0) {
                            // Enable the data type select
                            dataTypeIdSelect.disabled = false;
                            
                            // Add options for each data type
                            data.data_types.forEach(type => {
                                const option = document.createElement('option');
                                option.value = type.id;
                                option.textContent = type.name;
                                dataTypeIdSelect.appendChild(option);
                            });
                        }
                    })
                    .catch(error => console.error('Error fetching data types:', error));
            }
        });
        
        function openPlanModal(isEdit = false, planData = {}) {
            // Reset form
            document.querySelector('#planModal form').reset();
            
            // For new plans, set the suggested Plan ID
            if (!isEdit) {
                document.getElementById('manual_plan_id').value = <?php echo $suggestedPlanId; ?>;
            }
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('plan_id').value = planData.id;
                document.getElementById('manual_plan_id').value = planData.planId;
                document.getElementById('network_id').value = planData.network;
                document.getElementById('plan_name').value = planData.name;
                document.getElementById('plan_size').value = planData.size;
                document.getElementById('plan_validity').value = planData.validity;
                document.getElementById('plan_api_id').value = planData.apiId;
                document.getElementById('cost_price').value = planData.cost;
                document.getElementById('amount_smart').value = planData.smart;
                document.getElementById('amount_vendor').value = planData.vendor;
                document.getElementById('amount_api').value = planData.api;
                document.getElementById('status').value = planData.status;
                
                // Trigger network change to load data types
                const event = new Event('change');
                networkIdSelect.dispatchEvent(event);
                
                // Need to wait for data types to load before setting the selected one
                setTimeout(() => {
                    // Check if data types have loaded
                    if (dataTypeIdSelect.options.length > 1) {
                        dataTypeIdSelect.value = planData.datatype;
                    } else {
                        // If not loaded yet, create and add the option
                        const option = document.createElement('option');
                        option.value = planData.datatype;
                        option.textContent = planData.datatypename;
                        option.selected = true;
                        dataTypeIdSelect.appendChild(option);
                    }
                }, 500);
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Data Plan';
                submitPlanBtn.textContent = 'Update Plan';
                submitPlanBtn.name = 'edit_plan';
            } else {
                // Clear values for new plan
                document.getElementById('plan_id').value = '';
                
                // Set default modal title and button
                modalTitle.textContent = 'Add New Data Plan';
                submitPlanBtn.textContent = 'Add Plan';
                submitPlanBtn.name = 'add_plan';
            }
            
            // Show the modal
            planModal.classList.remove('hidden');
        }
        
        function openDeleteModal(planId, planName, networkName) {
            document.getElementById('delete_plan_id').value = planId;
            document.getElementById('deletePlanName').textContent = planName;
            document.getElementById('deletePlanNetwork').textContent = networkName;
            deletePlanModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            planModal.classList.add('hidden');
            deletePlanModal.classList.add('hidden');
        }
        
        // Add event listeners
        document.getElementById('addPlanBtn').addEventListener('click', () => openPlanModal(false));
        
        document.querySelectorAll('.edit-plan').forEach(button => {
            button.addEventListener('click', function() {
                const planData = {
                    id: this.getAttribute('data-id'),
                    network: this.getAttribute('data-network'),
                    datatype: this.getAttribute('data-datatype'),
                    datatypename: this.getAttribute('data-datatypename'),
                    name: this.getAttribute('data-name'),
                    size: this.getAttribute('data-size'),
                    validity: this.getAttribute('data-validity'),
                    apiId: this.getAttribute('data-api-id'),
                    cost: this.getAttribute('data-cost'),
                    smart: this.getAttribute('data-smart'),
                    vendor: this.getAttribute('data-vendor'),
                    api: this.getAttribute('data-api'),
                    status: this.getAttribute('data-status'),
                    planId: this.getAttribute('data-plan-id')
                };
                openPlanModal(true, planData);
            });
        });
        
        document.querySelectorAll('.delete-plan').forEach(button => {
            button.addEventListener('click', function() {
                const planId = this.getAttribute('data-id');
                const planName = this.getAttribute('data-name');
                const networkName = this.getAttribute('data-network');
                openDeleteModal(planId, planName, networkName);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === planModal || event.target === deletePlanModal) {
                closeAllModals();
            }
        });
        
        // Form validation
        const planForm = document.querySelector('#planModal form');
        const costPriceInput = document.getElementById('cost_price');
        const amountSmartInput = document.getElementById('amount_smart');
        const amountVendorInput = document.getElementById('amount_vendor');
        const amountApiInput = document.getElementById('amount_api');
        
        function validatePrices() {
            const costPrice = parseFloat(costPriceInput.value);
            const smartPrice = parseFloat(amountSmartInput.value);
            const vendorPrice = parseFloat(amountVendorInput.value);
            const apiPrice = parseFloat(amountApiInput.value);
            
            // Check if vendor price is less than or equal to smart price
            if (vendorPrice > smartPrice) {
                alert('Vendor price should be less than or equal to Smart user price.');
                return false;
            }
            
            // Check if API price is less than or equal to vendor price
            if (apiPrice > vendorPrice) {
                alert('API price should be less than or equal to Vendor price.');
                return false;
            }
            
            return true;
        }
        
        planForm.addEventListener('submit', function(event) {
            if (!validatePrices()) {
                event.preventDefault();
            }
        });
    </script>
</body>
</html>