<?php
// File: /admin/services/data_types.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize variables
$data_type_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
$action = isset($_GET['action']) ? $_GET['action'] : '';
$success = '';
$error = '';

// Get all networks
$networks = [];
$stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $networks[$row['id']] = $row['name'];
}

// Get all providers
$providers = [];
$stmt = $conn->prepare("SELECT id, name FROM providers WHERE type = 'data' AND status = 'active' ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $providers[$row['id']] = $row['name'];
}

// Process delete action
if ($action == 'delete' && $data_type_id > 0) {
    // Check if the data type is in use
    $stmt = $conn->prepare("SELECT COUNT(*) as count FROM data_plans WHERE data_type_id = ?");
    $stmt->bind_param("i", $data_type_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    
    if ($row['count'] > 0) {
        $error = "Cannot delete this data type because it is being used by data plans";
    } else {
        // First delete any provider mappings
        $stmt = $conn->prepare("DELETE FROM data_type_providers WHERE data_type_id = ?");
        $stmt->bind_param("i", $data_type_id);
        $stmt->execute();
        
        // Then delete the data type
        $stmt = $conn->prepare("DELETE FROM data_types WHERE id = ?");
        $stmt->bind_param("i", $data_type_id);
        
        if ($stmt->execute()) {
            $success = "Data type deleted successfully";
        } else {
            $error = "Failed to delete data type";
        }
    }
}

// Process form submission for adding/editing data type
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $edit_id = isset($_POST['edit_id']) ? (int)$_POST['edit_id'] : 0;
    $network_id = (int)$_POST['network_id'];
    $name = sanitizeInput($_POST['name']);
    $description = sanitizeInput($_POST['description']);
    $status = sanitizeInput($_POST['status']);
    $sort_order = (int)$_POST['sort_order'];
    
    // Get provider settings
    $provider_id = isset($_POST['provider_id']) ? (int)$_POST['provider_id'] : 0;
    $provider_network_id = sanitizeInput($_POST['provider_network_id']);
    
    // Validate input
    if (empty($name)) {
        $error = "Data type name is required";
    } elseif ($network_id <= 0) {
        $error = "Please select a network";
    } else {
        $conn->begin_transaction();
        
        try {
            if ($edit_id > 0) {
                // Update existing data type
                $stmt = $conn->prepare("UPDATE data_types SET network_id = ?, name = ?, description = ?, status = ?, sort_order = ? WHERE id = ?");
                $stmt->bind_param("isssii", $network_id, $name, $description, $status, $sort_order, $edit_id);
                
                if ($stmt->execute()) {
                    // Delete existing provider mappings
                    $stmt = $conn->prepare("DELETE FROM data_type_providers WHERE data_type_id = ?");
                    $stmt->bind_param("i", $edit_id);
                    $stmt->execute();
                    
                    // Add new provider mapping if selected
                    if ($provider_id > 0) {
                        $stmt = $conn->prepare("INSERT INTO data_type_providers (data_type_id, provider_id, provider_network_id, status) VALUES (?, ?, ?, 'active')");
                        $stmt->bind_param("iis", $edit_id, $provider_id, $provider_network_id);
                        $stmt->execute();
                    }
                    
                    $success = "Data type updated successfully";
                    $data_type_id = 0; // Reset to add mode
                } else {
                    throw new Exception("Failed to update data type");
                }
            } else {
                // Add new data type
                $stmt = $conn->prepare("INSERT INTO data_types (network_id, name, description, status, sort_order) VALUES (?, ?, ?, ?, ?)");
                $stmt->bind_param("isssi", $network_id, $name, $description, $status, $sort_order);
                
                if ($stmt->execute()) {
                    $new_data_type_id = $conn->insert_id;
                    
                    // Add provider mapping if selected
                    if ($provider_id > 0) {
                        $stmt = $conn->prepare("INSERT INTO data_type_providers (data_type_id, provider_id, provider_network_id, status) VALUES (?, ?, ?, 'active')");
                        $stmt->bind_param("iis", $new_data_type_id, $provider_id, $provider_network_id);
                        $stmt->execute();
                    }
                    
                    $success = "Data type added successfully";
                } else {
                    throw new Exception("Failed to add data type");
                }
            }
            
            $conn->commit();
        } catch (Exception $e) {
            $conn->rollback();
            $error = $e->getMessage();
        }
    }
}

// Get data type details if editing
$data_type = null;
$data_type_provider = null;

if ($data_type_id > 0 && $action == 'edit') {
    $stmt = $conn->prepare("SELECT * FROM data_types WHERE id = ?");
    $stmt->bind_param("i", $data_type_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $data_type = $result->fetch_assoc();
    
    if (!$data_type) {
        $error = "Data type not found";
        $data_type_id = 0;
    } else {
        // Get provider mapping if any
        $stmt = $conn->prepare("SELECT * FROM data_type_providers WHERE data_type_id = ? LIMIT 1");
        $stmt->bind_param("i", $data_type_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $data_type_provider = $result->fetch_assoc();
    }
}

// Get data types list with network names
$data_types = [];
$stmt = $conn->query("
    SELECT dt.*, n.name as network_name
    FROM data_types dt
    JOIN networks n ON dt.network_id = n.id
    ORDER BY n.name ASC, dt.sort_order ASC, dt.name ASC
");

while ($row = $stmt->fetch_assoc()) {
    $data_types[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $error = $flashMessage['message'];
    }
}
// Set current page for sidebar highlight
$currentPage = 'data_types';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Data Types Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <!-- Include Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Data Types Management</h1>
                <button id="addDataTypeBtn" class="accent-button py-2 px-4 rounded-md text-white">
                    <i class="fas fa-plus mr-2"></i> Add Data Type
                </button>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Data Type Form -->
            <div id="dataTypeFormCard" class="admin-card rounded-lg shadow-md p-6 mb-6 <?php echo (!$data_type && $action != 'edit') ? 'hidden' : ''; ?>">
                <h2 class="text-xl font-semibold text-white mb-4"><?php echo $data_type ? 'Edit Data Type' : 'Add Data Type'; ?></h2>
                
                <form method="POST" action="">
                    <?php if ($data_type): ?>
                        <input type="hidden" name="edit_id" value="<?php echo $data_type['id']; ?>">
                    <?php endif; ?>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                        <div>
                            <label for="network_id" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                            <select id="network_id" name="network_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                <option value="">Select Network</option>
                                <?php foreach ($networks as $id => $name): ?>
                                    <option value="<?php echo $id; ?>" <?php echo ($data_type && $data_type['network_id'] == $id) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($name); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div>
                            <label for="name" class="block text-sm font-medium text-gray-400 mb-1">Data Type Name</label>
                            <input type="text" id="name" name="name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $data_type ? htmlspecialchars($data_type['name']) : ''; ?>" required>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                        <textarea id="description" name="description" rows="2" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50"><?php echo $data_type ? htmlspecialchars($data_type['description']) : ''; ?></textarea>
                    </div>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                        <div>
                            <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                            <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                <option value="active" <?php echo ($data_type && $data_type['status'] == 'active') ? 'selected' : ''; ?>>Active</option>
                                <option value="inactive" <?php echo ($data_type && $data_type['status'] == 'inactive') ? 'selected' : ''; ?>>Inactive</option>
                            </select>
                        </div>
                        
                        <div>
                            <label for="sort_order" class="block text-sm font-medium text-gray-400 mb-1">Sort Order</label>
                            <input type="number" id="sort_order" name="sort_order" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $data_type ? $data_type['sort_order'] : '0'; ?>" min="0">
                        </div>
                    </div>
                    
                    <div class="mb-4 p-4 bg-gray-800 rounded-md">
                        <h3 class="text-white font-medium mb-3">Provider Configuration</h3>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div>
                                <label for="provider_id" class="block text-sm font-medium text-gray-400 mb-1">Provider</label>
                                <select id="provider_id" name="provider_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                    <option value="">No Provider (Manual Processing)</option>
                                    <?php foreach ($providers as $id => $name): ?>
                                        <option value="<?php echo $id; ?>" <?php echo ($data_type_provider && $data_type_provider['provider_id'] == $id) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($name); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            
                            <div>
                                <label for="provider_network_id" class="block text-sm font-medium text-gray-400 mb-1">Provider Network/Plan ID</label>
                                <input type="text" id="provider_network_id" name="provider_network_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $data_type_provider ? htmlspecialchars($data_type_provider['provider_network_id']) : ''; ?>" placeholder="e.g. 1, mtn_sme">
                                <p class="mt-1 text-xs text-gray-500">The network/plan ID as expected by the provider's API</p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" id="cancelBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md">
                            Cancel
                        </button>
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            <?php echo $data_type ? 'Update Data Type' : 'Add Data Type'; ?>
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Data Types List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden">
                <?php if (empty($data_types)): ?>
                    <div class="p-6 text-center">
                        <p class="text-gray-400">No data types found. Click the "Add Data Type" button to create one.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-700">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        ID
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Network
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Data Type
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Description
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Sort Order
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Status
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Actions
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-700">
                                <?php foreach ($data_types as $item): ?>
                                    <tr>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo $item['id']; ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($item['network_name']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($item['name']); ?>
                                        </td>
                                        <td class="px-6 py-4 text-sm text-gray-300">
                                            <?php echo htmlspecialchars($item['description'] ?? 'N/A'); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo $item['sort_order']; ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full <?php echo $item['status'] == 'active' ? 'bg-green-500 bg-opacity-20 text-green-300' : 'bg-red-500 bg-opacity-20 text-red-300'; ?>">
                                                <?php echo ucfirst($item['status']); ?>
                                            </span>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium space-x-2">
                                            <a href="?action=edit&id=<?php echo $item['id']; ?>" class="text-indigo-400 hover:text-indigo-300" title="Edit">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="?action=delete&id=<?php echo $item['id']; ?>" class="text-red-400 hover:text-red-300 delete-data-type" data-id="<?php echo $item['id']; ?>" title="Delete">
                                                <i class="fas fa-trash-alt"></i>
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Delete Confirmation Modal -->
    <div id="deleteConfirmModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg max-w-md w-full mx-4 z-10">
            <div class="p-6">
                <h3 class="text-xl font-semibold text-white mb-4">Confirm Delete</h3>
                <p class="text-gray-300 mb-6">Are you sure you want to delete this data type? This action cannot be undone.</p>
                <div class="flex justify-end space-x-3">
                    <button id="cancelDeleteBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md">
                        Cancel
                    </button>
                    <a id="confirmDeleteBtn" href="#" class="bg-red-600 hover:bg-red-700 text-white py-2 px-4 rounded-md">
                        Delete
                    </a>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Show/hide data type form
            const addDataTypeBtn = document.getElementById('addDataTypeBtn');
            const cancelBtn = document.getElementById('cancelBtn');
            const dataTypeFormCard = document.getElementById('dataTypeFormCard');
            
            addDataTypeBtn.addEventListener('click', () => {
                dataTypeFormCard.classList.remove('hidden');
                // Reset form if it was in edit mode
                const form = dataTypeFormCard.querySelector('form');
                const editIdInput = form.querySelector('input[name="edit_id"]');
                if (editIdInput) {
                    form.removeChild(editIdInput);
                }
                form.reset();
                form.action = '';
                dataTypeFormCard.querySelector('h2').textContent = 'Add Data Type';
                form.querySelector('button[type="submit"]').textContent = 'Add Data Type';
            });
            
            cancelBtn.addEventListener('click', () => {
                dataTypeFormCard.classList.add('hidden');
            });
            
            // Delete confirmation
            const deleteConfirmModal = document.getElementById('deleteConfirmModal');
            const cancelDeleteBtn = document.getElementById('cancelDeleteBtn');
            const confirmDeleteBtn = document.getElementById('confirmDeleteBtn');
            const deleteButtons = document.querySelectorAll('.delete-data-type');
            
            deleteButtons.forEach(button => {
                button.addEventListener('click', (e) => {
                    e.preventDefault();
                    const dataTypeId = button.getAttribute('data-id');
                    confirmDeleteBtn.href = `?action=delete&id=${dataTypeId}`;
                    deleteConfirmModal.classList.remove('hidden');
                });
            });
            
            cancelDeleteBtn.addEventListener('click', () => {
                deleteConfirmModal.classList.add('hidden');
            });
            
            // Close modal when clicking outside
            deleteConfirmModal.addEventListener('click', (e) => {
                if (e.target === deleteConfirmModal) {
                    deleteConfirmModal.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>