<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get networks
$networks = [];
$result = $conn->query("SELECT * FROM networks ORDER BY name");
while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

$actionSuccess = '';
$actionError = '';

// Process network actions (add/edit/delete)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_network']) || isset($_POST['edit_network'])) {
        // Common validation and data collection for both add and edit
        $networkId = isset($_POST['network_id']) ? (int)$_POST['network_id'] : 0;
        $networkName = sanitizeInput($_POST['network_name']);
        $networkCode = sanitizeInput($_POST['network_code']);
        $networkApiId = sanitizeInput($_POST['network_api_id']);
        $networkStatus = sanitizeInput($_POST['status']);
        
        // Validate inputs
        if (empty($networkName)) {
            $actionError = 'Network name is required';
        } elseif (empty($networkCode)) {
            $actionError = 'Network code is required';
        } elseif (!preg_match('/^[a-zA-Z0-9]+$/', $networkCode)) {
            $actionError = 'Network code must contain only letters and numbers';
        } elseif (!in_array($networkStatus, ['active', 'inactive'])) {
            $actionError = 'Invalid status';
        } else {
            // Check if network code already exists (for new network or when changing code)
            $stmt = $conn->prepare("SELECT id FROM networks WHERE code = ? AND id != ?");
            $stmt->bind_param("si", $networkCode, $networkId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $actionError = 'Network code already exists';
            }
        }
        
        if (empty($actionError)) {
            if (isset($_POST['add_network'])) {
                // Add new network
                $stmt = $conn->prepare("INSERT INTO networks (name, code, api_id, status) VALUES (?, ?, ?, ?)");
                $stmt->bind_param("ssss", $networkName, $networkCode, $networkApiId, $networkStatus);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Network added successfully';
                } else {
                    $actionError = 'Failed to add network: ' . $conn->error;
                }
            } else {
                // Edit existing network
                $stmt = $conn->prepare("UPDATE networks SET name = ?, code = ?, api_id = ?, status = ? WHERE id = ?");
                $stmt->bind_param("ssssi", $networkName, $networkCode, $networkApiId, $networkStatus, $networkId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Network updated successfully';
                } else {
                    $actionError = 'Failed to update network: ' . $conn->error;
                }
            }
            
            // Refresh networks list after action
            $networks = [];
            $result = $conn->query("SELECT * FROM networks ORDER BY name");
            while ($row = $result->fetch_assoc()) {
                $networks[] = $row;
            }
        }
    } elseif (isset($_POST['delete_network'])) {
        $networkId = (int)$_POST['network_id'];
        
        // Check if network has data plans
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM data_plans WHERE network_id = ?");
        $stmt->bind_param("i", $networkId);
        $stmt->execute();
        $result = $stmt->get_result();
        $dataPlansCount = $result->fetch_assoc()['count'];
        
        if ($dataPlansCount > 0) {
            $actionError = 'Cannot delete network that has data plans. Delete the data plans first or mark the network as inactive.';
        } else {
            // Check if network has been used in transactions
            $stmt = $conn->prepare("SELECT COUNT(*) as count FROM transactions WHERE meta_data LIKE ?");
            $searchPattern = '%"network_id":' . $networkId . '%';
            $stmt->bind_param("s", $searchPattern);
            $stmt->execute();
            $result = $stmt->get_result();
            $transactionCount = $result->fetch_assoc()['count'];
            
            if ($transactionCount > 0) {
                $actionError = 'Cannot delete network that has been used in transactions. Consider marking it as inactive instead.';
            } else {
                $stmt = $conn->prepare("DELETE FROM networks WHERE id = ?");
                $stmt->bind_param("i", $networkId);
                
                if ($stmt->execute()) {
                    $actionSuccess = 'Network deleted successfully';
                } else {
                    $actionError = 'Failed to delete network: ' . $conn->error;
                }
                
                // Refresh networks list after delete
                $networks = [];
                $result = $conn->query("SELECT * FROM networks ORDER BY name");
                while ($row = $result->fetch_assoc()) {
                    $networks[] = $row;
                }
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
// Set current page for sidebar highlight
$currentPage = 'networks';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Networks - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(156, 163, 175, 0.3);
            color: #d1d5db;
        }
        
        .network-logo {
            width: 40px;
            height: 40px;
            object-fit: contain;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <!-- Include Sidebar -->
        <?php require_once '../includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Networks Management</h1>
                <button id="addNetworkBtn" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                    <i class="fas fa-plus mr-2"></i> Add New Network
                </button>
            </div>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Networks List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($networks)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-network-wired text-4xl mb-3"></i>
                        <p>No networks found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Network</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Code</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">API ID</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Data Plans</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($networks as $network): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="flex items-center">
                                                <div class="h-10 w-10 rounded-full bg-gray-600 flex items-center justify-center mr-3 text-white">
                                                    <i class="fas fa-broadcast-tower"></i>
                                                </div>
                                                <span class="font-medium text-white"><?php echo htmlspecialchars($network['name']); ?></span>
                                            </div>
                                        </td>
                                        <td class="py-3 px-4 font-mono text-gray-300"><?php echo htmlspecialchars($network['code']); ?></td>
                                        <td class="py-3 px-4 font-mono text-gray-300"><?php echo htmlspecialchars($network['api_id'] ?: 'N/A'); ?></td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $network['status']; ?>">
                                                <?php echo ucfirst($network['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <?php
                                            // Get count of data plans for this network
                                            $networkId = $network['id'];
                                            $stmt = $conn->prepare("SELECT COUNT(*) as count FROM data_plans WHERE network_id = ?");
                                            $stmt->bind_param("i", $networkId);
                                            $stmt->execute();
                                            $result = $stmt->get_result();
                                            $plansCount = $result->fetch_assoc()['count'];
                                            ?>
                                            <a href="data_plans.php?network=<?php echo $network['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                <?php echo $plansCount; ?> plans
                                            </a>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-blue-400 hover:text-blue-300 edit-network" 
                                                        data-id="<?php echo $network['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($network['name']); ?>"
                                                        data-code="<?php echo htmlspecialchars($network['code']); ?>"
                                                        data-api-id="<?php echo htmlspecialchars($network['api_id']); ?>"
                                                        data-status="<?php echo $network['status']; ?>">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button class="text-red-500 hover:text-red-400 delete-network" 
                                                        data-id="<?php echo $network['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($network['name']); ?>"
                                                        data-plans="<?php echo $plansCount; ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Networks</h2>
                
                <div class="text-gray-300 space-y-4">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Networks are the telecom service providers for which you offer data plans and airtime services.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Network Code</h3>
                            <p class="text-gray-400">
                                Network codes are unique identifiers used throughout the system to reference specific networks.
                                They should be short and memorable (e.g., MTN, GLO, AIRTEL).
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">API ID</h3>
                            <p class="text-gray-400">
                                The API ID is the identifier used by your service provider's API to reference this network.
                                This value is required for API integrations to work correctly.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: If you need to temporarily disable a network, set its status to "Inactive" rather than deleting it.
                        This will ensure existing data and transaction history remain intact.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Add/Edit Network Modal -->
    <div id="networkModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Add New Network</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="network_id" name="network_id" value="">
                
                <div class="mb-4">
                    <label for="network_name" class="block text-sm font-medium text-gray-400 mb-1">Network Name</label>
                    <input type="text" id="network_name" name="network_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                </div>
                
                <div class="mb-4">
                    <label for="network_code" class="block text-sm font-medium text-gray-400 mb-1">Network Code</label>
                    <input type="text" id="network_code" name="network_code" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    <p class="mt-1 text-sm text-gray-500">A short, unique identifier (e.g., MTN, GLO)</p>
                </div>
                
                <div class="mb-4">
                    <label for="network_api_id" class="block text-sm font-medium text-gray-400 mb-1">API ID</label>
                    <input type="text" id="network_api_id" name="network_api_id" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    <p class="mt-1 text-sm text-gray-500">ID used by your service provider's API</p>
                </div>
                
                <div class="mb-6">
                    <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="active">Active</option>
                        <option value="inactive">Inactive</option>
                    </select>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" id="submitNetworkBtn" name="add_network" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Add Network
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete Network Modal -->
    <div id="deleteNetworkModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete Network</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="deletePlansWarning" class="hidden">
                <p class="text-gray-300 mb-6">Cannot delete <span id="deleteNetworkName1" class="font-semibold text-white"></span> because it has <span id="deletePlansCount" class="font-semibold text-white"></span> data plans. Please delete the data plans first or mark the network as inactive.</p>
                
                <div class="flex justify-end">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        OK
                    </button>
                </div>
            </div>
            
            <div id="deleteConfirmation" class="hidden">
                <p class="text-gray-300 mb-6">Are you sure you want to delete <span id="deleteNetworkName2" class="font-semibold text-white"></span>? This action cannot be undone.</p>
                
                <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-6">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i>
                        Warning: Deleting a network will also remove all associated data and configurations.
                    </p>
                </div>
                
                <form method="POST" action="">
                    <input type="hidden" id="delete_network_id" name="network_id" value="">
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Cancel
                        </button>
                        <button type="submit" name="delete_network" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                            Delete Network
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const networkModal = document.getElementById('networkModal');
        const deleteNetworkModal = document.getElementById('deleteNetworkModal');
        const modalTitle = document.getElementById('modalTitle');
        const submitNetworkBtn = document.getElementById('submitNetworkBtn');
        
        function openNetworkModal(isEdit = false, networkData = {}) {
            // Reset form
            document.querySelector('#networkModal form').reset();
            
            if (isEdit) {
                // Set form values for editing
                document.getElementById('network_id').value = networkData.id;
                document.getElementById('network_name').value = networkData.name;
                document.getElementById('network_code').value = networkData.code;
                document.getElementById('network_api_id').value = networkData.apiId;
                document.getElementById('status').value = networkData.status;
                
                // Update modal title and button
                modalTitle.textContent = 'Edit Network';
                submitNetworkBtn.textContent = 'Update Network';
                submitNetworkBtn.name = 'edit_network';
            } else {
                // Clear values for new network
                document.getElementById('network_id').value = '';
                
                // Set default modal title and button
                modalTitle.textContent = 'Add New Network';
                submitNetworkBtn.textContent = 'Add Network';
                submitNetworkBtn.name = 'add_network';
            }
            
            // Show the modal
            networkModal.classList.remove('hidden');
        }
        
        function openDeleteModal(networkId, networkName, plansCount) {
            document.getElementById('delete_network_id').value = networkId;
            
            if (plansCount > 0) {
                // Show warning that network has data plans
                document.getElementById('deleteNetworkName1').textContent = networkName;
                document.getElementById('deletePlansCount').textContent = plansCount;
                document.getElementById('deletePlansWarning').classList.remove('hidden');
                document.getElementById('deleteConfirmation').classList.add('hidden');
            } else {
                // Show delete confirmation
                document.getElementById('deleteNetworkName2').textContent = networkName;
                document.getElementById('deletePlansWarning').classList.add('hidden');
                document.getElementById('deleteConfirmation').classList.remove('hidden');
            }
            
            deleteNetworkModal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            networkModal.classList.add('hidden');
            deleteNetworkModal.classList.add('hidden');
        }
        
        // Add event listeners
        document.getElementById('addNetworkBtn').addEventListener('click', () => openNetworkModal(false));
        
        document.querySelectorAll('.edit-network').forEach(button => {
            button.addEventListener('click', function() {
                const networkData = {
                    id: this.getAttribute('data-id'),
                    name: this.getAttribute('data-name'),
                    code: this.getAttribute('data-code'),
                    apiId: this.getAttribute('data-api-id'),
                    status: this.getAttribute('data-status')
                };
                openNetworkModal(true, networkData);
            });
        });
        
        document.querySelectorAll('.delete-network').forEach(button => {
            button.addEventListener('click', function() {
                const networkId = this.getAttribute('data-id');
                const networkName = this.getAttribute('data-name');
                const plansCount = parseInt(this.getAttribute('data-plans'));
                openDeleteModal(networkId, networkName, plansCount);
            });
        });
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === networkModal || event.target === deleteNetworkModal) {
                closeAllModals();
            }
        });
    </script>
</body>
</html>