<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get all site settings
$stmt = $conn->prepare("SELECT * FROM settings ORDER BY id ASC");
$stmt->execute();
$result = $stmt->get_result();
$settings = [];

while ($row = $result->fetch_assoc()) {
    $settings[$row['setting_name']] = $row['setting_value'];
}

// Process form submission
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // General settings
    if (isset($_POST['update_general'])) {
        $siteName = sanitizeInput($_POST['site_name'] ?? '');
        $siteDescription = sanitizeInput($_POST['site_description'] ?? '');
        $adminEmail = sanitizeInput($_POST['admin_email'] ?? '');
        $supportEmail = sanitizeInput($_POST['support_email'] ?? '');
        $currency = sanitizeInput($_POST['currency'] ?? '₦');
        $currencyCode = sanitizeInput($_POST['currency_code'] ?? 'NGN');
        
        // Validate inputs
        if (empty($siteName)) {
            $error = 'Site name is required';
        } elseif (empty($adminEmail)) {
            $error = 'Admin email is required';
        } elseif (!filter_var($adminEmail, FILTER_VALIDATE_EMAIL)) {
            $error = 'Invalid admin email format';
        } elseif (!empty($supportEmail) && !filter_var($supportEmail, FILTER_VALIDATE_EMAIL)) {
            $error = 'Invalid support email format';
        } else {
            // Update settings
            $settingsToUpdate = [
                'site_name' => $siteName,
                'site_description' => $siteDescription,
                'admin_email' => $adminEmail,
                'support_email' => $supportEmail,
                'currency' => $currency,
                'currency_code' => $currencyCode
            ];
            
            updateSettings($settingsToUpdate, $conn, $adminId);
            $success = 'General settings updated successfully';
        }
    }
    
    // Payment settings
    elseif (isset($_POST['update_payment'])) {
        $fundingChargePercentage = (float)($_POST['funding_charge_percentage'] ?? 1.5);
        $checkoutMinAmount = (float)($_POST['checkout_min_amount'] ?? 100);
        $checkoutCharge = (float)($_POST['checkout_charge'] ?? 50);
        
        // Validate inputs
        if ($fundingChargePercentage < 0 || $fundingChargePercentage > 100) {
            $error = 'Funding charge percentage must be between 0 and 100';
        } elseif ($checkoutMinAmount < 0) {
            $error = 'Minimum checkout amount cannot be negative';
        } elseif ($checkoutCharge < 0) {
            $error = 'Checkout charge cannot be negative';
        } else {
            // Update settings
            $settingsToUpdate = [
                'funding_charge_percentage' => $fundingChargePercentage,
                'checkout_min_amount' => $checkoutMinAmount,
                'checkout_charge' => $checkoutCharge
            ];
            
            updateSettings($settingsToUpdate, $conn, $adminId);
            $success = 'Payment settings updated successfully';
        }
    }
    
    // Payment gateway settings
    elseif (isset($_POST['update_gateways'])) {
        $monnifyEnabled = isset($_POST['monnify_enabled']) ? '1' : '0';
        $paystackEnabled = isset($_POST['paystack_enabled']) ? '1' : '0';
        $manualTransferEnabled = isset($_POST['manual_transfer_enabled']) ? '1' : '0';
        
        // Manual transfer details
        $manualBankName = sanitizeInput($_POST['manual_bank_name'] ?? '');
        $manualAccountNumber = sanitizeInput($_POST['manual_account_number'] ?? '');
        $manualAccountName = sanitizeInput($_POST['manual_account_name'] ?? '');
        
        // Validate inputs for manual transfer if enabled
        if ($manualTransferEnabled == '1') {
            if (empty($manualBankName)) {
                $error = 'Bank name is required for manual transfer';
            } elseif (empty($manualAccountNumber)) {
                $error = 'Account number is required for manual transfer';
            } elseif (empty($manualAccountName)) {
                $error = 'Account name is required for manual transfer';
            }
        }
        
        if (empty($error)) {
            // Update settings
            $settingsToUpdate = [
                'monnify_enabled' => $monnifyEnabled,
                'paystack_enabled' => $paystackEnabled,
                'manual_transfer_enabled' => $manualTransferEnabled,
                'manual_bank_name' => $manualBankName,
                'manual_account_number' => $manualAccountNumber,
                'manual_account_name' => $manualAccountName
            ];
            
            updateSettings($settingsToUpdate, $conn, $adminId);
            $success = 'Payment gateway settings updated successfully';
        }
    }
    
    // Paystack settings
    elseif (isset($_POST['update_paystack'])) {
        $paystackPublicKey = sanitizeInput($_POST['paystack_public_key'] ?? '');
        $paystackSecretKey = sanitizeInput($_POST['paystack_secret_key'] ?? '');
        
        // Update settings
        $settingsToUpdate = [
            'paystack_live_public_key' => $paystackPublicKey,
            'paystack_live_secret_key' => $paystackSecretKey
        ];
        
        updateSettings($settingsToUpdate, $conn, $adminId);
        $success = 'Paystack settings updated successfully';
    }
    
    // Monnify settings
    elseif (isset($_POST['update_monnify'])) {
        $monnifyApiKey = sanitizeInput($_POST['monnify_api_key'] ?? '');
        $monnifySecretKey = sanitizeInput($_POST['monnify_secret_key'] ?? '');
        $monnifyContractCode = sanitizeInput($_POST['monnify_contract_code'] ?? '');
        
        // Update settings
        $settingsToUpdate = [
            'monnify_api_key' => $monnifyApiKey,
            'monnify_secret_key' => $monnifySecretKey,
            'monnify_contract_code' => $monnifyContractCode
        ];
        
        updateSettings($settingsToUpdate, $conn, $adminId);
        $success = 'Monnify settings updated successfully';
    }
    
    // Refresh settings
    $stmt = $conn->prepare("SELECT * FROM settings ORDER BY id ASC");
    $stmt->execute();
    $result = $stmt->get_result();
    $settings = [];
    
    while ($row = $result->fetch_assoc()) {
        $settings[$row['setting_name']] = $row['setting_value'];
    }
}

// Helper function to update settings
function updateSettings($settingsArray, $conn, $adminId) {
    foreach ($settingsArray as $name => $value) {
        // Check if setting exists
        $stmt = $conn->prepare("SELECT id FROM settings WHERE setting_name = ?");
        $stmt->bind_param("s", $name);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            // Update existing setting
            $stmt = $conn->prepare("UPDATE settings SET setting_value = ? WHERE setting_name = ?");
            $stmt->bind_param("ss", $value, $name);
        } else {
            // Insert new setting
            $stmt = $conn->prepare("INSERT INTO settings (setting_name, setting_value) VALUES (?, ?)");
            $stmt->bind_param("ss", $name, $value);
        }
        
        $stmt->execute();
    }
    
    // Log admin action
    $action = "Updated site settings";
    $details = "Admin updated site settings";
    $ipAddress = $_SERVER['REMOTE_ADDR'];
    
    // Check if admin_logs table exists
    $stmt = $conn->prepare("SHOW TABLES LIKE 'admin_logs'");
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Insert log
        $stmt = $conn->prepare("
            INSERT INTO admin_logs 
            (admin_id, action, details, ip_address)
            VALUES (?, ?, ?, ?)
        ");
        $stmt->bind_param("isss", $adminId, $action, $details, $ipAddress);
        $stmt->execute();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .tab-button {
            border-bottom: 2px solid transparent;
            transition: all 0.2s;
            color: var(--text-secondary);
        }
        
        .tab-button.active {
            border-bottom-color: var(--accent-color);
            color: white;
        }
        
        /* Toggle switch styling */
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 50px;
            height: 24px;
        }
        
        .toggle-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }
        
        .toggle-slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #555;
            transition: .4s;
            border-radius: 24px;
        }
        
        .toggle-slider:before {
            position: absolute;
            content: "";
            height: 16px;
            width: 16px;
            left: 4px;
            bottom: 4px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }
        
        input:checked + .toggle-slider {
            background-color: var(--accent-color);
        }
        
        input:checked + .toggle-slider:before {
            transform: translateX(26px);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Site Settings</h1>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="admin-card rounded-lg shadow-md overflow-hidden">
                <!-- Settings Tabs -->
                <div class="flex flex-wrap border-b border-gray-700">
                    <button id="generalTab" class="tab-button px-4 py-3 focus:outline-none font-medium active">General</button>
                    <button id="paymentTab" class="tab-button px-4 py-3 focus:outline-none font-medium">Payment</button>
                    <button id="gatewaysTab" class="tab-button px-4 py-3 focus:outline-none font-medium">Payment Gateways</button>
                    <button id="paystackTab" class="tab-button px-4 py-3 focus:outline-none font-medium">Paystack</button>
                    <button id="monnifyTab" class="tab-button px-4 py-3 focus:outline-none font-medium">Monnify</button>
                </div>
                
                <!-- General Settings Tab -->
                <div id="generalTabContent" class="tab-content p-6">
                    <form method="POST" action="">
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                            <div>
                                <label for="site_name" class="block text-sm font-medium text-gray-400 mb-1">Site Name</label>
                                <input type="text" id="site_name" name="site_name" value="<?php echo htmlspecialchars($settings['site_name'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            </div>
                            
                            <div>
                                <label for="site_description" class="block text-sm font-medium text-gray-400 mb-1">Site Description</label>
                                <input type="text" id="site_description" name="site_description" value="<?php echo htmlspecialchars($settings['site_description'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            
                            <div>
                                <label for="admin_email" class="block text-sm font-medium text-gray-400 mb-1">Admin Email</label>
                                <input type="email" id="admin_email" name="admin_email" value="<?php echo htmlspecialchars($settings['admin_email'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            </div>
                            
                            <div>
                                <label for="support_email" class="block text-sm font-medium text-gray-400 mb-1">Support Email</label>
                                <input type="email" id="support_email" name="support_email" value="<?php echo htmlspecialchars($settings['support_email'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            
                            <div>
                                <label for="currency" class="block text-sm font-medium text-gray-400 mb-1">Currency Symbol</label>
                                <input type="text" id="currency" name="currency" value="<?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            </div>
                            
                            <div>
                                <label for="currency_code" class="block text-sm font-medium text-gray-400 mb-1">Currency Code</label>
                                <input type="text" id="currency_code" name="currency_code" value="<?php echo htmlspecialchars($settings['currency_code'] ?? 'NGN'); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                            </div>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_general" class="accent-button py-2 px-4 rounded-md text-white">
                                Save General Settings
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- Payment Settings Tab -->
                <div id="paymentTabContent" class="tab-content p-6 hidden">
                    <form method="POST" action="">
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                            <div>
                                <label for="funding_charge_percentage" class="block text-sm font-medium text-gray-400 mb-1">Funding Charge Percentage</label>
                                <div class="relative mt-1 rounded-md shadow-sm">
                                    <input type="number" id="funding_charge_percentage" name="funding_charge_percentage" value="<?php echo htmlspecialchars($settings['funding_charge_percentage'] ?? '1.5'); ?>" min="0" max="100" step="0.01" class="form-input block w-full pr-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                    <div class="absolute inset-y-0 right-0 pr-3 flex items-center pointer-events-none">
                                        <span class="text-gray-500 sm:text-sm">%</span>
                                    </div>
                                </div>
                                <p class="mt-1 text-xs text-gray-500">Charge percentage for dedicated account transfers</p>
                            </div>
                            
                            <div>
                                <label for="checkout_min_amount" class="block text-sm font-medium text-gray-400 mb-1">Minimum Checkout Amount</label>
                                <div class="relative mt-1 rounded-md shadow-sm">
                                    <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                        <span class="text-gray-500 sm:text-sm"><?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?></span>
                                    </div>
                                    <input type="number" id="checkout_min_amount" name="checkout_min_amount" value="<?php echo htmlspecialchars($settings['checkout_min_amount'] ?? '100'); ?>" min="0" step="0.01" class="form-input block w-full pl-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                </div>
                                <p class="mt-1 text-xs text-gray-500">Minimum amount for checkout payments</p>
                            </div>
                            
                            <div>
                                <label for="checkout_charge" class="block text-sm font-medium text-gray-400 mb-1">Checkout Charge</label>
                                <div class="relative mt-1 rounded-md shadow-sm">
                                    <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                        <span class="text-gray-500 sm:text-sm"><?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?></span>
                                    </div>
                                    <input type="number" id="checkout_charge" name="checkout_charge" value="<?php echo htmlspecialchars($settings['checkout_charge'] ?? '50'); ?>" min="0" step="0.01" class="form-input block w-full pl-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                </div>
                                <p class="mt-1 text-xs text-gray-500">Fixed charge for checkout payments</p>
                            </div>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_payment" class="accent-button py-2 px-4 rounded-md text-white">
                                Save Payment Settings
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- Payment Gateways Tab -->
                <div id="gatewaysTabContent" class="tab-content p-6 hidden">
                    <form method="POST" action="">
                        <div class="mb-8">
                            <h3 class="text-lg font-semibold text-white mb-4">Enable/Disable Payment Gateways</h3>
                            
                            <div class="grid grid-cols-1 gap-6">
                                <div class="flex items-center justify-between p-4 bg-gray-800 rounded-md">
                                    <div>
                                        <h4 class="font-medium text-white">Monnify Accounts</h4>
                                        <p class="text-sm text-gray-400 mt-1">Multiple bank options (Moniepoint, Wema, Sterling, Fidelity)</p>
                                    </div>
                                    <label class="toggle-switch">
                                        <input type="checkbox" name="monnify_enabled" <?php echo (isset($settings['monnify_enabled']) && $settings['monnify_enabled'] == '1') ? 'checked' : ''; ?>>
                                        <span class="toggle-slider"></span>
                                    </label>
                                </div>
                                
                                <div class="flex items-center justify-between p-4 bg-gray-800 rounded-md">
                                    <div>
                                        <h4 class="font-medium text-white">Paystack Account</h4>
                                        <p class="text-sm text-gray-400 mt-1">Dedicated Wema Bank account for instant funding</p>
                                    </div>
                                    <label class="toggle-switch">
                                        <input type="checkbox" name="paystack_enabled" <?php echo (isset($settings['paystack_enabled']) && $settings['paystack_enabled'] == '1') ? 'checked' : ''; ?>>
                                        <span class="toggle-slider"></span>
                                    </label>
                                </div>
                                
                                <div class="flex items-center justify-between p-4 bg-gray-800 rounded-md">
                                    <div>
                                        <h4 class="font-medium text-white">Manual Bank Transfer</h4>
                                        <p class="text-sm text-gray-400 mt-1">Manual verification of bank transfers (no service charge)</p>
                                    </div>
                                    <label class="toggle-switch">
                                        <input type="checkbox" name="manual_transfer_enabled" id="manual_transfer_switch" <?php echo (isset($settings['manual_transfer_enabled']) && $settings['manual_transfer_enabled'] == '1') ? 'checked' : ''; ?>>
                                        <span class="toggle-slider"></span>
                                    </label>
                                </div>
                            </div>
                        </div>
                        
                        <div id="manualTransferSettings" class="border border-gray-700 rounded-md p-4 <?php echo (isset($settings['manual_transfer_enabled']) && $settings['manual_transfer_enabled'] == '1') ? '' : 'hidden'; ?>">
                            <h3 class="text-lg font-semibold text-white mb-4">Manual Bank Transfer Settings</h3>
                            
                            <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                                <div>
                                    <label for="manual_bank_name" class="block text-sm font-medium text-gray-400 mb-1">Bank Name</label>
                                    <input type="text" id="manual_bank_name" name="manual_bank_name" value="<?php echo htmlspecialchars($settings['manual_bank_name'] ?? 'Access Bank'); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                </div>
                                
                                <div>
                                    <label for="manual_account_number" class="block text-sm font-medium text-gray-400 mb-1">Account Number</label>
                                    <input type="text" id="manual_account_number" name="manual_account_number" value="<?php echo htmlspecialchars($settings['manual_account_number'] ?? '0123456789'); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                </div>
                                
                                <div>
                                    <label for="manual_account_name" class="block text-sm font-medium text-gray-400 mb-1">Account Name</label>
                                    <input type="text" id="manual_account_name" name="manual_account_name" value="<?php echo htmlspecialchars($settings['manual_account_name'] ?? 'Company Official Account'); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                </div>
                            </div>
                            
                            <p class="mt-4 text-sm text-gray-400">
                                <i class="fas fa-info-circle mr-1"></i> These details will be shown to users when they select the Manual Transfer option.
                            </p>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_gateways" class="accent-button py-2 px-4 rounded-md text-white">
                                Save Gateway Settings
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- Paystack Settings Tab -->
                <div id="paystackTabContent" class="tab-content p-6 hidden">
                    <form method="POST" action="">
                        <div class="grid grid-cols-1 gap-6">
                            <div>
                                <label for="paystack_public_key" class="block text-sm font-medium text-gray-400 mb-1">Paystack Public Key</label>
                                <input type="text" id="paystack_public_key" name="paystack_public_key" value="<?php echo htmlspecialchars($settings['paystack_live_public_key'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            
                            <div>
                                <label for="paystack_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Paystack Secret Key</label>
                                <input type="password" id="paystack_secret_key" name="paystack_secret_key" value="<?php echo htmlspecialchars($settings['paystack_live_secret_key'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_paystack_secret" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                                    <label for="show_paystack_secret" class="ml-2 text-sm text-gray-400">Show secret key</label>
                                </div>
                            </div>
                            
                            <div class="p-4 bg-gray-800 rounded-md">
                                <h3 class="font-medium text-white mb-2">Paystack Webhook URL</h3>
                                <div class="flex items-center">
                                    <input type="text" id="paystack_webhook_url" value="<?php echo SITE_URL; ?>/webhook/paystack.php" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" readonly>
                                    <button type="button" id="copyPaystackWebhookBtn" class="ml-2 p-2 bg-gray-700 rounded-md hover:bg-gray-600">
                                        <i class="fas fa-copy text-gray-400"></i>
                                    </button>
                                </div>
                                <p class="mt-2 text-sm text-gray-400">
                                    Add this URL to your Paystack dashboard under Settings &gt; API Keys & Webhooks &gt; Webhooks to receive payment notifications.
                                </p>
                            </div>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_paystack" class="accent-button py-2 px-4 rounded-md text-white">
                                Save Paystack Settings
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- Monnify Settings Tab -->
                <div id="monnifyTabContent" class="tab-content p-6 hidden">
                    <form method="POST" action="">
                        <div class="grid grid-cols-1 gap-6">
                            <div>
                                <label for="monnify_api_key" class="block text-sm font-medium text-gray-400 mb-1">Monnify API Key</label>
                                <input type="text" id="monnify_api_key" name="monnify_api_key" value="<?php echo htmlspecialchars($settings['monnify_api_key'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            
                            <div>
                                <label for="monnify_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Monnify Secret Key</label>
                                <input type="password" id="monnify_secret_key" name="monnify_secret_key" value="<?php echo htmlspecialchars($settings['monnify_secret_key'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_monnify_secret" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4">
                                    <label for="show_monnify_secret" class="ml-2 text-sm text-gray-400">Show secret key</label>
                                </div>
                            </div>
                            
                            <div>
                                <label for="monnify_contract_code" class="block text-sm font-medium text-gray-400 mb-1">Monnify Contract Code</label>
                                <input type="text" id="monnify_contract_code" name="monnify_contract_code" value="<?php echo htmlspecialchars($settings['monnify_contract_code'] ?? ''); ?>" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            
                            <div class="p-4 bg-gray-800 rounded-md">
                                <h3 class="font-medium text-white mb-2">Monnify Webhook URL</h3>
                                <div class="flex items-center">
                                    <input type="text" id="monnify_webhook_url" value="<?php echo SITE_URL; ?>/webhook/monnify.php" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" readonly>
                                    <button type="button" id="copyMonnifyWebhookBtn" class="ml-2 p-2 bg-gray-700 rounded-md hover:bg-gray-600">
                                        <i class="fas fa-copy text-gray-400"></i>
                                    </button>
                                </div>
                                <p class="mt-2 text-sm text-gray-400">
                                    Add this URL to your Monnify dashboard under Settings &gt; Webhooks to receive payment notifications.
                                </p>
                            </div>
                        </div>
                        
                        <div class="mt-6 flex justify-end">
                            <button type="submit" name="update_monnify" class="accent-button py-2 px-4 rounded-md text-white">
                                Save Monnify Settings
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Tab switching
            const generalTab = document.getElementById('generalTab');
            const paymentTab = document.getElementById('paymentTab');
            const gatewaysTab = document.getElementById('gatewaysTab');
            const paystackTab = document.getElementById('paystackTab');
            const monnifyTab = document.getElementById('monnifyTab');
            
            const generalTabContent = document.getElementById('generalTabContent');
            const paymentTabContent = document.getElementById('paymentTabContent');
            const gatewaysTabContent = document.getElementById('gatewaysTabContent');
            const paystackTabContent = document.getElementById('paystackTabContent');
            const monnifyTabContent = document.getElementById('monnifyTabContent');
            
            generalTab.addEventListener('click', function() {
                setActiveTab(generalTab, generalTabContent);
            });
            
            paymentTab.addEventListener('click', function() {
                setActiveTab(paymentTab, paymentTabContent);
            });
            
            gatewaysTab.addEventListener('click', function() {
                setActiveTab(gatewaysTab, gatewaysTabContent);
            });
            
            paystackTab.addEventListener('click', function() {
                setActiveTab(paystackTab, paystackTabContent);
            });
            
            monnifyTab.addEventListener('click', function() {
                setActiveTab(monnifyTab, monnifyTabContent);
            });
            
            function setActiveTab(tab, content) {
                // Remove active class from all tabs
                [generalTab, paymentTab, gatewaysTab, paystackTab, monnifyTab].forEach(t => {
                    t.classList.remove('active');
                });
                
                // Hide all tab contents
                [generalTabContent, paymentTabContent, gatewaysTabContent, paystackTabContent, monnifyTabContent].forEach(c => {
                    c.classList.add('hidden');
                });
                
                // Set active tab and show content
                tab.classList.add('active');
                content.classList.remove('hidden');
            }
            
            // Toggle secret keys visibility
            const showPaystackSecret = document.getElementById('show_paystack_secret');
            const paystackSecretKey = document.getElementById('paystack_secret_key');
            
            if (showPaystackSecret && paystackSecretKey) {
                showPaystackSecret.addEventListener('change', function() {
                    paystackSecretKey.type = this.checked ? 'text' : 'password';
                });
            }
            
            const showMonnifySecret = document.getElementById('show_monnify_secret');
            const monnifySecretKey = document.getElementById('monnify_secret_key');
            
            if (showMonnifySecret && monnifySecretKey) {
                showMonnifySecret.addEventListener('change', function() {
                    monnifySecretKey.type = this.checked ? 'text' : 'password';
                });
            }
            
            // Copy webhook URLs
            const copyPaystackWebhookBtn = document.getElementById('copyPaystackWebhookBtn');
            const paystackWebhookUrl = document.getElementById('paystack_webhook_url');
            
            if (copyPaystackWebhookBtn && paystackWebhookUrl) {
                copyPaystackWebhookBtn.addEventListener('click', function() {
                    copyToClipboard(paystackWebhookUrl, copyPaystackWebhookBtn);
                });
            }
            
            const copyMonnifyWebhookBtn = document.getElementById('copyMonnifyWebhookBtn');
            const monnifyWebhookUrl = document.getElementById('monnify_webhook_url');
            
            if (copyMonnifyWebhookBtn && monnifyWebhookUrl) {
                copyMonnifyWebhookBtn.addEventListener('click', function() {
                    copyToClipboard(monnifyWebhookUrl, copyMonnifyWebhookBtn);
                });
            }
            
            function copyToClipboard(inputElement, buttonElement) {
                inputElement.select();
                document.execCommand('copy');
                
                const icon = buttonElement.querySelector('i');
                icon.className = 'fas fa-check text-green-500';
                
                setTimeout(function() {
                    icon.className = 'fas fa-copy text-gray-400';
                }, 2000);
            }
            
            // Toggle manual transfer settings
            const manualTransferSwitch = document.getElementById('manual_transfer_switch');
            const manualTransferSettings = document.getElementById('manualTransferSettings');
            
            if (manualTransferSwitch && manualTransferSettings) {
                manualTransferSwitch.addEventListener('change', function() {
                    if (this.checked) {
                        manualTransferSettings.classList.remove('hidden');
                    } else {
                        manualTransferSettings.classList.add('hidden');
                    }
                });
            }
        });
    </script>
</body>
</html>