<?php
// File: /admin/settings/check_balance.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get provider ID
$providerId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($providerId <= 0) {
    setFlashMessage("Invalid provider ID", "error");
    redirect(ADMIN_URL . '/settings/providers.php');
}

// Get provider info
$stmt = $conn->prepare("SELECT * FROM providers WHERE id = ?");
$stmt->bind_param("i", $providerId);
$stmt->execute();
$result = $stmt->get_result();
$provider = $result->fetch_assoc();

if (!$provider) {
    setFlashMessage("Provider not found", "error");
    redirect(ADMIN_URL . '/settings/providers.php');
}

// Initialize variables
$balance = null;
$error = null;
$rawResponse = null;
$success = false;

// Always try to check the balance (no need for form submission)
try {
    // Parse the base domain from the API URL
    $apiUrl = $provider['api_url'];
    
    // Check if the URL already contains /api/user
    if (strpos($apiUrl, '/api/user/') === false) {
        // Parse the domain
        $parsedUrl = parse_url($apiUrl);
        $domain = $parsedUrl['scheme'] . '://' . $parsedUrl['host'];
        if (isset($parsedUrl['port'])) {
            $domain .= ':' . $parsedUrl['port'];
        }
        
        // Construct the correct endpoint URL
        $apiUrl = $domain . '/api/user/';
    }
    
    // Prepare API call
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $apiUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    
    $headers = [
        "Authorization: Token " . $provider['api_key'],
        'Content-Type: application/json'
    ];
    
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    
    // Execute API call
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $rawResponse = $response;
    
    if (curl_errno($ch)) {
        throw new Exception('API connection error: ' . curl_error($ch));
    }
    
    curl_close($ch);
    
    // Process response
    $responseData = json_decode($response, true);
    
    if ($httpCode < 200 || $httpCode >= 300) {
        throw new Exception('API request failed. Status code: ' . $httpCode);
    }
    
    // Extract balance information based on API response structure
    // First check if the balance is within a 'user' object like in your working example
    if (isset($responseData['user']['Account_Balance'])) {
        $balance = $responseData['user']['Account_Balance'];
    } elseif (isset($responseData['user']['wallet_balance'])) {
        $balance = $responseData['user']['wallet_balance'];
    } 
    // Fallback to other potential structures
    elseif (isset($responseData['Account_Balance'])) {
        $balance = $responseData['Account_Balance'];
    } elseif (isset($responseData['wallet_balance'])) {
        $balance = $responseData['wallet_balance'];
    } elseif (isset($responseData['data']) && isset($responseData['data']['balance'])) {
        $balance = $responseData['data']['balance'];
    } else {
        throw new Exception('Could not determine balance from API response. Please check the API response structure below.');
    }
    
    // Update provider balance in database
    $stmt = $conn->prepare("UPDATE providers SET balance = ?, last_balance_check = NOW() WHERE id = ?");
    $stmt->bind_param("di", $balance, $providerId);
    
    if ($stmt->execute()) {
        $success = true;
        
        // Set flash message and redirect back to providers.php
        setFlashMessage("Provider balance updated successfully", "success");
        redirect(ADMIN_URL . '/settings/providers.php');
    } else {
        throw new Exception('Failed to update balance in the database');
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Check Provider Balance - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .response-container {
            background-color: #2d2d2d;
            border: 1px solid #444;
            border-radius: 0.375rem;
            padding: 1rem;
            margin-top: 1rem;
            max-height: 300px;
            overflow-y: auto;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow container mx-auto px-4 py-8">
        <div class="flex justify-between items-center mb-6">
            <h1 class="text-2xl font-bold text-white">Check Provider Balance</h1>
            <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="py-2 px-4 bg-gray-700 hover:bg-gray-600 text-white rounded-md">
                <i class="fas fa-arrow-left mr-2"></i> Back to Providers
            </a>
        </div>
        
        <div class="admin-card rounded-lg shadow-lg p-6 mb-8">
            <div class="flex items-center mb-4">
                <h2 class="text-xl font-bold"><?php echo htmlspecialchars($provider['name']); ?></h2>
                <span class="ml-3 px-3 py-1 text-sm rounded-full <?php echo $provider['status'] == 'active' ? 'bg-green-500 bg-opacity-20 text-green-300' : 'bg-red-500 bg-opacity-20 text-red-300'; ?>">
                    <?php echo ucfirst($provider['status']); ?>
                </span>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6 mb-6">
                <div>
                    <p class="text-sm text-gray-400 mb-1">Provider Type</p>
                    <p><?php echo ucfirst($provider['type']); ?></p>
                </div>
                <div>
                    <p class="text-sm text-gray-400 mb-1">API URL</p>
                    <p class="truncate"><?php echo htmlspecialchars($provider['api_url']); ?></p>
                </div>
            </div>
            
            <div class="border-t border-gray-700 pt-6 mb-6">
                <h3 class="text-lg font-semibold mb-4">Balance Information</h3>
                
                <?php if ($error): ?>
                <div class="bg-red-500 bg-opacity-20 text-red-300 p-4 rounded-md mb-4">
                    <p class="font-semibold">Error</p>
                    <p><?php echo htmlspecialchars($error); ?></p>
                    <p class="mt-2 text-sm">API endpoint used: <code><?php echo htmlspecialchars($apiUrl); ?></code></p>
                </div>
                
                <div class="bg-gray-800 p-6 rounded-lg text-center mb-6">
                    <p class="text-sm text-gray-400 mb-2">Current Balance</p>
                    <p class="text-3xl font-bold text-indigo-400">
                        <?php echo $provider['balance'] ? '₦' . number_format($provider['balance'], 2) : 'N/A'; ?>
                    </p>
                    <?php if ($provider['last_balance_check']): ?>
                    <p class="text-xs text-gray-500 mt-2">Last checked: <?php echo date('M j, Y g:i A', strtotime($provider['last_balance_check'])); ?></p>
                    <?php endif; ?>
                </div>
                
                <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="block w-full text-center accent-button py-3 px-4 rounded-md text-white font-medium">
                    Return to Providers
                </a>
                <?php endif; ?>
            </div>
            
            <?php if ($rawResponse && $error): ?>
            <div class="mt-6">
                <h3 class="text-lg font-semibold mb-2">API Response</h3>
                <div class="response-container">
                    <pre class="text-xs text-gray-300"><?php echo htmlspecialchars($rawResponse); ?></pre>
                </div>
            </div>
            <?php endif; ?>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>