<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get email settings
$emailSettings = [];
$result = $conn->query("SELECT * FROM email_settings LIMIT 1");
if ($result->num_rows > 0) {
    $emailSettings = $result->fetch_assoc();
}

// Get email templates
$emailTemplates = [];
$result = $conn->query("SELECT * FROM email_templates ORDER BY name");
while ($row = $result->fetch_assoc()) {
    $emailTemplates[] = $row;
}

$success = '';
$errors = [];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_settings'])) {
    // Get form data
    $smtpHost = sanitizeInput($_POST['smtp_host']);
    $smtpPort = (int)sanitizeInput($_POST['smtp_port']);
    $smtpUsername = sanitizeInput($_POST['smtp_username']);
    $smtpPassword = $_POST['smtp_password']; // Don't sanitize password to preserve special characters
    $smtpEncryption = sanitizeInput($_POST['smtp_encryption']);
    $fromEmail = sanitizeInput($_POST['from_email']);
    $fromName = sanitizeInput($_POST['from_name']);
    
    // Basic validation
    if (empty($smtpHost)) {
        $errors[] = 'SMTP host is required';
    }
    
    if (empty($smtpPort)) {
        $errors[] = 'SMTP port is required';
    }
    
    if (empty($fromEmail)) {
        $errors[] = 'From email is required';
    } elseif (!filter_var($fromEmail, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid from email format';
    }
    
    if (empty($fromName)) {
        $errors[] = 'From name is required';
    }
    
    // If no errors, update settings
    if (empty($errors)) {
        if (empty($emailSettings)) {
            // Insert new settings
            $stmt = $conn->prepare("INSERT INTO email_settings (smtp_host, smtp_port, smtp_username, smtp_password, smtp_encryption, from_email, from_name) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param("sisssss", $smtpHost, $smtpPort, $smtpUsername, $smtpPassword, $smtpEncryption, $fromEmail, $fromName);
        } else {
            // Update existing settings - don't update password if empty
            if (empty($smtpPassword)) {
                $stmt = $conn->prepare("UPDATE email_settings SET smtp_host = ?, smtp_port = ?, smtp_username = ?, smtp_encryption = ?, from_email = ?, from_name = ?");
                $stmt->bind_param("sisssss", $smtpHost, $smtpPort, $smtpUsername, $smtpEncryption, $fromEmail, $fromName);
            } else {
                $stmt = $conn->prepare("UPDATE email_settings SET smtp_host = ?, smtp_port = ?, smtp_username = ?, smtp_password = ?, smtp_encryption = ?, from_email = ?, from_name = ?");
                $stmt->bind_param("sisssss", $smtpHost, $smtpPort, $smtpUsername, $smtpPassword, $smtpEncryption, $fromEmail, $fromName);
            }
        }
        
        if ($stmt->execute()) {
            $success = 'Email settings saved successfully!';
            
            // Refresh email settings
            $result = $conn->query("SELECT * FROM email_settings LIMIT 1");
            if ($result->num_rows > 0) {
                $emailSettings = $result->fetch_assoc();
            }
        } else {
            $errors[] = 'Failed to save email settings: ' . $conn->error;
        }
    }
} 
// [Keep the existing code until the test email section]

// ... existing code ...

 elseif ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['test_email'])) {
    // Get form data
    $testEmail = sanitizeInput($_POST['test_email_address']);
    
    // Validate email
    if (empty($testEmail)) {
        $errors[] = 'Test email address is required';
    } elseif (!filter_var($testEmail, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid test email format';
    }
    
    // If no errors, send test email
    if (empty($errors)) {
        // Send actual test email using PHPMailer
        $testResult = testEmailConfig($testEmail);
        
        if ($testResult['status'] === 'success') {
            $success = $testResult['message'];
        } else {
            $errors[] = $testResult['message'];
        }
    }
}

// [Continue with the rest of the code]
 elseif ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_template'])) {
    // Get form data
    $templateId = (int)$_POST['template_id'];
    $templateSubject = sanitizeInput($_POST['template_subject']);
    $templateBody = $_POST['template_body']; // Don't sanitize to preserve HTML
    
    // Basic validation
    if (empty($templateSubject)) {
        $errors[] = 'Template subject is required';
    }
    
    if (empty($templateBody)) {
        $errors[] = 'Template body is required';
    }
    
    // If no errors, update template
    if (empty($errors)) {
        $stmt = $conn->prepare("UPDATE email_templates SET subject = ?, body = ? WHERE id = ?");
        $stmt->bind_param("ssi", $templateSubject, $templateBody, $templateId);
        
        if ($stmt->execute()) {
            $success = 'Email template updated successfully!';
            
            // Refresh email templates
            $emailTemplates = [];
            $result = $conn->query("SELECT * FROM email_templates ORDER BY name");
            while ($row = $result->fetch_assoc()) {
                $emailTemplates[] = $row;
            }
        } else {
            $errors[] = 'Failed to update email template: ' . $conn->error;
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $errors[] = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Email Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Email Settings</h1>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- SMTP Settings Tab -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">SMTP Configuration</h2>
                
                <form method="POST" action="">
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="mb-4">
                            <label for="smtp_host" class="block text-sm font-medium text-gray-400 mb-1">SMTP Host</label>
                            <input type="text" id="smtp_host" name="smtp_host" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($emailSettings['smtp_host'] ?? ''); ?>" required>
                        </div>
                        
                        <div class="mb-4">
                            <label for="smtp_port" class="block text-sm font-medium text-gray-400 mb-1">SMTP Port</label>
                            <input type="number" id="smtp_port" name="smtp_port" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($emailSettings['smtp_port'] ?? '587'); ?>" required>
                        </div>
                        
                        <div class="mb-4">
                            <label for="smtp_username" class="block text-sm font-medium text-gray-400 mb-1">SMTP Username</label>
                            <input type="text" id="smtp_username" name="smtp_username" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($emailSettings['smtp_username'] ?? ''); ?>" required>
                        </div>
                        
                        <div class="mb-4">
                            <label for="smtp_password" class="block text-sm font-medium text-gray-400 mb-1">SMTP Password</label>
                            <input type="password" id="smtp_password" name="smtp_password" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="<?php echo empty($emailSettings['smtp_password']) ? '' : '••••••••••••••••'; ?>">
                            <p class="mt-1 text-sm text-gray-500">Leave blank to keep existing password</p>
                        </div>
                        
                        <div class="mb-4">
                            <label for="smtp_encryption" class="block text-sm font-medium text-gray-400 mb-1">Encryption</label>
                            <select id="smtp_encryption" name="smtp_encryption" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                <option value="none" <?php echo (isset($emailSettings['smtp_encryption']) && $emailSettings['smtp_encryption'] === 'none') ? 'selected' : ''; ?>>None</option>
                                <option value="ssl" <?php echo (isset($emailSettings['smtp_encryption']) && $emailSettings['smtp_encryption'] === 'ssl') ? 'selected' : ''; ?>>SSL</option>
                                <option value="tls" <?php echo (isset($emailSettings['smtp_encryption']) && $emailSettings['smtp_encryption'] === 'tls') ? 'selected' : ''; ?>>TLS</option>
                            </select>
                        </div>
                        
                        <div class="mb-4">
                            <label for="from_email" class="block text-sm font-medium text-gray-400 mb-1">From Email</label>
                            <input type="email" id="from_email" name="from_email" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($emailSettings['from_email'] ?? ''); ?>" required>
                        </div>
                        
                        <div class="mb-4">
                            <label for="from_name" class="block text-sm font-medium text-gray-400 mb-1">From Name</label>
                            <input type="text" id="from_name" name="from_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($emailSettings['from_name'] ?? ''); ?>" required>
                        </div>
                    </div>
                    
                    <div class="mt-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md mb-6">
                        <p class="text-indigo-300 text-sm">
                            <i class="fas fa-info-circle mr-2"></i>
                            These settings are used to configure the email sending functionality. Make sure to use a valid SMTP server with proper authentication.
                        </p>
                    </div>
                    
                    <div class="flex justify-between">
                        <button type="submit" name="save_settings" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Settings
                        </button>
                        
                        <div class="flex items-center">
                            <div class="mr-2">
                                <input type="email" name="test_email_address" placeholder="Enter email for testing" class="form-input rounded-md shadow-sm py-2 px-3 text-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            </div>
                            <button type="submit" name="test_email" class="py-2 px-4 bg-gray-700 text-white rounded-md text-sm hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Send Test Email
                            </button>
                        </div>
                    </div>
                </form>
            </div>
            
            <!-- Email Templates Tab -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Email Templates</h2>
                </div>
                
                <div class="mb-4 text-gray-300">
                    <p>Configure email templates used for various system notifications. Click on a template to edit it.</p>
                </div>
                
                <!-- Templates List -->
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4 mb-4">
                    <?php foreach ($emailTemplates as $template): ?>
                        <div class="template-card bg-gray-800 rounded-lg p-4 cursor-pointer hover:bg-gray-700 transition-colors" data-id="<?php echo $template['id']; ?>" data-name="<?php echo htmlspecialchars($template['name']); ?>" data-subject="<?php echo htmlspecialchars($template['subject']); ?>" data-body="<?php echo htmlspecialchars($template['body']); ?>">
                            <h3 class="font-semibold text-white mb-2"><?php echo htmlspecialchars($template['name']); ?></h3>
                            <p class="text-gray-400 text-sm truncate"><?php echo htmlspecialchars($template['subject']); ?></p>
                        </div>
                    <?php endforeach; ?>
                </div>
                
                <div class="mt-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                    <h3 class="font-semibold text-yellow-300 mb-2">Email Template Variables</h3>
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-2 text-sm">
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{user_name}}</span>
                            <span class="text-gray-400">User's full name</span>
                        </div>
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{user_email}}</span>
                            <span class="text-gray-400">User's email address</span>
                        </div>
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{site_name}}</span>
                            <span class="text-gray-400">Website name</span>
                        </div>
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{verification_link}}</span>
                            <span class="text-gray-400">Email verification link</span>
                        </div>
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{reset_link}}</span>
                            <span class="text-gray-400">Password reset link</span>
                        </div>
                        <div class="flex justify-between">
                            <span class="text-gray-300">{{amount}}</span>
                            <span class="text-gray-400">Transaction amount</span>
                        </div>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Template Edit Modal -->
    <div id="templateModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white" id="modalTitle">Edit Template</h3>
                <button id="closeModal" class="text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form id="templateForm" method="POST" action="">
                <input type="hidden" id="template_id" name="template_id" value="">
                
                <div class="mb-4">
                    <label for="template_name" class="block text-sm font-medium text-gray-400 mb-1">Template Name</label>
                    <input type="text" id="template_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700" readonly>
                </div>
                
                <div class="mb-4">
                    <label for="template_subject" class="block text-sm font-medium text-gray-400 mb-1">Email Subject</label>
                    <input type="text" id="template_subject" name="template_subject" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                </div>
                
                <div class="mb-6">
                    <label for="template_body" class="block text-sm font-medium text-gray-400 mb-1">Email Body</label>
                    <textarea id="template_body" name="template_body" rows="10" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                    <p class="mt-1 text-sm text-gray-500">You can use HTML tags and template variables like {{user_name}}, {{site_name}}, etc.</p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" id="cancelBtn" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="save_template" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Save Template
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Template modal functionality
        const templateModal = document.getElementById('templateModal');
        const modalTitle = document.getElementById('modalTitle');
        const templateForm = document.getElementById('templateForm');
        const templateIdInput = document.getElementById('template_id');
        const templateNameInput = document.getElementById('template_name');
        const templateSubjectInput = document.getElementById('template_subject');
        const templateBodyInput = document.getElementById('template_body');
        const closeModal = document.getElementById('closeModal');
        const cancelBtn = document.getElementById('cancelBtn');
        
        function openTemplateModal(id, name, subject, body) {
            templateIdInput.value = id;
            templateNameInput.value = name;
            templateSubjectInput.value = subject;
            templateBodyInput.value = body;
            modalTitle.textContent = 'Edit Template: ' + name;
            templateModal.classList.remove('hidden');
        }
        
        function closeTemplateModal() {
            templateModal.classList.add('hidden');
        }
        
        closeModal.addEventListener('click', closeTemplateModal);
        cancelBtn.addEventListener('click', closeTemplateModal);
        
        // Handle template card clicks
        const templateCards = document.querySelectorAll('.template-card');
        templateCards.forEach(card => {
            card.addEventListener('click', function() {
                const id = this.getAttribute('data-id');
                const name = this.getAttribute('data-name');
                const subject = this.getAttribute('data-subject');
                const body = this.getAttribute('data-body');
                
                openTemplateModal(id, name, subject, body);
            });
        });
        
        // Close modal when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === templateModal) {
                closeTemplateModal();
            }
        });
    </script>
</body>
</html>