<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get all settings
$settings = [];
$settingsResult = $conn->query("SELECT * FROM settings ORDER BY setting_name");
while ($row = $settingsResult->fetch_assoc()) {
    $settings[$row['setting_name']] = $row['setting_value'];
}

$success = '';
$errors = [];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $siteName = sanitizeInput($_POST['site_name']);
    $siteDescription = sanitizeInput($_POST['site_description']);
    $contactEmail = sanitizeInput($_POST['contact_email']);
    $contactPhone = sanitizeInput($_POST['contact_phone']);
    $upgradeFee = (float) sanitizeInput($_POST['upgrade_fee']);
    $fundingChargePercentage = (float) sanitizeInput($_POST['funding_charge_percentage']);
    $checkoutMinAmount = (float) sanitizeInput($_POST['checkout_min_amount']);
    $checkoutCharge = (float) sanitizeInput($_POST['checkout_charge']);
    $currency = sanitizeInput($_POST['currency']);
    
    // Basic validation
    if (empty($siteName)) {
        $errors[] = 'Site name is required';
    }
    
    if (empty($contactEmail)) {
        $errors[] = 'Contact email is required';
    } elseif (!filter_var($contactEmail, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid contact email format';
    }
    
    if ($upgradeFee < 0) {
        $errors[] = 'Upgrade fee cannot be negative';
    }
    
    if ($fundingChargePercentage < 0 || $fundingChargePercentage > 100) {
        $errors[] = 'Funding charge percentage must be between 0 and 100';
    }
    
    if ($checkoutMinAmount < 0) {
        $errors[] = 'Checkout minimum amount cannot be negative';
    }
    
    if ($checkoutCharge < 0) {
        $errors[] = 'Checkout charge cannot be negative';
    }
    
    // If no errors, update settings
    if (empty($errors)) {
        $settingsToUpdate = [
            'site_name' => $siteName,
            'site_description' => $siteDescription,
            'contact_email' => $contactEmail,
            'contact_phone' => $contactPhone,
            'upgrade_fee' => $upgradeFee,
            'funding_charge_percentage' => $fundingChargePercentage,
            'checkout_min_amount' => $checkoutMinAmount,
            'checkout_charge' => $checkoutCharge,
            'currency' => $currency
        ];
        
        $updateSuccess = true;
        
        foreach ($settingsToUpdate as $name => $value) {
            if (!updateSetting($name, $value)) {
                $updateSuccess = false;
                $errors[] = 'Failed to update ' . $name;
            }
        }
        
        if ($updateSuccess) {
            $success = 'Settings updated successfully!';
            
            // Refresh settings
            $settings = [];
            $settingsResult = $conn->query("SELECT * FROM settings ORDER BY setting_name");
            while ($row = $settingsResult->fetch_assoc()) {
                $settings[$row['setting_name']] = $row['setting_value'];
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $errors[] = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>General Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">General Settings</h1>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <form method="POST" action="">
                <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <!-- Site Information -->
                    <div class="admin-card rounded-lg shadow-md p-6 col-span-1 md:col-span-2">
                        <h2 class="text-xl font-semibold text-white mb-4">Site Information</h2>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="site_name" class="block text-sm font-medium text-gray-400 mb-1">Site Name</label>
                                <input type="text" id="site_name" name="site_name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['site_name'] ?? ''); ?>" required>
                                <p class="mt-1 text-sm text-gray-500">The name of your website that appears in the title and header.</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="currency" class="block text-sm font-medium text-gray-400 mb-1">Currency Symbol</label>
                                <input type="text" id="currency" name="currency" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?>" required maxlength="3">
                                <p class="mt-1 text-sm text-gray-500">Currency symbol to use throughout the site (e.g., ₦, $, €).</p>
                            </div>
                            
                            <div class="mb-4 md:col-span-2">
                                <label for="site_description" class="block text-sm font-medium text-gray-400 mb-1">Site Description</label>
                                <textarea id="site_description" name="site_description" rows="3" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50"><?php echo htmlspecialchars($settings['site_description'] ?? ''); ?></textarea>
                                <p class="mt-1 text-sm text-gray-500">A brief description of your website used for SEO and meta tags.</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="contact_email" class="block text-sm font-medium text-gray-400 mb-1">Contact Email</label>
                                <input type="email" id="contact_email" name="contact_email" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['contact_email'] ?? ''); ?>" required>
                                <p class="mt-1 text-sm text-gray-500">The primary contact email displayed on the website.</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="contact_phone" class="block text-sm font-medium text-gray-400 mb-1">Contact Phone</label>
                                <input type="text" id="contact_phone" name="contact_phone" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['contact_phone'] ?? ''); ?>">
                                <p class="mt-1 text-sm text-gray-500">The primary contact phone number displayed on the website.</p>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Pricing Settings -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold text-white mb-4">User Upgrade Settings</h2>
                        
                        <div class="mb-4">
                            <label for="upgrade_fee" class="block text-sm font-medium text-gray-400 mb-1">Vendor Upgrade Fee</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?></span>
                                <input type="number" id="upgrade_fee" name="upgrade_fee" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['upgrade_fee'] ?? '1000'); ?>" min="0" step="0.01" required>
                            </div>
                            <p class="mt-1 text-sm text-gray-500">The fee charged to upgrade from Smart User to Vendor User.</p>
                        </div>
                    </div>
                    
                    <!-- Wallet Funding Settings -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Wallet Funding Settings</h2>
                        
                        <div class="mb-4">
                            <label for="funding_charge_percentage" class="block text-sm font-medium text-gray-400 mb-1">Funding Charge Percentage</label>
                            <div class="flex">
                                <input type="number" id="funding_charge_percentage" name="funding_charge_percentage" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['funding_charge_percentage'] ?? '5'); ?>" min="0" max="100" step="0.1" required>
                                <span class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                            </div>
                            <p class="mt-1 text-sm text-gray-500">The percentage charged for dedicated account funding.</p>
                        </div>
                        
                        <div class="mb-4">
                            <label for="checkout_min_amount" class="block text-sm font-medium text-gray-400 mb-1">Checkout Minimum Amount</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?></span>
                                <input type="number" id="checkout_min_amount" name="checkout_min_amount" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['checkout_min_amount'] ?? '200'); ?>" min="0" step="0.01" required>
                            </div>
                            <p class="mt-1 text-sm text-gray-500">The minimum amount allowed for Paystack checkout funding.</p>
                        </div>
                        
                        <div class="mb-4">
                            <label for="checkout_charge" class="block text-sm font-medium text-gray-400 mb-1">Checkout Fixed Charge</label>
                            <div class="flex">
                                <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo htmlspecialchars($settings['currency'] ?? '₦'); ?></span>
                                <input type="number" id="checkout_charge" name="checkout_charge" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($settings['checkout_charge'] ?? '100'); ?>" min="0" step="0.01" required>
                            </div>
                            <p class="mt-1 text-sm text-gray-500">The fixed charge for Paystack checkout funding.</p>
                        </div>
                    </div>
                </div>
                
                <!-- Submit Button -->
                <div class="mt-6 flex justify-end">
                    <button type="submit" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Save Settings
                    </button>
                </div>
            </form>
            
            <!-- Settings Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6 mt-6">
                <h2 class="text-xl font-semibold text-white mb-4">About General Settings</h2>
                
                <div class="space-y-4 text-gray-300">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        The general settings control the basic information and functionality of your VTU platform.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Site Information</h3>
                            <p class="text-gray-400">
                                These settings control how your website appears to users, including the site name,
                                description, and contact information.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Pricing Settings</h3>
                            <p class="text-gray-400">
                                Configure the fees charged for account upgrades and wallet funding to balance
                                profitability with competitive rates.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: Regularly review and update your settings to ensure they remain competitive in the market.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
    </script>
</body>
</html>