<?php
// File: admin/settings/monnify.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get Monnify configuration
$monnifyConfig = [];
$result = $conn->query("SELECT * FROM monnify_configs WHERE is_active = 1 LIMIT 1");
if ($result && $result->num_rows > 0) {
    $monnifyConfig = $result->fetch_assoc();
}

// Get funding charge setting
$fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);

$success = '';
$errors = [];

// Process Monnify settings form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_monnify'])) {
    // Get form data
    $isLive = isset($_POST['is_live']) ? 0 : 1; // Note: We invert this because is_test=0 means live mode
    $liveApiKey = sanitizeInput($_POST['live_api_key']);
    $liveSecretKey = sanitizeInput($_POST['live_secret_key']);
    $liveContractCode = sanitizeInput($_POST['live_contract_code']);
    $testApiKey = sanitizeInput($_POST['test_api_key']);
    $testSecretKey = sanitizeInput($_POST['test_secret_key']);
    $testContractCode = sanitizeInput($_POST['test_contract_code']);
    $webhookSecret = sanitizeInput($_POST['webhook_secret']);
    
    // Basic validation
    if (!$isLive) { // Live mode
        if (empty($liveApiKey)) {
            $errors[] = 'Monnify Live API Key is required when using live mode';
        }
        
        if (empty($liveSecretKey)) {
            $errors[] = 'Monnify Live Secret Key is required when using live mode';
        }
        
        if (empty($liveContractCode)) {
            $errors[] = 'Monnify Live Contract Code is required when using live mode';
        }
    } else { // Test mode
        if (empty($testApiKey)) {
            $errors[] = 'Monnify Test API Key is required when using test mode';
        }
        
        if (empty($testSecretKey)) {
            $errors[] = 'Monnify Test Secret Key is required when using test mode';
        }
        
        if (empty($testContractCode)) {
            $errors[] = 'Monnify Test Contract Code is required when using test mode';
        }
    }
    
    // If no errors, update settings
    if (empty($errors)) {
        // Set the base URL based on live/test mode
        $baseUrl = !$isLive ? 'https://api.monnify.com' : 'https://sandbox.monnify.com';
        
        // API key and secret key based on mode
        $apiKey = !$isLive ? $liveApiKey : $testApiKey;
        $secretKey = !$isLive ? $liveSecretKey : $testSecretKey;
        $contractCode = !$isLive ? $liveContractCode : $testContractCode;
        
        // Check if config exists
        if (!empty($monnifyConfig)) {
            // Update existing config
            $stmt = $conn->prepare("
                UPDATE monnify_configs 
                SET api_key = ?, 
                    secret_key = ?, 
                    contract_code = ?, 
                    base_url = ?, 
                    webhook_secret = ?, 
                    is_test = ?, 
                    updated_at = NOW() 
                WHERE id = ?
            ");
            
            $stmt->bind_param("sssssii", 
                $apiKey,
                $secretKey,
                $contractCode,
                $baseUrl,
                $webhookSecret,
                $isLive,
                $monnifyConfig['id']
            );
            
            if ($stmt->execute()) {
                $success = 'Monnify settings updated successfully!';
                
                // Refresh config
                $result = $conn->query("SELECT * FROM monnify_configs WHERE is_active = 1 LIMIT 1");
                if ($result && $result->num_rows > 0) {
                    $monnifyConfig = $result->fetch_assoc();
                }
            } else {
                $errors[] = 'Failed to update Monnify settings: ' . $stmt->error;
            }
        } else {
            // Insert new config
            $stmt = $conn->prepare("
                INSERT INTO monnify_configs 
                (api_key, secret_key, contract_code, base_url, webhook_secret, is_test) 
                VALUES (?, ?, ?, ?, ?, ?)
            ");
            
            $stmt->bind_param("sssssi",
                $apiKey,
                $secretKey,
                $contractCode,
                $baseUrl,
                $webhookSecret,
                $isLive
            );
            
            if ($stmt->execute()) {
                $success = 'Monnify settings created successfully!';
                
                // Refresh config
                $result = $conn->query("SELECT * FROM monnify_configs WHERE is_active = 1 LIMIT 1");
                if ($result && $result->num_rows > 0) {
                    $monnifyConfig = $result->fetch_assoc();
                }
            } else {
                $errors[] = 'Failed to create Monnify settings: ' . $stmt->error;
            }
        }
    }
}

// Process funding charge form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_charge'])) {
    // Get form data
    $fundingChargePercentage = (float)sanitizeInput($_POST['funding_charge_percentage']);
    
    // Basic validation
    if ($fundingChargePercentage < 0 || $fundingChargePercentage > 10) {
        $errors[] = 'Funding charge percentage must be between 0% and 10%';
    }
    
    // If no errors, update setting
    if (empty($errors)) {
        if (updateSetting('funding_charge_percentage', $fundingChargePercentage)) {
            $success = 'Funding charge percentage updated successfully!';
        } else {
            $errors[] = 'Failed to update funding charge percentage';
        }
    }
}

// Get webhook URL
$webhookUrl = SITE_URL . '/webhook/monnify.php';

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $errors[] = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Monnify Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .toggle-checkbox:checked {
            border-color: var(--accent-color);
            right: 0;
        }
        .toggle-checkbox:checked + .toggle-label {
            background-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/paystack.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-money-bill mr-3"></i>
                                <span>Paystack Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/monnify.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-university mr-3"></i>
                                <span>Monnify Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Monnify Settings</h1>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Monnify Settings -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Monnify API Settings</h2>
                
                <form method="POST" action="">
                    <div class="mb-4">
                        <label class="flex items-center cursor-pointer">
                            <div class="relative">
                                <input type="checkbox" id="is_live" name="is_live" class="toggle-checkbox sr-only" 
                                    <?php echo (!empty($monnifyConfig) && $monnifyConfig['is_test'] == 0) ? 'checked' : ''; ?>>
                                <div class="toggle-label block w-14 h-8 rounded-full bg-gray-600 transition-colors"></div>
                                <div class="toggle-checkbox absolute left-1 top-1 bg-white w-6 h-6 rounded-full transition-transform"></div>
                            </div>
                            <span class="ml-3 text-gray-300">Use Live Mode</span>
                        </label>
                        <p class="mt-1 text-sm text-gray-500 ml-16">When enabled, the system will use live keys for processing real transactions. Disable for testing.</p>
                    </div>
                    
                    <div class="mt-6 border-t border-gray-700 pt-6">
                        <h3 class="text-lg font-medium text-white mb-4">Live API Keys</h3>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="live_api_key" class="block text-sm font-medium text-gray-400 mb-1">Live API Key</label>
                                <input type="text" id="live_api_key" name="live_api_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 0 ? $monnifyConfig['api_key'] : ''); ?>">
                            </div>
                            
                            <div class="mb-4">
                                <label for="live_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Live Secret Key</label>
                                <input type="password" id="live_secret_key" name="live_secret_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 0 ? $monnifyConfig['secret_key'] : ''); ?>">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_live_secret" class="mr-2">
                                    <label for="show_live_secret" class="text-sm text-gray-400">Show Secret Key</label>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="live_contract_code" class="block text-sm font-medium text-gray-400 mb-1">Live Contract Code</label>
                                <input type="text" id="live_contract_code" name="live_contract_code" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 0 ? $monnifyConfig['contract_code'] : ''); ?>">
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 border-t border-gray-700 pt-6">
                        <h3 class="text-lg font-medium text-white mb-4">Test API Keys</h3>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="test_api_key" class="block text-sm font-medium text-gray-400 mb-1">Test API Key</label>
                                <input type="text" id="test_api_key" name="test_api_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 1 ? $monnifyConfig['api_key'] : ''); ?>">
                            </div>
                            
                            <div class="mb-4">
                                <label for="test_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Test Secret Key</label>
                                <input type="password" id="test_secret_key" name="test_secret_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 1 ? $monnifyConfig['secret_key'] : ''); ?>">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_test_secret" class="mr-2">
                                    <label for="show_test_secret" class="text-sm text-gray-400">Show Secret Key</label>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="test_contract_code" class="block text-sm font-medium text-gray-400 mb-1">Test Contract Code</label>
                                <input type="text" id="test_contract_code" name="test_contract_code" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) && $monnifyConfig['is_test'] == 1 ? $monnifyConfig['contract_code'] : ''); ?>">
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 border-t border-gray-700 pt-6">
                        <h3 class="text-lg font-medium text-white mb-4">Webhook Configuration</h3>
                        
                        <div class="grid grid-cols-1 gap-4">
                            <div class="mb-4">
                                <label for="webhook_url" class="block text-sm font-medium text-gray-400 mb-1">Webhook URL</label>
                                <div class="flex">
                                    <input type="text" id="webhook_url" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700" 
                                        value="<?php echo htmlspecialchars($webhookUrl); ?>" readonly>
                                    <button type="button" id="copy_webhook" class="bg-gray-600 hover:bg-gray-500 text-white px-4 rounded-r-md">
                                        <i class="fas fa-copy"></i>
                                    </button>
                                </div>
                                <p class="mt-1 text-sm text-gray-500">Use this URL in your Monnify dashboard to set up webhooks.</p>
                            </div>
                            
                            <div class="mb-4">
                                <label for="webhook_secret" class="block text-sm font-medium text-gray-400 mb-1">Webhook Secret</label>
                                <input type="password" id="webhook_secret" name="webhook_secret" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                    value="<?php echo htmlspecialchars(!empty($monnifyConfig) ? $monnifyConfig['webhook_secret'] : ''); ?>">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_webhook_secret" class="mr-2">
                                    <label for="show_webhook_secret" class="text-sm text-gray-400">Show Webhook Secret</label>
                                </div>
                                <p class="mt-1 text-sm text-gray-500">This should match the webhook secret in your Monnify dashboard.</p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md mb-6">
                        <p class="text-indigo-300 text-sm mb-2">
                            <i class="fas fa-info-circle mr-2"></i>
                            <strong>Important:</strong> You can get your Monnify API keys from your Monnify dashboard. For security, keep your secret keys confidential.
                        </p>
                        <p class="text-indigo-300 text-sm">
                            To verify dedicated virtual accounts are working properly, make sure to follow these steps in your Monnify dashboard:
                        </p>
                        <ol class="list-decimal pl-6 mt-2 text-indigo-300 text-sm">
                            <li>Enable multi-bank reserved accounts</li>
                            <li>Add the webhook URL shown above</li>
                            <li>Set the webhook secret</li>
                            <li>Enable the banks you want to provide to your users (Moniepoint, Wema, Sterling, Fidelity)</li>
                        </ol>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="save_monnify" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Monnify Settings
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Funding Charge Settings -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Funding Charge Settings</h2>
                
                <form method="POST" action="">
                    <div class="mb-6">
                        <p class="text-gray-300 mb-4">Configure the charge percentage applied to funds received via Monnify dedicated accounts.</p>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="funding_charge_percentage" class="block text-sm font-medium text-gray-400 mb-1">Funding Charge Percentage (%)</label>
                                <div class="flex">
                                    <input type="number" id="funding_charge_percentage" name="funding_charge_percentage" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                        value="<?php echo htmlspecialchars($fundingChargePercentage); ?>" min="0" max="10" step="0.1" required>
                                    <span class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                                </div>
                                <p class="mt-1 text-sm text-gray-500">This percentage will be deducted from funds transferred to dedicated accounts.</p>
                            </div>
                            
                            <div class="mb-4 bg-gray-800 p-4 rounded-md">
                                <h4 class="font-medium text-white mb-2">Example Calculation</h4>
                                <div class="flex justify-between text-sm mb-1">
                                    <span class="text-gray-400">Transfer Amount:</span>
                                    <span class="text-white">₦1,000.00</span>
                                </div>
                                <div class="flex justify-between text-sm mb-1">
                                    <span class="text-gray-400">Charge (<span id="example_percentage"><?php echo $fundingChargePercentage; ?></span>%):</span>
                                    <span class="text-white">-₦<span id="example_charge"><?php echo number_format(1000 * $fundingChargePercentage / 100, 2); ?></span></span>
                                </div>
                                <div class="flex justify-between text-sm font-medium">
                                    <span class="text-gray-400">Amount Credited:</span>
                                    <span class="text-white">₦<span id="example_credited"><?php echo number_format(1000 - (1000 * $fundingChargePercentage / 100), 2); ?></span></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-6">
                        <p class="text-yellow-300 text-sm">
                            <i class="fas fa-exclamation-triangle mr-2"></i>
                            <strong>Note:</strong> Make sure the charge percentage is sufficient to cover the fees charged by Monnify for these transactions.
                            Monnify typically charges 1.5% for their services, so setting a value lower than that may result in losses.
                        </p>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="save_charge" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Charge Settings
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Information Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Monnify Integration</h2>
                
                <div class="space-y-4 text-gray-300">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        Monnify provides dedicated virtual bank accounts that your users can transfer to for instant wallet funding.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Dedicated Accounts</h3>
                            <p class="text-gray-400">
                                Each user gets dedicated accounts from multiple banks including Moniepoint, Wema, Sterling, and Fidelity. 
                                These accounts are permanently linked to the user's wallet.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Instant Crediting</h3>
                            <p class="text-gray-400">
                                When users transfer to their dedicated accounts, their wallet is credited instantly via webhooks.
                                This creates a seamless funding experience.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        <strong>Tip:</strong> Start with test mode to verify the integration is working correctly before enabling live mode.
                    </p>
                    
                    <div class="p-4 bg-gray-800 rounded-md">
                        <h3 class="font-medium text-white mb-2">Monnify Setup Checklist</h3>
                        <ul class="list-disc pl-5 space-y-1 text-gray-400">
                            <li>Create a Monnify account at <a href="https://monnify.com" target="_blank" class="text-indigo-400 hover:underline">monnify.com</a></li>
                            <li>Generate API keys and contract code in your Monnify dashboard</li>
                            <li>Configure the webhook URL in your Monnify dashboard (copy from above)</li>
                            <li>Enable the multi-bank reserved accounts feature</li>
                            <li>Enable the banks you want to offer (Moniepoint is recommended)</li>
                            <li>Test the integration with small amounts before going live</li>
                        </ul>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Show/hide secret keys
        document.getElementById('show_live_secret').addEventListener('change', function() {
            const passwordField = document.getElementById('live_secret_key');
            passwordField.type = this.checked ? 'text' : 'password';
        });
        
        document.getElementById('show_test_secret').addEventListener('change', function() {
            const passwordField = document.getElementById('test_secret_key');
            passwordField.type = this.checked ? 'text' : 'password';
        });
        
        document.getElementById('show_webhook_secret').addEventListener('change', function() {
            const passwordField = document.getElementById('webhook_secret');
            passwordField.type = this.checked ? 'text' : 'password';
        });
        
        // Toggle checkbox styling
        const toggleCheckbox = document.querySelector('.toggle-checkbox');
        const toggleLabel = document.querySelector('.toggle-label');
        
        toggleCheckbox.addEventListener('change', function() {
            if (this.checked) {
                toggleLabel.classList.add('bg-indigo-600');
                toggleLabel.classList.remove('bg-gray-600');
            } else {
                toggleLabel.classList.remove('bg-indigo-600');
                toggleLabel.classList.add('bg-gray-600');
            }
        });
        
        // Check initial state
        if (toggleCheckbox.checked) {
            toggleLabel.classList.add('bg-indigo-600');
            toggleLabel.classList.remove('bg-gray-600');
        }
        
        // Copy webhook URL
        document.getElementById('copy_webhook').addEventListener('click', function() {
            const webhookUrlField = document.getElementById('webhook_url');
            webhookUrlField.select();
            webhookUrlField.setSelectionRange(0, 99999); // For mobile devices
            
            // Copy to clipboard
            document.execCommand('copy');
            
            // Visual feedback
            this.innerHTML = '<i class="fas fa-check"></i>';
            setTimeout(() => {
                this.innerHTML = '<i class="fas fa-copy"></i>';
            }, 2000);
        });
        
        // Update example calculation when percentage changes
        document.getElementById('funding_charge_percentage').addEventListener('input', function() {
            const percentage = parseFloat(this.value) || 0;
            const amount = 1000;
            const charge = (amount * percentage / 100).toFixed(2);
            const credited = (amount - charge).toFixed(2);
            
            document.getElementById('example_percentage').textContent = percentage;
            document.getElementById('example_charge').textContent = formatNumber(charge);
            document.getElementById('example_credited').textContent = formatNumber(credited);
        });
        
        function formatNumber(num) {
            return new Intl.NumberFormat('en-NG', { 
                minimumFractionDigits: 2,
                maximumFractionDigits: 2
            }).format(num);
        }
    </script>
</body>
</html>