<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get payment settings
$paystackSettings = [];
$result = $conn->query("SELECT setting_name, setting_value FROM settings WHERE setting_name LIKE 'paystack_%'");
while ($row = $result->fetch_assoc()) {
    $paystackSettings[str_replace('paystack_', '', $row['setting_name'])] = $row['setting_value'];
}

// Get other payment related settings
$discountSettings = [];
$result = $conn->query("SELECT setting_name, setting_value FROM settings WHERE setting_name LIKE '%_discount_%'");
while ($row = $result->fetch_assoc()) {
    $discountSettings[$row['setting_name']] = $row['setting_value'];
}

$success = '';
$errors = [];

// Process Paystack settings form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_paystack'])) {
    // Get form data
    $paystackLive = isset($_POST['paystack_live']) ? 1 : 0;
    $paystackLivePublicKey = sanitizeInput($_POST['paystack_live_public_key']);
    $paystackLiveSecretKey = sanitizeInput($_POST['paystack_live_secret_key']);
    $paystackTestPublicKey = sanitizeInput($_POST['paystack_test_public_key']);
    $paystackTestSecretKey = sanitizeInput($_POST['paystack_test_secret_key']);
    
    // Basic validation
    if ($paystackLive) {
        if (empty($paystackLivePublicKey)) {
            $errors[] = 'Paystack Live Public Key is required when using live mode';
        }
        
        if (empty($paystackLiveSecretKey)) {
            $errors[] = 'Paystack Live Secret Key is required when using live mode';
        }
    } else {
        if (empty($paystackTestPublicKey)) {
            $errors[] = 'Paystack Test Public Key is required when using test mode';
        }
        
        if (empty($paystackTestSecretKey)) {
            $errors[] = 'Paystack Test Secret Key is required when using test mode';
        }
    }
    
    // If no errors, update settings
    if (empty($errors)) {
        $settingsToUpdate = [
            'paystack_live' => $paystackLive,
            'paystack_live_public_key' => $paystackLivePublicKey,
            'paystack_live_secret_key' => $paystackLiveSecretKey,
            'paystack_test_public_key' => $paystackTestPublicKey,
            'paystack_test_secret_key' => $paystackTestSecretKey
        ];
        
        $updateSuccess = true;
        
        foreach ($settingsToUpdate as $name => $value) {
            if (!updateSetting($name, $value)) {
                $updateSuccess = false;
                $errors[] = 'Failed to update ' . $name;
            }
        }
        
        if ($updateSuccess) {
            $success = 'Paystack settings updated successfully!';
            
            // Refresh settings
            $paystackSettings = [];
            $result = $conn->query("SELECT setting_name, setting_value FROM settings WHERE setting_name LIKE 'paystack_%'");
            while ($row = $result->fetch_assoc()) {
                $paystackSettings[str_replace('paystack_', '', $row['setting_name'])] = $row['setting_value'];
            }
        }
    }
}

// Process discount settings form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_discounts'])) {
    // Get form data
    $airtimeDiscountSmart = (float)sanitizeInput($_POST['airtime_discount_smart']);
    $airtimeDiscountVendor = (float)sanitizeInput($_POST['airtime_discount_vendor']);
    $airtimeDiscountApi = (float)sanitizeInput($_POST['airtime_discount_api']);
    
    // Basic validation
    if ($airtimeDiscountSmart < 0 || $airtimeDiscountSmart > 100) {
        $errors[] = 'Smart user airtime discount must be between 0 and 100';
    }
    
    if ($airtimeDiscountVendor < 0 || $airtimeDiscountVendor > 100) {
        $errors[] = 'Vendor airtime discount must be between 0 and 100';
    }
    
    if ($airtimeDiscountApi < 0 || $airtimeDiscountApi > 100) {
        $errors[] = 'API user airtime discount must be between 0 and 100';
    }
    
    // If no errors, update settings
    if (empty($errors)) {
        $settingsToUpdate = [
            'airtime_discount_smart' => $airtimeDiscountSmart,
            'airtime_discount_vendor' => $airtimeDiscountVendor,
            'airtime_discount_api' => $airtimeDiscountApi
        ];
        
        $updateSuccess = true;
        
        foreach ($settingsToUpdate as $name => $value) {
            if (!updateSetting($name, $value)) {
                $updateSuccess = false;
                $errors[] = 'Failed to update ' . $name;
            }
        }
        
        if ($updateSuccess) {
            $success = 'Discount settings updated successfully!';
            
            // Refresh settings
            $discountSettings = [];
            $result = $conn->query("SELECT setting_name, setting_value FROM settings WHERE setting_name LIKE '%_discount_%'");
            while ($row = $result->fetch_assoc()) {
                $discountSettings[$row['setting_name']] = $row['setting_value'];
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $errors[] = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Payment Settings - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .toggle-checkbox:checked {
            border-color: var(--accent-color);
            right: 0;
        }
        .toggle-checkbox:checked + .toggle-label {
            background-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Payment Settings</h1>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Paystack Settings -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Paystack Settings</h2>
                
                <form method="POST" action="">
                    <div class="mb-4">
                        <label class="flex items-center cursor-pointer">
                            <div class="relative">
                                <input type="checkbox" id="paystack_live" name="paystack_live" class="toggle-checkbox sr-only" <?php echo (!empty($paystackSettings['live']) && $paystackSettings['live'] == 1) ? 'checked' : ''; ?>>
                                <div class="toggle-label block w-14 h-8 rounded-full bg-gray-600 transition-colors"></div>
                                <div class="toggle-checkbox absolute left-1 top-1 bg-white w-6 h-6 rounded-full transition-transform"></div>
                            </div>
                            <span class="ml-3 text-gray-300">Use Live Mode</span>
                        </label>
                        <p class="mt-1 text-sm text-gray-500 ml-16">When enabled, the system will use live keys for processing real transactions. Disable for testing.</p>
                    </div>
                    
                    <div class="mt-6 border-t border-gray-700 pt-6">
                        <h3 class="text-lg font-medium text-white mb-4">Live Keys</h3>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="paystack_live_public_key" class="block text-sm font-medium text-gray-400 mb-1">Live Public Key</label>
                                <input type="text" id="paystack_live_public_key" name="paystack_live_public_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackSettings['live_public_key'] ?? ''); ?>">
                            </div>
                            
                            <div class="mb-4">
                                <label for="paystack_live_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Live Secret Key</label>
                                <input type="password" id="paystack_live_secret_key" name="paystack_live_secret_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackSettings['live_secret_key'] ?? ''); ?>">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_live_secret" class="mr-2">
                                    <label for="show_live_secret" class="text-sm text-gray-400">Show Secret Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 border-t border-gray-700 pt-6">
                        <h3 class="text-lg font-medium text-white mb-4">Test Keys</h3>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div class="mb-4">
                                <label for="paystack_test_public_key" class="block text-sm font-medium text-gray-400 mb-1">Test Public Key</label>
                                <input type="text" id="paystack_test_public_key" name="paystack_test_public_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackSettings['test_public_key'] ?? ''); ?>">
                            </div>
                            
                            <div class="mb-4">
                                <label for="paystack_test_secret_key" class="block text-sm font-medium text-gray-400 mb-1">Test Secret Key</label>
                                <input type="password" id="paystack_test_secret_key" name="paystack_test_secret_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($paystackSettings['test_secret_key'] ?? ''); ?>">
                                <div class="mt-1 flex items-center">
                                    <input type="checkbox" id="show_test_secret" class="mr-2">
                                    <label for="show_test_secret" class="text-sm text-gray-400">Show Secret Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-6 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md mb-6">
                        <p class="text-indigo-300 text-sm">
                            <i class="fas fa-info-circle mr-2"></i>
                            You can get your Paystack API keys from your Paystack dashboard. For security, keep your secret keys confidential.
                        </p>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="save_paystack" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Paystack Settings
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Discount Settings -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Airtime Discount Settings</h2>
                
                <form method="POST" action="">
                    <div class="mb-6">
                        <p class="text-gray-300 mb-4">Configure the discount rates for airtime purchases based on user type.</p>
                        
                        <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                            <div class="mb-4">
                                <label for="airtime_discount_smart" class="block text-sm font-medium text-gray-400 mb-1">Smart User Discount (%)</label>
                                <div class="flex">
                                    <input type="number" id="airtime_discount_smart" name="airtime_discount_smart" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($discountSettings['airtime_discount_smart'] ?? '2'); ?>" min="0" max="100" step="0.1" required>
                                    <span class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="airtime_discount_vendor" class="block text-sm font-medium text-gray-400 mb-1">Vendor User Discount (%)</label>
                                <div class="flex">
                                    <input type="number" id="airtime_discount_vendor" name="airtime_discount_vendor" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($discountSettings['airtime_discount_vendor'] ?? '3'); ?>" min="0" max="100" step="0.1" required>
                                    <span class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                                </div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="airtime_discount_api" class="block text-sm font-medium text-gray-400 mb-1">API User Discount (%)</label>
                                <div class="flex">
                                    <input type="number" id="airtime_discount_api" name="airtime_discount_api" class="form-input block w-full rounded-l-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($discountSettings['airtime_discount_api'] ?? '4'); ?>" min="0" max="100" step="0.1" required>
                                    <span class="inline-flex items-center px-3 rounded-r-md border border-l-0 border-gray-600 bg-gray-700 text-gray-400">%</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="save_discounts" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Discount Settings
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Payment Info Card -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">About Payment Settings</h2>
                
                <div class="space-y-4 text-gray-300">
                    <p>
                        <i class="fas fa-info-circle text-blue-400 mr-2"></i>
                        The payment settings control how payments are processed on your VTU platform.
                    </p>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Paystack Integration</h3>
                            <p class="text-gray-400">
                                Paystack is used for processing card payments and virtual account funding. Configure your API keys to enable these features.
                            </p>
                        </div>
                        
                        <div class="bg-gray-800 p-4 rounded-md">
                            <h3 class="font-semibold text-white mb-2">Discount Settings</h3>
                            <p class="text-gray-400">
                                Set different discount rates for different user types to encourage upgrades and maintain competitive pricing.
                            </p>
                        </div>
                    </div>
                    
                    <p>
                        <i class="fas fa-lightbulb text-yellow-400 mr-2"></i>
                        Tip: Use test mode with Paystack test keys to validate your payment flow before going live.
                    </p>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Show/hide secret keys
        document.getElementById('show_live_secret').addEventListener('change', function() {
            const passwordField = document.getElementById('paystack_live_secret_key');
            passwordField.type = this.checked ? 'text' : 'password';
        });
        
        document.getElementById('show_test_secret').addEventListener('change', function() {
            const passwordField = document.getElementById('paystack_test_secret_key');
            passwordField.type = this.checked ? 'text' : 'password';
        });
        
        // Toggle checkbox styling
        const toggleCheckbox = document.querySelector('.toggle-checkbox');
        const toggleLabel = document.querySelector('.toggle-label');
        
        toggleCheckbox.addEventListener('change', function() {
            if (this.checked) {
                toggleLabel.classList.add('bg-indigo-600');
                toggleLabel.classList.remove('bg-gray-600');
            } else {
                toggleLabel.classList.remove('bg-indigo-600');
                toggleLabel.classList.add('bg-gray-600');
            }
        });
        
        // Check initial state
        if (toggleCheckbox.checked) {
            toggleLabel.classList.add('bg-indigo-600');
            toggleLabel.classList.remove('bg-gray-600');
        }
    </script>
</body>
</html>