<?php
// File: /admin/settings/provider_balance_test.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get provider ID
$providerId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($providerId <= 0) {
    setFlashMessage("Invalid provider ID", "error");
    redirect(ADMIN_URL . '/settings/providers.php');
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get admin data
$adminId = $_SESSION['admin_id'];
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get provider info
$stmt = $conn->prepare("SELECT * FROM providers WHERE id = ?");
$stmt->bind_param("i", $providerId);
$stmt->execute();
$result = $stmt->get_result();
$provider = $result->fetch_assoc();

if (!$provider) {
    setFlashMessage("Provider not found", "error");
    redirect(ADMIN_URL . '/settings/providers.php');
}

// Initialize variables
$balanceInfo = null;
$error = null;
$rawResponse = null;
$requestDetails = null;
$balance = null;
$statusCode = null;
$responseTime = null;

// Process form submission to check balance
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['check_balance'])) {
    try {
        // Record start time for response time calculation
        $startTime = microtime(true);
        
        // Prepare API call 
        $apiUrl = $provider['api_url'];
        
        // Ensure URL ends with /user if needed
        if (strpos($apiUrl, '/user') === false) {
            $apiUrl = rtrim($apiUrl, '/') . '/user';
        }
        
        $requestDetails = [
            'url' => $apiUrl,
            'method' => 'GET',
            'headers' => [
                "Authorization: Token " . $provider['api_key'],
                'Content-Type: application/json'
            ]
        ];
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $apiUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        
        $headers = [
            "Authorization: Token " . $provider['api_key'],
            'Content-Type: application/json'
        ];
        
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        
        // Add some debug options
        curl_setopt($ch, CURLOPT_VERBOSE, true);
        $verbose = fopen('php://temp', 'w+');
        curl_setopt($ch, CURLOPT_STDERR, $verbose);
        
        // Execute API call
        $response = curl_exec($ch);
        $statusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $responseTime = round((microtime(true) - $startTime) * 1000); // in milliseconds
        
        // Debug info from verbose output
        rewind($verbose);
        $verboseLog = stream_get_contents($verbose);
        
        if (curl_errno($ch)) {
            throw new Exception('API connection error: ' . curl_error($ch) . "\n\nDebug info: " . $verboseLog);
        }
        
        curl_close($ch);
        
        // Store raw response for display
        $rawResponse = $response;
        
        // Process response
        $responseData = json_decode($response, true);
        
        if ($statusCode < 200 || $statusCode >= 300) {
            throw new Exception('API request failed. Status code: ' . $statusCode . 
                                "\n\nResponse: " . $response . 
                                "\n\nDebug info: " . $verboseLog);
        }
        
        // Extract balance information based on API response structure
        if (isset($responseData['balance'])) {
            $balance = $responseData['balance'];
        } elseif (isset($responseData['wallet_balance'])) {
            $balance = $responseData['wallet_balance'];
        } elseif (isset($responseData['data']) && isset($responseData['data']['balance'])) {
            $balance = $responseData['data']['balance'];
        } elseif (isset($responseData['data']) && isset($responseData['data']['wallet_balance'])) {
            $balance = $responseData['data']['wallet_balance'];
        } else {
            // Try to find any field that might contain balance
            $possibleFields = ['account_balance', 'available_balance', 'wallet', 'credit'];
            foreach ($possibleFields as $field) {
                if (isset($responseData[$field])) {
                    $balance = $responseData[$field];
                    break;
                }
            }
            
            if ($balance === null) {
                throw new Exception('Could not determine balance from API response');
            }
        }
        
        // Create balance info object
        $balanceInfo = [
            'balance' => $balance,
            'checked_at' => date('Y-m-d H:i:s'),
            'raw_response' => $responseData
        ];
        
        // Update provider balance in database
        $stmt = $conn->prepare("UPDATE providers SET balance = ?, last_balance_check = NOW() WHERE id = ?");
        $stmt->bind_param("di", $balance, $providerId);
        $stmt->execute();
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Provider Balance Test - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        pre {
            background-color: #1a1a1a;
            color: #e0e0e0;
            border: 1px solid #333;
            border-radius: 4px;
            padding: 1rem;
            overflow-x: auto;
            white-space: pre-wrap;
            word-wrap: break-word;
        }
        
        /* Syntax highlighting */
        .string { color: #a8ff60; }
        .number { color: #ff73fd; }
        .boolean { color: #569cd6; }
        .null { color: #569cd6; }
        .key { color: #9cdcfe; }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_types.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-layer-group mr-3"></i>
                                <span>Data Types</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-plug mr-3"></i>
                                <span>Providers</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Provider Balance Test</h1>
                <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600">
                    <i class="fas fa-arrow-left mr-2"></i> Back to Providers
                </a>
            </div>
            
            <!-- Provider Info -->
            <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Provider Information</h2>
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div>
                        <p class="text-gray-400 text-sm">Name</p>
                        <p class="text-white font-medium"><?php echo htmlspecialchars($provider['name']); ?></p>
                    </div>
                    <div>
                        <p class="text-gray-400 text-sm">Type</p>
                        <p class="text-white"><?php echo ucfirst($provider['type']); ?></p>
                    </div>
                    <div>
                        <p class="text-gray-400 text-sm">API URL</p>
                        <p class="text-white"><?php echo htmlspecialchars($provider['api_url']); ?></p>
                    </div>
                    <div>
                        <p class="text-gray-400 text-sm">API Key</p>
                        <p class="text-white font-mono"><?php echo substr($provider['api_key'], 0, 10) . '...'; ?></p>
                    </div>
                    <div>
                        <p class="text-gray-400 text-sm">Current Balance</p>
                        <p class="text-white font-medium"><?php echo $provider['balance'] !== null ? formatAmount($provider['balance']) : 'Not checked'; ?></p>
                    </div>
                    <div>
                        <p class="text-gray-400 text-sm">Last Checked</p>
                        <p class="text-white"><?php echo $provider['last_balance_check'] ? date('M d, Y H:i', strtotime($provider['last_balance_check'])) : 'Never'; ?></p>
                    </div>
                </div>
                
                <div class="mt-6">
                    <form method="POST" action="">
                        <button type="submit" name="check_balance" class="accent-button py-2 px-4 rounded-md text-white">
                            <i class="fas fa-sync-alt mr-2"></i> Check Balance Now
                        </button>
                    </form>
                </div>
            </div>
            
            <?php if ($error): ?>
                <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                    <h2 class="text-xl font-semibold text-red-400 mb-4">API Error</h2>
                    
                    <div class="p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md">
                        <pre class="text-red-300"><?php echo htmlspecialchars($error); ?></pre>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if ($balance !== null): ?>
                <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                    <h2 class="text-xl font-semibold text-green-400 mb-4">Balance Result</h2>
                    
                    <div class="p-4 bg-green-500 bg-opacity-10 border border-green-500 rounded-md mb-4">
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div>
                                <p class="text-gray-400 text-sm">Balance</p>
                                <p class="text-green-400 text-2xl font-bold"><?php echo formatAmount($balance); ?></p>
                            </div>
                            <div>
                                <p class="text-gray-400 text-sm">Checked At</p>
                                <p class="text-white"><?php echo date('M d, Y H:i:s'); ?></p>
                            </div>
                            <?php if ($statusCode): ?>
                                <div>
                                    <p class="text-gray-400 text-sm">Status Code</p>
                                    <p class="text-white"><?php echo $statusCode; ?></p>
                                </div>
                            <?php endif; ?>
                            <?php if ($responseTime): ?>
                                <div>
                                    <p class="text-gray-400 text-sm">Response Time</p>
                                    <p class="text-white"><?php echo $responseTime; ?> ms</p>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    
                    <div class="mt-4">
                        <p class="text-gray-300 mb-2">The provider's balance has been updated in the database.</p>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if ($requestDetails): ?>
                <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                    <h2 class="text-xl font-semibold text-white mb-4">API Request Details</h2>
                    
                    <div class="mb-4">
                        <p class="text-gray-400 text-sm mb-1">URL</p>
                        <div class="p-2 bg-gray-800 rounded-md">
                            <code class="text-blue-400"><?php echo htmlspecialchars($requestDetails['url']); ?></code>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <p class="text-gray-400 text-sm mb-1">Method</p>
                        <div class="p-2 bg-gray-800 rounded-md">
                            <code class="text-purple-400"><?php echo htmlspecialchars($requestDetails['method']); ?></code>
                        </div>
                    </div>
                    
                    <div>
                        <p class="text-gray-400 text-sm mb-1">Headers</p>
                        <div class="p-2 bg-gray-800 rounded-md">
                            <?php foreach ($requestDetails['headers'] as $header): ?>
                                <code class="text-green-400 block"><?php echo htmlspecialchars($header); ?></code>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if ($rawResponse): ?>
                <div class="admin-card rounded-lg shadow-md p-6">
                    <h2 class="text-xl font-semibold text-white mb-4">API Raw Response</h2>
                    
                    <pre><?php 
                        $json = json_decode($rawResponse, true);
                        if ($json) {
                            // Pretty print JSON
                            echo formatJson(json_encode($json, JSON_PRETTY_PRINT)); 
                        } else {
                            // Raw output if not JSON
                            echo htmlspecialchars($rawResponse);
                        }
                    ?></pre>
                </div>
            <?php endif; ?>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>

<?php
// Format JSON with syntax highlighting
function formatJson($json) {
    $result = '';
    $level = 0;
    $in_quotes = false;
    $in_escape = false;
    $ends_line_level = NULL;
    $json_length = strlen($json);

    for ($i = 0; $i < $json_length; $i++) {
        $char = $json[$i];
        $new_line_level = NULL;
        $post = "";
        if ($ends_line_level !== NULL) {
            $new_line_level = $ends_line_level;
            $ends_line_level = NULL;
        }
        if ($in_escape) {
            $in_escape = false;
        } else if ($char === '"') {
            $in_quotes = !$in_quotes;
        } else if (!$in_quotes) {
            switch ($char) {
                case '}': case ']':
                    $level--;
                    $ends_line_level = NULL;
                    $new_line_level = $level;
                    break;
                case '{': case '[':
                    $level++;
                case ',':
                    $ends_line_level = $level;
                    break;
                case ':':
                    $post = " ";
                    break;
                case " ": case "\t": case "\n": case "\r":
                    $char = "";
                    $ends_line_level = $new_line_level;
                    $new_line_level = NULL;
                    break;
            }
        } else if ($char === '\\') {
            $in_escape = true;
        }
        if ($new_line_level !== NULL) {
            $result .= "\n".str_repeat("    ", $new_line_level);
        }
        
        // Add syntax highlighting
        if ($char === '"' && $in_quotes) {
            $result .= '<span class="string">"';
            continue;
        } else if ($char === '"' && !$in_quotes) {
            $result .= '"</span>';
            continue;
        } else if ($in_quotes) {
            $result .= '<span class="string">' . $char . '</span>';
            continue;
        }
        
        // Numbers
        if (ctype_digit($char) || $char === '.' && ctype_digit($json[$i+1])) {
            $j = $i;
            $number = '';
            while (isset($json[$j]) && (ctype_digit($json[$j]) || $json[$j] === '.')) {
                $number .= $json[$j++];
            }
            $result .= '<span class="number">' . $number . '</span>';
            $i = $j - 1;
            continue;
        }
        
        // Keys in objects
        if ($char === '"' && !$in_quotes && isset($json[$i+1])) {
            $j = $i + 1;
            $key = '';
            while (isset($json[$j]) && $json[$j] !== '"') {
                $key .= $json[$j++];
            }
            $result .= '<span class="key">"' . $key . '"</span>';
            $i = $j;
            continue;
        }
        
        // Boolean and null
        if ($char === 't' && substr($json, $i, 4) === 'true') {
            $result .= '<span class="boolean">true</span>';
            $i += 3;
            continue;
        }
        if ($char === 'f' && substr($json, $i, 5) === 'false') {
            $result .= '<span class="boolean">false</span>';
            $i += 4;
            continue;
        }
        if ($char === 'n' && substr($json, $i, 4) === 'null') {
            $result .= '<span class="null">null</span>';
            $i += 3;
            continue;
        }
        
        $result .= $char . $post;
    }

    return $result;
}
?>