<?php
// File: /admin/settings/providers.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Initialize variables
$provider_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
$action = isset($_GET['action']) ? $_GET['action'] : '';
$success = '';
$error = '';

// Process delete action
if ($action == 'delete' && $provider_id > 0) {
    // Check if the provider is in use
    $stmt = $conn->prepare("SELECT COUNT(*) as count FROM data_type_providers WHERE provider_id = ?");
    $stmt->bind_param("i", $provider_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    
    if ($row['count'] > 0) {
        $error = "Cannot delete this provider because it is being used by data types";
    } else {
        $stmt = $conn->prepare("DELETE FROM providers WHERE id = ?");
        $stmt->bind_param("i", $provider_id);
        
        if ($stmt->execute()) {
            $success = "Provider deleted successfully";
        } else {
            $error = "Failed to delete provider";
        }
    }
}

// Process form submission for adding/editing provider
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $edit_id = isset($_POST['edit_id']) ? (int)$_POST['edit_id'] : 0;
    $name = sanitizeInput($_POST['name']);
    $type = sanitizeInput($_POST['type']);
    $api_url = sanitizeInput($_POST['api_url']);
    $api_key = sanitizeInput($_POST['api_key']);
    $status = sanitizeInput($_POST['status']);
    
    // Validate input
    if (empty($name)) {
        $error = "Provider name is required";
    } elseif (empty($api_url)) {
        $error = "API URL is required";
    } elseif (empty($api_key)) {
        $error = "API key is required";
    } else {
        if ($edit_id > 0) {
            // Update existing provider
            $stmt = $conn->prepare("UPDATE providers SET name = ?, type = ?, api_url = ?, api_key = ?, status = ? WHERE id = ?");
            $stmt->bind_param("sssssi", $name, $type, $api_url, $api_key, $status, $edit_id);
            
            if ($stmt->execute()) {
                $success = "Provider updated successfully";
                $provider_id = 0; // Reset to add mode
            } else {
                $error = "Failed to update provider";
            }
        } else {
            // Add new provider
            $stmt = $conn->prepare("INSERT INTO providers (name, type, api_url, api_key, status) VALUES (?, ?, ?, ?, ?)");
            $stmt->bind_param("sssss", $name, $type, $api_url, $api_key, $status);
            
            if ($stmt->execute()) {
                $success = "Provider added successfully";
            } else {
                $error = "Failed to add provider";
            }
        }
    }
}

// Get provider details if editing
$provider = null;
if ($provider_id > 0 && $action == 'edit') {
    $stmt = $conn->prepare("SELECT * FROM providers WHERE id = ?");
    $stmt->bind_param("i", $provider_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $provider = $result->fetch_assoc();
    
    if (!$provider) {
        $error = "Provider not found";
        $provider_id = 0;
    }
}

// Get providers list
$providers = [];
$stmt = $conn->prepare("SELECT * FROM providers ORDER BY name ASC");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $providers[] = $row;
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $success = $flashMessage['message'];
    } else {
        $error = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Providers Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_types.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-layer-group mr-3"></i>
                                <span>Data Types</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/api_settings.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cogs mr-3"></i>
                                <span>API Settings</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-sliders-h mr-3"></i>
                                <span>General Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/email.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-envelope mr-3"></i>
                                <span>Email Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/payment.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-credit-card mr-3"></i>
                                <span>Payment Settings</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/providers.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                                <i class="fas fa-plug mr-3"></i>
                                <span>Providers</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Other</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>" target="_blank" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-external-link-alt mr-3"></i>
                                <span>View Site</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Providers Management</h1>
                <button id="addProviderBtn" class="accent-button py-2 px-4 rounded-md text-white">
                    <i class="fas fa-plus mr-2"></i> Add Provider
                </button>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Provider Form -->
            <div id="providerFormCard" class="admin-card rounded-lg shadow-md p-6 mb-6 <?php echo (!$provider && $action != 'edit') ? 'hidden' : ''; ?>">
                <h2 class="text-xl font-semibold text-white mb-4"><?php echo $provider ? 'Edit Provider' : 'Add Provider'; ?></h2>
                
                <form method="POST" action="">
                    <?php if ($provider): ?>
                        <input type="hidden" name="edit_id" value="<?php echo $provider['id']; ?>">
                    <?php endif; ?>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                        <div>
                            <label for="name" class="block text-sm font-medium text-gray-400 mb-1">Provider Name</label>
                            <input type="text" id="name" name="name" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $provider ? htmlspecialchars($provider['name']) : ''; ?>" required>
                        </div>
                        
                        <div>
                            <label for="type" class="block text-sm font-medium text-gray-400 mb-1">Provider Type</label>
                            <select id="type" name="type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                <option value="data" <?php echo ($provider && $provider['type'] == 'data') ? 'selected' : ''; ?>>Data</option>
                                <option value="airtime" <?php echo ($provider && $provider['type'] == 'airtime') ? 'selected' : ''; ?>>Airtime</option>
                                <option value="electricity" <?php echo ($provider && $provider['type'] == 'electricity') ? 'selected' : ''; ?>>Electricity</option>
                                <option value="cable" <?php echo ($provider && $provider['type'] == 'cable') ? 'selected' : ''; ?>>Cable TV</option>
                                <option value="general" <?php echo ($provider && $provider['type'] == 'general') ? 'selected' : ''; ?>>General</option>
                            </select>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="api_url" class="block text-sm font-medium text-gray-400 mb-1">API URL</label>
                        <input type="text" id="api_url" name="api_url" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $provider ? htmlspecialchars($provider['api_url']) : ''; ?>" required>
                    </div>
                    
                    <div class="mb-4">
                        <label for="api_key" class="block text-sm font-medium text-gray-400 mb-1">API Key</label>
                        <div class="relative">
                            <input type="password" id="api_key" name="api_key" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 pr-10" value="<?php echo $provider ? htmlspecialchars($provider['api_key']) : ''; ?>" required>
                            <button type="button" id="toggleApiKey" class="absolute inset-y-0 right-0 pr-3 flex items-center text-gray-400 hover:text-white">
                                <i class="fas fa-eye"></i>
                            </button>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="active" <?php echo ($provider && $provider['status'] == 'active') ? 'selected' : ''; ?>>Active</option>
                            <option value="inactive" <?php echo ($provider && $provider['status'] == 'inactive') ? 'selected' : ''; ?>>Inactive</option>
                        </select>
                    </div>
                    
                    <div class="flex justify-end space-x-3">
                        <button type="button" id="cancelBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md">
                            Cancel
                        </button>
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            <?php echo $provider ? 'Update Provider' : 'Add Provider'; ?>
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Providers List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden">
                <?php if (empty($providers)): ?>
                    <div class="p-6 text-center">
                        <p class="text-gray-400">No providers found. Click the "Add Provider" button to create one.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-700">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        ID
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Name
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Type
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        API URL
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Balance
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Status
                                    </th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                        Actions
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-700">
                                <?php foreach ($providers as $item): ?>
                                    <tr>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo $item['id']; ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo htmlspecialchars($item['name']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo ucfirst($item['type']); ?>
                                        </td>
                                        <td class="px-6 py-4 text-sm text-gray-300">
                                            <?php echo htmlspecialchars($item['api_url']); ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                            <?php echo $item['balance'] ? '₦' . number_format($item['balance'], 2) : 'N/A'; ?>
                                            <a href="check_balance.php?id=<?php echo $item['id']; ?>" class="ml-2 text-indigo-400 hover:text-indigo-300" title="Check Balance">
                                                <i class="fas fa-sync-alt"></i>
                                            </a>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full <?php echo $item['status'] == 'active' ? 'bg-green-500 bg-opacity-20 text-green-300' : 'bg-red-500 bg-opacity-20 text-red-300'; ?>">
                                                <?php echo ucfirst($item['status']); ?>
                                            </span>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium space-x-2">
                                            <a href="?action=edit&id=<?php echo $item['id']; ?>" class="text-indigo-400 hover:text-indigo-300" title="Edit">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="?action=delete&id=<?php echo $item['id']; ?>" class="text-red-400 hover:text-red-300 delete-provider" data-id="<?php echo $item['id']; ?>" title="Delete">
                                                <i class="fas fa-trash-alt"></i>
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Delete Confirmation Modal -->
    <div id="deleteConfirmModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="bg-gray-800 rounded-lg max-w-md w-full mx-4 z-10">
            <div class="p-6">
                <h3 class="text-xl font-semibold text-white mb-4">Confirm Delete</h3>
                <p class="text-gray-300 mb-6">Are you sure you want to delete this provider? This action cannot be undone.</p>
                <div class="flex justify-end space-x-3">
                    <button id="cancelDeleteBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md">
                        Cancel
                    </button>
                    <a id="confirmDeleteBtn" href="#" class="bg-red-600 hover:bg-red-700 text-white py-2 px-4 rounded-md">
                        Delete
                    </a>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Show/hide provider form
            const addProviderBtn = document.getElementById('addProviderBtn');
            const cancelBtn = document.getElementById('cancelBtn');
            const providerFormCard = document.getElementById('providerFormCard');
            
            addProviderBtn.addEventListener('click', () => {
                providerFormCard.classList.remove('hidden');
                // Reset form if it was in edit mode
                const form = providerFormCard.querySelector('form');
                const editIdInput = form.querySelector('input[name="edit_id"]');
                if (editIdInput) {
                    form.removeChild(editIdInput);
                }
                form.reset();
                form.action = '';
                providerFormCard.querySelector('h2').textContent = 'Add Provider';
                form.querySelector('button[type="submit"]').textContent = 'Add Provider';
            });
            
            cancelBtn.addEventListener('click', () => {
                providerFormCard.classList.add('hidden');
            });
            
            // Toggle API Key visibility
            const toggleApiKey = document.getElementById('toggleApiKey');
            const apiKeyInput = document.getElementById('api_key');
            
            toggleApiKey.addEventListener('click', () => {
                if (apiKeyInput.type === 'password') {
                    apiKeyInput.type = 'text';
                    toggleApiKey.innerHTML = '<i class="fas fa-eye-slash"></i>';
                } else {
                    apiKeyInput.type = 'password';
                    toggleApiKey.innerHTML = '<i class="fas fa-eye"></i>';
                }
            });
            
            // Delete confirmation
            const deleteConfirmModal = document.getElementById('deleteConfirmModal');
            const cancelDeleteBtn = document.getElementById('cancelDeleteBtn');
            const confirmDeleteBtn = document.getElementById('confirmDeleteBtn');
            const deleteButtons = document.querySelectorAll('.delete-provider');
            
            deleteButtons.forEach(button => {
                button.addEventListener('click', (e) => {
                    e.preventDefault();
                    const providerId = button.getAttribute('data-id');
                    confirmDeleteBtn.href = `?action=delete&id=${providerId}`;
                    deleteConfirmModal.classList.remove('hidden');
                });
            });
            
            cancelDeleteBtn.addEventListener('click', () => {
                deleteConfirmModal.classList.add('hidden');
            });
            
            // Close modal when clicking outside
            deleteConfirmModal.addEventListener('click', (e) => {
                if (e.target === deleteConfirmModal) {
                    deleteConfirmModal.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>