<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Process actions
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $action = $_POST['action'];
    
    if ($action === 'update_status' && isset($_POST['ticket_id']) && isset($_POST['status'])) {
        $ticketId = (int)$_POST['ticket_id'];
        $status = sanitizeInput($_POST['status']);
        
        if (!in_array($status, ['open', 'pending', 'replied', 'closed'])) {
            $error = 'Invalid status';
        } else {
            $stmt = $conn->prepare("UPDATE support_tickets SET status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $ticketId);
            
            if ($stmt->execute()) {
                $success = 'Ticket status updated successfully';
            } else {
                $error = 'Failed to update ticket status';
            }
        }
    } elseif ($action === 'add_reply' && isset($_POST['ticket_id']) && isset($_POST['reply_message'])) {
        $ticketId = (int)$_POST['ticket_id'];
        $message = sanitizeInput($_POST['reply_message']);
        
        if (empty($message)) {
            $error = 'Reply message cannot be empty';
        } else {
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Insert reply
                $stmt = $conn->prepare("
                    INSERT INTO ticket_replies
                    (ticket_id, admin_id, message)
                    VALUES (?, ?, ?)
                ");
                $stmt->bind_param("iis", $ticketId, $adminId, $message);
                $stmt->execute();
                
                // Update ticket status to replied
                $status = 'replied';
                $stmt = $conn->prepare("UPDATE support_tickets SET status = ? WHERE id = ?");
                $stmt->bind_param("si", $status, $ticketId);
                $stmt->execute();
                
                // Get ticket owner
                $stmt = $conn->prepare("SELECT user_id FROM support_tickets WHERE id = ?");
                $stmt->bind_param("i", $ticketId);
                $stmt->execute();
                $result = $stmt->get_result();
                $ticket = $result->fetch_assoc();
                
                if ($ticket) {
                    // Create notification for user
                    $userId = $ticket['user_id'];
                    $title = 'Support Ticket Reply';
                    $notifyMessage = 'Your support ticket has received a reply from our support team.';
                    
                    $stmt = $conn->prepare("
                        INSERT INTO notifications
                        (user_id, title, message, type, is_read)
                        VALUES (?, ?, ?, 'info', 0)
                    ");
                    $stmt->bind_param("iss", $userId, $title, $notifyMessage);
                    $stmt->execute();
                    
                    // Send email notification to user
                    $stmt = $conn->prepare("SELECT email FROM users WHERE id = ?");
                    $stmt->bind_param("i", $userId);
                    $stmt->execute();
                    $result = $stmt->get_result();
                    $user = $result->fetch_assoc();
                    
                    if ($user && $user['email']) {
                        $subject = 'Your Support Ticket Has a Reply - ' . getSetting('site_name');
                        $emailContent = "
                            <p>Hello,</p>
                            <p>Your support ticket has received a reply from our team.</p>
                            <p>You can view the full conversation by logging into your account and visiting the Support section.</p>
                            <p>Thank you for your patience.</p>
                            <p>Regards,<br>" . getSetting('site_name') . " Support Team</p>
                        ";
                        
                        sendEmail($user['email'], $subject, $emailContent);
                    }
                }
                
                // Commit transaction
                $conn->commit();
                
                $success = 'Reply added successfully';
            } catch (Exception $e) {
                // Rollback transaction
                $conn->rollback();
                $error = 'Error: ' . $e->getMessage();
            }
        }
    }
}

// Get filters
$status = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$userId = isset($_GET['user_id']) ? (int)$_GET['user_id'] : 0;
$search = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Pagination parameters
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// Build query
$query = "SELECT st.*, u.username, u.email FROM support_tickets st JOIN users u ON st.user_id = u.id WHERE 1=1";
$countQuery = "SELECT COUNT(*) as total FROM support_tickets st JOIN users u ON st.user_id = u.id WHERE 1=1";
$params = [];
$types = "";

if ($status) {
    $query .= " AND st.status = ?";
    $countQuery .= " AND st.status = ?";
    $params[] = $status;
    $types .= "s";
}

if ($userId) {
    $query .= " AND st.user_id = ?";
    $countQuery .= " AND st.user_id = ?";
    $params[] = $userId;
    $types .= "i";
}

if ($search) {
    $searchTerm = "%$search%";
    $query .= " AND (st.subject LIKE ? OR st.message LIKE ? OR u.username LIKE ? OR u.email LIKE ?)";
    $countQuery .= " AND (st.subject LIKE ? OR st.message LIKE ? OR u.username LIKE ? OR u.email LIKE ?)";
    $params[] = $searchTerm;
    $params[] = $searchTerm;
    $params[] = $searchTerm;
    $params[] = $searchTerm;
    $types .= "ssss";
}

// Add sorting and pagination
$query .= " ORDER BY st.created_at DESC LIMIT ? OFFSET ?";
$params[] = $limit;
$params[] = $offset;
$types .= "ii";

// Get total count for pagination
$countStmt = $conn->prepare($countQuery);
if (!empty($params) && !empty($types)) {
    $bindParams = array_slice($params, 0, -2); // Remove limit and offset
    $bindTypes = substr($types, 0, -2); // Remove types for limit and offset
    if (!empty($bindParams)) {
        $countStmt->bind_param($bindTypes, ...$bindParams);
    }
}
$countStmt->execute();
$countResult = $countStmt->get_result();
$totalTickets = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalTickets / $limit);

// Get tickets
$stmt = $conn->prepare($query);
if (!empty($params) && !empty($types)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();
$tickets = [];

while ($row = $result->fetch_assoc()) {
    $tickets[] = $row;
}

// Get user list for filter
$stmt = $conn->prepare("SELECT id, username, email FROM users ORDER BY username ASC");
$stmt->execute();
$result = $stmt->get_result();
$users = [];

while ($row = $result->fetch_assoc()) {
    $users[] = $row;
}
// Set current page for sidebar highlight
$currentPage = 'support_tickets';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Support Tickets - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        /* Ticket status badge styles */
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-open {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .status-replied {
            background-color: rgba(59, 130, 246, 0.3);
            color: #93c5fd;
        }
        
        .status-closed {
            background-color: rgba(107, 114, 128, 0.3);
            color: #d1d5db;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
       <!-- Include Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Support Tickets</h1>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Search and Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="flex flex-col md:flex-row md:items-end space-y-3 md:space-y-0 md:space-x-4">
                    <div class="flex-1 min-w-0">
                        <label for="search" class="block text-sm font-medium text-gray-400 mb-1">Search</label>
                        <input type="text" id="search" name="search" value="<?php echo htmlspecialchars($search); ?>" placeholder="Subject, Message, Username, Email" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Status</option>
                            <option value="open" <?php echo $status === 'open' ? 'selected' : ''; ?>>Open</option>
                            <option value="pending" <?php echo $status === 'pending' ? 'selected' : ''; ?>>Pending</option>
                            <option value="replied" <?php echo $status === 'replied' ? 'selected' : ''; ?>>Replied</option>
                            <option value="closed" <?php echo $status === 'closed' ? 'selected' : ''; ?>>Closed</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="user_id" class="block text-sm font-medium text-gray-400 mb-1">User</label>
                        <select id="user_id" name="user_id" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Users</option>
                            <?php foreach ($users as $user): ?>
                                <option value="<?php echo $user['id']; ?>" <?php echo $userId == $user['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($user['username']); ?> (<?php echo htmlspecialchars($user['email']); ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="flex space-x-2">
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                            <i class="fas fa-search mr-2"></i> Filter
                        </button>
                        
                        <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="bg-gray-700 hover:bg-gray-600 py-2 px-4 rounded-md text-white">
                            <i class="fas fa-redo mr-2"></i> Reset
                        </a>
                    </div>
                </form>
            </div>
            
            <!-- Tickets Table -->
            <div class="admin-card rounded-lg shadow-md p-6">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold text-white">Tickets</h2>
                    <div class="text-sm text-gray-400">
                        Total: <span class="text-white"><?php echo $totalTickets; ?></span> tickets
                    </div>
                </div>
                
                <?php if (empty($tickets)): ?>
                    <div class="text-center py-8 text-gray-400">
                        <div class="h-16 w-16 mx-auto mb-4 rounded-full bg-gray-700 flex items-center justify-center">
                            <i class="fas fa-ticket-alt text-2xl text-gray-500"></i>
                        </div>
                        <p>No tickets found matching your criteria.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Ticket ID</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Subject</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">User</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Category</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Created</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($tickets as $ticket): ?>
                                    <tr class="hover:bg-gray-700">
                                        <td class="py-3 px-4 text-sm text-white">
                                            #<?php echo $ticket['id']; ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white">
                                            <?php echo htmlspecialchars($ticket['subject']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <div><?php echo htmlspecialchars($ticket['username']); ?></div>
                                            <div class="text-xs text-gray-400"><?php echo htmlspecialchars($ticket['email']); ?></div>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo ucfirst($ticket['category']); ?>
                                        </td>
                                        <td class="py-3 px-4 whitespace-nowrap">
                                            <?php
                                            $statusClass = 'status-' . $ticket['status'];
                                            ?>
                                            <span class="status-badge <?php echo $statusClass; ?>">
                                                <?php echo ucfirst($ticket['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo date('M d, Y g:i A', strtotime($ticket['created_at'])); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm font-medium whitespace-nowrap">
                                            <a href="<?php echo ADMIN_URL; ?>/view_ticket.php?id=<?php echo $ticket['id']; ?>" class="text-indigo-400 hover:text-indigo-300 mr-2">
                                                <i class="fas fa-eye"></i>
                                            </a>
                                            <button type="button" class="reply-ticket text-green-400 hover:text-green-300 mr-2" data-ticket-id="<?php echo $ticket['id']; ?>" data-subject="<?php echo htmlspecialchars($ticket['subject']); ?>">
                                                <i class="fas fa-reply"></i>
                                            </button>
                                            <button type="button" class="change-status text-yellow-400 hover:text-yellow-300" data-ticket-id="<?php echo $ticket['id']; ?>" data-status="<?php echo $ticket['status']; ?>">
                                                <i class="fas fa-cog"></i>
                                            </button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <!-- Pagination -->
                    <?php if ($totalPages > 1): ?>
                        <div class="flex justify-center mt-6">
                            <nav class="inline-flex rounded-md shadow">
                                <?php if ($page > 1): ?>
                                    <a href="?page=<?php echo $page - 1; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo $userId ? '&user_id=' . $userId : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-l-md hover:bg-gray-600">
                                        <i class="fas fa-chevron-left"></i>
                                    </a>
                                <?php else: ?>
                                    <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-l-md cursor-not-allowed">
                                        <i class="fas fa-chevron-left"></i>
                                    </span>
                                <?php endif; ?>
                                
                                <?php
                                $startPage = max(1, $page - 2);
                                $endPage = min($totalPages, $startPage + 4);
                                if ($endPage - $startPage < 4 && $startPage > 1) {
                                    $startPage = max(1, $endPage - 4);
                                }
                                
                                for ($i = $startPage; $i <= $endPage; $i++):
                                ?>
                                    <a href="?page=<?php echo $i; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo $userId ? '&user_id=' . $userId : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="py-2 px-4 <?php echo $i === $page ? 'bg-indigo-600' : 'bg-gray-700 hover:bg-gray-600'; ?> text-white <?php echo $i === $startPage ? '' : 'border-l border-gray-600'; ?>">
                                        <?php echo $i; ?>
                                    </a>
                                <?php endfor; ?>
                                
                                <?php if ($endPage < $totalPages): ?>
                                    <span class="py-2 px-4 bg-gray-700 text-gray-300 border-l border-gray-600">...</span>
                                    <a href="?page=<?php echo $totalPages; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo $userId ? '&user_id=' . $userId : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="py-2 px-4 bg-gray-700 text-white hover:bg-gray-600 border-l border-gray-600">
                                        <?php echo $totalPages; ?>
                                    </a>
                                <?php endif; ?>
                                
                                <?php if ($page < $totalPages): ?>
                                    <a href="?page=<?php echo $page + 1; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo $userId ? '&user_id=' . $userId : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-r-md hover:bg-gray-600 border-l border-gray-600">
                                        <i class="fas fa-chevron-right"></i>
                                    </a>
                                <?php else: ?>
                                    <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-r-md cursor-not-allowed border-l border-gray-600">
                                        <i class="fas fa-chevron-right"></i>
                                    </span>
                                <?php endif; ?>
                            </nav>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Reply Modal -->
    <div id="replyModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Reply to Ticket</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="replyModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="add_reply">
                <input type="hidden" name="ticket_id" id="replyTicketId">
                
                <div class="mb-4">
                    <div class="text-gray-400 mb-2">Replying to: <span id="replyTicketSubject" class="text-white"></span></div>
                </div>
                
                <div class="mb-4">
                    <label for="reply_message" class="block text-sm font-medium text-gray-400 mb-1">Your Reply</label>
                    <textarea id="reply_message" name="reply_message" rows="6" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                </div>
                
                <div class="mt-6 flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="replyModal">
                        Cancel
                    </button>
                    <button type="submit" class="bg-green-600 hover:bg-green-700 py-2 px-4 rounded-md text-white">
                        <i class="fas fa-paper-plane mr-1"></i> Send Reply
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Change Status Modal -->
    <div id="statusModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Change Ticket Status</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="statusModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="update_status">
                <input type="hidden" name="ticket_id" id="statusTicketId">
                
                <div class="mb-6">
                    <label for="status_select" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                    <select id="status_select" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        <option value="open">Open</option>
                        <option value="pending">Pending</option>
                        <option value="replied">Replied</option>
                        <option value="closed">Closed</option>
                    </select>
                </div>
                
                <div class="flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="statusModal">
                        Cancel
                    </button>
                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                        <i class="fas fa-save mr-1"></i> Update Status
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Reply Modal
            const replyModal = document.getElementById('replyModal');
            const replyTicketId = document.getElementById('replyTicketId');
            const replyTicketSubject = document.getElementById('replyTicketSubject');
            const replyButtons = document.querySelectorAll('.reply-ticket');
            
            replyButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const ticketId = this.getAttribute('data-ticket-id');
                    const subject = this.getAttribute('data-subject');
                    
                    replyTicketId.value = ticketId;
                    replyTicketSubject.textContent = subject;
                    
                    replyModal.classList.remove('hidden');
                });
            });
            
            // Change Status Modal
            const statusModal = document.getElementById('statusModal');
            const statusTicketId = document.getElementById('statusTicketId');
            const statusSelect = document.getElementById('status_select');
            const statusButtons = document.querySelectorAll('.change-status');
            
            statusButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const ticketId = this.getAttribute('data-ticket-id');
                    const currentStatus = this.getAttribute('data-status');
                    
                    statusTicketId.value = ticketId;
                    
                    // Set current status
                    for (let i = 0; i < statusSelect.options.length; i++) {
                        if (statusSelect.options[i].value === currentStatus) {
                            statusSelect.selectedIndex = i;
                            break;
                        }
                    }
                    
                    statusModal.classList.remove('hidden');
                });
            });
            
            // Close modals
            const closeModalButtons = document.querySelectorAll('.close-modal');
            
            closeModalButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const targetModal = document.getElementById(this.getAttribute('data-target'));
                    targetModal.classList.add('hidden');
                });
            });
            
            // Close modals when clicking outside
            window.addEventListener('click', function(e) {
                if (e.target === replyModal) {
                    replyModal.classList.add('hidden');
                }
                if (e.target === statusModal) {
                    statusModal.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>