<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Pagination settings
$perPage = 20;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $perPage;

// Filter settings
$typeFilter = isset($_GET['type']) ? sanitizeInput($_GET['type']) : '';
$statusFilter = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';
$startDate = isset($_GET['start_date']) ? sanitizeInput($_GET['start_date']) : '';
$endDate = isset($_GET['end_date']) ? sanitizeInput($_GET['end_date']) : '';

// Build query
$query = "SELECT t.*, u.username, u.email 
          FROM transactions t
          LEFT JOIN users u ON t.user_id = u.id
          WHERE 1=1";
$countQuery = "SELECT COUNT(*) as total 
               FROM transactions t
               LEFT JOIN users u ON t.user_id = u.id
               WHERE 1=1";
$params = [];
$types = "";

if ($typeFilter) {
    $query .= " AND t.type = ?";
    $countQuery .= " AND t.type = ?";
    $params[] = $typeFilter;
    $types .= "s";
}

if ($statusFilter) {
    $query .= " AND t.status = ?";
    $countQuery .= " AND t.status = ?";
    $params[] = $statusFilter;
    $types .= "s";
}

if ($search) {
    $searchParam = "%$search%";
    $query .= " AND (t.txn_ref LIKE ? OR u.username LIKE ? OR u.email LIKE ? OR t.description LIKE ?)";
    $countQuery .= " AND (t.txn_ref LIKE ? OR u.username LIKE ? OR u.email LIKE ? OR t.description LIKE ?)";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "ssss";
}

if ($startDate) {
    $query .= " AND DATE(t.created_at) >= ?";
    $countQuery .= " AND DATE(t.created_at) >= ?";
    $params[] = $startDate;
    $types .= "s";
}

if ($endDate) {
    $query .= " AND DATE(t.created_at) <= ?";
    $countQuery .= " AND DATE(t.created_at) <= ?";
    $params[] = $endDate;
    $types .= "s";
}

// Order by latest first
$query .= " ORDER BY t.created_at DESC LIMIT ?, ?";
$params[] = $offset;
$params[] = $perPage;
$types .= "ii";

// Prepare and execute query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();
$transactions = [];

while ($row = $result->fetch_assoc()) {
    $transactions[] = $row;
}

// Get total records for pagination
$countStmt = $conn->prepare($countQuery);
if (!empty($params)) {
    // Remove limit parameters which are the last two
    $countParams = array_slice($params, 0, -2);
    $countTypes = substr($types, 0, -2);
    if (!empty($countParams)) {
        $countStmt->bind_param($countTypes, ...$countParams);
    }
}
$countStmt->execute();
$countResult = $countStmt->get_result();
$totalRecords = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $perPage);

// For the summary statistics
$summaryQuery = "SELECT 
                    COUNT(*) as total_count,
                    SUM(CASE WHEN status = 'successful' THEN 1 ELSE 0 END) as successful_count,
                    SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending_count,
                    SUM(CASE WHEN status = 'failed' THEN 1 ELSE 0 END) as failed_count,
                    SUM(CASE WHEN status = 'successful' THEN amount ELSE 0 END) as successful_amount,
                    SUM(CASE WHEN status = 'successful' THEN fee ELSE 0 END) as total_fees
                FROM transactions";
$summaryParams = [];
$summaryTypes = "";

// Apply the same filters as the main query except pagination
if ($typeFilter) {
    $summaryQuery .= " WHERE type = ?";
    $summaryParams[] = $typeFilter;
    $summaryTypes .= "s";
    
    if ($statusFilter) {
        $summaryQuery .= " AND status = ?";
        $summaryParams[] = $statusFilter;
        $summaryTypes .= "s";
    }
    
    if ($startDate) {
        $summaryQuery .= " AND DATE(created_at) >= ?";
        $summaryParams[] = $startDate;
        $summaryTypes .= "s";
    }
    
    if ($endDate) {
        $summaryQuery .= " AND DATE(created_at) <= ?";
        $summaryParams[] = $endDate;
        $summaryTypes .= "s";
    }
} else {
    if ($statusFilter) {
        $summaryQuery .= " WHERE status = ?";
        $summaryParams[] = $statusFilter;
        $summaryTypes .= "s";
        
        if ($startDate) {
            $summaryQuery .= " AND DATE(created_at) >= ?";
            $summaryParams[] = $startDate;
            $summaryTypes .= "s";
        }
        
        if ($endDate) {
            $summaryQuery .= " AND DATE(created_at) <= ?";
            $summaryParams[] = $endDate;
            $summaryTypes .= "s";
        }
    } else {
        if ($startDate) {
            $summaryQuery .= " WHERE DATE(created_at) >= ?";
            $summaryParams[] = $startDate;
            $summaryTypes .= "s";
            
            if ($endDate) {
                $summaryQuery .= " AND DATE(created_at) <= ?";
                $summaryParams[] = $endDate;
                $summaryTypes .= "s";
            }
        } else if ($endDate) {
            $summaryQuery .= " WHERE DATE(created_at) <= ?";
            $summaryParams[] = $endDate;
            $summaryTypes .= "s";
        }
    }
}

$summaryStmt = $conn->prepare($summaryQuery);
if (!empty($summaryParams)) {
    $summaryStmt->bind_param($summaryTypes, ...$summaryParams);
}
$summaryStmt->execute();
$summaryResult = $summaryStmt->get_result();
$summary = $summaryResult->fetch_assoc();

// Get transaction types for filter dropdown
$transactionTypes = [];
$result = $conn->query("SELECT DISTINCT type FROM transactions ORDER BY type");
while ($row = $result->fetch_assoc()) {
    $transactionTypes[] = $row['type'];
}

// Process transaction action (update status)
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_status'])) {
    $txnId = (int)$_POST['transaction_id'];
    $newStatus = sanitizeInput($_POST['new_status']);
    $user_id = (int)$_POST['user_id'];
    $amount = (float)$_POST['amount'];
    $txnType = sanitizeInput($_POST['transaction_type']);
    
    // Validate status
    if (!in_array($newStatus, ['pending', 'successful', 'failed'])) {
        $actionError = 'Invalid status';
    } else {
        // Get current transaction
        $stmt = $conn->prepare("SELECT * FROM transactions WHERE id = ?");
        $stmt->bind_param("i", $txnId);
        $stmt->execute();
        $result = $stmt->get_result();
        $transaction = $result->fetch_assoc();
        
        if (!$transaction) {
            $actionError = 'Transaction not found';
        } else {
            $currentStatus = $transaction['status'];
            
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Update transaction status
                $stmt = $conn->prepare("UPDATE transactions SET status = ? WHERE id = ?");
                $stmt->bind_param("si", $newStatus, $txnId);
                $stmt->execute();
                
                // If status changed, handle wallet balance adjustments
                if ($currentStatus !== $newStatus) {
                    // If transaction was successful and now failed/pending, subtract from balance
                    if ($currentStatus === 'successful' && ($newStatus === 'failed' || $newStatus === 'pending')) {
                        if ($txnType === 'funding') {
                            // Subtract from balance for funding
                            $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
                            $stmt->bind_param("di", $amount, $user_id);
                            $stmt->execute();
                        } elseif (in_array($txnType, ['data', 'airtime', 'cable', 'electricity'])) {
                            // Add back to balance for purchases
                            $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                            $stmt->bind_param("di", $amount, $user_id);
                            $stmt->execute();
                        }
                    }
                    // If transaction was failed/pending and now successful, add to balance
                    elseif (($currentStatus === 'failed' || $currentStatus === 'pending') && $newStatus === 'successful') {
                        if ($txnType === 'funding') {
                            // Add to balance for funding
                            $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                            $stmt->bind_param("di", $amount, $user_id);
                            $stmt->execute();
                        } elseif (in_array($txnType, ['data', 'airtime', 'cable', 'electricity'])) {
                            // Subtract from balance for purchases
                            $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
                            $stmt->bind_param("di", $amount, $user_id);
                            $stmt->execute();
                        }
                    }
                }
                
                // Commit transaction
                $conn->commit();
                
                $actionSuccess = 'Transaction status updated successfully';
                
                // Refresh transactions after update
                $stmt = $conn->prepare($query);
                if (!empty($params)) {
                    $stmt->bind_param($types, ...$params);
                }
                $stmt->execute();
                $result = $stmt->get_result();
                $transactions = [];
                
                while ($row = $result->fetch_assoc()) {
                    $transactions[] = $row;
                }
                
                // Update summary
                $summaryStmt = $conn->prepare($summaryQuery);
                if (!empty($summaryParams)) {
                    $summaryStmt->bind_param($summaryTypes, ...$summaryParams);
                }
                $summaryStmt->execute();
                $summaryResult = $summaryStmt->get_result();
                $summary = $summaryResult->fetch_assoc();
            } catch (Exception $e) {
                // Roll back transaction on error
                $conn->rollback();
                $actionError = 'Failed to update transaction status: ' . $e->getMessage();
            }
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Transactions - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-successful {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .status-failed {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        .type-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .type-funding {
            background-color: rgba(34, 197, 94, 0.2);
            color: #86efac;
        }
        
        .type-data {
            background-color: rgba(37, 99, 235, 0.2);
            color: #93c5fd;
        }
        
        .type-airtime {
            background-color: rgba(168, 85, 247, 0.2);
            color: #d8b4fe;
        }
        
        .type-cable {
            background-color: rgba(244, 63, 94, 0.2);
            color: #fda4af;
        }
        
        .type-electricity {
            background-color: rgba(234, 179, 8, 0.2);
            color: #fde047;
        }
        
        .summary-card {
            transition: all 0.3s ease;
        }
        
        .summary-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <!-- Include Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">Transaction Management</h1>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Transaction Summary -->
            <div class="grid grid-cols-1 md:grid-cols-4 gap-4 mb-6">
                <div class="admin-card rounded-lg p-4 shadow-md summary-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Transactions</p>
                            <h3 class="text-2xl font-bold text-white"><?php echo number_format($summary['total_count']); ?></h3>
                        </div>
                        <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center">
                            <i class="fas fa-exchange-alt text-indigo-400"></i>
                        </div>
                    </div>
                </div>
                
                <div class="admin-card rounded-lg p-4 shadow-md summary-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Successful</p>
                            <h3 class="text-2xl font-bold text-green-400"><?php echo number_format($summary['successful_count']); ?></h3>
                        </div>
                        <div class="h-10 w-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center">
                            <i class="fas fa-check text-green-400"></i>
                        </div>
                    </div>
                </div>
                
                <div class="admin-card rounded-lg p-4 shadow-md summary-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Transaction Volume</p>
                            <h3 class="text-2xl font-bold text-white"><?php echo formatAmount($summary['successful_amount']); ?></h3>
                        </div>
                        <div class="h-10 w-10 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center">
                            <i class="fas fa-chart-line text-blue-400"></i>
                        </div>
                    </div>
                </div>
                
                <div class="admin-card rounded-lg p-4 shadow-md summary-card">
                    <div class="flex justify-between items-start">
                        <div>
                            <p class="text-gray-400 text-sm">Total Fees</p>
                            <h3 class="text-2xl font-bold text-white"><?php echo formatAmount($summary['total_fees']); ?></h3>
                        </div>
                        <div class="h-10 w-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center">
                            <i class="fas fa-money-bill-wave text-yellow-400"></i>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="flex flex-col md:flex-row flex-wrap md:items-end space-y-4 md:space-y-0 md:space-x-4">
                    <div class="flex-1 min-w-0 md:max-w-xs">
                        <label for="search" class="block text-sm font-medium text-gray-400 mb-1">Search</label>
                        <input type="text" id="search" name="search" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Txn Ref, Username, Email" value="<?php echo htmlspecialchars($search); ?>">
                    </div>
                    
                    <div class="w-full md:w-auto">
                        <label for="type" class="block text-sm font-medium text-gray-400 mb-1">Type</label>
                        <select id="type" name="type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Types</option>
                            <?php foreach ($transactionTypes as $type): ?>
                                <option value="<?php echo $type; ?>" <?php echo $typeFilter === $type ? 'selected' : ''; ?>>
                                    <?php echo ucfirst($type); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="w-full md:w-auto">
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Statuses</option>
                            <option value="successful" <?php echo $statusFilter === 'successful' ? 'selected' : ''; ?>>Successful</option>
                            <option value="pending" <?php echo $statusFilter === 'pending' ? 'selected' : ''; ?>>Pending</option>
                            <option value="failed" <?php echo $statusFilter === 'failed' ? 'selected' : ''; ?>>Failed</option>
                        </select>
                    </div>
                    
                    <div class="w-full md:w-auto">
                        <label for="start_date" class="block text-sm font-medium text-gray-400 mb-1">Start Date</label>
                        <input type="date" id="start_date" name="start_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $startDate; ?>">
                    </div>
                    
                    <div class="w-full md:w-auto">
                        <label for="end_date" class="block text-sm font-medium text-gray-400 mb-1">End Date</label>
                        <input type="date" id="end_date" name="end_date" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo $endDate; ?>">
                    </div>
                    
                    <div class="w-full md:w-auto md:ml-2">
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white w-full">Filter</button>
                    </div>
                    
                    <?php if ($typeFilter || $statusFilter || $search || $startDate || $endDate): ?>
                        <div class="w-full md:w-auto md:ml-2">
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="inline-block bg-gray-700 py-2 px-4 rounded-md text-white text-center hover:bg-gray-600 transition-colors w-full">
                                Clear Filters
                            </a>
                        </div>
                    <?php endif; ?>
                </form>
            </div>
            
            <!-- Transactions List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($transactions)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-exchange-alt text-4xl mb-3"></i>
                        <p>No transactions found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Ref</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">User</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Amount</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Fee</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Date</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($transactions as $transaction): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4 whitespace-nowrap">
                                            <span class="text-sm font-mono text-gray-300"><?php echo htmlspecialchars($transaction['txn_ref']); ?></span>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div>
                                                <div class="text-sm font-medium text-white"><?php echo htmlspecialchars($transaction['username'] ?: 'N/A'); ?></div>
                                                <div class="text-sm text-gray-400"><?php echo htmlspecialchars($transaction['email'] ?: 'N/A'); ?></div>
                                            </div>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="type-badge <?php echo 'type-' . $transaction['type']; ?>">
                                                <?php echo ucfirst($transaction['type']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 font-medium text-white">
                                            <?php echo formatAmount($transaction['amount']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-gray-300">
                                            <?php echo formatAmount($transaction['fee']); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $transaction['status']; ?>">
                                                <?php echo ucfirst($transaction['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo date('M d, Y H:i', strtotime($transaction['created_at'])); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex space-x-2">
                                                <button class="text-indigo-400 hover:text-indigo-300 view-transaction" data-id="<?php echo $transaction['id']; ?>">
                                                    <i class="fas fa-eye"></i>
                                                </button>
                                                <button class="text-blue-400 hover:text-blue-300 change-status" 
                                                        data-id="<?php echo $transaction['id']; ?>"
                                                        data-ref="<?php echo htmlspecialchars($transaction['txn_ref']); ?>"
                                                        data-type="<?php echo $transaction['type']; ?>"
                                                        data-status="<?php echo $transaction['status']; ?>"
                                                        data-user-id="<?php echo $transaction['user_id']; ?>"
                                                        data-username="<?php echo htmlspecialchars($transaction['username'] ?: 'N/A'); ?>"
                                                        data-amount="<?php echo $transaction['amount']; ?>">
                                                    <i class="fas fa-exchange-alt"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <!-- Pagination -->
                    <?php if ($totalPages > 1): ?>
                        <div class="px-4 py-3 flex items-center justify-between border-t border-gray-700">
                            <div class="hidden sm:block">
                                <p class="text-sm text-gray-400">
                                    Showing <span class="font-medium"><?php echo $offset + 1; ?></span> to <span class="font-medium"><?php echo min($offset + $perPage, $totalRecords); ?></span> of <span class="font-medium"><?php echo $totalRecords; ?></span> results
                                </p>
                            </div>
                            <div class="flex-1 flex justify-between sm:justify-end">
                                <?php if ($page > 1): ?>
                                    <a href="?page=<?php echo $page - 1; ?><?php echo $typeFilter ? '&type=' . $typeFilter : ''; ?><?php echo $statusFilter ? '&status=' . $statusFilter : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $startDate ? '&start_date=' . $startDate : ''; ?><?php echo $endDate ? '&end_date=' . $endDate : ''; ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Previous
                                    </a>
                                <?php endif; ?>
                                
                                <?php if ($page < $totalPages): ?>
                                    <a href="?page=<?php echo $page + 1; ?><?php echo $typeFilter ? '&type=' . $typeFilter : ''; ?><?php echo $statusFilter ? '&status=' . $statusFilter : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $startDate ? '&start_date=' . $startDate : ''; ?><?php echo $endDate ? '&end_date=' . $endDate : ''; ?>" class="ml-3 relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Next
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- View Transaction Modal -->
    <div id="viewTransactionModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Transaction Details</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="transactionDetailsContent" class="text-gray-300">
                <!-- Transaction details will be loaded here -->
                <div class="text-center py-8">
                    <div class="inline-block animate-spin rounded-full h-8 w-8 border-t-2 border-b-2 border-indigo-500"></div>
                    <p class="mt-2">Loading transaction details...</p>
                </div>
            </div>
            
            <div class="mt-6 flex justify-end">
                <button class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                    Close
                </button>
            </div>
        </div>
    </div>
    
    <!-- Change Status Modal -->
    <div id="changeStatusModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Change Transaction Status</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-4">You are updating the status for transaction <span id="statusTxnRef" class="font-semibold text-white"></span> by <span id="statusUsername" class="font-semibold text-white"></span>.</p>
            
            <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-4">
                <p class="text-yellow-300 text-sm">
                    <i class="fas fa-exclamation-triangle mr-2"></i>
                    <strong>Warning:</strong> Changing transaction status will update user wallet balance accordingly. Please proceed with caution.
                </p>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="transaction_id" name="transaction_id" value="">
                <input type="hidden" id="user_id" name="user_id" value="">
                <input type="hidden" id="amount" name="amount" value="">
                <input type="hidden" id="transaction_type" name="transaction_type" value="">
                
                <div class="mb-6">
                    <label for="new_status" class="block text-sm font-medium text-gray-400 mb-1">New Status</label>
                    <select id="new_status" name="new_status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="pending">Pending</option>
                        <option value="successful">Successful</option>
                        <option value="failed">Failed</option>
                    </select>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="update_status" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Update Status
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const viewTransactionModal = document.getElementById('viewTransactionModal');
        const changeStatusModal = document.getElementById('changeStatusModal');
        
        function closeAllModals() {
            viewTransactionModal.classList.add('hidden');
            changeStatusModal.classList.add('hidden');
        }
        
        // Close modal buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            if (event.target === viewTransactionModal || event.target === changeStatusModal) {
                closeAllModals();
            }
        });
        
        // View transaction details
        document.querySelectorAll('.view-transaction').forEach(button => {
            button.addEventListener('click', function() {
                const transactionId = this.getAttribute('data-id');
                viewTransactionModal.classList.remove('hidden');
                
                // Show loading indicator
                document.getElementById('transactionDetailsContent').innerHTML = `
                    <div class="text-center py-8">
                        <div class="inline-block animate-spin rounded-full h-8 w-8 border-t-2 border-b-2 border-indigo-500"></div>
                        <p class="mt-2">Loading transaction details...</p>
                    </div>
                `;
                
                // Fetch transaction details (placeholder - in real implementation, you would make an AJAX request)
                // This is a simplified placeholder. In a real implementation, you would perform an AJAX request
                // to get transaction details from the server.
                setTimeout(() => {
                    // Simulate fetching transaction details
                    const details = `
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <div>
                                <h4 class="text-lg font-medium text-white mb-2">Transaction Information</h4>
                                <div class="space-y-2">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">ID:</span>
                                        <span>${transactionId}</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Type:</span>
                                        <span>Data Purchase</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Amount:</span>
                                        <span>₦1,500.00</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Fee:</span>
                                        <span>₦30.00</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Status:</span>
                                        <span class="status-badge status-successful">Successful</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Date:</span>
                                        <span>Jun 15, 2023 08:32 AM</span>
                                    </div>
                                </div>
                            </div>
                            
                            <div>
                                <h4 class="text-lg font-medium text-white mb-2">Additional Details</h4>
                                <div class="space-y-2">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Network:</span>
                                        <span>MTN</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Plan:</span>
                                        <span>2GB Monthly</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Phone:</span>
                                        <span>08012345678</span>
                                    </div>
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">API Response:</span>
                                        <span>Success</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <div class="mt-4 pt-4 border-t border-gray-700">
                            <h4 class="text-lg font-medium text-white mb-2">Transaction Description</h4>
                            <p>Purchase of 2GB data plan for 08012345678 on MTN network.</p>
                        </div>
                    `;
                    
                    document.getElementById('transactionDetailsContent').innerHTML = details;
                }, 1000);
            });
        });
        
        // Change transaction status
        document.querySelectorAll('.change-status').forEach(button => {
            button.addEventListener('click', function() {
                const transactionId = this.getAttribute('data-id');
                const txnRef = this.getAttribute('data-ref');
                const username = this.getAttribute('data-username');
                const currentStatus = this.getAttribute('data-status');
                const userId = this.getAttribute('data-user-id');
                const amount = this.getAttribute('data-amount');
                const transactionType = this.getAttribute('data-type');
                
                // Set form values
                document.getElementById('transaction_id').value = transactionId;
                document.getElementById('user_id').value = userId;
                document.getElementById('amount').value = amount;
                document.getElementById('transaction_type').value = transactionType;
                document.getElementById('statusTxnRef').textContent = txnRef;
                document.getElementById('statusUsername').textContent = username;
                
                // Set current status in dropdown
                document.getElementById('new_status').value = currentStatus;
                
                // Show the modal
                changeStatusModal.classList.remove('hidden');
            });
        });
        
        // Date range validation
        const startDateInput = document.getElementById('start_date');
        const endDateInput = document.getElementById('end_date');
        
        function validateDateRange() {
            if (startDateInput.value && endDateInput.value) {
                const startDate = new Date(startDateInput.value);
                const endDate = new Date(endDateInput.value);
                
                if (endDate < startDate) {
                    alert('End date cannot be earlier than start date');
                    endDateInput.value = '';
                }
            }
        }
        
        startDateInput.addEventListener('change', validateDateRange);
        endDateInput.addEventListener('change', validateDateRange);
    </script>
</body>
</html>