<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Pagination settings
$perPage = 20;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $perPage;

// Filter settings
$userType = isset($_GET['user_type']) ? sanitizeInput($_GET['user_type']) : '';
$status = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Build query
$query = "SELECT * FROM users WHERE 1=1";
$countQuery = "SELECT COUNT(*) as total FROM users WHERE 1=1";
$params = [];
$types = "";

if ($userType) {
    $query .= " AND user_type = ?";
    $countQuery .= " AND user_type = ?";
    $params[] = $userType;
    $types .= "s";
}

if ($status) {
    $query .= " AND status = ?";
    $countQuery .= " AND status = ?";
    $params[] = $status;
    $types .= "s";
}

if ($search) {
    $searchParam = "%$search%";
    $query .= " AND (username LIKE ? OR email LIKE ? OR full_name LIKE ? OR phone LIKE ?)";
    $countQuery .= " AND (username LIKE ? OR email LIKE ? OR full_name LIKE ? OR phone LIKE ?)";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "ssss";
}

// Order by latest first
$query .= " ORDER BY created_at DESC LIMIT ?, ?";
$params[] = $offset;
$params[] = $perPage;
$types .= "ii";

// Prepare and execute query
$stmt = $conn->prepare($query);
if (!empty($params) && !empty($types)) {  // Check that both params and types are not empty
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();
$users = [];

while ($row = $result->fetch_assoc()) {
    $users[] = $row;
}

// Get total records for pagination
$countStmt = $conn->prepare($countQuery);
if (!empty($params) && strlen($types) > 2) {  // Fix here: ensure there are types beyond the "ii" for LIMIT
    // Remove limit parameters which are the last two
    $countStmt->bind_param(substr($types, 0, -2), ...array_slice($params, 0, -2));
} else {
    // No filters were applied, so no parameters to bind
}
$countStmt->execute();
$countResult = $countStmt->get_result();
$totalRecords = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $perPage);

// Process user action (suspend/activate/delete)
$actionSuccess = '';
$actionError = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['suspend_user'])) {
        $userId = (int)$_POST['user_id'];
        $stmt = $conn->prepare("UPDATE users SET status = 'suspended' WHERE id = ?");
        $stmt->bind_param("i", $userId);
        
        if ($stmt->execute()) {
            $actionSuccess = 'User suspended successfully';
        } else {
            $actionError = 'Failed to suspend user: ' . $conn->error;
        }
    } elseif (isset($_POST['activate_user'])) {
        $userId = (int)$_POST['user_id'];
        $stmt = $conn->prepare("UPDATE users SET status = 'active' WHERE id = ?");
        $stmt->bind_param("i", $userId);
        
        if ($stmt->execute()) {
            $actionSuccess = 'User activated successfully';
        } else {
            $actionError = 'Failed to activate user: ' . $conn->error;
        }
    } elseif (isset($_POST['delete_user'])) {
        $userId = (int)$_POST['user_id'];
        
        // First check if user has any transactions
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM transactions WHERE user_id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $transactionCount = $result->fetch_assoc()['count'];
        
        if ($transactionCount > 0) {
            $actionError = 'Cannot delete user with existing transactions. Consider suspending the account instead.';
        } else {
            $stmt = $conn->prepare("DELETE FROM users WHERE id = ?");
            $stmt->bind_param("i", $userId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'User deleted successfully';
            } else {
                $actionError = 'Failed to delete user: ' . $conn->error;
            }
        }
    } elseif (isset($_POST['fund_wallet'])) {
        $userId = (int)$_POST['user_id'];
        $amount = (float)$_POST['amount'];
        $description = sanitizeInput($_POST['description']);
        
        if ($amount <= 0) {
            $actionError = 'Amount must be greater than zero';
        } else {
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Add amount to user's balance
                $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                $stmt->bind_param("di", $amount, $userId);
                $stmt->execute();
                
                // Record transaction
                $txnRef = 'ADMIN_FUND_' . time();
                $stmt = $conn->prepare("INSERT INTO transactions (user_id, txn_ref, type, amount, description, status) VALUES (?, ?, 'funding', ?, ?, 'successful')");
                $stmt->bind_param("isds", $userId, $txnRef, $amount, $description);
                $stmt->execute();
                
                // Commit transaction
                $conn->commit();
                
                $actionSuccess = 'Wallet funded successfully with ' . formatAmount($amount);
            } catch (Exception $e) {
                $conn->rollback();
                $actionError = 'Failed to fund wallet: ' . $e->getMessage();
            }
        }
    } elseif (isset($_POST['change_type'])) {
        $userId = (int)$_POST['user_id'];
        $newType = sanitizeInput($_POST['new_type']);
        
        if (!in_array($newType, ['smart', 'vendor', 'api'])) {
            $actionError = 'Invalid user type';
        } else {
            $stmt = $conn->prepare("UPDATE users SET user_type = ? WHERE id = ?");
            $stmt->bind_param("si", $newType, $userId);
            
            if ($stmt->execute()) {
                $actionSuccess = 'User type changed successfully to ' . ucfirst($newType);
            } else {
                $actionError = 'Failed to change user type: ' . $conn->error;
            }
        }
    }
    
    // Refresh user list after action
    if ($actionSuccess || $actionError) {
        // Re-execute query to get updated data
        $stmt = $conn->prepare($query);
        if (!empty($params) && !empty($types)) {  // Added check for empty types
            $stmt->bind_param($types, ...$params);
        }
        $stmt->execute();
        $result = $stmt->get_result();
        $users = [];
        
        while ($row = $result->fetch_assoc()) {
            $users[] = $row;
        }
    }
}

// Get flash message
$flashMessage = getFlashMessage();
if ($flashMessage) {
    if ($flashMessage['type'] === 'success') {
        $actionSuccess = $flashMessage['message'];
    } else {
        $actionError = $flashMessage['message'];
    }
}
// Set current page for sidebar highlight
$currentPage = 'users';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Management - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .modal {
            background-color: rgba(0, 0, 0, 0.7);
        }
        
        .modal-content {
            background-color: var(--bg-card);
        }
        
        .table-header {
            background-color: #1a1a1a;
        }
        
        .table-row:hover {
            background-color: #2a2a2a;
        }
        
        .user-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .user-badge.smart {
            background-color: rgba(37, 99, 235, 0.3);
            color: #93c5fd;
        }
        
        .user-badge.vendor {
            background-color: rgba(22, 163, 74, 0.3);
            color: #86efac;
        }
        
        .user-badge.api {
            background-color: rgba(244, 63, 94, 0.3);
            color: #fda4af;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-suspended {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
               <!-- Include Sidebar -->
        <?php require_once 'includes/sidebar.php'; ?>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">User Management</h1>
                <a href="add_user.php" class="accent-button py-2 px-4 rounded-md text-white flex items-center">
                    <i class="fas fa-plus mr-2"></i> Add New User
                </a>
            </div>
            
            <?php if ($actionError): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionError; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($actionSuccess): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $actionSuccess; ?></p>
                </div>
            <?php endif; ?>
            
            <!-- Filters -->
            <div class="admin-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="flex flex-col md:flex-row md:items-end space-y-4 md:space-y-0 md:space-x-4">
                    <div class="flex-1">
                        <label for="search" class="block text-sm font-medium text-gray-400 mb-1">Search</label>
                        <input type="text" id="search" name="search" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Search by username, email, name, phone" value="<?php echo htmlspecialchars($search); ?>">
                    </div>
                    
                    <div>
                        <label for="user_type" class="block text-sm font-medium text-gray-400 mb-1">User Type</label>
                        <select id="user_type" name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Types</option>
                            <option value="smart" <?php echo $userType === 'smart' ? 'selected' : ''; ?>>Smart</option>
                            <option value="vendor" <?php echo $userType === 'vendor' ? 'selected' : ''; ?>>Vendor</option>
                            <option value="api" <?php echo $userType === 'api' ? 'selected' : ''; ?>>API</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Statuses</option>
                            <option value="active" <?php echo $status === 'active' ? 'selected' : ''; ?>>Active</option>
                            <option value="suspended" <?php echo $status === 'suspended' ? 'selected' : ''; ?>>Suspended</option>
                        </select>
                    </div>
                    
                    <div class="md:flex-none">
                        <button type="submit" class="accent-button py-2 px-4 rounded-md text-white w-full">Filter</button>
                    </div>
                </form>
            </div>
            
            <!-- User List -->
            <div class="admin-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($users)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-users text-4xl mb-3"></i>
                        <p>No users found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">User</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Contact</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Balance</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Registered</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Actions</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-700">
                                <?php foreach ($users as $user): ?>
                                    <tr class="table-row">
                                        <td class="py-3 px-4">
                                            <div class="flex items-center">
                                                <div class="h-10 w-10 rounded-full bg-gray-600 flex items-center justify-center mr-3 text-white">
                                                    <?php echo substr($user['username'], 0, 1); ?>
                                                </div>
                                                <div>
                                                    <div class="font-medium text-white"><?php echo htmlspecialchars($user['username']); ?></div>
                                                    <div class="text-sm text-gray-400"><?php echo htmlspecialchars($user['full_name']); ?></div>
                                                </div>
                                            </div>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="text-sm text-white"><?php echo htmlspecialchars($user['email']); ?></div>
                                            <div class="text-sm text-gray-400"><?php echo htmlspecialchars($user['phone']); ?></div>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="user-badge <?php echo $user['user_type']; ?>">
                                                <?php echo ucfirst($user['user_type']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 font-medium text-white">
                                            <?php echo formatAmount($user['balance']); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="status-badge <?php echo 'status-' . $user['status']; ?>">
                                                <?php echo ucfirst($user['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo date('M d, Y', strtotime($user['created_at'])); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <div class="flex flex-wrap space-x-2">
                                                <button class="text-indigo-400 hover:text-indigo-300 view-user" data-id="<?php echo $user['id']; ?>">
                                                    <i class="fas fa-eye"></i>
                                                </button>
                                                <button class="text-blue-400 hover:text-blue-300 fund-wallet" 
                                                        data-id="<?php echo $user['id']; ?>" 
                                                        data-name="<?php echo htmlspecialchars($user['username']); ?>">
                                                    <i class="fas fa-wallet"></i>
                                                </button>
                                                <button class="text-yellow-400 hover:text-yellow-300 change-type" 
                                                        data-id="<?php echo $user['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($user['username']); ?>"
                                                        data-type="<?php echo $user['user_type']; ?>">
                                                    <i class="fas fa-user-tag"></i>
                                                </button>
                                                <?php if ($user['status'] === 'active'): ?>
                                                    <button class="text-red-400 hover:text-red-300 suspend-user" 
                                                            data-id="<?php echo $user['id']; ?>"
                                                            data-name="<?php echo htmlspecialchars($user['username']); ?>">
                                                        <i class="fas fa-user-slash"></i>
                                                    </button>
                                                <?php else: ?>
                                                    <button class="text-green-400 hover:text-green-300 activate-user" 
                                                            data-id="<?php echo $user['id']; ?>"
                                                            data-name="<?php echo htmlspecialchars($user['username']); ?>">
                                                        <i class="fas fa-user-check"></i>
                                                    </button>
                                                <?php endif; ?>
                                                <button class="text-red-500 hover:text-red-400 delete-user" 
                                                        data-id="<?php echo $user['id']; ?>"
                                                        data-name="<?php echo htmlspecialchars($user['username']); ?>">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <!-- Pagination -->
                    <?php if ($totalPages > 1): ?>
                        <div class="px-4 py-3 flex items-center justify-between border-t border-gray-700">
                            <div class="hidden sm:block">
                                <p class="text-sm text-gray-400">
                                    Showing <span class="font-medium"><?php echo $offset + 1; ?></span> to <span class="font-medium"><?php echo min($offset + $perPage, $totalRecords); ?></span> of <span class="font-medium"><?php echo $totalRecords; ?></span> results
                                </p>
                            </div>
                            <div class="flex-1 flex justify-between sm:justify-end">
                                <?php if ($page > 1): ?>
                                    <a href="?page=<?php echo $page - 1; ?><?php echo $userType ? '&user_type=' . $userType : ''; ?><?php echo $status ? '&status=' . $status : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Previous
                                    </a>
                                <?php endif; ?>
                                
                                <?php if ($page < $totalPages): ?>
                                    <a href="?page=<?php echo $page + 1; ?><?php echo $userType ? '&user_type=' . $userType : ''; ?><?php echo $status ? '&status=' . $status : ''; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?>" class="ml-3 relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Next
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Modals -->
    <!-- Suspend User Modal -->
    <div id="suspendModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Suspend User</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to suspend <span id="suspendUserName" class="font-semibold text-white"></span>? This user will not be able to login or use the platform until reactivated.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="suspend_user_id" name="user_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="suspend_user" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Suspend User
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Activate User Modal -->
    <div id="activateModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Activate User</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to activate <span id="activateUserName" class="font-semibold text-white"></span>? This user will be able to login and use the platform again.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="activate_user_id" name="user_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="activate_user" class="py-2 px-4 bg-green-600 text-white rounded-md hover:bg-green-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-green-500">
                        Activate User
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Delete User Modal -->
    <div id="deleteModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Delete User</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-6">Are you sure you want to delete <span id="deleteUserName" class="font-semibold text-white"></span>? This action cannot be undone and all user data will be permanently removed.</p>
            
            <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-6">
                <p class="text-yellow-300 text-sm">
                    <i class="fas fa-exclamation-triangle mr-2"></i>
                    Note: Users with existing transactions cannot be deleted. Consider suspending the account instead.
                </p>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" id="delete_user_id" name="user_id" value="">
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="delete_user" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500">
                        Delete User
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Fund Wallet Modal -->
    <div id="fundWalletModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Fund User Wallet</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-4">You are funding the wallet for <span id="fundUserName" class="font-semibold text-white"></span>.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="fund_user_id" name="user_id" value="">
                
                <div class="mb-4">
                    <label for="amount" class="block text-sm font-medium text-gray-400 mb-1">Amount</label>
                    <div class="flex">
                        <span class="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-600 bg-gray-700 text-gray-400"><?php echo getSetting('currency') ?: '₦'; ?></span>
                        <input type="number" id="amount" name="amount" class="form-input block w-full rounded-none rounded-r-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter amount" step="0.01" min="0.01" required>
                    </div>
                </div>
                
                <div class="mb-6">
                    <label for="description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                    <input type="text" id="description" name="description" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter description" value="Admin wallet funding" required>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="fund_wallet" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Fund Wallet
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Change User Type Modal -->
    <div id="changeTypeModal" class="fixed inset-0 z-50 flex items-center justify-center modal hidden">
        <div class="modal-content rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Change User Type</h3>
                <button class="close-modal text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-300 mb-4">You are changing the user type for <span id="changeTypeUserName" class="font-semibold text-white"></span>.</p>
            
            <form method="POST" action="">
                <input type="hidden" id="change_type_user_id" name="user_id" value="">
                
                <div class="mb-6">
                    <label for="new_type" class="block text-sm font-medium text-gray-400 mb-1">New User Type</label>
                    <select id="new_type" name="new_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        <option value="smart">Smart User</option>
                        <option value="vendor">Vendor</option>
                        <option value="api">API User</option>
                    </select>
                </div>
                
                <div class="p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md mb-6">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i>
                        Warning: Changing user type may affect their pricing rates and access to features.
                    </p>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" class="close-modal py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="change_type" class="accent-button py-2 px-4 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Change Type
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Modal functionality
        const modals = {
            suspendModal: document.getElementById('suspendModal'),
            activateModal: document.getElementById('activateModal'),
            deleteModal: document.getElementById('deleteModal'),
            fundWalletModal: document.getElementById('fundWalletModal'),
            changeTypeModal: document.getElementById('changeTypeModal')
        };
        
        function openModal(modalId, data = {}) {
            const modal = modals[modalId];
            if (!modal) return;
            
            // Set form data based on modal type
            if (modalId === 'suspendModal') {
                document.getElementById('suspend_user_id').value = data.id;
                document.getElementById('suspendUserName').textContent = data.name;
            } else if (modalId === 'activateModal') {
                document.getElementById('activate_user_id').value = data.id;
                document.getElementById('activateUserName').textContent = data.name;
            } else if (modalId === 'deleteModal') {
                document.getElementById('delete_user_id').value = data.id;
                document.getElementById('deleteUserName').textContent = data.name;
            } else if (modalId === 'fundWalletModal') {
                document.getElementById('fund_user_id').value = data.id;
                document.getElementById('fundUserName').textContent = data.name;
            } else if (modalId === 'changeTypeModal') {
                document.getElementById('change_type_user_id').value = data.id;
                document.getElementById('changeTypeUserName').textContent = data.name;
                document.getElementById('new_type').value = data.type;
            }
            
            modal.classList.remove('hidden');
        }
        
        function closeAllModals() {
            Object.values(modals).forEach(modal => {
                modal.classList.add('hidden');
            });
        }
        
        // Add event listeners to close buttons
        document.querySelectorAll('.close-modal').forEach(button => {
            button.addEventListener('click', closeAllModals);
        });
        
        // Close modals when clicking outside
        window.addEventListener('click', (event) => {
            Object.entries(modals).forEach(([id, modal]) => {
                if (event.target === modal) {
                    closeAllModals();
                }
            });
        });
        
        // Add event listeners to action buttons
        document.querySelectorAll('.suspend-user').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                const userName = this.getAttribute('data-name');
                openModal('suspendModal', { id: userId, name: userName });
            });
        });
        
        document.querySelectorAll('.activate-user').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                const userName = this.getAttribute('data-name');
                openModal('activateModal', { id: userId, name: userName });
            });
        });
        
        document.querySelectorAll('.delete-user').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                const userName = this.getAttribute('data-name');
                openModal('deleteModal', { id: userId, name: userName });
            });
        });
        
        document.querySelectorAll('.fund-wallet').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                const userName = this.getAttribute('data-name');
                openModal('fundWalletModal', { id: userId, name: userName });
            });
        });
        
        document.querySelectorAll('.change-type').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                const userName = this.getAttribute('data-name');
                const userType = this.getAttribute('data-type');
                openModal('changeTypeModal', { id: userId, name: userName, type: userType });
            });
        });
        
        // View user functionality
        document.querySelectorAll('.view-user').forEach(button => {
            button.addEventListener('click', function() {
                const userId = this.getAttribute('data-id');
                window.location.href = 'view_user.php?id=' + userId;
            });
        });
    </script>
</body>
</html>