<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Get ticket ID
$ticketId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($ticketId <= 0) {
    setFlashMessage('Invalid ticket ID', 'error');
    redirect(ADMIN_URL . '/support_tickets.php');
}

// Get admin data
$adminId = $_SESSION['admin_id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin info
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Get the ticket
$stmt = $conn->prepare("
    SELECT st.*, u.username, u.email, u.phone 
    FROM support_tickets st
    JOIN users u ON st.user_id = u.id
    WHERE st.id = ?
");
$stmt->bind_param("i", $ticketId);
$stmt->execute();
$result = $stmt->get_result();
$ticket = $result->fetch_assoc();

if (!$ticket) {
    setFlashMessage('Ticket not found', 'error');
    redirect(ADMIN_URL . '/support_tickets.php');
}

// Process actions
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action']) && $_POST['action'] === 'update_status') {
        $status = sanitizeInput($_POST['status']);
        
        if (!in_array($status, ['open', 'pending', 'replied', 'closed'])) {
            $error = 'Invalid status';
        } else {
            $stmt = $conn->prepare("UPDATE support_tickets SET status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $ticketId);
            
            if ($stmt->execute()) {
                $success = 'Ticket status updated successfully';
                
                // Update ticket data
                $ticket['status'] = $status;
                
                // Create notification for user
                $notifyTitle = 'Ticket Status Updated';
                $notifyMessage = 'Your support ticket #' . $ticketId . ' status has been updated to ' . ucfirst($status) . '.';
                
                $stmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, 'info', 0)
                ");
                $stmt->bind_param("iss", $ticket['user_id'], $notifyTitle, $notifyMessage);
                $stmt->execute();
            } else {
                $error = 'Failed to update ticket status';
            }
        }
    } elseif (isset($_POST['action']) && $_POST['action'] === 'add_reply') {
        $message = sanitizeInput($_POST['reply_message']);
        
        if (empty($message)) {
            $error = 'Reply message cannot be empty';
        } else {
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Insert reply
                $stmt = $conn->prepare("
                    INSERT INTO ticket_replies
                    (ticket_id, admin_id, message)
                    VALUES (?, ?, ?)
                ");
                $stmt->bind_param("iis", $ticketId, $adminId, $message);
                $stmt->execute();
                
                // Update ticket status to replied
                $status = 'replied';
                $stmt = $conn->prepare("UPDATE support_tickets SET status = ? WHERE id = ?");
                $stmt->bind_param("si", $status, $ticketId);
                $stmt->execute();
                
                // Update ticket data
                $ticket['status'] = $status;
                
                // Create notification for user
                $notifyTitle = 'Support Ticket Reply';
                $notifyMessage = 'Your support ticket #' . $ticketId . ' has received a reply from our support team.';
                
                $stmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, 'info', 0)
                ");
                $stmt->bind_param("iss", $ticket['user_id'], $notifyTitle, $notifyMessage);
                $stmt->execute();
                
                // Send email notification to user
                if ($ticket['email']) {
                    $subject = 'Your Support Ticket Has a Reply - ' . getSetting('site_name');
                    $emailContent = "
                        <p>Hello {$ticket['username']},</p>
                        <p>Your support ticket has received a reply from our team.</p>
                        <p>Ticket Details:</p>
                        <p><strong>Ticket ID:</strong> #{$ticketId}<br>
                        <strong>Subject:</strong> {$ticket['subject']}<br>
                        <strong>Status:</strong> Replied</p>
                        <p>You can view the full conversation by logging into your account and visiting the Support section.</p>
                        <p>Thank you for your patience.</p>
                        <p>Regards,<br>" . getSetting('site_name') . " Support Team</p>
                    ";
                    
                    sendEmail($ticket['email'], $subject, $emailContent);
                }
                
                // Commit transaction
                $conn->commit();
                
                $success = 'Reply added successfully';
            } catch (Exception $e) {
                // Rollback transaction
                $conn->rollback();
                $error = 'Error: ' . $e->getMessage();
            }
        }
    }
}

// Get ticket replies
$stmt = $conn->prepare("
    SELECT tr.*, u.username as user_username, a.username as admin_username 
    FROM ticket_replies tr
    LEFT JOIN users u ON tr.user_id = u.id
    LEFT JOIN admins a ON tr.admin_id = a.id
    WHERE tr.ticket_id = ?
    ORDER BY tr.created_at ASC
");
$stmt->bind_param("i", $ticketId);
$stmt->execute();
$result = $stmt->get_result();
$replies = [];

while ($row = $result->fetch_assoc()) {
    $replies[] = $row;
}

// Get user transactions if there's a reference
$transactions = [];
if (!empty($ticket['reference'])) {
    $reference = $ticket['reference'];
    $stmt = $conn->prepare("
        SELECT * FROM transactions 
        WHERE user_id = ? AND txn_ref = ?
    ");
    $stmt->bind_param("is", $ticket['user_id'], $reference);
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($row = $result->fetch_assoc()) {
        $transactions[] = $row;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Ticket - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        /* Ticket status badge styles */
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-open {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .status-replied {
            background-color: rgba(59, 130, 246, 0.3);
            color: #93c5fd;
        }
        
        .status-closed {
            background-color: rgba(107, 114, 128, 0.3);
            color: #d1d5db;
        }
        
        .transaction-type {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .transaction-credit, .transaction-fund {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .transaction-debit, .transaction-data, .transaction-airtime, .transaction-cable, .transaction-electricity {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        .transaction-status-successful {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .transaction-status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .transaction-status-failed {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-bell mr-3"></i>
                                <span>Notifications</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700 border-l-3 border-indigo-500">
                                <i class="fas fa-ticket-alt mr-3"></i>
                                <span>Support Tickets</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cog mr-3"></i>
                                <span>General</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex flex-col md:flex-row justify-between items-start md:items-center mb-6">
                <div>
                    <div class="flex items-center mb-2">
                        <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                            <i class="fas fa-arrow-left"></i> Back to Tickets
                        </a>
                        <h1 class="text-2xl font-bold text-white">Ticket #<?php echo $ticket['id']; ?></h1>
                    </div>
                    <div class="text-gray-400 text-sm">
                        <?php echo date('F j, Y, g:i a', strtotime($ticket['created_at'])); ?>
                    </div>
                </div>
                
                <div class="mt-4 md:mt-0 flex items-center space-x-2">
                    <?php
                    $statusColors = [
                        'open' => 'status-open',
                        'pending' => 'status-pending',
                        'replied' => 'status-replied',
                        'closed' => 'status-closed'
                    ];
                    $statusColor = $statusColors[$ticket['status']] ?? 'status-open';
                    ?>
                    <span class="status-badge <?php echo $statusColor; ?>">
                        <?php echo ucfirst($ticket['status']); ?>
                    </span>
                    
                    <button id="changeStatusBtn" class="bg-indigo-600 hover:bg-indigo-700 text-white text-sm py-1 px-3 rounded-md">
                        <i class="fas fa-cog mr-1"></i> Change Status
                    </button>
                </div>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 lg:grid-cols-4 gap-6">
                <!-- User and Ticket Info -->
                <div class="lg:col-span-1">
                    <!-- User Info Card -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <h2 class="text-lg font-semibold text-white mb-4">User Information</h2>
                        
                        <div class="flex items-center mb-4">
                            <div class="h-12 w-12 rounded-full bg-gray-700 flex items-center justify-center mr-3">
                                <i class="fas fa-user text-gray-400"></i>
                            </div>
                            <div>
                                <div class="font-medium text-white"><?php echo htmlspecialchars($ticket['username']); ?></div>
                                <a href="<?php echo ADMIN_URL; ?>/view_user.php?id=<?php echo $ticket['user_id']; ?>" class="text-xs text-indigo-400 hover:text-indigo-300">
                                    View User Profile
                                </a>
                            </div>
                        </div>
                        
                        <div class="space-y-2 text-sm">
                            <div class="flex justify-between">
                                <span class="text-gray-400">Email:</span>
                                <span class="text-white"><?php echo htmlspecialchars($ticket['email']); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Phone:</span>
                                <span class="text-white"><?php echo htmlspecialchars($ticket['phone'] ?? 'N/A'); ?></span>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Ticket Info Card -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <h2 class="text-lg font-semibold text-white mb-4">Ticket Information</h2>
                        
                        <div class="space-y-2 text-sm">
                            <div class="flex justify-between">
                                <span class="text-gray-400">Category:</span>
                                <span class="text-white"><?php echo ucfirst($ticket['category']); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Status:</span>
                                <span class="status-badge <?php echo $statusColor; ?>"><?php echo ucfirst($ticket['status']); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Created:</span>
                                <span class="text-white"><?php echo date('M d, Y', strtotime($ticket['created_at'])); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Time:</span>
                                <span class="text-white"><?php echo date('g:i A', strtotime($ticket['created_at'])); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Reference:</span>
                                <span class="text-white"><?php echo $ticket['reference'] ?: 'N/A'; ?></span>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Quick Actions Card -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-lg font-semibold text-white mb-4">Quick Actions</h2>
                        
                        <div class="space-y-2">
                            <button id="quickReplyBtn" class="w-full bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded-md text-sm flex items-center justify-center">
                                <i class="fas fa-reply mr-2"></i> Quick Reply
                            </button>
                            
                            <a href="<?php echo ADMIN_URL; ?>/send_notification.php?user_id=<?php echo $ticket['user_id']; ?>" class="w-full bg-blue-600 hover:bg-blue-700 text-white py-2 px-4 rounded-md text-sm flex items-center justify-center">
                                <i class="fas fa-bell mr-2"></i> Send Notification
                            </a>
                            
                            <?php if ($ticket['status'] !== 'closed'): ?>
                                <form method="POST" action="" class="inline w-full">
                                    <input type="hidden" name="action" value="update_status">
                                    <input type="hidden" name="status" value="closed">
                                    <button type="submit" class="w-full bg-red-600 hover:bg-red-700 text-white py-2 px-4 rounded-md text-sm flex items-center justify-center">
                                        <i class="fas fa-times-circle mr-2"></i> Close Ticket
                                    </button>
                                </form>
                            <?php else: ?>
                                <form method="POST" action="" class="inline w-full">
                                    <input type="hidden" name="action" value="update_status">
                                    <input type="hidden" name="status" value="open">
                                    <button type="submit" class="w-full bg-yellow-600 hover:bg-yellow-700 text-white py-2 px-4 rounded-md text-sm flex items-center justify-center">
                                        <i class="fas fa-folder-open mr-2"></i> Reopen Ticket
                                    </button>
                                </form>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                
                <!-- Ticket Content and Replies -->
                <div class="lg:col-span-3">
                    <!-- Ticket Details -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <h2 class="text-xl font-semibold text-white mb-4">
                            <?php echo htmlspecialchars($ticket['subject']); ?>
                        </h2>
                        
                        <!-- Original Message -->
                        <div class="bg-gray-700 rounded-lg p-4 mb-6">
                            <div class="flex justify-between items-start mb-2">
                                <div class="flex items-center">
                                    <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-user text-indigo-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($ticket['username']); ?></div>
                                        <div class="text-xs text-gray-400"><?php echo date('M d, Y, g:i a', strtotime($ticket['created_at'])); ?></div>
                                    </div>
                                </div>
                            </div>
                            <div class="mt-3 text-gray-300 whitespace-pre-wrap"><?php echo nl2br(htmlspecialchars($ticket['message'])); ?></div>
                            
                            <?php if ($ticket['reference']): ?>
                                <div class="mt-4 p-3 bg-gray-800 rounded text-sm">
                                    <div class="text-gray-400 mb-1">Reference:</div>
                                    <div class="text-gray-300"><?php echo htmlspecialchars($ticket['reference']); ?></div>
                                </div>
                            <?php endif; ?>
                        </div>
                        
                        <!-- Referenced Transaction (if any) -->
                        <?php if (!empty($transactions)): ?>
                            <div class="bg-gray-800 rounded-lg p-4 mb-6">
                                <h3 class="text-white font-medium mb-3">Referenced Transaction</h3>
                                
                                <div class="overflow-x-auto">
                                    <table class="min-w-full">
                                        <thead class="bg-gray-900">
                                            <tr>
                                                <th class="py-2 px-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                                                <th class="py-2 px-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Type</th>
                                                <th class="py-2 px-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                                                <th class="py-2 px-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                                <th class="py-2 px-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Actions</th>
                                            </tr>
                                        </thead>
                                        <tbody class="divide-y divide-gray-800">
                                            <?php foreach ($transactions as $tx): ?>
                                                <tr>
                                                    <td class="py-2 px-3 text-sm text-gray-300">
                                                        <?php echo date('M d, Y', strtotime($tx['created_at'])); ?>
                                                    </td>
                                                    <td class="py-2 px-3">
                                                        <span class="transaction-type transaction-<?php echo $tx['type']; ?>">
                                                            <?php echo ucfirst($tx['type']); ?>
                                                        </span>
                                                    </td>
                                                    <td class="py-2 px-3 text-sm text-white font-medium">
                                                        <?php echo $currency . number_format($tx['amount'], 2); ?>
                                                    </td>
                                                    <td class="py-2 px-3">
                                                        <span class="transaction-status-<?php echo $tx['status']; ?> status-badge">
                                                            <?php echo ucfirst($tx['status']); ?>
                                                        </span>
                                                    </td>
                                                    <td class="py-2 px-3">
                                                        <a href="<?php echo ADMIN_URL; ?>/view_transaction.php?id=<?php echo $tx['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                            <i class="fas fa-eye"></i>
                                                        </a>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        <?php endif; ?>
                        
                        <!-- Ticket Replies -->
                        <?php if (!empty($replies)): ?>
                            <div class="space-y-4">
                                <h3 class="text-white font-medium mb-3">Replies</h3>
                                
                                <?php foreach ($replies as $reply): ?>
                                    <div class="bg-gray-700 rounded-lg p-4">
                                        <div class="flex justify-between items-start mb-2">
                                            <div class="flex items-center">
                                                <div class="h-10 w-10 rounded-full <?php echo $reply['admin_id'] ? 'bg-yellow-500 bg-opacity-20' : 'bg-indigo-500 bg-opacity-20'; ?> flex items-center justify-center mr-3">
                                                    <i class="fas <?php echo $reply['admin_id'] ? 'fa-user-shield text-yellow-400' : 'fa-user text-indigo-400'; ?>"></i>
                                                </div>
                                                <div>
                                                    <div class="font-medium text-white">
                                                        <?php 
                                                        if ($reply['admin_id']) {
                                                            echo 'Support Team';
                                                            if ($reply['admin_username']) {
                                                                echo ' (' . htmlspecialchars($reply['admin_username']) . ')';
                                                            }
                                                        } else {
                                                            echo htmlspecialchars($ticket['username']);
                                                        }
                                                        ?>
                                                    </div>
                                                    <div class="text-xs text-gray-400"><?php echo date('M d, Y, g:i a', strtotime($reply['created_at'])); ?></div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="mt-3 text-gray-300 whitespace-pre-wrap"><?php echo nl2br(htmlspecialchars($reply['message'])); ?></div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                    
                    <!-- Reply Form -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-lg font-semibold text-white mb-4">Reply to Ticket</h2>
                        
                        <?php if ($ticket['status'] === 'closed'): ?>
                            <div class="bg-gray-700 rounded-lg p-4 text-center">
                                <div class="h-12 w-12 bg-gray-600 rounded-full flex items-center justify-center mx-auto mb-3">
                                    <i class="fas fa-lock text-yellow-400 text-xl"></i>
                                </div>
                                <p class="text-white font-medium mb-2">This ticket is closed</p>
                                <p class="text-gray-400 mb-4">You can reopen this ticket to continue the conversation.</p>
                                <form method="POST" action="" class="inline">
                                    <input type="hidden" name="action" value="update_status">
                                    <input type="hidden" name="status" value="open">
                                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                                        <i class="fas fa-folder-open mr-2"></i> Reopen Ticket
                                    </button>
                                </form>
                            </div>
                        <?php else: ?>
                            <form method="POST" action="">
                                <input type="hidden" name="action" value="add_reply">
                                
                                <div class="mb-4">
                                    <label for="reply_message" class="block text-sm font-medium text-gray-400 mb-2">Your Reply</label>
                                    <textarea id="reply_message" name="reply_message" rows="6" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                                </div>
                                
                                <div class="flex justify-end">
                                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                                        <i class="fas fa-paper-plane mr-2"></i> Send Reply
                                    </button>
                                </div>
                            </form>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Change Status Modal -->
    <div id="statusModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Change Ticket Status</h3>
                <button id="closeStatusModal" class="text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="update_status">
                
                <div class="mb-6">
                    <label for="status" class="block text-sm font-medium text-gray-400 mb-2">Status</label>
                    <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        <option value="open" <?php echo $ticket['status'] === 'open' ? 'selected' : ''; ?>>Open</option>
                        <option value="pending" <?php echo $ticket['status'] === 'pending' ? 'selected' : ''; ?>>Pending</option>
                        <option value="replied" <?php echo $ticket['status'] === 'replied' ? 'selected' : ''; ?>>Replied</option>
                        <option value="closed" <?php echo $ticket['status'] === 'closed' ? 'selected' : ''; ?>>Closed</option>
                    </select>
                </div>
                
                <div class="flex justify-end">
                    <button type="button" id="cancelStatusBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                        Cancel
                    </button>
                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                        <i class="fas fa-save mr-1"></i> Update Status
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Quick Reply Modal -->
    <div id="quickReplyModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-2xl w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Quick Reply</h3>
                <button id="closeQuickReplyModal" class="text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div class="mb-4">
                <div class="grid grid-cols-2 gap-3">
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="Thank you for contacting our support team. We've received your request and are looking into it. We'll get back to you as soon as possible.">
                        Acknowledgement
                    </button>
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="Thank you for your patience. We've resolved your issue. Please let us know if you need any further assistance or have additional questions.">
                        Issue Resolved
                    </button>
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="We need some additional information to help resolve your issue. Could you please provide the following details:\n\n1. \n2. \n3. \n\nThank you for your cooperation.">
                        Request More Info
                    </button>
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="I understand your frustration, and I apologize for any inconvenience caused. We're working on resolving your issue as quickly as possible. Thank you for your patience.">
                        Apology
                    </button>
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="We've escalated this issue to our technical team for further investigation. They'll look into it right away, and we'll update you as soon as we have more information.">
                        Escalation
                    </button>
                    <button class="quick-reply-template bg-gray-700 hover:bg-gray-600 text-white p-3 rounded-md text-sm text-left transition-colors" data-text="This issue has been fixed in our latest update. Please clear your cache and cookies, then restart your browser to ensure you're using the latest version. Let us know if the issue persists.">
                        Technical Fix
                    </button>
                </div>
            </div>
            
            <form method="POST" action="" id="quickReplyForm">
                <input type="hidden" name="action" value="add_reply">
                
                <div class="mb-4">
                    <label for="quick_reply_message" class="block text-sm font-medium text-gray-400 mb-2">Your Reply</label>
                    <textarea id="quick_reply_message" name="reply_message" rows="6" class="form-textarea block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                </div>
                
                <div class="flex justify-end">
                    <button type="button" id="cancelQuickReplyBtn" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2">
                        Cancel
                    </button>
                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                        <i class="fas fa-paper-plane mr-2"></i> Send Reply
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Change Status Modal
            const statusModal = document.getElementById('statusModal');
            const changeStatusBtn = document.getElementById('changeStatusBtn');
            const closeStatusModal = document.getElementById('closeStatusModal');
            const cancelStatusBtn = document.getElementById('cancelStatusBtn');
            
            changeStatusBtn.addEventListener('click', function() {
                statusModal.classList.remove('hidden');
            });
            
            closeStatusModal.addEventListener('click', function() {
                statusModal.classList.add('hidden');
            });
            
            cancelStatusBtn.addEventListener('click', function() {
                statusModal.classList.add('hidden');
            });
            
            // Quick Reply Modal
            const quickReplyModal = document.getElementById('quickReplyModal');
            const quickReplyBtn = document.getElementById('quickReplyBtn');
            const closeQuickReplyModal = document.getElementById('closeQuickReplyModal');
            const cancelQuickReplyBtn = document.getElementById('cancelQuickReplyBtn');
            const quickReplyTemplates = document.querySelectorAll('.quick-reply-template');
            const quickReplyMessage = document.getElementById('quick_reply_message');
            
            quickReplyBtn.addEventListener('click', function() {
                quickReplyModal.classList.remove('hidden');
            });
            
            closeQuickReplyModal.addEventListener('click', function() {
                quickReplyModal.classList.add('hidden');
            });
            
            cancelQuickReplyBtn.addEventListener('click', function() {
                quickReplyModal.classList.add('hidden');
            });
            
            quickReplyTemplates.forEach(template => {
                template.addEventListener('click', function() {
                    const templateText = this.getAttribute('data-text');
                    quickReplyMessage.value = templateText;
                });
            });
            
            // Close modals when clicking outside
            window.addEventListener('click', function(e) {
                if (e.target === statusModal) {
                    statusModal.classList.add('hidden');
                }
                if (e.target === quickReplyModal) {
                    quickReplyModal.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>