<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if admin is logged in
if (!isAdminLoggedIn()) {
    redirect(ADMIN_URL . '/login.php');
}

// Check if user ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    redirect(ADMIN_URL . '/users.php');
}

$userId = (int)$_GET['id'];
$db = getDB();
$conn = $db->getConnection();

// Get admin data
$adminId = $_SESSION['admin_id'];
$stmt = $conn->prepare("SELECT * FROM admins WHERE id = ?");
$stmt->bind_param("i", $adminId);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

if (!$admin) {
    // If admin not found, log out
    session_destroy();
    redirect(ADMIN_URL . '/login.php');
}

// Add the following after getting the admin data
$currency = getSetting('currency', '₦');

// Get user data
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    setFlashMessage('User not found.', 'error');
    redirect(ADMIN_URL . '/users.php');
}

// Get user transactions
$stmt = $conn->prepare("
    SELECT * FROM transactions 
    WHERE user_id = ? 
    ORDER BY created_at DESC 
    LIMIT 10
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$transactions = [];

while ($row = $result->fetch_assoc()) {
    $transactions[] = $row;
}

// Get transaction stats
$stmt = $conn->prepare("
    SELECT 
        COUNT(*) as total_transactions,
        SUM(CASE WHEN type = 'fund' AND status = 'successful' THEN 1 ELSE 0 END) as total_fund_transactions,
        SUM(CASE WHEN type = 'fund' AND status = 'successful' THEN amount ELSE 0 END) as total_fund_amount,
        SUM(CASE WHEN type IN ('data', 'airtime', 'cable', 'electricity') AND status = 'successful' THEN 1 ELSE 0 END) as total_purchase_transactions,
        SUM(CASE WHEN type IN ('data', 'airtime', 'cable', 'electricity') AND status = 'successful' THEN amount ELSE 0 END) as total_purchase_amount
    FROM transactions 
    WHERE user_id = ?
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$stats = $result->fetch_assoc();

// Process actions
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action']) && $_POST['action'] === 'update_user') {
        $username = sanitizeInput($_POST['username']);
        $email = sanitizeInput($_POST['email']);
        $phone = sanitizeInput($_POST['phone']);
        $userType = sanitizeInput($_POST['user_type']);
        $status = sanitizeInput($_POST['status']);
        
        // Validate inputs
        if (empty($username)) {
            $error = 'Username is required';
        } elseif (empty($email)) {
            $error = 'Email is required';
        } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $error = 'Invalid email format';
        } elseif (!in_array($userType, ['smart', 'vendor', 'api'])) {
            $error = 'Invalid user type';
        } elseif (!in_array($status, ['active', 'inactive', 'pending'])) {
            $error = 'Invalid status';
        } else {
            // Check if username or email already exists
            $stmt = $conn->prepare("
                SELECT COUNT(*) as count FROM users 
                WHERE (username = ? OR email = ?) AND id != ?
            ");
            $stmt->bind_param("ssi", $username, $email, $userId);
            $stmt->execute();
            $result = $stmt->get_result();
            $row = $result->fetch_assoc();
            
            if ($row['count'] > 0) {
                $error = 'Username or email already exists';
            } else {
                // Update user
                $stmt = $conn->prepare("
                    UPDATE users 
                    SET username = ?, email = ?, phone = ?, user_type = ?, status = ?
                    WHERE id = ?
                ");
                $stmt->bind_param("sssssi", $username, $email, $phone, $userType, $status, $userId);
                
                if ($stmt->execute()) {
                    $success = 'User updated successfully';
                    
                    // Refresh user data
                    $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
                    $stmt->bind_param("i", $userId);
                    $stmt->execute();
                    $result = $stmt->get_result();
                    $user = $result->fetch_assoc();
                    
                    // Create notification for user about account update
                    $notifyTitle = 'Account Updated';
                    $notifyMessage = 'Your account information has been updated by an administrator.';
                    
                    $stmt = $conn->prepare("
                        INSERT INTO notifications 
                        (user_id, title, message, type, is_read)
                        VALUES (?, ?, ?, 'info', 0)
                    ");
                    $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
                    $stmt->execute();
                } else {
                    $error = 'Failed to update user. Please try again.';
                }
            }
        }
    } else if (isset($_POST['action']) && $_POST['action'] === 'wallet_operation') {
        $amount = (float)$_POST['amount'];
        $operationType = sanitizeInput($_POST['operation_type']);
        $description = sanitizeInput($_POST['description']);
        
        if ($amount <= 0) {
            $error = 'Amount must be greater than zero';
        } elseif (!in_array($operationType, ['credit', 'debit'])) {
            $error = 'Invalid operation type';
        } else {
            $conn->begin_transaction();
            try {
                // Generate unique reference
                $reference = $operationType === 'credit' ? 'ADMIN_CREDIT_' : 'ADMIN_DEBIT_';
                $reference .= uniqid() . '_' . time();
                
                if ($operationType === 'debit' && $user['balance'] < $amount) {
                    throw new Exception('Insufficient balance for debit operation');
                }
                
                // Create transaction
                $stmt = $conn->prepare("
                    INSERT INTO transactions 
                    (user_id, txn_ref, type, amount, fee, description, status)
                    VALUES (?, ?, ?, ?, 0, ?, 'successful')
                ");
                $stmt->bind_param("issds", $userId, $reference, $operationType, $amount, $description);
                $stmt->execute();
                
                // Update user balance
                if ($operationType === 'credit') {
                    $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                } else {
                    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
                }
                $stmt->bind_param("di", $amount, $userId);
                $stmt->execute();
                
                // Create notification for user
                $notifyTitle = $operationType === 'credit' ? 'Wallet Credited' : 'Wallet Debited';
                $notifyMessage = 'Your wallet has been ' . ($operationType === 'credit' ? 'credited with ' : 'debited with ') . $currency . $amount . '. ' . $description;
                $notifyType = $operationType === 'credit' ? 'success' : 'warning';
                
                $stmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, ?, 0)
                ");
                $stmt->bind_param("isss", $userId, $notifyTitle, $notifyMessage, $notifyType);
                $stmt->execute();
                
                // Commit transaction
                $conn->commit();
                
                $success = 'Wallet operation completed successfully';
                
                // Refresh user data
                $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
                $stmt->bind_param("i", $userId);
                $stmt->execute();
                $result = $stmt->get_result();
                $user = $result->fetch_assoc();
                
                // Refresh transaction data
                $stmt = $conn->prepare("
                    SELECT * FROM transactions 
                    WHERE user_id = ? 
                    ORDER BY created_at DESC 
                    LIMIT 10
                ");
                $stmt->bind_param("i", $userId);
                $stmt->execute();
                $result = $stmt->get_result();
                $transactions = [];
                
                while ($row = $result->fetch_assoc()) {
                    $transactions[] = $row;
                }
            } catch (Exception $e) {
                $conn->rollback();
                $error = 'Error: ' . $e->getMessage();
            }
        }
    } else if (isset($_POST['action']) && $_POST['action'] === 'reset_password') {
        // Generate a random password
        $newPassword = generateRandomString(10);
        $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);
        
        // Update user password
        $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
        $stmt->bind_param("si", $hashedPassword, $userId);
        
        if ($stmt->execute()) {
            $success = 'Password reset successfully. New password: ' . $newPassword;
            
            // Create notification for user
            $notifyTitle = 'Password Reset';
            $notifyMessage = 'Your password has been reset by an administrator. Please use your new password to log in.';
            
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'warning', 0)
            ");
            $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
            $stmt->execute();
            
            // Send email to user with new password
            if (!empty($user['email'])) {
                $subject = 'Password Reset - ' . getSetting('site_name');
                $emailMsg = "
                    <p>Dear {$user['username']},</p>
                    <p>Your password has been reset by an administrator.</p>
                    <p>Your new password is: <strong>{$newPassword}</strong></p>
                    <p>Please log in with this password and then change it to a password of your choice for security reasons.</p>
                    <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                ";
                
                sendEmail($user['email'], $subject, $emailMsg);
            }
        } else {
            $error = 'Failed to reset password. Please try again.';
        }
    }
}
// dont redclar
if (!function_exists('generateRandomString')) {
// Helper function to generate random string
function generateRandomString($length = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[random_int(0, $charactersLength - 1)];
    }
    return $randomString; }
}
?> 
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View User - Admin Dashboard - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .admin-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .admin-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        /* Status badge styles */
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-inactive {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        /* Transaction type badge styles */
        .transaction-type {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .transaction-credit, .transaction-fund {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .transaction-debit, .transaction-data, .transaction-airtime, .transaction-cable, .transaction-electricity {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        /* User type badge styles */
        .user-type-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .user-type-smart {
            background-color: rgba(59, 130, 246, 0.3);
            color: #93c5fd;
        }
        
        .user-type-vendor {
            background-color: rgba(124, 58, 237, 0.3);
            color: #c4b5fd;
        }
        
        .user-type-api {
            background-color: rgba(236, 72, 153, 0.3);
            color: #f9a8d4;
        }
        
        .transaction-status-successful {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .transaction-status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .transaction-status-failed {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo ADMIN_URL; ?>" class="font-bold text-xl">
                    <?php echo getSetting('site_name'); ?> Admin
                </a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($admin['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="<?php echo ADMIN_URL; ?>/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="<?php echo ADMIN_URL; ?>/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                        <a href="<?php echo ADMIN_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="admin-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Main Menu</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-tachometer-alt mr-3"></i>
                                <span>Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/users.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700 border-l-3 border-indigo-500">
                                <i class="fas fa-users mr-3"></i>
                                <span>Users</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-exchange-alt mr-3"></i>
                                <span>Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/notifications.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-bell mr-3"></i>
                                <span>Notifications</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/support_tickets.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-ticket-alt mr-3"></i>
                                <span>Support Tickets</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Reseller</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/panels.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-store mr-3"></i>
                                <span>Panels</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/reseller/orders.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-shopping-cart mr-3"></i>
                                <span>Orders</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div class="mb-4">
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Services</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/data_plans.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-wifi mr-3"></i>
                                <span>Data Plans</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/services/networks.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-network-wired mr-3"></i>
                                <span>Networks</span>
                            </a>
                        </li>
                    </ul>
                </div>
                
                <div>
                    <h2 class="text-lg font-semibold text-gray-400 px-4 mb-2">Settings</h2>
                    <ul class="space-y-2">
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/settings/general.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-cog mr-3"></i>
                                <span>General</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo ADMIN_URL; ?>/promo_codes.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                                <i class="fas fa-gift mr-3"></i>
                                <span>Promo Codes</span>
                            </a>
                        </li>
                    </ul>
                </div>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex items-center mb-6">
                <a href="<?php echo ADMIN_URL; ?>/users.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                    <i class="fas fa-arrow-left"></i> Back to Users
                </a>
                <h1 class="text-2xl font-bold text-white">User Details</h1>
            </div>
            
            <?php if ($error): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $error; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
                <!-- User Info Column -->
                <div class="lg:col-span-1">
                    <!-- User Profile Card -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <div class="flex items-center mb-4">
                            <div class="h-16 w-16 rounded-full bg-gray-700 flex items-center justify-center mr-4">
                                <i class="fas fa-user text-xl text-gray-500"></i>
                            </div>
                            <div>
                                <h2 class="text-xl font-bold text-white"><?php echo htmlspecialchars($user['username']); ?></h2>
                                <div class="flex mt-1">
                                    <?php
                                    $statusBadge = '';
                                    switch ($user['status']) {
                                        case 'active':
                                            $statusBadge = 'status-active';
                                            break;
                                        case 'inactive':
                                            $statusBadge = 'status-inactive';
                                            break;
                                        case 'pending':
                                            $statusBadge = 'status-pending';
                                            break;
                                        default:
                                            $statusBadge = 'status-inactive';
                                    }
                                    
                                    $userTypeBadge = 'user-type-smart';
                                    $userTypeDisplay = 'Standard';
                                    if ($user['user_type'] === 'vendor') {
                                        $userTypeBadge = 'user-type-vendor';
                                        $userTypeDisplay = 'Vendor';
                                    } elseif ($user['user_type'] === 'api') {
                                        $userTypeBadge = 'user-type-api';
                                        $userTypeDisplay = 'API';
                                    }
                                    ?>
                                    <span class="status-badge <?php echo $statusBadge; ?> mr-2">
                                        <?php echo ucfirst($user['status']); ?>
                                    </span>
                                    <span class="user-type-badge <?php echo $userTypeBadge; ?>">
                                        <?php echo $userTypeDisplay; ?>
                                    </span>
                                </div>
                            </div>
                        </div>
                        
                        <div class="border-t border-gray-700 pt-4 mb-4">
                            <div class="grid grid-cols-2 gap-3">
                                <div>
                                    <p class="text-gray-400 text-sm">User ID</p>
                                    <p class="text-white">#<?php echo $user['id']; ?></p>
                                </div>
                                <div>
                                    <p class="text-gray-400 text-sm">Email</p>
                                    <p class="text-white"><?php echo htmlspecialchars($user['email']); ?></p>
                                </div>
                                <div>
                                    <p class="text-gray-400 text-sm">Phone</p>
                                    <p class="text-white"><?php echo htmlspecialchars($user['phone'] ?: 'Not provided'); ?></p>
                                </div>
                                <div>
                                    <p class="text-gray-400 text-sm">Email Verified</p>
                                    <p class="text-white"><?php echo $user['email_verified'] ? 'Yes' : 'No'; ?></p>
                                </div>
                                <div>
                                    <p class="text-gray-400 text-sm">Registered</p>
                                    <p class="text-white"><?php echo date('M d, Y', strtotime($user['created_at'])); ?></p>
                                </div>
                                <div>
                                    <p class="text-gray-400 text-sm">Last Login</p>
                                    <p class="text-white"><?php echo $lastLogin = isset($user['last_login']) && $user['last_login'] ? date('M d, Y H:i', strtotime($user['last_login'])) : 'Never'; ?></p>
                                </div>
                            </div>
                        </div>
                        
                        <div class="flex space-x-2">
                            <button id="editUserBtn" class="bg-indigo-600 hover:bg-indigo-700 text-white py-2 px-4 rounded-md text-sm">
                                <i class="fas fa-edit mr-1"></i> Edit User
                            </button>
                            <button id="resetPasswordBtn" class="bg-yellow-600 hover:bg-yellow-700 text-white py-2 px-4 rounded-md text-sm">
                                <i class="fas fa-key mr-1"></i> Reset Password
                            </button>
                        </div>
                    </div>
                    
                    <!-- Wallet Card -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Wallet</h2>
                        
                        <div class="text-center mb-6">
                            <div class="text-3xl font-bold text-white"><?php echo $currency . number_format($user['balance'], 2); ?></div>
                            <p class="text-gray-400 text-sm">Current Balance</p>
                        </div>
                        
                        <div class="grid grid-cols-2 gap-4 mb-6">
                            <div class="bg-gray-700 p-3 rounded-lg text-center">
                                <div class="text-xl font-bold text-white"><?php echo number_format($stats['total_transactions'] ?? 0); ?></div>
                                <p class="text-gray-400 text-sm">Transactions</p>
                            </div>
                            <div class="bg-gray-700 p-3 rounded-lg text-center">
                                <div class="text-xl font-bold text-white"><?php echo number_format($stats['total_fund_transactions'] ?? 0); ?></div>
                                <p class="text-gray-400 text-sm">Deposits</p>
                            </div>
                        </div>
                        
                        <div class="flex space-x-2">
                            <button id="creditWalletBtn" class="bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded-md text-sm flex-1">
                                <i class="fas fa-plus mr-1"></i> Credit Wallet
                            </button>
                            <button id="debitWalletBtn" class="bg-red-600 hover:bg-red-700 text-white py-2 px-4 rounded-md text-sm flex-1">
                                <i class="fas fa-minus mr-1"></i> Debit Wallet
                            </button>
                        </div>
                    </div>
                    
                    <!-- Stats Card -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Stats</h2>
                        
                        <div class="space-y-4">
                            <div>
                                <div class="flex justify-between mb-1">
                                    <span class="text-gray-400">Total Funded:</span>
                                    <span class="text-white font-medium"><?php echo $currency . number_format($stats['total_fund_amount'] ?? 0, 2); ?></span>
                                </div>
                                <div class="w-full bg-gray-700 rounded-full h-1.5">
                                    <div class="bg-green-500 h-1.5 rounded-full" style="width: 100%"></div>
                                </div>
                            </div>
                            
                            <div>
                                <div class="flex justify-between mb-1">
                                    <span class="text-gray-400">Total Spent:</span>
                                    <span class="text-white font-medium"><?php echo $currency . number_format($stats['total_purchase_amount'] ?? 0, 2); ?></span>
                                </div>
                                <div class="w-full bg-gray-700 rounded-full h-1.5">
                                    <?php 
                                    $percentSpent = 0;
                                    if (($stats['total_fund_amount'] ?? 0) > 0) {
                                        $percentSpent = min(100, (($stats['total_purchase_amount'] ?? 0) / ($stats['total_fund_amount'] ?? 0)) * 100);
                                    }
                                    ?>
                                    <div class="bg-red-500 h-1.5 rounded-full" style="width: <?php echo $percentSpent; ?>%"></div>
                                </div>
                            </div>
                            
                            <div class="border-t border-gray-700 pt-4">
                                <div class="grid grid-cols-2 gap-3">
                                    <div>
                                        <p class="text-gray-400 text-sm">Purchase Transactions</p>
                                        <p class="text-white"><?php echo number_format($stats['total_purchase_transactions'] ?? 0); ?></p>
                                    </div>
                                    <div>
                                        <p class="text-gray-400 text-sm">Account Status</p>
                                        <p class="text-white"><?php echo ucfirst($user['status']); ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Transactions Column -->
                <div class="lg:col-span-2">
                    <!-- Recent Transactions Card -->
                    <div class="admin-card rounded-lg shadow-md p-6 mb-6">
                        <div class="flex justify-between items-center mb-4">
                            <h2 class="text-xl font-semibold text-white">Recent Transactions</h2>
                            <a href="<?php echo ADMIN_URL; ?>/transactions.php?user_id=<?php echo $user['id']; ?>" class="text-indigo-400 hover:text-indigo-300 text-sm">
                                View All <i class="fas fa-arrow-right ml-1"></i>
                            </a>
                        </div>
                        
                        <?php if (empty($transactions)): ?>
                            <div class="text-center py-8 text-gray-400">
                                <div class="h-16 w-16 bg-gray-700 rounded-full flex items-center justify-center mx-auto mb-4">
                                    <i class="fas fa-exchange-alt text-2xl text-gray-500"></i>
                                </div>
                                <p>No transactions found for this user.</p>
                            </div>
                        <?php else: ?>
                            <div class="overflow-x-auto">
                                <table class="min-w-full">
                                    <thead class="bg-gray-700">
                                        <tr>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Reference</th>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Type</th>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                            <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                                        </tr>
                                    </thead>
                                    <tbody class="divide-y divide-gray-800">
                                        <?php foreach ($transactions as $transaction): ?>
                                            <tr class="hover:bg-gray-700">
                                                <td class="py-3 px-4 text-sm text-gray-300">
                                                    <?php echo date('M d, Y H:i', strtotime($transaction['created_at'])); ?>
                                                </td>
                                                <td class="py-3 px-4 text-sm text-white">
                                                    <?php echo substr($transaction['txn_ref'], 0, 15) . '...'; ?>
                                                </td>
                                                <td class="py-3 px-4">
                                                    <span class="transaction-type transaction-<?php echo $transaction['type']; ?>">
                                                        <?php echo ucfirst($transaction['type']); ?>
                                                    </span>
                                                </td>
                                                <td class="py-3 px-4 text-sm font-medium <?php echo in_array($transaction['type'], ['credit', 'fund']) ? 'text-green-500' : 'text-red-500'; ?>">
                                                    <?php echo (in_array($transaction['type'], ['credit', 'fund']) ? '+' : '-') . $currency . number_format($transaction['amount'], 2); ?>
                                                </td>
                                                <td class="py-3 px-4">
                                                    <span class="status-badge transaction-status-<?php echo $transaction['status']; ?>">
                                                        <?php echo ucfirst($transaction['status']); ?>
                                                    </span>
                                                </td>
                                                <td class="py-3 px-4 text-sm">
                                                    <a href="<?php echo ADMIN_URL; ?>/view_transaction.php?id=<?php echo $transaction['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                        <i class="fas fa-eye"></i>
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                    
                    <!-- Quick Actions Card -->
                    <div class="admin-card rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold text-white mb-4">Quick Actions</h2>
                        
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                            <a href="<?php echo ADMIN_URL; ?>/send_notification.php?user_id=<?php echo $user['id']; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 flex items-center transition-colors">
                                <div class="h-10 w-10 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mr-3">
                                    <i class="fas fa-bell text-blue-400"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white">Send Notification</div>
                                    <div class="text-xs text-gray-400">Send a custom notification to this user</div>
                                </div>
                            </a>
                            
                            <a href="<?php echo ADMIN_URL; ?>/login_as_user.php?id=<?php echo $user['id']; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 flex items-center transition-colors">
                                <div class="h-10 w-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                                    <i class="fas fa-user-secret text-yellow-400"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white">Login as User</div>
                                    <div class="text-xs text-gray-400">Impersonate this user for support</div>
                                </div>
                            </a>
                            
                            <?php if ($user['status'] === 'active'): ?>
                                <a href="<?php echo ADMIN_URL; ?>/deactivate_user.php?id=<?php echo $user['id']; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 flex items-center transition-colors">
                                    <div class="h-10 w-10 rounded-full bg-red-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-user-slash text-red-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white">Deactivate User</div>
                                        <div class="text-xs text-gray-400">Temporarily disable this account</div>
                                    </div>
                                </a>
                            <?php else: ?>
                                <a href="<?php echo ADMIN_URL; ?>/activate_user.php?id=<?php echo $user['id']; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 flex items-center transition-colors">
                                    <div class="h-10 w-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-user-check text-green-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white">Activate User</div>
                                        <div class="text-xs text-gray-400">Re-enable this account</div>
                                    </div>
                                </a>
                            <?php endif; ?>
                            
                            <a href="<?php echo ADMIN_URL; ?>/support_tickets.php?user_id=<?php echo $user['id']; ?>" class="bg-gray-700 hover:bg-gray-600 rounded-lg p-4 flex items-center transition-colors">
                                <div class="h-10 w-10 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mr-3">
                                    <i class="fas fa-headset text-purple-400"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white">Support Tickets</div>
                                    <div class="text-xs text-gray-400">View user's support tickets</div>
                                </div>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Edit User Modal -->
    <div id="editUserModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Edit User</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="editUserModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="update_user">
                <div class="space-y-4">
                    <div>
                        <label for="username" class="block text-sm font-medium text-gray-400 mb-1">Username</label>
                        <input type="text" id="username" name="username" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($user['username']); ?>" required>
                    </div>
                    
                    <div>
                        <label for="email" class="block text-sm font-medium text-gray-400 mb-1">Email</label>
                        <input type="email" id="email" name="email" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                    </div>
                    
                    <div>
                        <label for="phone" class="block text-sm font-medium text-gray-400 mb-1">Phone</label>
                        <input type="text" id="phone" name="phone" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($user['phone'] ?? ''); ?>">
                    </div>
                    
                    <div>
                        <label for="user_type" class="block text-sm font-medium text-gray-400 mb-1">Account Type</label>
                        <select id="user_type" name="user_type" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="smart" <?php echo $user['user_type'] === 'smart' ? 'selected' : ''; ?>>Standard User</option>
                            <option value="vendor" <?php echo $user['user_type'] === 'vendor' ? 'selected' : ''; ?>>Vendor</option>
                            <option value="api" <?php echo $user['user_type'] === 'api' ? 'selected' : ''; ?>>API User</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="active" <?php echo $user['status'] === 'active' ? 'selected' : ''; ?>>Active</option>
                            <option value="inactive" <?php echo $user['status'] === 'inactive' ? 'selected' : ''; ?>>Inactive</option>
                            <option value="pending" <?php echo $user['status'] === 'pending' ? 'selected' : ''; ?>>Pending</option>
                        </select>
                    </div>
                </div>
                
                <div class="mt-6 flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="editUserModal">
                        Cancel
                    </button>
                    <button type="submit" class="accent-button py-2 px-4 rounded-md text-white">
                        Save Changes
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Credit Wallet Modal -->
    <div id="creditWalletModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Credit Wallet</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="creditWalletModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="wallet_operation">
                <input type="hidden" name="operation_type" value="credit">
                
                <div class="space-y-4">
                    <div>
                        <label for="credit_amount" class="block text-sm font-medium text-gray-400 mb-1">Amount to Credit</label>
                        <div class="relative mt-1 rounded-md shadow-sm">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                            </div>
                            <input type="number" name="amount" id="credit_amount" min="1" step="0.01" class="form-input block w-full pl-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        </div>
                    </div>
                    
                    <div>
                        <label for="credit_description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                        <input type="text" name="description" id="credit_description" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Reason for crediting" required>
                    </div>
                </div>
                
                <div class="mt-6 flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="creditWalletModal">
                        Cancel
                    </button>
                    <button type="submit" class="bg-green-600 hover:bg-green-700 py-2 px-4 rounded-md text-white">
                        Credit Wallet
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Debit Wallet Modal -->
    <div id="debitWalletModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Debit Wallet</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="debitWalletModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div class="mb-4 text-white">
                <p>Current Balance: <span class="font-semibold"><?php echo $currency . number_format($user['balance'], 2); ?></span></p>
            </div>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="wallet_operation">
                <input type="hidden" name="operation_type" value="debit">
                
                <div class="space-y-4">
                    <div>
                        <label for="debit_amount" class="block text-sm font-medium text-gray-400 mb-1">Amount to Debit</label>
                        <div class="relative mt-1 rounded-md shadow-sm">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <span class="text-gray-500 sm:text-sm"><?php echo $currency; ?></span>
                            </div>
                            <input type="number" name="amount" id="debit_amount" min="1" max="<?php echo $user['balance']; ?>" step="0.01" class="form-input block w-full pl-8 rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        </div>
                    </div>
                    
                    <div>
                        <label for="debit_description" class="block text-sm font-medium text-gray-400 mb-1">Description</label>
                        <input type="text" name="description" id="debit_description" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Reason for debiting" required>
                    </div>
                </div>
                
                <div class="mt-6 flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="debitWalletModal">
                        Cancel
                    </button>
                    <button type="submit" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                        Debit Wallet
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Reset Password Modal -->
    <div id="resetPasswordModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
        <div class="absolute inset-0 bg-black bg-opacity-50"></div>
        <div class="relative bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white">Reset Password</h3>
                <button class="text-gray-400 hover:text-white close-modal" data-target="resetPasswordModal">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <p class="text-gray-400 mb-4">Are you sure you want to reset the password for <span class="font-semibold text-white"><?php echo htmlspecialchars($user['username']); ?></span>?</p>
            
            <p class="text-yellow-400 text-sm mb-6">
                <i class="fas fa-exclamation-triangle mr-1"></i> This will generate a new random password and send it to the user's email address.
            </p>
            
            <form method="POST" action="">
                <input type="hidden" name="action" value="reset_password">
                
                <div class="flex justify-end">
                    <button type="button" class="bg-gray-700 hover:bg-gray-600 text-white py-2 px-4 rounded-md mr-2 close-modal" data-target="resetPasswordModal">
                        Cancel
                    </button>
                    <button type="submit" class="bg-yellow-600 hover:bg-yellow-700 py-2 px-4 rounded-md text-white">
                        Reset Password
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Toggle profile dropdown
            const profileDropdownButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileDropdownButton.addEventListener('click', function() {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', function(e) {
                if (!profileDropdownButton.contains(e.target) && !profileDropdown.contains(e.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Modal controls
            const editUserBtn = document.getElementById('editUserBtn');
            const creditWalletBtn = document.getElementById('creditWalletBtn');
            const debitWalletBtn = document.getElementById('debitWalletBtn');
            const resetPasswordBtn = document.getElementById('resetPasswordBtn');
            const closeModalButtons = document.querySelectorAll('.close-modal');
            
            const editUserModal = document.getElementById('editUserModal');
            const creditWalletModal = document.getElementById('creditWalletModal');
            const debitWalletModal = document.getElementById('debitWalletModal');
            const resetPasswordModal = document.getElementById('resetPasswordModal');
            
            // Show modals
            editUserBtn.addEventListener('click', function() {
                editUserModal.classList.remove('hidden');
            });
            
            creditWalletBtn.addEventListener('click', function() {
                creditWalletModal.classList.remove('hidden');
            });
            
            debitWalletBtn.addEventListener('click', function() {
                debitWalletModal.classList.remove('hidden');
            });
            
            resetPasswordBtn.addEventListener('click', function() {
                resetPasswordModal.classList.remove('hidden');
            });
            
            // Close modals
            closeModalButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const targetModal = this.getAttribute('data-target');
                    document.getElementById(targetModal).classList.add('hidden');
                });
            });
            
            // Close modals when clicking outside
            window.addEventListener('click', function(e) {
                if (e.target === editUserModal) {
                    editUserModal.classList.add('hidden');
                }
                if (e.target === creditWalletModal) {
                    creditWalletModal.classList.add('hidden');
                }
                if (e.target === debitWalletModal) {
                    debitWalletModal.classList.add('hidden');
                }
                if (e.target === resetPasswordModal) {
                    resetPasswordModal.classList.add('hidden');
                }
            });
        });
    </script>
</body>
</html>