<?php
// File: /api/api_functions.php (Shared API Functions)
require_once dirname(__DIR__) . '/includes/config.php';
require_once dirname(__DIR__) . '/includes/functions.php';

/**
 * Authenticate an API request using the X-API-KEY header
 * 
 * @return array Authentication result with success status, message, and user data if successful
 */
function authenticateApiRequest() {
    // Get API key from header
    $apiKey = $_SERVER['HTTP_X_API_KEY'] ?? '';
    
    if (empty($apiKey)) {
        return [
            'success' => false,
            'message' => 'API key is required'
        ];
    }
    
    // Connect to database
    $db = getDB();
    $conn = $db->getConnection();
    
    // Find user with the given API key
    $stmt = $conn->prepare("SELECT * FROM users WHERE api_key = ? AND status = 'active' AND user_type = 'api'");
    $stmt->bind_param('s', $apiKey);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        return [
            'success' => false,
            'message' => 'Invalid API key'
        ];
    }
    
    $user = $result->fetch_assoc();
    
    // Check if user has API privileges
    if ($user['user_type'] !== 'api') {
        return [
            'success' => false,
            'message' => 'Your account is not authorized for API access'
        ];
    }
    
    // All checks passed
    return [
        'success' => true,
        'message' => 'Authentication successful',
        'user' => $user
    ];
}

/**
 * Get simplified network IDs for API users
 * 
 * @return array Mapping of internal network IDs to simplified IDs
 */
function getNetworkIdMapping($reverse = false) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    $simpleId = 1;
    
    while ($row = $result->fetch_assoc()) {
        if ($reverse) {
            $mapping[$simpleId] = $row['id'];
        } else {
            $mapping[$row['id']] = $simpleId;
        }
        $simpleId++;
    }
    
    return $mapping;
}

/**
 * Get simplified data plan IDs for API users
 * 
 * @return array Mapping of internal plan IDs to simplified IDs
 */
function getDataPlanIdMapping($reverse = false) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, plan_id FROM data_plans WHERE status = 'active' ORDER BY network_id, data_type_id, price");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    
    while ($row = $result->fetch_assoc()) {
        if ($reverse) {
            // Map from plan_id to internal id
            $mapping[$row['plan_id']] = $row['id'];
        } else {
            // Map from internal id to plan_id
            $mapping[$row['id']] = $row['plan_id'];
        }
    }
    
    return $mapping;
}

/**
 * Get user balance endpoint
 * 
 * @param array $user The authenticated user
 */
function getBalance($user) {
    echo json_encode([
        'status' => 'success',
        'message' => 'Balance retrieved successfully',
        'data' => [
            'balance' => floatval($user['balance']),
            'currency' => getSetting('currency', '₦')
        ]
    ]);
}

/**
 * Get user profile endpoint
 * 
 * @param array $user The authenticated user
 */
function getProfile($user) {
    // Remove sensitive fields
    unset($user['password']);
    unset($user['pin']);
    unset($user['api_key']);
    
    echo json_encode([
        'status' => 'success',
        'message' => 'Profile retrieved successfully',
        'data' => $user
    ]);
}

/**
 * Get data plans endpoint
 * 
 * @param array $user The authenticated user
 */
function getDataPlans($user) {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get the network ID if provided
    $networkId = isset($_GET['network_id']) ? (int)$_GET['network_id'] : 0;
    
    // Get network mapping for simplified IDs
    $networkMapping = getNetworkIdMapping(true); // Reverse mapping (simple ID -> internal ID)
    
    // If a simplified network ID was provided, convert it to the internal ID
    if ($networkId > 0) {
        $internalNetworkId = $networkMapping[$networkId] ?? 0;
    } else {
        $internalNetworkId = 0;
    }
    
    // Build the query based on filters
    $query = "SELECT p.id, p.plan_id, p.name, p.size as value, p.validity, 
                     IF(p.amount_api > 0, p.amount_api, p.price) as price, 
                     dt.name as data_type, n.id as network_id, n.name as network_name
              FROM data_plans p
              JOIN data_types dt ON p.data_type_id = dt.id
              JOIN networks n ON dt.network_id = n.id
              WHERE p.status = 'active'";
    
    $params = [];
    $types = "";
    
    if ($internalNetworkId > 0) {
        $query .= " AND n.id = ?";
        $params[] = $internalNetworkId;
        $types .= "i";
    }
    
    $query .= " ORDER BY n.name, dt.name, p.price";
    
    // Prepare and execute statement
    $stmt = $conn->prepare($query);
    if (!empty($params)) {
        $stmt->bind_param($types, ...$params);
    }
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Process results
    $plans = [];
    $networkIdMapping = getNetworkIdMapping(); // Get network ID mapping
    
    while ($row = $result->fetch_assoc()) {
        $simpleNetworkId = $networkIdMapping[$row['network_id']] ?? 0;
        
        $plans[] = [
            'id' => $row['plan_id'], // Use direct plan_id instead of mapping
            'network_id' => $simpleNetworkId,
            'network_name' => $row['network_name'],
            'name' => $row['name'],
            'data_type' => $row['data_type'],
            'size' => $row['value'],
            'validity' => $row['validity'],
            'price' => floatval($row['price'])
        ];
    }
    
    echo json_encode([
        'status' => 'success',
        'message' => 'Data plans retrieved successfully',
        'data' => $plans
    ]);
}

/**
 * Buy data endpoint
 * 
 * @param array $user The authenticated user
 */
function buyData($user) {
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['plan_id']) || empty($requestData['phone'])) {
        http_response_code(400);
        echo json_encode([
            'status' => 'error',
            'error' => 'BAD_REQUEST',
            'message' => 'Missing required fields: plan_id, phone'
        ]);
        return;
    }
    
    $planId = (int)$requestData['plan_id'];
    $phone = sanitizeInput($requestData['phone']);
    $reference = $requestData['reference'] ?? '';
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => 'error',
            'error' => 'VALIDATION_ERROR',
            'message' => 'Invalid phone number format'
        ]);
        return;
    }
    
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get plan by plan_id directly
    $stmt = $conn->prepare("SELECT id FROM data_plans WHERE plan_id = ? AND status = 'active'");
    $stmt->bind_param("i", $planId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        http_response_code(404);
        echo json_encode([
            'status' => 'error',
            'error' => 'NOT_FOUND',
            'message' => 'Plan ID not found'
        ]);
        return;
    }
    
    $planData = $result->fetch_assoc();
    $internalPlanId = $planData['id'];
    
    // Store original client reference
    $clientReference = $reference;
    
    // Prepare data for purchase endpoint
    $_POST = [
        'plan_id' => $internalPlanId,
        'phone' => $phone,
        'client_reference' => $clientReference
    ];
    
    // Store current output buffer
    ob_start();
    
    // Set user session for the purchase script
    $_SESSION['user_id'] = $user['id'];
    
    // Include the purchase script
    require_once dirname(__DIR__) . '/dashboard/process/buy_data.php';
    
    // Get the response
    $purchaseResponse = ob_get_clean();
    $purchaseData = json_decode($purchaseResponse, true);
    
    // Process response
    if ($purchaseData && isset($purchaseData['success'])) {
        if ($purchaseData['success']) {
            echo json_encode([
                'status' => 'success',
                'message' => $purchaseData['message'],
                'data' => [
                    'transaction_id' => $purchaseData['data']['transaction_id'] ?? null,
                    'reference' => $purchaseData['data']['reference'],
                    'amount' => floatval($purchaseData['data']['amount']),
                    'phone' => $purchaseData['data']['phone'],
                    'plan' => $purchaseData['data']['plan'],
                    'network' => $purchaseData['data']['network'],
                    'client_reference' => $clientReference
                ]
            ]);
        } else {
            http_response_code(400);
            echo json_encode([
                'status' => 'error',
                'error' => 'TRANSACTION_FAILED',
                'message' => $purchaseData['message']
            ]);
        }
    } else {
        http_response_code(500);
        error_log('Data purchase error: ' . $purchaseResponse);
        echo json_encode([
            'status' => 'error',
            'error' => 'INTERNAL_SERVER_ERROR',
            'message' => 'Failed to process data purchase'
        ]);
    }
}

/**
 * Buy airtime endpoint
 * 
 * @param array $user The authenticated user
 */
function buyAirtime($user) {
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network_id']) || empty($requestData['phone']) || !isset($requestData['amount'])) {
        http_response_code(400);
        echo json_encode([
            'status' => 'error',
            'error' => 'BAD_REQUEST',
            'message' => 'Missing required fields: network_id, phone, amount'
        ]);
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network_id'];
    $phone = sanitizeInput($requestData['phone']);
    $amount = (float)$requestData['amount'];
    $reference = $requestData['reference'] ?? '';
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => 'error',
            'error' => 'VALIDATION_ERROR',
            'message' => 'Invalid phone number format'
        ]);
        return;
    }
    
    // Validate amount
    if ($amount < 50) {
        http_response_code(400);
        echo json_encode([
            'status' => 'error',
            'error' => 'VALIDATION_ERROR',
            'message' => 'Minimum airtime amount is ₦50'
        ]);
        return;
    }
    
    // Convert simple network ID to internal ID
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    if ($internalNetworkId === 0) {
        http_response_code(404);
        echo json_encode([
            'status' => 'error',
            'error' => 'NOT_FOUND',
            'message' => 'Network ID not found'
        ]);
        return;
    }
    
    // Store original client reference
    $clientReference = $reference;
    
    // Prepare data for purchase endpoint
    $_POST = [
        'network_id' => $internalNetworkId,
        'phone' => $phone,
        'amount' => $amount,
        'client_reference' => $clientReference
    ];
    
    // Store current output buffer
    ob_start();
    
    // Set user session for the purchase script
    $_SESSION['user_id'] = $user['id'];
    
    // Include the purchase script
    require_once dirname(__DIR__) . '/dashboard/process/buy_airtime.php';
    
    // Get the response
    $purchaseResponse = ob_get_clean();
    $purchaseData = json_decode($purchaseResponse, true);
    
    // Process response
    if ($purchaseData && isset($purchaseData['success'])) {
        if ($purchaseData['success']) {
            echo json_encode([
                'status' => 'success',
                'message' => $purchaseData['message'],
                'data' => [
                    'transaction_id' => $purchaseData['data']['transaction_id'] ?? null,
                    'reference' => $purchaseData['data']['reference'],
                    'amount' => floatval($purchaseData['data']['amount']),
                    'phone' => $purchaseData['data']['phone'],
                    'network' => $purchaseData['data']['network'],
                    'client_reference' => $clientReference
                ]
            ]);
        } else {
            http_response_code(400);
            echo json_encode([
                'status' => 'error',
                'error' => 'TRANSACTION_FAILED',
                'message' => $purchaseData['message']
            ]);
        }
    } else {
        http_response_code(500);
        error_log('Airtime purchase error: ' . $purchaseResponse);
        echo json_encode([
            'status' => 'error',
            'error' => 'INTERNAL_SERVER_ERROR',
            'message' => 'Failed to process airtime purchase'
        ]);
    }
}

/**
 * Get transactions endpoint
 * 
 * @param array $user The authenticated user
 */
function getTransactions($user) {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get query parameters
    $page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
    $limit = isset($_GET['limit']) ? min(100, max(1, (int)$_GET['limit'])) : 20;
    $type = isset($_GET['type']) ? sanitizeInput($_GET['type']) : '';
    $reference = isset($_GET['reference']) ? sanitizeInput($_GET['reference']) : '';
    
    // Calculate offset
    $offset = ($page - 1) * $limit;
    
    // Build the query
    $query = "SELECT t.* FROM transactions t WHERE t.user_id = ?";
    $countQuery = "SELECT COUNT(*) as total FROM transactions t WHERE t.user_id = ?";
    
    $params = [$user['id']];
    $types = "i";
    
    if (!empty($type)) {
        $query .= " AND t.type = ?";
        $countQuery .= " AND t.type = ?";
        $params[] = $type;
        $types .= "s";
    }
    
    if (!empty($reference)) {
        $query .= " AND (t.txn_ref = ? OR t.meta_data LIKE ?)";
        $countQuery .= " AND (t.txn_ref = ? OR t.meta_data LIKE ?)";
        $params[] = $reference;
        $params[] = '%"client_reference":"' . $reference . '"%';
        $types .= "ss";
    }
    
    $query .= " ORDER BY t.created_at DESC LIMIT ?, ?";
    $params[] = $offset;
    $params[] = $limit;
    $types .= "ii";
    
    // Get total count for pagination
    $countStmt = $conn->prepare($countQuery);
    $countStmt->bind_param(substr($types, 0, -2), ...array_slice($params, 0, -2));
    $countStmt->execute();
    $totalResult = $countStmt->get_result()->fetch_assoc();
    $total = $totalResult['total'];
    
    // Execute main query
    $stmt = $conn->prepare($query);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Process transactions
    $transactions = [];
    while ($row = $result->fetch_assoc()) {
        $metaData = json_decode($row['meta_data'], true) ?? [];
        
        // Add client reference if present
        $clientRef = $metaData['client_reference'] ?? null;
        
        $transaction = [
            'id' => (int)$row['id'],
            'reference' => $row['txn_ref'],
            'type' => $row['type'],
            'amount' => floatval($row['amount']),
            'fee' => floatval($row['fee'] ?? 0),
            'status' => $row['status'],
            'description' => $row['description'],
            'created_at' => $row['created_at']
        ];
        
        if ($clientRef) {
            $transaction['client_reference'] = $clientRef;
        }
        
        $transactions[] = $transaction;
    }
    
    // Calculate pagination info
    $totalPages = ceil($total / $limit);
    
    echo json_encode([
        'status' => 'success',
        'message' => 'Transactions retrieved successfully',
        'data' => [
            'transactions' => $transactions,
            'pagination' => [
                'current_page' => $page,
                'total_pages' => $totalPages,
                'total_items' => $total,
                'limit' => $limit
            ]
        ]
    ]);
}

/**
 * Get single transaction endpoint
 * 
 * @param array $user The authenticated user
 * @param int $transactionId The transaction ID
 */
function getTransaction($user, $transactionId) {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get the transaction
    $stmt = $conn->prepare("SELECT * FROM transactions WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $transactionId, $user['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        http_response_code(404);
        echo json_encode([
            'status' => 'error',
            'error' => 'NOT_FOUND',
            'message' => 'Transaction not found'
        ]);
        return;
    }
    
    $transaction = $result->fetch_assoc();
    $metaData = json_decode($transaction['meta_data'], true) ?? [];
    
    // Create response data
    $responseData = [
        'id' => (int)$transaction['id'],
        'reference' => $transaction['txn_ref'],
        'type' => $transaction['type'],
        'amount' => floatval($transaction['amount']),
        'fee' => floatval($transaction['fee'] ?? 0),
        'status' => $transaction['status'],
        'description' => $transaction['description'],
        'created_at' => $transaction['created_at'],
        'meta_data' => $metaData
    ];
    
    // Add client reference if present
    if (isset($metaData['client_reference'])) {
        $responseData['client_reference'] = $metaData['client_reference'];
    }
    
    echo json_encode([
        'status' => 'success',
        'message' => 'Transaction retrieved successfully',
        'data' => $responseData
    ]);
}