<?php
// File: /api/api_v2_functions.php
require_once dirname(__DIR__) . '/includes/config.php';
require_once dirname(__DIR__) . '/includes/functions.php';

/**
 * Authenticate an API v2 request using the Token-based authentication
 * 
 * @return array Authentication result with success status, message, and user data if successful
 */
function authenticateApiV2Request() {
    // Get Authorization header
    $authHeader = $_SERVER['HTTP_AUTHORIZATION'] ?? '';
    
    // Check for Token format
    if (empty($authHeader) || !preg_match('/^Token\s+([a-zA-Z0-9]+)$/i', $authHeader, $matches)) {
        return [
            'success' => false,
            'message' => 'Authentication failed. Use format: "Authorization: Token YOUR_API_TOKEN"'
        ];
    }
    
    $apiToken = $matches[1];
    
    // Connect to database
    $db = getDB();
    $conn = $db->getConnection();
    
    // Find user with the given API token
    $stmt = $conn->prepare("SELECT * FROM users WHERE api_token = ? AND status = 'active' AND user_type = 'api'");
    $stmt->bind_param('s', $apiToken);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        return [
            'success' => false,
            'message' => 'Invalid API token'
        ];
    }
    
    $user = $result->fetch_assoc();
    
    // Check if user has API privileges
    if ($user['user_type'] !== 'api') {
        return [
            'success' => false,
            'message' => 'Your account is not authorized for API access'
        ];
    }
    
    // All checks passed
    return [
        'success' => true,
        'message' => 'Authentication successful',
        'user' => $user
    ];
}

/**
 * Apply rate limiting to API requests
 * 
 * @param int $userId The user ID
 * @param string $method The HTTP method (GET, POST, etc.)
 * @param string $version API version
 * @return array Result with success status and headers
 */
function applyRateLimit($userId, $method, $version = 'v2') {
    // Define limits based on method
    $limit = ($method === 'GET') ? 120 : 60; // Higher limits for API v2
    $windowInSeconds = 60;
    
    // Create a unique key for this user and method type
    $key = "rate_limit:{$userId}:{$version}:{$method}:" . floor(time() / $windowInSeconds);
    
    // Simple file-based rate limiting (you can replace with Redis or database if available)
    $cacheFile = sys_get_temp_dir() . "/vtu_ratelimit_{$userId}_{$version}_{$method}.txt";
    
    if (file_exists($cacheFile)) {
        $data = json_decode(file_get_contents($cacheFile), true);
        $current = $data['count'];
        $resetTime = $data['reset_time'];
    } else {
        $current = 0;
        $resetTime = time() + $windowInSeconds;
    }
    
    // Increment counter
    $current++;
    
    // Store updated count
    file_put_contents($cacheFile, json_encode([
        'count' => $current,
        'reset_time' => $resetTime
    ]));
    
    // Check if over limit
    $overLimit = $current > $limit;
    
    // Generate headers
    $headers = [
        'X-RateLimit-Limit' => $limit,
        'X-RateLimit-Remaining' => $overLimit ? 0 : $limit - $current,
        'X-RateLimit-Reset' => $resetTime
    ];
    
    return [
        'success' => !$overLimit,
        'headers' => $headers
    ];
}

/**
 * Get simplified network IDs for API users (Same as v1)
 * 
 * @return array Mapping of internal network IDs to simplified IDs
 */
function getNetworkIdMapping($reverse = false) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    $simpleId = 1;
    
    while ($row = $result->fetch_assoc()) {
        if ($reverse) {
            $mapping[$simpleId] = $row['id'];
        } else {
            $mapping[$row['id']] = $simpleId;
        }
        $simpleId++;
    }
    
    return $mapping;
}

/**
 * Get simplified data plan IDs for API users (Same as v1)
 * 
 * @return array Mapping of internal plan IDs to simplified IDs
 */
/**
 * Get data plan IDs directly from the database
 * 
 * @param bool $reverse Whether to reverse the mapping (not used anymore since we have real plan_ids)
 * @return array Mapping of internal IDs to plan IDs
 */
function getDataPlanIdMapping($reverse = false) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, plan_id FROM data_plans WHERE status = 'active'");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    
    while ($row = $result->fetch_assoc()) {
        if ($reverse) {
            // Map from plan_id to internal id
            $mapping[$row['plan_id']] = $row['id'];
        } else {
            // Map from internal id to plan_id
            $mapping[$row['id']] = $row['plan_id'];
        }
    }
    
    return $mapping;
}

/**
 * Get user info and balance
 * 
 * @param array $user The authenticated user
 */
function getUserInfo($user) {
    // Prepare user information with multiple balance key formats
    $userData = [
        'id' => $user['id'],
        'username' => $user['username'],
        'email' => $user['email'],
        'phone' => $user['phone'],
        'balance' => floatval($user['balance']),
        'account_balance' => floatval($user['balance']),
        'wallet_balance' => floatval($user['balance']),
        'Account_balance' => floatval($user['balance']),
        'Wallet_balance' => floatval($user['balance']),
        'Balance' => floatval($user['balance']),
        'account_type' => $user['user_type'],
        'created_at' => $user['created_at'],
        'currency' => getSetting('currency', '₦')
    ];
    
    // Return both user and data keys for better compatibility
    echo json_encode([
        'status' => true,
        'message' => 'User information retrieved successfully',
        'user' => $userData,
        'data' => $userData
    ]);
}

/**
 * Get account balance (multiple formats)
 * 
 * @param array $user The authenticated user
 */
function getAccountBalance($user) {
    // Return balance in multiple formats for compatibility
    $balanceData = [
        'balance' => floatval($user['balance']),
        'account_balance' => floatval($user['balance']),
        'wallet_balance' => floatval($user['balance']),
        'Account_balance' => floatval($user['balance']),
        'Wallet_balance' => floatval($user['balance']),
        'Balance' => floatval($user['balance']),
        'currency' => getSetting('currency', '₦')
    ];
    
    // Return both user and data keys for better compatibility
    echo json_encode([
        'status' => true,
        'message' => 'Balance retrieved successfully',
        'user' => $balanceData,
        'data' => $balanceData
    ]);
}
/**
 * Purchase data bundle
 * 
 * @param array $user The authenticated user
 */
function purchaseData($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Detect format: By default use maskwasub format for backward compatibility
    // Use new format only when explicitly requested via 'api_version' or 'format' parameter
    $useMaskwasubFormat = true;
    if (isset($requestData['api_version']) && $requestData['api_version'] == '2') {
        $useMaskwasubFormat = false;
    }
    if (isset($requestData['format']) && strtolower($requestData['format']) == 'new') {
        $useMaskwasubFormat = false;
    }
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['plan'])) {
        http_response_code(400);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Missing required fields: network, mobile_number, plan"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Missing required fields: network, mobile_number, plan',
                'error_code' => 'MISSING_REQUIRED_FIELDS'
            ]);
        }
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $simplePlanId = (int)$requestData['plan']; // Treating plan as integer ID (same as v1)
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'DATA_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Invalid phone number format"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Invalid phone number format',
                'error_code' => 'INVALID_PHONE_NUMBER'
            ]);
        }
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            
            if ($useMaskwasubFormat) {
                echo json_encode([
                    "Status" => "failed",
                    "message" => "Duplicate transaction. This request_id has already been processed."
                ]);
            } else {
                echo json_encode([
                    'status' => false,
                    'message' => 'Duplicate transaction. This request_id has already been processed.',
                    'error_code' => 'DUPLICATE_TRANSACTION'
                ]);
            }
            return;
        }
    }
    
    // Convert simple network ID to internal ID (using same mapping as v1)
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $internalNetworkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Network not found or inactive"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Network not found or inactive',
                'error_code' => 'INVALID_NETWORK'
            ]);
        }
        return;
    }
    
    // Convert simple plan ID to internal ID (using same mapping as v1)
    $planIdMapping = getDataPlanIdMapping(true); // Reverse mapping
    $internalPlanId = $planIdMapping[$simplePlanId] ?? 0;
    
    // Get the data plan
    $stmt = $conn->prepare("
        SELECT dp.*, n.name as network_name 
        FROM data_plans dp
        JOIN networks n ON dp.network_id = n.id
        WHERE dp.id = ? AND dp.status = 'active' AND n.id = ?
    ");
    $stmt->bind_param("ii", $internalPlanId, $internalNetworkId);
    $stmt->execute();
    $plan = $stmt->get_result()->fetch_assoc();
    
    if (!$plan) {
        http_response_code(404);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Data plan not found or inactive"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Data plan not found or inactive',
                'error_code' => 'INVALID_PLAN'
            ]);
        }
        return;
    }
    
    // Determine price based on user type
    $priceField = 'price'; // Default price
    switch($user['user_type']) {
        case 'api':
            $priceField = $plan['amount_api'] > 0 ? 'amount_api' : 'price';
            break;
        case 'smart':
            $priceField = $plan['amount_smart'] > 0 ? 'amount_smart' : 'price';
            break;
        case 'vendor':
            $priceField = $plan['amount_vendor'] > 0 ? 'amount_vendor' : 'price';
            break;
    }
    
    $price = $plan[$priceField];
    
    // Check if user has sufficient balance
    if ($user['balance'] < $price) {
        http_response_code(402);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Insufficient balance"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Insufficient balance',
                'error_code' => 'INSUFFICIENT_BALANCE'
            ]);
        }
        return;
    }
    
    // Store balance before transaction
    $balanceBefore = floatval($user['balance']);
    
    // Use the same approach as API v1 - prepare to call dashboard process script
    try {
        // Store original request ID
        $originalRequestId = $requestId;
        
        // Set up $_SESSION for the dashboard script
        $_SESSION['user_id'] = $user['id'];
        
        // Set up $_POST variables for the dashboard script
        $_POST = [
            'plan_id' => $internalPlanId, // Use the internal plan ID
            'phone' => $phone,
            'client_reference' => $requestId // Use request_id as client_reference
        ];
        
        // Store current output buffer
        ob_start();
        
        // Include the purchase script from dashboard
        require_once dirname(__DIR__) . '/dashboard/process/buy_data.php';
        
        // Get the response
        $purchaseResponse = ob_get_clean();
        $purchaseData = json_decode($purchaseResponse, true);
        
        // Process response
        if ($purchaseData && isset($purchaseData['success'])) {
            if ($purchaseData['success']) {
                // Get updated balance after transaction
                $stmt = $conn->prepare("SELECT balance FROM users WHERE id = ?");
                $stmt->bind_param("i", $user['id']);
                $stmt->execute();
                $balanceResult = $stmt->get_result();
                $balanceAfter = $balanceResult->fetch_assoc()['balance'] ?? $user['balance'];
                
                // Get API response message if available
                $apiResponse = '';
                if (isset($purchaseData['data']['provider_response'])) {
                    $apiResponse = $purchaseData['data']['provider_response'];
                } elseif (isset($purchaseData['message'])) {
                    $apiResponse = $purchaseData['message'];
                } else {
                    $apiResponse = 'Data purchase successful';
                }
                
                if ($useMaskwasubFormat) {
                    // Format in maskwasub style
                    $response = [
                        "id" => mt_rand(1000000, 9999999),
                        "network" => $simpleNetworkId,
                        "ident" => $purchaseData['data']['reference'] ?? $originalRequestId,
                        "balance_before" => (string)number_format($balanceBefore, 2, '.', ''),
                        "balance_after" => (string)number_format(floatval($balanceAfter), 2, '.', ''),
                        "mobile_number" => $phone,
                        "plan" => $simplePlanId,
                        "Status" => "successful",
                        "api_response" => $apiResponse,
                        "plan_network" => $network['name'],
                        "plan_name" => $plan['name'],
                        "plan_type" => $plan['plan_type'] ?? 'GIFTING',
                        "plan_amount" => (string)$price,
                        "create_date" => date("Y-m-d\TH:i:s.u"),
                        "Ported_number" => $isPortedNumber
                    ];
                    
                    echo json_encode($response);
                } else {
                    // Format in new API style
                    $responseData = [
                        'transaction_reference' => $purchaseData['data']['reference'] ?? $originalRequestId,
                        'amount' => floatval($price),
                        'phone' => $phone,
                        'network' => $network['name'],
                        'data_plan' => $plan['name'],
                        'date' => date('Y-m-d H:i:s'),
                        'request_id' => $originalRequestId,
                        'balance_before' => $balanceBefore,
                        'balance_after' => floatval($balanceAfter),
                        'plan_id' => $simplePlanId,
                        'api_response' => $apiResponse
                    ];
                    
                    echo json_encode([
                        'status' => true,
                        'message' => $purchaseData['message'] ?? 'Data purchase successful',
                        'data' => $responseData
                    ]);
                }
            } else {
                // Failed purchase
                http_response_code(400);
                
                if ($useMaskwasubFormat) {
                    echo json_encode([
                        "Status" => "failed",
                        "message" => $purchaseData['message'] ?? 'Data purchase failed'
                    ]);
                } else {
                    echo json_encode([
                        'status' => false,
                        'message' => $purchaseData['message'] ?? 'Data purchase failed',
                        'error_code' => 'PROVIDER_ERROR',
                        'error_details' => $purchaseData['error_details'] ?? null
                    ]);
                }
            }
        } else {
            // Unexpected response format
            http_response_code(500);
            error_log('Data purchase error (unexpected response format): ' . $purchaseResponse);
            
            if ($useMaskwasubFormat) {
                echo json_encode([
                    "Status" => "failed",
                    "message" => "An error occurred while processing your request"
                ]);
            } else {
                echo json_encode([
                    'status' => false,
                    'message' => 'An error occurred while processing your request',
                    'error_code' => 'SYSTEM_ERROR'
                ]);
            }
        }
    } catch (Exception $e) {
        // Log error
        error_log("Data purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "An error occurred: " . $e->getMessage()
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'An error occurred: ' . $e->getMessage(),
                'error_code' => 'SYSTEM_ERROR'
            ]);
        }
    }
}
/**
 * Purchase data bundle
 * 
 * @param array $user The authenticated user
 */
function purchaseData33($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['plan'])) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Missing required fields: network, mobile_number, plan',
            'error_code' => 'MISSING_REQUIRED_FIELDS'
        ]);
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $simplePlanId = (int)$requestData['plan']; // Treating plan as integer ID (same as v1)
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'DATA_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid phone number format',
            'error_code' => 'INVALID_PHONE_NUMBER'
        ]);
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            echo json_encode([
                'status' => false,
                'message' => 'Duplicate transaction. This request_id has already been processed.',
                'error_code' => 'DUPLICATE_TRANSACTION'
            ]);
            return;
        }
    }
    
    // Convert simple network ID to internal ID (using same mapping as v1)
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $internalNetworkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Network not found or inactive',
            'error_code' => 'INVALID_NETWORK'
        ]);
        return;
    }
    
    // Convert simple plan ID to internal ID (using same mapping as v1)
    $planIdMapping = getDataPlanIdMapping(true); // Reverse mapping
    $internalPlanId = $planIdMapping[$simplePlanId] ?? 0;
    
    // Get the data plan
    $stmt = $conn->prepare("
        SELECT dp.*, n.name as network_name 
        FROM data_plans dp
        JOIN networks n ON dp.network_id = n.id
        WHERE dp.id = ? AND dp.status = 'active' AND n.id = ?
    ");
    $stmt->bind_param("ii", $internalPlanId, $internalNetworkId);
    $stmt->execute();
    $plan = $stmt->get_result()->fetch_assoc();
    
    if (!$plan) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Data plan not found or inactive',
            'error_code' => 'INVALID_PLAN'
        ]);
        return;
    }
    
    // Determine price based on user type
    $priceField = 'price'; // Default price
    switch($user['user_type']) {
        case 'api':
            $priceField = $plan['amount_api'] > 0 ? 'amount_api' : 'price';
            break;
        case 'smart':
            $priceField = $plan['amount_smart'] > 0 ? 'amount_smart' : 'price';
            break;
        case 'vendor':
            $priceField = $plan['amount_vendor'] > 0 ? 'amount_vendor' : 'price';
            break;
    }
    
    $price = $plan[$priceField];
    
    // Check if user has sufficient balance
    if ($user['balance'] < $price) {
        http_response_code(402);
        echo json_encode([
            'status' => false,
            'message' => 'Insufficient balance',
            'error_code' => 'INSUFFICIENT_BALANCE'
        ]);
        return;
    }
    
    // Use the same approach as API v1 - prepare to call dashboard process script
    try {
        // Store original request ID
        $originalRequestId = $requestId;
        
        // Set up $_SESSION for the dashboard script
        $_SESSION['user_id'] = $user['id'];
        
        // Set up $_POST variables for the dashboard script
        $_POST = [
            'plan_id' => $internalPlanId, // Use the internal plan ID
            'phone' => $phone,
            'client_reference' => $requestId // Use request_id as client_reference
        ];
        
        // Store current output buffer
        ob_start();
        
        // Include the purchase script from dashboard
        require_once dirname(__DIR__) . '/dashboard/process/buy_data.php';
        
        // Get the response
        $purchaseResponse = ob_get_clean();
        $purchaseData = json_decode($purchaseResponse, true);
        
        // Process response and convert to API v2 format
        if ($purchaseData && isset($purchaseData['success'])) {
            if ($purchaseData['success']) {
                // Successful purchase
                $responseData = [
                    'transaction_reference' => $purchaseData['data']['reference'] ?? '',
                    'amount' => isset($purchaseData['data']['final_amount']) ? floatval($purchaseData['data']['final_amount']) : floatval($purchaseData['data']['original_amount']),
                    'phone' => $purchaseData['data']['phone'] ?? $phone,
                    'network' => $purchaseData['data']['network'] ?? $network['name'],
                    'data_plan' => $purchaseData['data']['plan'] ?? $plan['name'],
                    'date' => date('Y-m-d H:i:s'),
                    'request_id' => $originalRequestId
                ];
                
                echo json_encode([
                    'status' => true,
                    'message' => $purchaseData['message'] ?? 'Data purchase successful',
                    'data' => $responseData,
                    'user' => $responseData
                ]);
            } else {
                // Failed purchase
                http_response_code(400);
                echo json_encode([
                    'status' => false,
                    'message' => $purchaseData['message'] ?? 'Data purchase failed',
                    'error_code' => 'PROVIDER_ERROR',
                    'error_details' => $purchaseData['error_details'] ?? null
                ]);
            }
        } else {
            // Unexpected response format
            http_response_code(500);
            error_log('Data purchase error (unexpected response format): ' . $purchaseResponse);
            echo json_encode([
                'status' => false,
                'message' => 'An error occurred while processing your request',
                'error_code' => 'SYSTEM_ERROR'
            ]);
        }
    } catch (Exception $e) {
        // Log error
        error_log("Data purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            'status' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
            'error_code' => 'SYSTEM_ERROR'
        ]);
    }
}
/**
 * Purchase airtime
 * 
 * @param array $user The authenticated user
 */
function purchaseAirtime($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Detect format: By default use maskwasub format for backward compatibility
    // Use new format only when explicitly requested via 'api_version' or 'format' parameter
    $useMaskwasubFormat = true;
    if (isset($requestData['api_version']) && $requestData['api_version'] == '2') {
        $useMaskwasubFormat = false;
    }
    if (isset($requestData['format']) && strtolower($requestData['format']) == 'new') {
        $useMaskwasubFormat = false;
    }
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['amount'])) {
        http_response_code(400);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Missing required fields: network, mobile_number, amount"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Missing required fields: network, mobile_number, amount',
                'error_code' => 'MISSING_REQUIRED_FIELDS'
            ]);
        }
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $amount = (float)$requestData['amount'];
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $airtimeType = isset($requestData['airtime_type']) ? sanitizeInput($requestData['airtime_type']) : 'VTU';
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'AIRTIME_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Invalid phone number format"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Invalid phone number format',
                'error_code' => 'INVALID_PHONE_NUMBER'
            ]);
        }
        return;
    }
    
    // Validate amount
    if ($amount < 50 || $amount > 5000) {
        http_response_code(400);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Invalid amount. Amount must be between 50 and 5000"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Invalid amount. Amount must be between 50 and 5000',
                'error_code' => 'INVALID_AMOUNT'
            ]);
        }
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            
            if ($useMaskwasubFormat) {
                echo json_encode([
                    "Status" => "failed",
                    "message" => "Duplicate transaction. This request_id has already been processed."
                ]);
            } else {
                echo json_encode([
                    'status' => false,
                    'message' => 'Duplicate transaction. This request_id has already been processed.',
                    'error_code' => 'DUPLICATE_TRANSACTION'
                ]);
            }
            return;
        }
    }
    
    // Convert simple network ID to internal ID (using same mapping as v1)
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $internalNetworkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "Network not found or inactive"
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'Network not found or inactive',
                'error_code' => 'INVALID_NETWORK'
            ]);
        }
        return;
    }
    
    // Use the same approach as API v1 - prepare to call dashboard process script
    try {
        // Store original values for later use
        $balanceBefore = floatval($user['balance']);
        
        // Set up $_SESSION for the dashboard script
        $_SESSION['user_id'] = $user['id'];
        
        // Set up $_POST variables for the dashboard script
        $_POST = [
            'network_id' => $internalNetworkId,
            'phone' => $phone,
            'amount' => $amount,
            'client_reference' => $requestId
        ];
        
        // Store current output buffer
        ob_start();
        
        // Include the purchase script from dashboard
        require_once dirname(__DIR__) . '/dashboard/process/buy_airtime.php';
        
        // Get the response
        $purchaseResponse = ob_get_clean();
        $purchaseData = json_decode($purchaseResponse, true);
        
        // Process response
        if ($purchaseData && isset($purchaseData['success'])) {
            if ($purchaseData['success']) {
                // Get updated balance after transaction
                $stmt = $conn->prepare("SELECT balance FROM users WHERE id = ?");
                $stmt->bind_param("i", $user['id']);
                $stmt->execute();
                $balanceResult = $stmt->get_result();
                $balanceAfter = $balanceResult->fetch_assoc()['balance'] ?? $user['balance'];
                
                if ($useMaskwasubFormat) {
                    // Return in maskwasub.com format
                    $response = [
                        "id" => mt_rand(1000000, 9999999),
                        "airtime_type" => $airtimeType,
                        "network" => $simpleNetworkId,
                        "ident" => $purchaseData['data']['reference'] ?? $requestId,
                        "paid_amount" => (string)number_format(floatval($amount) * 0.97, 2, '.', ''),
                        "mobile_number" => $phone,
                        "amount" => (string)$amount,
                        "plan_amount" => (string)$amount,
                        "plan_network" => $network['name'],
                        "balance_before" => (string)number_format($balanceBefore, 2, '.', ''),
                        "balance_after" => (string)number_format(floatval($balanceAfter), 2, '.', ''),
                        "Status" => "successful",
                        "create_date" => date("Y-m-d\TH:i:s.u"),
                        "Ported_number" => $isPortedNumber
                    ];
                    
                    echo json_encode($response);
                } else {
                    // Return in new API format
                    $responseData = [
                        'transaction_reference' => $purchaseData['data']['reference'] ?? $requestId,
                        'amount' => floatval($amount),
                        'phone' => $phone,
                        'network' => $network['name'],
                        'date' => date('Y-m-d H:i:s'),
                        'request_id' => $requestId,
                        'balance_before' => $balanceBefore,
                        'balance_after' => floatval($balanceAfter)
                    ];
                    
                    echo json_encode([
                        'status' => true,
                        'message' => $purchaseData['message'] ?? 'Airtime purchase successful',
                        'data' => $responseData
                    ]);
                }
            } else {
                // Failed purchase
                http_response_code(400);
                
                if ($useMaskwasubFormat) {
                    echo json_encode([
                        "Status" => "failed",
                        "message" => $purchaseData['message'] ?? 'Airtime purchase failed'
                    ]);
                } else {
                    echo json_encode([
                        'status' => false,
                        'message' => $purchaseData['message'] ?? 'Airtime purchase failed',
                        'error_code' => 'PROVIDER_ERROR',
                        'error_details' => $purchaseData['error_details'] ?? null
                    ]);
                }
            }
        } else {
            // Unexpected response format
            http_response_code(500);
            error_log('Airtime purchase error (unexpected response format): ' . $purchaseResponse);
            
            if ($useMaskwasubFormat) {
                echo json_encode([
                    "Status" => "failed",
                    "message" => "An error occurred while processing your request"
                ]);
            } else {
                echo json_encode([
                    'status' => false,
                    'message' => 'An error occurred while processing your request',
                    'error_code' => 'SYSTEM_ERROR'
                ]);
            }
        }
    } catch (Exception $e) {
        // Log error
        error_log("Airtime purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        
        if ($useMaskwasubFormat) {
            echo json_encode([
                "Status" => "failed",
                "message" => "An error occurred: " . $e->getMessage()
            ]);
        } else {
            echo json_encode([
                'status' => false,
                'message' => 'An error occurred: ' . $e->getMessage(),
                'error_code' => 'SYSTEM_ERROR'
            ]);
        }
    }
}
/**
 * Purchase airtime
 * 
 * @param array $user The authenticated user
 */
function purchaseAirtime22($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['amount'])) {
        http_response_code(400);
        // Always use this format for errors
        echo json_encode([
            "Status" => "failed",
            "message" => "Missing required fields: network, mobile_number, amount"
        ]);
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $amount = (float)$requestData['amount'];
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $airtimeType = isset($requestData['airtime_type']) ? sanitizeInput($requestData['airtime_type']) : 'VTU';
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'AIRTIME_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            "Status" => "failed",
            "message" => "Invalid phone number format"
        ]);
        return;
    }
    
    // Validate amount
    if ($amount < 50 || $amount > 5000) {
        http_response_code(400);
        echo json_encode([
            "Status" => "failed",
            "message" => "Invalid amount. Amount must be between 50 and 5000"
        ]);
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            echo json_encode([
                "Status" => "failed",
                "message" => "Duplicate transaction. This request_id has already been processed."
            ]);
            return;
        }
    }
    
    // Convert simple network ID to internal ID (using same mapping as v1)
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $internalNetworkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        echo json_encode([
            "Status" => "failed",
            "message" => "Network not found or inactive"
        ]);
        return;
    }
    
    // Use the same approach as API v1 - prepare to call dashboard process script
    try {
        // Store original values for later use
        $balanceBefore = floatval($user['balance']);
        
        // Set up $_SESSION for the dashboard script
        $_SESSION['user_id'] = $user['id'];
        
        // Set up $_POST variables for the dashboard script
        $_POST = [
            'network_id' => $internalNetworkId,
            'phone' => $phone,
            'amount' => $amount,
            'client_reference' => $requestId
        ];
        
        // Store current output buffer
        ob_start();
        
        // Include the purchase script from dashboard
        require_once dirname(__DIR__) . '/dashboard/process/buy_airtime.php';
        
        // Get the response
        $purchaseResponse = ob_get_clean();
        $purchaseData = json_decode($purchaseResponse, true);
        
        // Process response
        if ($purchaseData && isset($purchaseData['success'])) {
            if ($purchaseData['success']) {
                // Get updated balance after transaction
                $stmt = $conn->prepare("SELECT balance FROM users WHERE id = ?");
                $stmt->bind_param("i", $user['id']);
                $stmt->execute();
                $balanceResult = $stmt->get_result();
                $balanceAfter = $balanceResult->fetch_assoc()['balance'] ?? $user['balance'];
                
                // Always return in this format
                $response = [
                    "id" => mt_rand(1000000, 9999999),
                    "airtime_type" => $airtimeType,
                    "network" => $simpleNetworkId,
                    "ident" => $purchaseData['data']['reference'] ?? $requestId,
                    "paid_amount" => (string)number_format(floatval($amount) * 0.97, 2, '.', ''),
                    "mobile_number" => $phone,
                    "amount" => (string)$amount,
                    "plan_amount" => (string)$amount,
                    "plan_network" => $network['name'],
                    "balance_before" => (string)number_format($balanceBefore, 2, '.', ''),
                    "balance_after" => (string)number_format(floatval($balanceAfter), 2, '.', ''),
                    "Status" => "successful",
                    "create_date" => date("Y-m-d\TH:i:s.u"),
                    "Ported_number" => $isPortedNumber
                ];
                
                // Success response doesn't need a specific HTTP status code
                echo json_encode($response);
            } else {
                // Failed purchase
                http_response_code(400);
                echo json_encode([
                    "Status" => "failed",
                    "message" => $purchaseData['message'] ?? 'Airtime purchase failed'
                ]);
            }
        } else {
            // Unexpected response format
            http_response_code(500);
            error_log('Airtime purchase error (unexpected response format): ' . $purchaseResponse);
            echo json_encode([
                "Status" => "failed",
                "message" => "An error occurred while processing your request"
            ]);
        }
    } catch (Exception $e) {
        // Log error
        error_log("Airtime purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            "Status" => "failed",
            "message" => "An error occurred: " . $e->getMessage()
        ]);
    }
}
/**
 * Purchase airtime
 * 
 * @param array $user The authenticated user
 */
function purchaseAirtime4444($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['amount'])) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Missing required fields: network, mobile_number, amount',
            'error_code' => 'MISSING_REQUIRED_FIELDS'
        ]);
        return;
    }
    
    $simpleNetworkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $amount = (float)$requestData['amount'];
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $airtimeType = isset($requestData['airtime_type']) ? sanitizeInput($requestData['airtime_type']) : 'VTU';
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'AIRTIME_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid phone number format',
            'error_code' => 'INVALID_PHONE_NUMBER'
        ]);
        return;
    }
    
    // Validate amount
    if ($amount < 50 || $amount > 5000) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid amount. Amount must be between 50 and 5000',
            'error_code' => 'INVALID_AMOUNT'
        ]);
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            echo json_encode([
                'status' => false,
                'message' => 'Duplicate transaction. This request_id has already been processed.',
                'error_code' => 'DUPLICATE_TRANSACTION'
            ]);
            return;
        }
    }
    
    // Convert simple network ID to internal ID (using same mapping as v1)
    $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
    $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
    $stmt->bind_param("i", $internalNetworkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Network not found or inactive',
            'error_code' => 'INVALID_NETWORK'
        ]);
        return;
    }
    
    // Use the same approach as API v1 - prepare to call dashboard process script
    try {
        // Store original request ID
        $originalRequestId = $requestId;
        
        // Set up $_SESSION for the dashboard script
        $_SESSION['user_id'] = $user['id'];
        
        // Set up $_POST variables for the dashboard script
        $_POST = [
            'network_id' => $internalNetworkId,
            'phone' => $phone,
            'amount' => $amount,
            'client_reference' => $requestId // Use request_id as client_reference
        ];
        
        // Store current output buffer
        ob_start();
        
        // Include the purchase script from dashboard
        require_once dirname(__DIR__) . '/dashboard/process/buy_airtime.php';
        
        // Get the response
        $purchaseResponse = ob_get_clean();
        $purchaseData = json_decode($purchaseResponse, true);
        
        // Process response and convert to API v2 format
        if ($purchaseData && isset($purchaseData['success'])) {
            if ($purchaseData['success']) {
                // Successful purchase
                $responseData = [
                    'transaction_reference' => $purchaseData['data']['reference'] ?? '',
                    'amount' => floatval($purchaseData['data']['amount'] ?? $amount),
                    'phone' => $purchaseData['data']['phone'] ?? $phone,
                    'network' => $purchaseData['data']['network'] ?? $network['name'],
                    'date' => date('Y-m-d H:i:s'),
                    'request_id' => $originalRequestId
                ];
                
                echo json_encode([
                    'status' => true,
                    'message' => $purchaseData['message'] ?? 'Airtime purchase successful',
                    'data' => $responseData,
                    'user' => $responseData
                ]);
            } else {
                // Failed purchase
                http_response_code(400);
                echo json_encode([
                    'status' => false,
                    'message' => $purchaseData['message'] ?? 'Airtime purchase failed',
                    'error_code' => 'PROVIDER_ERROR',
                    'error_details' => $purchaseData['error_details'] ?? null
                ]);
            }
        } else {
            // Unexpected response format
            http_response_code(500);
            error_log('Airtime purchase error (unexpected response format): ' . $purchaseResponse);
            echo json_encode([
                'status' => false,
                'message' => 'An error occurred while processing your request',
                'error_code' => 'SYSTEM_ERROR'
            ]);
        }
    } catch (Exception $e) {
        // Log error
        error_log("Airtime purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            'status' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
            'error_code' => 'SYSTEM_ERROR'
        ]);
    }
}
 
/**
 * Get data plans with real-time pricing
 * 
 * @param array $user The authenticated user
 */
function getDataPlans($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get the network ID if provided
    $simpleNetworkId = isset($_GET['network']) ? (int)$_GET['network'] : 0;
    
    // Convert simple network ID to internal ID if provided
    $internalNetworkId = 0;
    if ($simpleNetworkId > 0) {
        $networkIdMapping = getNetworkIdMapping(true); // Reverse mapping
        $internalNetworkId = $networkIdMapping[$simpleNetworkId] ?? 0;
    }
    
    // Build the query based on filters
    $query = "
        SELECT dp.id, dp.name, dp.size, dp.validity,
               CASE WHEN ? = 'api' AND dp.amount_api > 0 THEN dp.amount_api
                    WHEN ? = 'smart' AND dp.amount_smart > 0 THEN dp.amount_smart
                    WHEN ? = 'vendor' AND dp.amount_vendor > 0 THEN dp.amount_vendor
                    ELSE dp.price END as price,
               n.id as internal_network_id, n.name as network_name
        FROM data_plans dp
        JOIN networks n ON dp.network_id = n.id
        WHERE dp.status = 'active'
    ";
    
    $params = [$user['user_type'], $user['user_type'], $user['user_type']];
    $types = "sss";
    
    if ($internalNetworkId > 0) {
        $query .= " AND n.id = ?";
        $params[] = $internalNetworkId;
        $types .= "i";
    }
    
    $query .= " ORDER BY n.name, dp.price";
    
    // Prepare and execute statement
    $stmt = $conn->prepare($query);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Process results
    $plans = [];
    $idMapping = getDataPlanIdMapping(); // Get ID mapping (internal ID -> simple ID)
    $networkIdMapping = getNetworkIdMapping(); // Get network ID mapping
    
    while ($row = $result->fetch_assoc()) {
        $simpleId = $idMapping[$row['id']] ?? 0;
        $simpleNetworkId = $networkIdMapping[$row['internal_network_id']] ?? 0;
        
        $plans[] = [
            'id' => $simpleId,
            'name' => $row['name'],
            'size' => $row['size'],
            'price' => floatval($row['price']),
            'validity' => $row['validity'],
            'network' => $row['network_name'],
            'network_id' => $simpleNetworkId
        ];
    }
    
    echo json_encode([
        'status' => true,
        'message' => 'Data plans retrieved successfully',
        'data' => $plans,
        'user' => $plans
    ]);
}

/**
 * Get available networks
 * 
 * @param array $user The authenticated user
 */
function getNetworks($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get all active networks
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY name");
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Get network ID mapping
    $networkIdMapping = getNetworkIdMapping();
    
    $networks = [];
    while ($row = $result->fetch_assoc()) {
        $simpleId = $networkIdMapping[$row['id']] ?? 0;
        
        $networks[] = [
            'id' => $simpleId,
            'name' => $row['name']
        ];
    }
    
    echo json_encode([
        'status' => true,
        'message' => 'Networks retrieved successfully',
        'data' => $networks,
        'user' => $networks
    ]);
}

/**
 * Get provider network ID mapping
 * 
 * @param int $providerId The provider ID
 * @param int $networkId The network ID
 * @param string $serviceType The service type (airtime, data, etc.)
 * @return string The provider's network ID or the original network ID if not found
 */
function getProviderNetworkIdV2($providerId, $networkId, $serviceType) {
    global $conn;
    
    try {
        $stmt = $conn->prepare("
            SELECT provider_network_id FROM network_providers 
            WHERE provider_id = ? AND network_id = ? AND service_type = ?
        ");
        $stmt->bind_param("iis", $providerId, $networkId, $serviceType);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row && !empty($row['provider_network_id'])) {
            return $row['provider_network_id'];
        }
    } catch (Exception $e) {
        error_log("Error getting provider network ID: " . $e->getMessage());
    }
    
    // Return network ID as fallback
    return $networkId;
}

/**
 * Get provider plan ID mapping
 * 
 * @param int $providerId The provider ID
 * @param int $planId The plan ID
 * @param string $serviceType The service type (data, etc.)
 * @return string The provider's plan ID or the original plan ID if not found
 */
function getProviderPlanId($providerId, $planId, $serviceType) {
    global $conn;
    
    try {
        $stmt = $conn->prepare("
            SELECT provider_plan_id FROM plan_providers 
            WHERE provider_id = ? AND plan_id = ? AND service_type = ?
        ");
        $stmt->bind_param("iis", $providerId, $planId, $serviceType);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row && !empty($row['provider_plan_id'])) {
            return $row['provider_plan_id'];
        }
    } catch (Exception $e) {
        error_log("Error getting provider plan ID: " . $e->getMessage());
    }
    
    // Return plan ID as fallback
    return $planId;
}

/**
 * Format phone number for provider
 * 
 * @param string $phone The phone number
 * @return string Formatted phone number
 */
function formatPhoneNumber($phone) {
    // Strip any non-numeric characters
    $phone = preg_replace('/[^0-9]/', '', $phone);
    
    // Remove leading country code if present
    if (substr($phone, 0, 3) == '234') {
        $phone = '0' . substr($phone, 3);
    }
    
    return $phone;
}

/**
 * Create a notification for the user
 * 
 * @param int $userId User ID
 * @param string $title Notification title
 * @param string $message Notification message
 * @param string $type Notification type (success, error, info)
 */
function createNotification($userId, $title, $message, $type = 'info') {
    global $conn;
    
    try {
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, ?, 0)
        ");
        $stmt->bind_param("isss", $userId, $title, $message, $type);
        $stmt->execute();
    } catch (Exception $e) {
        error_log("Error creating notification: " . $e->getMessage());
    }
}
?>