<?php
// File: /api/api_v2_functions.php
require_once dirname(__DIR__) . '/includes/config.php';
require_once dirname(__DIR__) . '/includes/functions.php';

/**
 * Authenticate an API v2 request using the Token-based authentication
 * 
 * @return array Authentication result with success status, message, and user data if successful
 */
function authenticateApiV2Request() {
    // Get Authorization header
    $authHeader = $_SERVER['HTTP_AUTHORIZATION'] ?? '';
    
    // Check for Token format
    if (empty($authHeader) || !preg_match('/^Token\s+([a-zA-Z0-9]+)$/i', $authHeader, $matches)) {
        return [
            'success' => false,
            'message' => 'Authentication failed. Use format: "Authorization: Token YOUR_API_TOKEN"'
        ];
    }
    
    $apiToken = $matches[1];
    
    // Connect to database
    $db = getDB();
    $conn = $db->getConnection();
    
    // Find user with the given API token
    $stmt = $conn->prepare("SELECT * FROM users WHERE api_token = ? AND status = 'active' AND user_type = 'api'");
    $stmt->bind_param('s', $apiToken);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        return [
            'success' => false,
            'message' => 'Invalid API token'
        ];
    }
    
    $user = $result->fetch_assoc();
    
    // Check if user has API privileges
    if ($user['user_type'] !== 'api') {
        return [
            'success' => false,
            'message' => 'Your account is not authorized for API access'
        ];
    }
    
    // All checks passed
    return [
        'success' => true,
        'message' => 'Authentication successful',
        'user' => $user
    ];
}

/**
 * Apply rate limiting to API requests
 * 
 * @param int $userId The user ID
 * @param string $method The HTTP method (GET, POST, etc.)
 * @param string $version API version
 * @return array Result with success status and headers
 */
function applyRateLimit($userId, $method, $version = 'v2') {
    // Define limits based on method
    $limit = ($method === 'GET') ? 120 : 60; // Higher limits for API v2
    $windowInSeconds = 60;
    
    // Create a unique key for this user and method type
    $key = "rate_limit:{$userId}:{$version}:{$method}:" . floor(time() / $windowInSeconds);
    
    // Simple file-based rate limiting (you can replace with Redis or database if available)
    $cacheFile = sys_get_temp_dir() . "/vtu_ratelimit_{$userId}_{$version}_{$method}.txt";
    
    if (file_exists($cacheFile)) {
        $data = json_decode(file_get_contents($cacheFile), true);
        $current = $data['count'];
        $resetTime = $data['reset_time'];
    } else {
        $current = 0;
        $resetTime = time() + $windowInSeconds;
    }
    
    // Increment counter
    $current++;
    
    // Store updated count
    file_put_contents($cacheFile, json_encode([
        'count' => $current,
        'reset_time' => $resetTime
    ]));
    
    // Check if over limit
    $overLimit = $current > $limit;
    
    // Generate headers
    $headers = [
        'X-RateLimit-Limit' => $limit,
        'X-RateLimit-Remaining' => $overLimit ? 0 : $limit - $current,
        'X-RateLimit-Reset' => $resetTime
    ];
    
    return [
        'success' => !$overLimit,
        'headers' => $headers
    ];
}

/**
 * Get user info and balance
 * 
 * @param array $user The authenticated user
 */
function getUserInfo($user) {
    // Prepare user information with multiple balance key formats
    $userData = [
        'id' => $user['id'],
        'username' => $user['username'],
        'email' => $user['email'],
        'phone' => $user['phone'],
        'balance' => floatval($user['balance']),
        'account_balance' => floatval($user['balance']),
        'wallet_balance' => floatval($user['balance']),
        'Account_balance' => floatval($user['balance']),
        'Wallet_balance' => floatval($user['balance']),
        'Balance' => floatval($user['balance']),
        'account_type' => $user['user_type'],
        'created_at' => $user['created_at'],
        'currency' => getSetting('currency', '₦')
    ];
    
    echo json_encode([
        'status' => true,
        'message' => 'User information retrieved successfully',
        'user' => $userData,
        'data' => $userData
    ]);
}

/**
 * Get account balance (multiple formats)
 * 
 * @param array $user The authenticated user
 */
function getAccountBalance($user) {
    // Return balance in multiple formats for compatibility
    $balanceData = [
        'balance' => floatval($user['balance']),
        'account_balance' => floatval($user['balance']),
        'wallet_balance' => floatval($user['balance']),
        'Account_balance' => floatval($user['balance']),
        'Wallet_balance' => floatval($user['balance']),
        'Balance' => floatval($user['balance']),
        'currency' => getSetting('currency', '₦')
    ];
    
    echo json_encode([
        'status' => true,
        'message' => 'Balance retrieved successfully',
        'user' => $userData,
        'data' => $balanceData
    ]);
}

/**
 * Purchase data bundle
 * 
 * @param array $user The authenticated user
 */
function purchaseData($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['plan'])) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Missing required fields: network, mobile_number, plan',
            'error_code' => 'MISSING_REQUIRED_FIELDS'
        ]);
        return;
    }
    
    $networkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $planId = $requestData['plan'];
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'DATA_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid phone number format',
            'error_code' => 'INVALID_PHONE_NUMBER'
        ]);
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            echo json_encode([
                'status' => false,
                'message' => 'Duplicate transaction. This request_id has already been processed.',
                'error_code' => 'DUPLICATE_TRANSACTION'
            ]);
            return;
        }
    }
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE api_id = ? AND status = 'active'");
    $stmt->bind_param("i", $networkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Network not found or inactive',
            'error_code' => 'INVALID_NETWORK'
        ]);
        return;
    }
    
    // Get the data plan
    $stmt = $conn->prepare("
        SELECT dp.*, n.name as network_name 
        FROM data_plans dp
        JOIN networks n ON dp.network_id = n.id
        WHERE dp.api_plan_id = ? AND dp.status = 'active' AND n.id = ?
    ");
    $stmt->bind_param("si", $planId, $network['id']);
    $stmt->execute();
    $plan = $stmt->get_result()->fetch_assoc();
    
    if (!$plan) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Data plan not found or inactive',
            'error_code' => 'INVALID_PLAN'
        ]);
        return;
    }
    
    // Determine price based on user type
    $priceField = 'price'; // Default price
    switch($user['user_type']) {
        case 'api':
            $priceField = $plan['amount_api'] > 0 ? 'amount_api' : 'price';
            break;
        case 'smart':
            $priceField = $plan['amount_smart'] > 0 ? 'amount_smart' : 'price';
            break;
        case 'vendor':
            $priceField = $plan['amount_vendor'] > 0 ? 'amount_vendor' : 'price';
            break;
    }
    
    $price = $plan[$priceField];
    
    // Check if user has sufficient balance
    if ($user['balance'] < $price) {
        http_response_code(402);
        echo json_encode([
            'status' => false,
            'message' => 'Insufficient balance',
            'error_code' => 'INSUFFICIENT_BALANCE'
        ]);
        return;
    }
    
    // Begin transaction
    $conn->begin_transaction();
    
    try {
        // Generate reference
        $reference = 'DATA_' . time() . '_' . rand(1000, 9999);
        
        // Create transaction record
        $stmt = $conn->prepare("
            INSERT INTO transactions (user_id, txn_ref, type, amount, description, status, meta_data)
            VALUES (?, ?, 'data', ?, ?, 'pending', ?)
        ");
        
        $description = "Data purchase of {$plan['name']} for {$phone}";
        $metaData = json_encode([
            'network_id' => $network['id'],
            'plan_id' => $plan['id'],
            'phone' => $phone,
            'ported_number' => $isPortedNumber,
            'request_id' => $requestId
        ]);
        
        $stmt->bind_param("isdss", $user['id'], $reference, $price, $description, $metaData);
        $stmt->execute();
        $txnId = $conn->insert_id;
        
        // Deduct from user's balance
        $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
        $stmt->bind_param("di", $price, $user['id']);
        $stmt->execute();
        
        // Get provider for this network
        $stmt = $conn->prepare("
            SELECT p.* FROM network_providers np
            JOIN providers p ON np.provider_id = p.id
            WHERE np.network_id = ? AND np.service_type = 'data' AND p.status = 'active'
            ORDER BY np.is_default DESC
            LIMIT 1
        ");
        $stmt->bind_param("i", $network['id']);
        $stmt->execute();
        $provider = $stmt->get_result()->fetch_assoc();
        
        if (!$provider) {
            throw new Exception("No active provider available for this network");
        }
        
        // Format the phone number for provider
        $formattedPhone = formatPhoneNumber($phone);
        
        // Get provider-specific plan and network IDs
        $providerNetworkId = getProviderNetworkId($provider['id'], $network['id'], 'data');
        $providerPlanId = getProviderPlanId($provider['id'], $plan['id'], 'data');
        
        // Prepare API request to provider
        $apiUrl = $provider['api_url'];
        if (strpos($apiUrl, '/data') === false) {
            $apiUrl = rtrim($apiUrl, '/') . '/data/';
        }
        
        $requestBody = json_encode([
            'network' => $providerNetworkId,
            'mobile_number' => $formattedPhone,
            'plan' => $providerPlanId,
            'Ported_number' => $isPortedNumber
        ]);
        
        $ch = curl_init($apiUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $requestBody);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Authorization: Token ' . $provider['api_key'],
            'Content-Type: application/json'
        ]);
        
        // Execute request
        $apiResponse = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $curlError = curl_error($ch);
        curl_close($ch);
        
        // Log API response
        error_log("Provider API Response ($httpCode): " . $apiResponse);
        error_log("Provider API Error (if any): " . $curlError);
        
        // Parse API response
        $apiResponseData = json_decode($apiResponse, true);
        
        // Update transaction based on provider response
        if ($httpCode >= 200 && $httpCode < 300 && isset($apiResponseData['status']) && $apiResponseData['status'] === true) {
            // Transaction successful
            $stmt = $conn->prepare("UPDATE transactions SET status = 'successful', api_response = ? WHERE id = ?");
            $stmt->bind_param("si", $apiResponse, $txnId);
            $stmt->execute();
            
            // Create notification
            createNotification($user['id'], 'Data Purchase Successful', $description, 'success');
            
            // Commit transaction
            $conn->commit();
            
            // Return success response
            echo json_encode([
                'status' => true,
                'message' => 'Data purchase successful',
                'data' => [
                    'transaction_reference' => $reference,
                    'amount' => $price,
                    'phone' => $phone,
                    'network' => $network['name'],
                    'data_plan' => $plan['name'],
                    'date' => date('Y-m-d H:i:s'),
                    'request_id' => $requestId
                ]
            ]);
        } else {
            // Transaction failed
            $error = isset($apiResponseData['message']) ? $apiResponseData['message'] : 'Provider API error';
            
            // Update transaction
            $stmt = $conn->prepare("UPDATE transactions SET status = 'failed', api_response = ? WHERE id = ?");
            $stmt->bind_param("si", $apiResponse, $txnId);
            $stmt->execute();
            
            // Refund user's balance
            $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
            $stmt->bind_param("di", $price, $user['id']);
            $stmt->execute();
            
            // Create notification
            createNotification($user['id'], 'Data Purchase Failed', "Your data purchase for {$phone} failed: {$error}", 'error');
            
            // Commit transaction
            $conn->commit();
            
            // Return error response
            http_response_code(400);
            echo json_encode([
                'status' => false,
                'message' => 'Data purchase failed: ' . $error,
                'error_code' => 'PROVIDER_ERROR'
            ]);
        }
    } catch (Exception $e) {
        // Rollback transaction
        $conn->rollback();
        
        // Log error
        error_log("Data purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            'status' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
            'error_code' => 'SYSTEM_ERROR'
        ]);
    }
}

/**
 * Purchase airtime
 * 
 * @param array $user The authenticated user
 */
function purchaseAirtime($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get request body
    $requestData = json_decode(file_get_contents('php://input'), true);
    
    // Validate required fields
    if (empty($requestData['network']) || 
        empty($requestData['mobile_number']) || 
        empty($requestData['amount'])) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Missing required fields: network, mobile_number, amount',
            'error_code' => 'MISSING_REQUIRED_FIELDS'
        ]);
        return;
    }
    
    $networkId = (int)$requestData['network'];
    $phone = sanitizeInput($requestData['mobile_number']);
    $amount = (float)$requestData['amount'];
    $isPortedNumber = isset($requestData['Ported_number']) ? (bool)$requestData['Ported_number'] : false;
    $airtimeType = isset($requestData['airtime_type']) ? sanitizeInput($requestData['airtime_type']) : 'VTU';
    $requestId = isset($requestData['request_id']) ? sanitizeInput($requestData['request_id']) : 'AIRTIME_' . time() . rand(1000, 9999);
    
    // Validate phone number
    if (!preg_match('/^(0|\+?234)[789][01]\d{8}$/', $phone)) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid phone number format',
            'error_code' => 'INVALID_PHONE_NUMBER'
        ]);
        return;
    }
    
    // Validate amount
    if ($amount < 50 || $amount > 5000) {
        http_response_code(400);
        echo json_encode([
            'status' => false,
            'message' => 'Invalid amount. Amount must be between 50 and 5000',
            'error_code' => 'INVALID_AMOUNT'
        ]);
        return;
    }
    
    // Check if request_id already exists to prevent duplicate transactions
    if (isset($requestData['request_id'])) {
        $stmt = $conn->prepare("SELECT id FROM transactions WHERE meta_data LIKE ?");
        $searchPattern = '%"request_id":"' . $requestData['request_id'] . '"%';
        $stmt->bind_param("s", $searchPattern);
        $stmt->execute();
        
        if ($stmt->get_result()->num_rows > 0) {
            http_response_code(409);
            echo json_encode([
                'status' => false,
                'message' => 'Duplicate transaction. This request_id has already been processed.',
                'error_code' => 'DUPLICATE_TRANSACTION'
            ]);
            return;
        }
    }
    
    // Get the network
    $stmt = $conn->prepare("SELECT * FROM networks WHERE api_id = ? AND status = 'active'");
    $stmt->bind_param("i", $networkId);
    $stmt->execute();
    $network = $stmt->get_result()->fetch_assoc();
    
    if (!$network) {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'Network not found or inactive',
            'error_code' => 'INVALID_NETWORK'
        ]);
        return;
    }
    
    // Apply discount based on user type
    $discountKey = 'airtime_discount_' . $user['user_type'];
    $discountPercent = (float)getSetting($discountKey, 0);
    $discount = 0;
    
    if ($discountPercent > 0) {
        $discount = ($amount * $discountPercent) / 100;
    }
    
    // Calculate final amount after discount
    $finalAmount = $amount - $discount;
    
    // Check if user has sufficient balance
    if ($user['balance'] < $finalAmount) {
        http_response_code(402);
        echo json_encode([
            'status' => false,
            'message' => 'Insufficient balance',
            'error_code' => 'INSUFFICIENT_BALANCE'
        ]);
        return;
    }
    
    // Begin transaction
    $conn->begin_transaction();
    
    try {
        // Generate reference
        $reference = 'AIRTIME_' . time() . '_' . rand(1000, 9999);
        
        // Create transaction record
        $stmt = $conn->prepare("
            INSERT INTO transactions (user_id, txn_ref, type, amount, description, status, meta_data)
            VALUES (?, ?, 'airtime', ?, ?, 'pending', ?)
        ");
        
        $description = "Airtime purchase of {$amount} for {$phone}";
        $metaData = json_encode([
            'network_id' => $network['id'],
            'phone' => $phone,
            'amount' => $amount,
            'discount' => $discount,
            'final_amount' => $finalAmount,
            'airtime_type' => $airtimeType,
            'ported_number' => $isPortedNumber,
            'request_id' => $requestId
        ]);
        
        $stmt->bind_param("isdss", $user['id'], $reference, $finalAmount, $description, $metaData);
        $stmt->execute();
        $txnId = $conn->insert_id;
        
        // Deduct from user's balance
        $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
        $stmt->bind_param("di", $finalAmount, $user['id']);
        $stmt->execute();
        
        // Get provider for this network
        $stmt = $conn->prepare("
            SELECT p.* FROM network_providers np
            JOIN providers p ON np.provider_id = p.id
            WHERE np.network_id = ? AND np.service_type = 'airtime' AND p.status = 'active'
            ORDER BY np.is_default DESC
            LIMIT 1
        ");
        $stmt->bind_param("i", $network['id']);
        $stmt->execute();
        $provider = $stmt->get_result()->fetch_assoc();
        
        if (!$provider) {
            throw new Exception("No active provider available for this network");
        }
        
        // Format the phone number for provider
        $formattedPhone = formatPhoneNumber($phone);
        
        // Get provider-specific network ID
        $providerNetworkId = getProviderNetworkId($provider['id'], $network['id'], 'airtime');
        
        // Prepare API request to provider
        $apiUrl = $provider['api_url'];
        if (strpos($apiUrl, '/topup') === false) {
            $apiUrl = rtrim($apiUrl, '/') . '/topup/';
        }
        
        $requestBody = json_encode([
            'network' => $providerNetworkId,
            'mobile_number' => $formattedPhone,
            'amount' => $amount,
            'Ported_number' => $isPortedNumber,
            'airtime_type' => $airtimeType
        ]);
        
        $ch = curl_init($apiUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $requestBody);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Authorization: Token ' . $provider['api_key'],
            'Content-Type: application/json'
        ]);
        
        // Execute request
        $apiResponse = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $curlError = curl_error($ch);
        curl_close($ch);
        
        // Log API response
        error_log("Provider API Response ($httpCode): " . $apiResponse);
        error_log("Provider API Error (if any): " . $curlError);
        
        // Parse API response
        $apiResponseData = json_decode($apiResponse, true);
        
        // Update transaction based on provider response
        if ($httpCode >= 200 && $httpCode < 300 && isset($apiResponseData['status']) && $apiResponseData['status'] === true) {
            // Transaction successful
            $stmt = $conn->prepare("UPDATE transactions SET status = 'successful', api_response = ? WHERE id = ?");
            $stmt->bind_param("si", $apiResponse, $txnId);
            $stmt->execute();
            
            // Create notification
            createNotification($user['id'], 'Airtime Purchase Successful', $description, 'success');
            
            // Commit transaction
            $conn->commit();
            
            // Return success response
            echo json_encode([
                'status' => true,
                'message' => 'Airtime purchase successful',
                'data' => [
                    'transaction_reference' => $reference,
                    'amount' => $amount,
                    'phone' => $phone,
                    'network' => $network['name'],
                    'date' => date('Y-m-d H:i:s'),
                    'request_id' => $requestId
                ]
            ]);
        } else {
            // Transaction failed
            $error = isset($apiResponseData['message']) ? $apiResponseData['message'] : 'Provider API error';
            
            // Update transaction
            $stmt = $conn->prepare("UPDATE transactions SET status = 'failed', api_response = ? WHERE id = ?");
            $stmt->bind_param("si", $apiResponse, $txnId);
            $stmt->execute();
            
            // Refund user's balance
            $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
            $stmt->bind_param("di", $finalAmount, $user['id']);
            $stmt->execute();
            
            // Create notification
            createNotification($user['id'], 'Airtime Purchase Failed', "Your airtime purchase for {$phone} failed: {$error}", 'error');
            
            // Commit transaction
            $conn->commit();
            
            // Return error response
            http_response_code(400);
            echo json_encode([
                'status' => false,
                'message' => 'Airtime purchase failed: ' . $error,
                'error_code' => 'PROVIDER_ERROR'
            ]);
        }
    } catch (Exception $e) {
        // Rollback transaction
        $conn->rollback();
        
        // Log error
        error_log("Airtime purchase error: " . $e->getMessage());
        
        // Return error response
        http_response_code(500);
        echo json_encode([
            'status' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
            'error_code' => 'SYSTEM_ERROR'
        ]);
    }
}

/**
 * Get data plans with real-time pricing
 * 
 * @param array $user The authenticated user
 */
function getDataPlans($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get the network ID if provided
    $networkId = isset($_GET['network']) ? (int)$_GET['network'] : 0;
    
    // Build the query based on filters
    $query = "
        SELECT dp.id, dp.name, dp.size, dp.validity, dp.api_plan_id,
               CASE WHEN ? = 'api' AND dp.amount_api > 0 THEN dp.amount_api
                    WHEN ? = 'smart' AND dp.amount_smart > 0 THEN dp.amount_smart
                    WHEN ? = 'vendor' AND dp.amount_vendor > 0 THEN dp.amount_vendor
                    ELSE dp.price END as price,
               n.id as internal_network_id, n.name as network_name, n.api_id as network_id
        FROM data_plans dp
        JOIN networks n ON dp.network_id = n.id
        WHERE dp.status = 'active'
    ";
    
    $params = [$user['user_type'], $user['user_type'], $user['user_type']];
    $types = "sss";
    
    if ($networkId > 0) {
        $query .= " AND n.api_id = ?";
        $params[] = $networkId;
        $types .= "i";
    }
    
    $query .= " ORDER BY n.name, dp.price";
    
    // Prepare and execute statement
    $stmt = $conn->prepare($query);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();
    
    // Process results
    $plans = [];
    while ($row = $result->fetch_assoc()) {
        $plans[] = [
            'id' => $row['api_plan_id'],
            'name' => $row['name'],
            'size' => $row['size'],
            'price' => floatval($row['price']),
            'validity' => $row['validity'],
            'network' => $row['network_name'],
            'network_id' => $row['network_id']
        ];
    }
    
    echo json_encode([
        'status' => true,
        'message' => 'Data plans retrieved successfully',
        'data' => $plans
    ]);
}

/**
 * Get available networks
 * 
 * @param array $user The authenticated user
 */
function getNetworks($user) {
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get all active networks
    $stmt = $conn->prepare("SELECT id, name, api_id FROM networks WHERE status = 'active' ORDER BY name");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $networks = [];
    while ($row = $result->fetch_assoc()) {
        $networks[] = [
            'id' => $row['api_id'],
            'name' => $row['name']
        ];
    }
    
    echo json_encode([
        'status' => true,
        'message' => 'Networks retrieved successfully',
        'data' => $networks
    ]);
}

/**
 * Get provider network ID mapping
 * 
 * @param int $providerId The provider ID
 * @param int $networkId The network ID
 * @param string $serviceType The service type (airtime, data, etc.)
 * @return string The provider's network ID or the original network ID if not found
 */
function getProviderNetworkId($providerId, $networkId, $serviceType) {
    // Get a fresh database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    
    try {
        $stmt = $conn->prepare("
            SELECT provider_network_id FROM network_providers 
            WHERE provider_id = ? AND network_id = ? AND service_type = ?
        ");
        $stmt->bind_param("iis", $providerId, $networkId, $serviceType);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row && !empty($row['provider_network_id'])) {
            return $row['provider_network_id'];
        }
    } catch (Exception $e) {
        error_log("Error getting provider network ID: " . $e->getMessage());
    }
    
    // Return network ID as fallback
    return $networkId;
}

/**
 * Get provider plan ID mapping
 * 
 * @param int $providerId The provider ID
 * @param int $planId The plan ID
 * @param string $serviceType The service type (data, etc.)
 * @return string The provider's plan ID or the original plan ID if not found
 */
function getProviderPlanId($providerId, $planId, $serviceType) {
    global $conn;
    
    try {
        $stmt = $conn->prepare("
            SELECT provider_plan_id FROM plan_providers 
            WHERE provider_id = ? AND plan_id = ? AND service_type = ?
        ");
        $stmt->bind_param("iis", $providerId, $planId, $serviceType);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row && !empty($row['provider_plan_id'])) {
            return $row['provider_plan_id'];
        }
    } catch (Exception $e) {
        error_log("Error getting provider plan ID: " . $e->getMessage());
    }
    
    // Return plan ID as fallback
    return $planId;
}

/**
 * Format phone number for provider
 * 
 * @param string $phone The phone number
 * @return string Formatted phone number
 */
function formatPhoneNumber($phone) {
    // Strip any non-numeric characters
    $phone = preg_replace('/[^0-9]/', '', $phone);
    
    // Remove leading country code if present
    if (substr($phone, 0, 3) == '234') {
        $phone = '0' . substr($phone, 3);
    }
    
    return $phone;
}

/**
 * Create a notification for the user
 * 
 * @param int $userId User ID
 * @param string $title Notification title
 * @param string $message Notification message
 * @param string $type Notification type (success, error, info)
 */
function createNotification($userId, $title, $message, $type = 'info') {
    // Get a fresh database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    
    try {
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, ?, 0)
        ");
        $stmt->bind_param("isss", $userId, $title, $message, $type);
        $stmt->execute();
    } catch (Exception $e) {
        error_log("Error creating notification: " . $e->getMessage());
    }
}
?>