<?php
// File: /api/v2/index.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../api_v2_functions.php';

// Enable error reporting for debugging (remove in production)
ini_set('display_errors', 0);
error_log('API v2 Request: ' . $_SERVER['REQUEST_METHOD'] . ' ' . $_SERVER['REQUEST_URI']);

// Set headers for JSON API
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

// Handle preflight requests
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Authenticate the request
$authResult = authenticateApiV2Request();
if (!$authResult['success']) {
    http_response_code(401);
    echo json_encode([
        'status' => false,
        'message' => $authResult['message'],
        'error_code' => 'AUTHENTICATION_FAILED'
    ]);
    exit;
}

// Get the authenticated user
$apiUser = $authResult['user'];

// Parse the request path
$requestUri = $_SERVER['REQUEST_URI'];
$basePath = parse_url(SITE_URL, PHP_URL_PATH) . '/api/v2/';
$path = str_replace($basePath, '', $requestUri);
$path = strtok($path, '?'); // Remove query string
$path = trim($path, '/');

// Route the request to the appropriate handler
$method = $_SERVER['REQUEST_METHOD'];

try {
    // Apply rate limits (optional)
    $rateLimitResult = applyRateLimit($apiUser['id'], $method, 'v2');
    
    // Add rate limit headers to the response
    foreach ($rateLimitResult['headers'] as $name => $value) {
        header("$name: $value");
    }
    
    // Check if rate limit is exceeded
    if (!$rateLimitResult['success']) {
        http_response_code(429);
        echo json_encode([
            'status' => false,
            'message' => 'Too many requests. Please try again later.',
            'error_code' => 'RATE_LIMIT_EXCEEDED'
        ]);
        exit;
    }
    
    // Balance and account endpoints
    if (($path === 'user' || $path === 'user/') && $method === 'GET') {
        getUserInfo($apiUser);
    } 
    elseif (($path === 'balance' || $path === 'balance/') && $method === 'GET') {
        getAccountBalance($apiUser);
    }
    // Data service endpoints
    elseif (($path === 'data' || $path === 'data/') && $method === 'POST') {
        purchaseData($apiUser);
    }
    // Airtime service endpoints
    elseif (($path === 'topup' || $path === 'topup/' || $path === 'airtime' || $path === 'airtime/') && $method === 'POST') {
        purchaseAirtime($apiUser);
    }
    // Data plans endpoint
    elseif (($path === 'data-plans' || $path === 'data-plans/') && $method === 'GET') {
        getDataPlans($apiUser);
    }
    // Network providers endpoint
    elseif (($path === 'networks' || $path === 'networks/') && $method === 'GET') {
        getNetworks($apiUser);
    }
    // If no route matches
    else {
        http_response_code(404);
        echo json_encode([
            'status' => false,
            'message' => 'The requested endpoint does not exist',
            'error_code' => 'ENDPOINT_NOT_FOUND'
        ]);
    }
} catch (Exception $e) {
    http_response_code(500);
    error_log('API v2 Error: ' . $e->getMessage());
    echo json_encode([
        'status' => false,
        'message' => 'An unexpected error occurred',
        'error_code' => 'INTERNAL_SERVER_ERROR'
    ]);
}
?>