<?php
// Include the configuration file
require_once $_SERVER['DOCUMENT_ROOT'] . '/includes/config.php';

// Connect to the database
try {
    $db = new PDO("mysql:host=" . DB_HOST . ";dbname=" . DB_NAME, DB_USER, DB_PASS);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Connection failed: " . $e->getMessage());
}

// Initialize variables
$authenticated = false;
$error_message = '';
$success_message = '';
$token = '';

// Check if token is provided
if (isset($_POST['token'])) {
    $token = trim($_POST['token']);
    
    // Validate token (6 digits)
    if (!preg_match('/^\d{6}$/', $token)) {
        $error_message = 'Token must be 6 digits';
    } else {
        // Check if token exists and is valid
        try {
            $query = "SELECT * FROM auth_tokens WHERE token = :token AND expires_at > NOW() LIMIT 1";
            $stmt = $db->prepare($query);
            $stmt->bindParam(':token', $token);
            $stmt->execute();
            
            if ($stmt->rowCount() > 0) {
                $authenticated = true;
                
                // Store token in session for subsequent requests
                $_SESSION['auth_token'] = $token;
            } else {
                $error_message = 'Invalid or expired token';
            }
        } catch (PDOException $e) {
            $error_message = 'Database error: ' . $e->getMessage();
        }
    }
} elseif (isset($_SESSION['auth_token'])) {
    // Check if token in session is still valid
    try {
        $query = "SELECT * FROM auth_tokens WHERE token = :token AND expires_at > NOW() LIMIT 1";
        $stmt = $db->prepare($query);
        $stmt->bindParam(':token', $_SESSION['auth_token']);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            $authenticated = true;
            $token = $_SESSION['auth_token'];
        } else {
            // Token expired, clear session
            unset($_SESSION['auth_token']);
            $error_message = 'Session expired, please enter token again';
        }
    } catch (PDOException $e) {
        $error_message = 'Database error: ' . $e->getMessage();
    }
}

// Handle form submissions if authenticated
if ($authenticated) {
    // Add new changelog entry
    if (isset($_POST['action']) && $_POST['action'] == 'add') {
        $version = trim($_POST['version']);
        $title = trim($_POST['title']);
        $description = trim($_POST['description']);
        $release_date = trim($_POST['release_date']);
        $type = trim($_POST['type']);
        
        // Validate inputs
        if (empty($version) || empty($title) || empty($description) || empty($release_date) || empty($type)) {
            $error_message = 'All fields are required';
        } else {
            try {
                $query = "INSERT INTO changelog_entries (version, title, description, release_date, type) 
                          VALUES (:version, :title, :description, :release_date, :type)";
                $stmt = $db->prepare($query);
                $stmt->bindParam(':version', $version);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':description', $description);
                $stmt->bindParam(':release_date', $release_date);
                $stmt->bindParam(':type', $type);
                
                if ($stmt->execute()) {
                    $success_message = 'Changelog entry added successfully';
                } else {
                    $error_message = 'Failed to add changelog entry';
                }
            } catch (PDOException $e) {
                $error_message = 'Database error: ' . $e->getMessage();
            }
        }
    }
    
    // Edit changelog entry
    elseif (isset($_POST['action']) && $_POST['action'] == 'edit') {
        $id = intval($_POST['id']);
        $version = trim($_POST['version']);
        $title = trim($_POST['title']);
        $description = trim($_POST['description']);
        $release_date = trim($_POST['release_date']);
        $type = trim($_POST['type']);
        
        // Validate inputs
        if (empty($version) || empty($title) || empty($description) || empty($release_date) || empty($type)) {
            $error_message = 'All fields are required';
        } else {
            try {
                $query = "UPDATE changelog_entries 
                          SET version = :version, title = :title, description = :description, 
                              release_date = :release_date, type = :type 
                          WHERE id = :id";
                $stmt = $db->prepare($query);
                $stmt->bindParam(':id', $id);
                $stmt->bindParam(':version', $version);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':description', $description);
                $stmt->bindParam(':release_date', $release_date);
                $stmt->bindParam(':type', $type);
                
                if ($stmt->execute()) {
                    $success_message = 'Changelog entry updated successfully';
                } else {
                    $error_message = 'Failed to update changelog entry';
                }
            } catch (PDOException $e) {
                $error_message = 'Database error: ' . $e->getMessage();
            }
        }
    }
    
    // Delete changelog entry
    elseif (isset($_POST['action']) && $_POST['action'] == 'delete') {
        $id = intval($_POST['id']);
        
        try {
            $query = "DELETE FROM changelog_entries WHERE id = :id";
            $stmt = $db->prepare($query);
            $stmt->bindParam(':id', $id);
            
            if ($stmt->execute()) {
                $success_message = 'Changelog entry deleted successfully';
            } else {
                $error_message = 'Failed to delete changelog entry';
            }
        } catch (PDOException $e) {
            $error_message = 'Database error: ' . $e->getMessage();
        }
    }
    
    // Generate new token
    elseif (isset($_POST['action']) && $_POST['action'] == 'generate_token') {
        // Generate a random 6-digit token
        $new_token = sprintf("%06d", mt_rand(0, 999999));
        
        // Set expiration time (1 year from now)
        $expires_at = date('Y-m-d H:i:s', strtotime('+1 year'));
        
        try {
            // First, invalidate all existing tokens
            $query = "UPDATE auth_tokens SET expires_at = NOW() WHERE expires_at > NOW()";
            $stmt = $db->prepare($query);
            $stmt->execute();
            
            // Then, insert new token
            $query = "INSERT INTO auth_tokens (token, expires_at) VALUES (:token, :expires_at)";
            $stmt = $db->prepare($query);
            $stmt->bindParam(':token', $new_token);
            $stmt->bindParam(':expires_at', $expires_at);
            
            if ($stmt->execute()) {
                $success_message = "New token generated: " . $new_token . " (valid for 1 year)";
                
                // Update session
                $_SESSION['auth_token'] = $new_token;
                $token = $new_token;
            } else {
                $error_message = 'Failed to generate new token';
            }
        } catch (PDOException $e) {
            $error_message = 'Database error: ' . $e->getMessage();
        }
    }
    
    // Fetch all changelog entries for display
    try {
        $query = "SELECT * FROM changelog_entries ORDER BY STR_TO_DATE(CONCAT('01-', REPLACE(version, '.', '-')), '%d-%m-%Y') DESC, id DESC";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $changelog_entries = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        $error_message = 'Failed to fetch changelog entries: ' . $e->getMessage();
        $changelog_entries = [];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>VTU Platform - Changelog Management</title>
    
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    
    <!-- Summernote WYSIWYG Editor -->
    <link href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-bs4.min.css" rel="stylesheet">
    
    <style>
        :root {
            --primary-color: #5D5CDE;
            --secondary-color: #6c757d;
            --light-bg: #ffffff;
            --dark-bg: #181818;
            --light-text: #212529;
            --dark-text: #f8f9fa;
        }
        
        body {
            background-color: var(--light-bg);
            color: var(--light-text);
            transition: all 0.3s ease;
            padding-top: 80px;
        }
        
        body.dark-mode {
            background-color: var(--dark-bg);
            color: var(--dark-text);
        }
        
        .navbar {
            background-color: var(--primary-color);
        }
        
        .navbar-brand, .nav-link {
            color: white !important;
        }
        
        .auth-container, .admin-container {
            max-width: 900px;
            margin: 0 auto;
        }
        
        .auth-card {
            max-width: 400px;
            margin: 100px auto;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
        }
        
        .dark-mode .auth-card, .dark-mode .card {
            background-color: #2c2c2c;
            color: var(--dark-text);
        }
        
        .auth-header {
            background-color: var(--primary-color);
            color: white;
            padding: 20px;
            border-radius: 10px 10px 0 0;
            text-align: center;
        }
        
        .auth-body {
            padding: 20px;
        }
        
        .btn-primary {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
        }
        
        .btn-primary:hover {
            background-color: #4a49b8;
            border-color: #4a49b8;
        }
        
        .toggle-dark-mode {
            cursor: pointer;
            padding: 5px 10px;
            border-radius: 50px;
            background-color: transparent;
            border: 1px solid white;
            color: white;
            transition: all 0.3s ease;
        }
        
        .toggle-dark-mode:hover {
            background-color: rgba(255, 255, 255, 0.2);
        }
        
        .table th {
            background-color: var(--primary-color);
            color: white;
        }
        
        .dark-mode .table th {
            background-color: #4a49b8;
        }
        
        .dark-mode .table {
            color: var(--dark-text);
        }
        
        .dark-mode .table td {
            border-color: #444;
        }
        
        .entry-actions {
            white-space: nowrap;
        }
        
        .version-badge {
            font-size: 0.8rem;
            padding: 5px 10px;
            border-radius: 50px;
            display: inline-block;
        }
        
        /* Form styling */
        .form-label {
            font-weight: 600;
        }
        
        .dark-mode .form-control, .dark-mode .form-select {
            background-color: #333;
            border-color: #555;
            color: white;
        }
        
        .dark-mode .form-control:focus, .dark-mode .form-select:focus {
            background-color: #444;
            color: white;
        }
        
        .note-editor {
            margin-bottom: 20px;
        }
        
        .dark-mode .note-editor.note-frame {
            border-color: #555;
        }
        
        .dark-mode .note-editor .note-editing-area {
            background-color: #333;
            color: white;
        }
        
        /* Token display */
        .token-display {
            background-color: #f8f9fa;
            border: 1px solid #dee2e6;
            border-radius: 5px;
            padding: 10px 15px;
            font-family: monospace;
            font-size: 1.2rem;
            text-align: center;
            margin-bottom: 20px;
        }
        
        .dark-mode .token-display {
            background-color: #333;
            border-color: #555;
            color: white;
        }
        
        /* Badge colors */
        .bg-feature {
            background-color: #28a745;
        }
        
        .bg-improvement {
            background-color: #17a2b8;
        }
        
        .bg-bug-fix {
            background-color: #ffc107;
            color: #212529;
        }
        
        .bg-security {
            background-color: #dc3545;
        }
        
        @media (max-width: 768px) {
            .table-responsive {
                overflow-x: auto;
            }
            
            .entry-actions .btn {
                padding: 0.25rem 0.5rem;
                font-size: 0.875rem;
            }
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg fixed-top">
        <div class="container">
            <a class="navbar-brand" href="<?php echo SITE_URL; ?>/changelog/">
                <i class="fas fa-history"></i> VTU Platform Changelog
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <?php if ($authenticated): ?>
                    <li class="nav-item">
                        <a class="nav-link" href="<?php echo SITE_URL; ?>/changelog/">View Changelog</a>
                    </li>
                    <li class="nav-item">
                        <form method="post" class="d-inline">
                            <input type="hidden" name="action" value="logout">
                            <button type="submit" class="nav-link btn btn-link">Logout</button>
                        </form>
                    </li>
                    <?php endif; ?>
                    <li class="nav-item">
                        <button id="darkModeToggle" class="toggle-dark-mode">
                            <i class="fas fa-moon"></i>
                        </button>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <?php if (!$authenticated): ?>
    <!-- Authentication form -->
    <div class="container auth-container">
        <div class="auth-card">
            <div class="auth-header">
                <h2><i class="fas fa-lock"></i> Authentication Required</h2>
            </div>
            <div class="auth-body">
                <?php if (!empty($error_message)): ?>
                    <div class="alert alert-danger"><?php echo $error_message; ?></div>
                <?php endif; ?>
                
                <form method="post">
                    <div class="mb-3">
                        <label for="token" class="form-label">Enter 6-Digit Token</label>
                        <input type="password" class="form-control form-control-lg" id="token" name="token" placeholder="Enter token" required maxlength="6" pattern="\d{6}">
                        <div class="form-text">Enter the 6-digit token to access the changelog management system.</div>
                    </div>
                    <div class="d-grid">
                        <button type="submit" class="btn btn-primary btn-lg">Authenticate</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <?php else: ?>
    <!-- Admin panel (only visible when authenticated) -->
    <div class="container admin-container">
        <h1 class="mb-4"><i class="fas fa-history"></i> Changelog Management</h1>
        
        <?php if (!empty($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>
        
        <?php if (!empty($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>
        
        <!-- Current token display -->
        <div class="card mb-4">
            <div class="card-header bg-primary text-white">
                <h5 class="mb-0">Current Authentication Token</h5>
            </div>
            <div class="card-body">
                <div class="token-display"><?php echo $token; ?></div>
                <form method="post" class="d-grid gap-2">
                    <input type="hidden" name="action" value="generate_token">
                    <button type="submit" class="btn btn-warning">Generate New Token</button>
                    <div class="form-text text-center">Warning: This will invalidate the current token.</div>
                </form>
            </div>
        </div>
        
        <!-- Add new changelog entry form -->
        <div class="card mb-4">
            <div class="card-header bg-primary text-white">
                <h5 class="mb-0">Add New Changelog Entry</h5>
            </div>
            <div class="card-body">
                <form method="post" id="addEntryForm">
                    <input type="hidden" name="action" value="add">
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="version" class="form-label">Version Number</label>
                            <input type="text" class="form-control" id="version" name="version" placeholder="e.g., 1.0.1" required>
                        </div>
                        <div class="col-md-6">
                            <label for="type" class="form-label">Entry Type</label>
                            <select class="form-select" id="type" name="type" required>
                                <option value="" selected disabled>Select type...</option>
                                <option value="Feature">Feature</option>
                                <option value="Improvement">Improvement</option>
                                <option value="Bug Fix">Bug Fix</option>
                                <option value="Security">Security</option>
                                <option value="Other">Other</option>
                            </select>
                        </div>
                    </div>
                    
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="release_date" class="form-label">Release Date</label>
                            <input type="date" class="form-control" id="release_date" name="release_date" value="<?php echo date('Y-m-d'); ?>" required>
                        </div>
                        <div class="col-md-6">
                            <label for="title" class="form-label">Title</label>
                            <input type="text" class="form-control" id="title" name="title" placeholder="Brief title for this release" required>
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">Description</label>
                        <textarea class="form-control summernote" id="description" name="description" rows="5" placeholder="Detailed changelog information" required></textarea>
                        <div class="form-text">Use bullet points for listing individual changes.</div>
                    </div>
                    
                    <div class="d-grid">
                        <button type="submit" class="btn btn-primary">Add Changelog Entry</button>
                    </div>
                </form>
            </div>
        </div>
        
        <!-- Existing changelog entries -->
        <div class="card">
            <div class="card-header bg-primary text-white">
                <h5 class="mb-0">Existing Changelog Entries</h5>
            </div>
            <div class="card-body">
                <?php if (empty($changelog_entries)): ?>
                    <div class="alert alert-info">No changelog entries available yet.</div>
                <?php else: ?>
                    <div class="table-responsive">
                        <table class="table table-striped">
                            <thead>
                                <tr>
                                    <th>Version</th>
                                    <th>Type</th>
                                    <th>Title</th>
                                    <th>Release Date</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($changelog_entries as $entry): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($entry['version']); ?></td>
                                        <td>
                                            <span class="badge version-badge bg-<?php echo strtolower(str_replace(' ', '-', $entry['type'])); ?>">
                                                <?php echo htmlspecialchars($entry['type']); ?>
                                            </span>
                                        </td>
                                        <td><?php echo htmlspecialchars($entry['title']); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($entry['release_date'])); ?></td>
                                        <td class="entry-actions">
                                            <button type="button" class="btn btn-sm btn-primary edit-entry" 
                                                    data-id="<?php echo $entry['id']; ?>"
                                                    data-version="<?php echo htmlspecialchars($entry['version']); ?>"
                                                    data-title="<?php echo htmlspecialchars($entry['title']); ?>"
                                                    data-type="<?php echo htmlspecialchars($entry['type']); ?>"
                                                    data-release-date="<?php echo date('Y-m-d', strtotime($entry['release_date'])); ?>"
                                                    data-description="<?php echo htmlspecialchars($entry['description']); ?>">
                                                <i class="fas fa-edit"></i> Edit
                                            </button>
                                            <button type="button" class="btn btn-sm btn-danger delete-entry" 
                                                    data-id="<?php echo $entry['id']; ?>"
                                                    data-version="<?php echo htmlspecialchars($entry['version']); ?>">
                                                <i class="fas fa-trash"></i> Delete
                                            </button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <!-- Edit Entry Modal -->
    <div class="modal fade" id="editEntryModal" tabindex="-1" aria-labelledby="editEntryModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header bg-primary text-white">
                    <h5 class="modal-title" id="editEntryModalLabel">Edit Changelog Entry</h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form method="post" id="editEntryForm">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="id" id="edit_id">
                        
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="edit_version" class="form-label">Version Number</label>
                                <input type="text" class="form-control" id="edit_version" name="version" required>
                            </div>
                            <div class="col-md-6">
                                <label for="edit_type" class="form-label">Entry Type</label>
                                <select class="form-select" id="edit_type" name="type" required>
                                    <option value="Feature">Feature</option>
                                    <option value="Improvement">Improvement</option>
                                    <option value="Bug Fix">Bug Fix</option>
                                    <option value="Security">Security</option>
                                    <option value="Other">Other</option>
                                </select>
                            </div>
                        </div>
                        
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="edit_release_date" class="form-label">Release Date</label>
                                <input type="date" class="form-control" id="edit_release_date" name="release_date" required>
                            </div>
                            <div class="col-md-6">
                                <label for="edit_title" class="form-label">Title</label>
                                <input type="text" class="form-control" id="edit_title" name="title" required>
                            </div>
                        </div>
                        
                        <div class="mb-3">
                            <label for="edit_description" class="form-label">Description</label>
                            <textarea class="form-control summernote" id="edit_description" name="description" rows="5" required></textarea>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="button" class="btn btn-primary" id="saveEditBtn">Save Changes</button>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Delete Confirmation Modal -->
    <div class="modal fade" id="deleteEntryModal" tabindex="-1" aria-labelledby="deleteEntryModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header bg-danger text-white">
                    <h5 class="modal-title" id="deleteEntryModalLabel">Confirm Deletion</h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>Are you sure you want to delete the changelog entry for version <strong id="delete_version"></strong>?</p>
                    <p class="text-danger">This action cannot be undone!</p>
                    <form method="post" id="deleteEntryForm">
                        <input type="hidden" name="action" value="delete">
                        <input type="hidden" name="id" id="delete_id">
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="button" class="btn btn-danger" id="confirmDeleteBtn">Delete</button>
                </div>
            </div>
        </div>
    </div>
    <?php endif; ?>

    <!-- jQuery (required for Bootstrap and Summernote) -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    
    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    
    <!-- Summernote JS -->
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-bs4.min.js"></script>
    
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Dark mode toggle
            const darkModeToggle = document.getElementById('darkModeToggle');
            const body = document.body;
            
            // Check user preference
            if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
                body.classList.add('dark-mode');
                darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
            }
            
            // Toggle dark mode
            darkModeToggle.addEventListener('click', function() {
                body.classList.toggle('dark-mode');
                if (body.classList.contains('dark-mode')) {
                    darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
                } else {
                    darkModeToggle.innerHTML = '<i class="fas fa-moon"></i>';
                }
            });
            
            // Listen for OS theme changes
            window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
                if (event.matches) {
                    body.classList.add('dark-mode');
                    darkModeToggle.innerHTML = '<i class="fas fa-sun"></i>';
                } else {
                    body.classList.remove('dark-mode');
                    darkModeToggle.innerHTML = '<i class="fas fa-moon"></i>';
                }
            });
            
            <?php if ($authenticated): ?>
            // Initialize Summernote WYSIWYG editor
            $('.summernote').summernote({
                height: 200,
                toolbar: [
                    ['style', ['style']],
                    ['font', ['bold', 'underline', 'clear']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['table', ['table']],
                    ['insert', ['link']],
                    ['view', ['fullscreen', 'codeview', 'help']]
                ]
            });
            
            // Edit entry
            document.querySelectorAll('.edit-entry').forEach(button => {
                button.addEventListener('click', function() {
                    const id = this.getAttribute('data-id');
                    const version = this.getAttribute('data-version');
                    const title = this.getAttribute('data-title');
                    const type = this.getAttribute('data-type');
                    const releaseDate = this.getAttribute('data-release-date');
                    const description = this.getAttribute('data-description');
                    
                    document.getElementById('edit_id').value = id;
                    document.getElementById('edit_version').value = version;
                    document.getElementById('edit_title').value = title;
                    document.getElementById('edit_type').value = type;
                    document.getElementById('edit_release_date').value = releaseDate;
                    
                    // Set content to Summernote editor
                    $('#edit_description').summernote('code', description);
                    
                    // Show the modal
                    const editModal = new bootstrap.Modal(document.getElementById('editEntryModal'));
                    editModal.show();
                });
            });
            
            // Save edit
            document.getElementById('saveEditBtn').addEventListener('click', function() {
                document.getElementById('editEntryForm').submit();
            });
            
            // Delete entry
            document.querySelectorAll('.delete-entry').forEach(button => {
                button.addEventListener('click', function() {
                    const id = this.getAttribute('data-id');
                    const version = this.getAttribute('data-version');
                    
                    document.getElementById('delete_id').value = id;
                    document.getElementById('delete_version').textContent = version;
                    
                    // Show the modal
                    const deleteModal = new bootstrap.Modal(document.getElementById('deleteEntryModal'));
                    deleteModal.show();
                });
            });
            
            // Confirm delete
            document.getElementById('confirmDeleteBtn').addEventListener('click', function() {
                document.getElementById('deleteEntryForm').submit();
            });
            <?php endif; ?>
        });
    </script>
</body>
</html>