<?php
// File: cron/calculate_achievements.php
require_once __DIR__ . '/../includes/config.php';
require_once __DIR__ . '/../includes/functions.php';

// Set up basic error handling for cron environment
ini_set('display_errors', 0);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/achievement_errors.log');

// Create a lock file to prevent multiple instances from running simultaneously
$lockFile = __DIR__ . '/achievement_cron.lock';
if (file_exists($lockFile)) {
    $lockTime = filemtime($lockFile);
    // If lock is older than 1 hour, it may be from a failed run
    if (time() - $lockTime < 3600) {
        logMessage("Another instance is already running. Exiting.");
        exit;
    } else {
        logMessage("Found stale lock file. Removing and continuing.");
        unlink($lockFile);
    }
}
// Create lock file
file_put_contents($lockFile, time());

try {
    // Set resource limits - these may be overridden by hosting provider
    set_time_limit(1800); // 30 minutes
    ini_set('memory_limit', '256M');
    
    // Get database connection
    $db = getDB();
    $conn = $db->getConnection();
    
    // Log the start of the process
    logMessage("Achievement calculation started at " . date('Y-m-d H:i:s'));
    
    // Process in smaller batches to avoid memory issues
    processAchievements($conn);
    
    logMessage("Achievement processing completed at " . date('Y-m-d H:i:s'));
} catch (Exception $e) {
    logMessage("ERROR: " . $e->getMessage());
} finally {
    // Always remove lock file when done
    if (file_exists($lockFile)) {
        unlink($lockFile);
    }
}

// Process achievements in batches
function processAchievements($conn) {
    // Get all active achievements
    $stmt = $conn->prepare("SELECT * FROM achievements WHERE is_active = 1");
    $stmt->execute();
    $result = $stmt->get_result();
    $achievements = [];
    
    while ($row = $result->fetch_assoc()) {
        $achievements[] = $row;
    }
    
    // Process each achievement
    foreach ($achievements as $achievement) {
        logMessage("Processing achievement: " . $achievement['title']);
        
        // Different handling based on requirement type
        switch ($achievement['requirement_type']) {
            case 'transaction_count':
                processTransactionCount($conn, $achievement);
                break;
            case 'airtime_purchase':
                processAirtimePurchase($conn, $achievement);
                break;
            case 'data_purchase':
                processDataPurchase($conn, $achievement);
                break;
            case 'wallet_balance':
                processWalletBalance($conn, $achievement);
                break;
            case 'funding_total':
                processFundingTotal($conn, $achievement);
                break;
            case 'specific_plan':
                processSpecificPlan($conn, $achievement);
                break;
            case 'consecutive_days':
                processConsecutiveDays($conn, $achievement);
                break;
        }
        
        // Small pause to be nice to shared hosting
        usleep(50000); // 0.05 seconds
    }
}

// Helper function to log messages
function logMessage($message) {
    echo $message . "\n";
    // Write to a log file for cron job tracking
    file_put_contents(__DIR__ . '/achievement_log.txt', date('Y-m-d H:i:s') . ": " . $message . "\n", FILE_APPEND);
}

// Function to process transaction count achievements
function processTransactionCount($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    $period = $achievement['requirement_period'];
    
    // Build date constraint based on period
    $dateConstraint = getDateConstraint($period);
    
    // Get all users who are tracking this achievement and have transactions in the period
    $query = "
        SELECT u.id AS user_id, COUNT(t.id) AS transaction_count
        FROM users u
        JOIN transactions t ON u.id = t.user_id
        INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
        WHERE t.status = 'successful'
        {$dateConstraint}
        AND t.created_at >= ua.tracking_started_at
        GROUP BY u.id
        HAVING COUNT(t.id) > 0
    ";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $achievement['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    while ($row = $result->fetch_assoc()) {
        $userId = $row['user_id'];
        $progress = $row['transaction_count'];
        $isCompleted = $progress >= $requirementValue ? 1 : 0;
        
        updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
        $processed++;
    }
    
    logMessage("Processed transaction count for {$processed} users");
}

// Function to process airtime purchase achievements
function processAirtimePurchase($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    $period = $achievement['requirement_period'];
    
    if ($period === 'single') {
        // For single transaction, find users who made at least one purchase of the required amount since starting tracking
        $query = "
            SELECT u.id AS user_id, MAX(t.amount) AS max_amount
            FROM users u
            JOIN transactions t ON u.id = t.user_id
            INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
            WHERE t.type = 'airtime' AND t.status = 'successful'
            AND t.created_at >= ua.tracking_started_at
            GROUP BY u.id
            HAVING MAX(t.amount) >= ?
        ";
        
        $stmt = $conn->prepare($query);
        $stmt->bind_param("id", $achievement['id'], $requirementValue);
        $stmt->execute();
        $result = $stmt->get_result();
        
        $processed = 0;
        while ($row = $result->fetch_assoc()) {
            $userId = $row['user_id'];
            $progress = $row['max_amount'];
            
            updateUserAchievement($conn, $userId, $achievement['id'], $progress, 1);
            $processed++;
        }
        
        logMessage("Processed single airtime purchase for {$processed} users");
    } else {
        // For period-based, sum the amounts
        $dateConstraint = getDateConstraint($period);
        
        $query = "
            SELECT u.id AS user_id, SUM(t.amount) AS total_amount
            FROM users u
            JOIN transactions t ON u.id = t.user_id
            INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
            WHERE t.type = 'airtime' AND t.status = 'successful'
            {$dateConstraint}
            AND t.created_at >= ua.tracking_started_at
            GROUP BY u.id
            HAVING SUM(t.amount) > 0
        ";
        
        $stmt = $conn->prepare($query);
        $stmt->bind_param("i", $achievement['id']);
        $stmt->execute();
        $result = $stmt->get_result();
        
        $processed = 0;
        while ($row = $result->fetch_assoc()) {
            $userId = $row['user_id'];
            $progress = $row['total_amount'];
            $isCompleted = $progress >= $requirementValue ? 1 : 0;
            
            updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
            $processed++;
        }
        
        logMessage("Processed period airtime purchase for {$processed} users");
    }
}

// Function to process data purchase achievements
function processDataPurchase($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    $period = $achievement['requirement_period'];
    
    // Build date constraint based on period
    $dateConstraint = getDateConstraint($period);
    
    // Get all users who are tracking this achievement and have data purchases in the period
    $query = "
        SELECT u.id AS user_id, COUNT(t.id) AS purchase_count
        FROM users u
        JOIN transactions t ON u.id = t.user_id
        INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
        WHERE t.type = 'data' AND t.status = 'successful'
        {$dateConstraint}
        AND t.created_at >= ua.tracking_started_at
        GROUP BY u.id
        HAVING COUNT(t.id) > 0
    ";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $achievement['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    while ($row = $result->fetch_assoc()) {
        $userId = $row['user_id'];
        $progress = $row['purchase_count'];
        $isCompleted = $progress >= $requirementValue ? 1 : 0;
        
        updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
        $processed++;
    }
    
    logMessage("Processed data purchase for {$processed} users");
}

// Function to process wallet balance achievements
function processWalletBalance($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    
    // Get all users who are tracking this achievement and have sufficient balance
    $query = "
        SELECT u.id AS user_id, u.balance
        FROM users u
        INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
        WHERE u.balance > 0
    ";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $achievement['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    while ($row = $result->fetch_assoc()) {
        $userId = $row['user_id'];
        $progress = $row['balance'];
        $isCompleted = $progress >= $requirementValue ? 1 : 0;
        
        updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
        $processed++;
    }
    
    logMessage("Processed wallet balance for {$processed} users");
}

// Function to process funding total achievements
function processFundingTotal($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    $period = $achievement['requirement_period'];
    
    // Build date constraint based on period
    $dateConstraint = getDateConstraint($period);
    
    // Get all users who are tracking this achievement and have funding in the period
    $query = "
        SELECT u.id AS user_id, SUM(t.amount) AS total_funding
        FROM users u
        JOIN transactions t ON u.id = t.user_id
        INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
        WHERE t.type = 'funding' AND t.status = 'successful'
        {$dateConstraint}
        AND t.created_at >= ua.tracking_started_at
        GROUP BY u.id
        HAVING SUM(t.amount) > 0
    ";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $achievement['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    while ($row = $result->fetch_assoc()) {
        $userId = $row['user_id'];
        $progress = $row['total_funding'];
        $isCompleted = $progress >= $requirementValue ? 1 : 0;
        
        updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
        $processed++;
    }
    
    logMessage("Processed funding total for {$processed} users");
}

// Function to process specific plan achievements
function processSpecificPlan($conn, $achievement) {
    $requirementValue = $achievement['requirement_value'];
    $period = $achievement['requirement_period'];
    $requirementDetails = json_decode($achievement['requirement_details'], true);
    
    $planId = $requirementDetails['plan_id'] ?? 0;
    $dataTypeId = $requirementDetails['data_type_id'] ?? null;
    
    if ($planId <= 0) {
        logMessage("Error: No plan ID specified for specific plan achievement");
        return;
    }
    
    // Build date constraint based on period
    $dateConstraint = getDateConstraint($period);
    
    // For older MySQL versions that might not support JSON_EXTRACT, use fallback approach
    // Check if we can use JSON functions
    $jsonSupported = true;
    try {
        $testQuery = "SELECT JSON_EXTRACT('{\"test\":1}', '$.test') as test";
        $conn->query($testQuery);
    } catch (Exception $e) {
        $jsonSupported = false;
        logMessage("JSON functions not supported by database. Using fallback approach.");
    }
    
    if ($jsonSupported) {
        // Use JSON_EXTRACT if supported
        $query = "
            SELECT u.id AS user_id, COUNT(t.id) AS purchase_count
            FROM users u
            JOIN transactions t ON u.id = t.user_id
            INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
            WHERE t.type = 'data' AND t.status = 'successful'
            AND JSON_EXTRACT(t.metadata, '$.plan_id') = ?
            {$dateConstraint}
            AND t.created_at >= ua.tracking_started_at
        ";
        
        if ($dataTypeId) {
            $query .= " AND JSON_EXTRACT(t.metadata, '$.data_type_id') = " . intval($dataTypeId);
        }
    } else {
        // Fallback using LIKE if JSON functions not supported
        $query = "
            SELECT u.id AS user_id, COUNT(t.id) AS purchase_count
            FROM users u
            JOIN transactions t ON u.id = t.user_id
            INNER JOIN user_achievements ua ON u.id = ua.user_id AND ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
            WHERE t.type = 'data' AND t.status = 'successful'
            AND t.metadata LIKE '%\"plan_id\":$planId%'
            {$dateConstraint}
            AND t.created_at >= ua.tracking_started_at
        ";
        
        if ($dataTypeId) {
            $query .= " AND t.metadata LIKE '%\"data_type_id\":$dataTypeId%'";
        }
    }
    
    $query .= " GROUP BY u.id HAVING COUNT(t.id) > 0";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("ii", $achievement['id'], $planId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    while ($row = $result->fetch_assoc()) {
        $userId = $row['user_id'];
        $progress = $row['purchase_count'];
        $isCompleted = $progress >= $requirementValue ? 1 : 0;
        
        updateUserAchievement($conn, $userId, $achievement['id'], $progress, $isCompleted);
        $processed++;
    }
    
    logMessage("Processed specific plan for {$processed} users");
}

// Function to process consecutive days achievements
function processConsecutiveDays($conn, $achievement) {
    $requirementDetails = json_decode($achievement['requirement_details'], true);
    $consecutiveDays = $requirementDetails['consecutive_days'] ?? 5;
    $minTransactions = $requirementDetails['min_transactions'] ?? 1;
    
    // Get all users who are tracking this achievement
    $query = "
        SELECT u.id, ua.tracking_started_at
        FROM users u
        INNER JOIN user_achievements ua ON u.id = ua.user_id 
        WHERE ua.achievement_id = ? AND ua.is_tracking = 1 AND ua.is_completed = 0
    ";
    
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $achievement['id']);
    $stmt->execute();
    $result = $stmt->get_result();
    
    $processed = 0;
    $batchSize = 25; // Process in small batches to avoid memory issues
    
    while ($row = $result->fetch_assoc()) {
        $userId = $row['id'];
        $trackingStartedAt = $row['tracking_started_at'];
        
        // Get the last 60 days of transactions since tracking started, grouped by date
        $query = "
            SELECT DATE(created_at) AS transaction_date, COUNT(*) AS transactions_count
            FROM transactions
            WHERE user_id = ? AND status = 'successful'
            AND created_at >= ?
            AND created_at >= DATE_SUB(NOW(), INTERVAL 60 DAY)
            GROUP BY DATE(created_at)
            ORDER BY transaction_date DESC
        ";
        
        $stmt2 = $conn->prepare($query);
        $stmt2->bind_param("is", $userId, $trackingStartedAt);
        $stmt2->execute();
        $result2 = $stmt2->get_result();
        
        $days = [];
        while ($row2 = $result2->fetch_assoc()) {
            if ($row2['transactions_count'] >= $minTransactions) {
                $days[] = $row2['transaction_date'];
            }
        }
        
        // Calculate max consecutive days
        $maxConsecutive = calculateConsecutiveDays($days);
        $isCompleted = $maxConsecutive >= $consecutiveDays ? 1 : 0;
        
        // Save progress details as JSON
        $progressData = json_encode([
            'consecutive_days' => $maxConsecutive,
            'required_days' => $consecutiveDays,
            'min_transactions' => $minTransactions
        ]);
        
        updateUserAchievement($conn, $userId, $achievement['id'], $maxConsecutive, $isCompleted, $progressData);
        
        $processed++;
        
        // Add small pause after each batch to be nice to shared hosting
        if ($processed % $batchSize === 0) {
            logMessage("Processed consecutive days for {$processed} users so far...");
            usleep(50000); // 0.05 seconds
        }
    }
    
    logMessage("Processed consecutive days for {$processed} users total");
}

// Helper function to calculate consecutive days
function calculateConsecutiveDays($days) {
    if (empty($days)) {
        return 0;
    }
    
    $days = array_map(function($day) {
        return strtotime($day);
    }, $days);
    sort($days);
    
    $maxConsecutive = 1;
    $currentConsecutive = 1;
    
    for ($i = 1; $i < count($days); $i++) {
        // Check if days are consecutive (86400 seconds = 1 day)
        if ($days[$i] - $days[$i-1] == 86400) {
            $currentConsecutive++;
            $maxConsecutive = max($maxConsecutive, $currentConsecutive);
        } else if ($days[$i] - $days[$i-1] > 86400) {
            // Reset consecutive count if gap is more than a day
            $currentConsecutive = 1;
        }
    }
    
    return $maxConsecutive;
}

// Helper function to get date constraint for SQL query
function getDateConstraint($period) {
    switch ($period) {
        case 'day':
            return " AND t.created_at >= DATE_SUB(NOW(), INTERVAL 1 DAY)";
        case 'week':
            return " AND t.created_at >= DATE_SUB(NOW(), INTERVAL 7 DAY)";
        case 'month':
            return " AND t.created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)";
        case 'year':
            return " AND t.created_at >= DATE_SUB(NOW(), INTERVAL 365 DAY)";
        case 'all_time':
        default:
            return "";
    }
}

// Helper function to update user achievement progress
function updateUserAchievement($conn, $userId, $achievementId, $progress, $isCompleted, $progressData = null) {
    // Check if user already has a record for this achievement
    $stmt = $conn->prepare("
        SELECT id, progress, is_completed, completed_at, last_reward_at, last_calculated_at
        FROM user_achievements
        WHERE user_id = ? AND achievement_id = ?
    ");
    $stmt->bind_param("ii", $userId, $achievementId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        // This shouldn't happen with the new system as records are created when users click "Go"
        logMessage("Warning: No achievement record found for user $userId and achievement $achievementId");
        return;
    } else {
        // Record exists, update it
        $record = $result->fetch_assoc();
        
        // Only update if progress has changed or achievement is newly completed
        if ($record['progress'] != $progress || ($isCompleted && !$record['is_completed'])) {
            $stmt = $conn->prepare("
                UPDATE user_achievements
                SET progress = ?,
                    progress_data = ?,
                    is_completed = ?,
                    completed_at = ?,
                    last_calculated_at = NOW()
                WHERE user_id = ? AND achievement_id = ?
            ");
            
            $completedAt = null;
            
            // If newly completed, set completed_at to now
            if ($isCompleted && !$record['is_completed']) {
                $completedAt = date('Y-m-d H:i:s');
                
                // Create notification for newly completed achievement
                createAchievementNotification($conn, $userId, $achievementId);
            } else if ($record['completed_at']) {
                // Keep the original completion date if already completed
                $completedAt = $record['completed_at'];
            }
            
            $stmt->bind_param("dssisi", $progress, $progressData, $isCompleted, $completedAt, $userId, $achievementId);
            $stmt->execute();
            
            // Log significant progress updates
            if ($isCompleted && !$record['is_completed']) {
                logMessage("User $userId completed achievement $achievementId!");
            }
        }
    }
}

// Helper function to create achievement completion notification
function createAchievementNotification($conn, $userId, $achievementId) {
    // Get achievement details
    $stmt = $conn->prepare("SELECT title FROM achievements WHERE id = ?");
    $stmt->bind_param("i", $achievementId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $achievement = $result->fetch_assoc();
        $title = "Achievement Completed!";
        $message = "Congratulations! You've completed the achievement: " . $achievement['title'] . ". Visit your achievements page to claim your reward.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications
            (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $stmt->bind_param("iss", $userId, $title, $message);
        $stmt->execute();
    }
}
?>