<?php
// File: cron/process_referrals.php
require_once __DIR__ . '/../includes/config.php';
require_once __DIR__ . '/../includes/functions.php';

// This file should be run via a cron job daily

// Set execution time limit to avoid timeouts
set_time_limit(0);

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Log function
function logMessage($message) {
    echo date('Y-m-d H:i:s') . " - " . $message . "\n";
    file_put_contents(__DIR__ . '/referral_log.txt', date('Y-m-d H:i:s') . " - " . $message . "\n", FILE_APPEND);
}

logMessage("Starting referral processing");

// Process referrals - update transaction counts and total spend
try {
    // Begin transaction
    $conn->begin_transaction();
    
    // Get all pending referrals
    $stmt = $conn->prepare("
        SELECT r.id, r.referrer_id, r.referred_id, r.status, r.requirements_met, 
               r.transaction_count, r.total_spend
        FROM referrals r
        WHERE r.status = 'pending'
    ");
    $stmt->execute();
    $result = $stmt->get_result();
    $referrals = [];
    
    while ($row = $result->fetch_assoc()) {
        $referrals[] = $row;
    }
    
    logMessage("Found " . count($referrals) . " pending referrals to process");
    
    // Process each referral
    foreach ($referrals as $referral) {
        $referralId = $referral['id'];
        $referrerId = $referral['referrer_id'];
        $referredId = $referral['referred_id'];
        
        // Calculate total successful transactions
        $stmt = $conn->prepare("
            SELECT COUNT(*) as transaction_count, SUM(amount + fee) as total_spend
            FROM transactions
            WHERE user_id = ? AND status = 'successful'
        ");
        $stmt->bind_param("i", $referredId);
        $stmt->execute();
        $result = $stmt->get_result();
        $stats = $result->fetch_assoc();
        
        $transactionCount = $stats['transaction_count'] ?? 0;
        $totalSpend = $stats['total_spend'] ?? 0;
        
        // Update referral with latest stats
        $stmt = $conn->prepare("
            UPDATE referrals
            SET transaction_count = ?,
                total_spend = ?
            WHERE id = ?
        ");
        $stmt->bind_param("idi", $transactionCount, $totalSpend, $referralId);
        $stmt->execute();
        
        // Check if referral meets requirements
        $meetsTransactionRequirement = $transactionCount >= 30;
        $meetsSpendRequirement = $totalSpend >= 5000;
        
        if ($meetsTransactionRequirement || $meetsSpendRequirement) {
            // Mark as qualified and notify referrer
            $stmt = $conn->prepare("
                UPDATE referrals
                SET status = 'qualified',
                    requirements_met = 1,
                    qualified_at = NOW()
                WHERE id = ?
            ");
            $stmt->bind_param("i", $referralId);
            $stmt->execute();
            
            // Get referred user info
            $stmt = $conn->prepare("SELECT username FROM users WHERE id = ?");
            $stmt->bind_param("i", $referredId);
            $stmt->execute();
            $result = $stmt->get_result();
            $referredUser = $result->fetch_assoc();
            
            // Create notification for referrer
            $notifyTitle = "Referral Qualified";
            $notifyMessage = "Your referral " . $referredUser['username'] . " has met the requirements. You can now claim your reward!";
            
            $stmt = $conn->prepare("
                INSERT INTO notifications
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'success', 0)
            ");
            $stmt->bind_param("iss", $referrerId, $notifyTitle, $notifyMessage);
            $stmt->execute();
            
            logMessage("Referral ID $referralId qualified (transactions: $transactionCount, spend: $totalSpend)");
        } else {
            logMessage("Referral ID $referralId not yet qualified (transactions: $transactionCount, spend: $totalSpend)");
        }
    }
    
    // Process elimination contests if needed
    $today = date('Y-m-d');
    
    // Find active elimination contests that need processing
    $stmt = $conn->prepare("
        SELECT c.*, (
            SELECT MAX(el.elimination_date) 
            FROM contest_elimination_logs el 
            WHERE el.contest_id = c.id
        ) as last_elimination
        FROM referral_contests c
        WHERE c.is_active = 1
        AND c.is_elimination = 1
        AND c.start_date <= NOW()
        AND c.end_date >= NOW()
    ");
    $stmt->execute();
    $result = $stmt->get_result();
    $eliminationContests = [];
    
    while ($row = $result->fetch_assoc()) {
        $eliminationContests[] = $row;
    }
    
    logMessage("Found " . count($eliminationContests) . " active elimination contests");
    
    foreach ($eliminationContests as $contest) {
        $contestId = $contest['id'];
        $frequency = $contest['elimination_frequency'];
        $threshold = $contest['elimination_threshold'];
        $lastElimination = $contest['last_elimination'];
        
        $shouldEliminate = false;
        
        // Check if elimination is due
        if (!$lastElimination) {
            // First elimination
            $shouldEliminate = true;
        } else {
            if ($frequency === 'daily') {
                // Check if last elimination was not today
                $shouldEliminate = date('Y-m-d', strtotime($lastElimination)) !== $today;
            } else if ($frequency === 'weekly') {
                // Check if it's been at least 7 days since last elimination
                $daysSinceLastElimination = (strtotime($today) - strtotime($lastElimination)) / (60 * 60 * 24);
                $shouldEliminate = $daysSinceLastElimination >= 7;
            }
        }
        
        if ($shouldEliminate) {
            logMessage("Running elimination for contest ID $contestId ($frequency)");
            
            // Find entries to eliminate
            $stmt = $conn->prepare("
                SELECT ce.id, ce.user_id, ce.referral_count, u.username
                FROM contest_entries ce
                JOIN users u ON ce.user_id = u.id
                WHERE ce.contest_id = ? 
                AND ce.is_disqualified = 0
                ORDER BY (ce.referral_count + ce.manual_adjustment) ASC, ce.created_at DESC
            ");
            $stmt->bind_param("i", $contestId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            $entries = [];
            while ($row = $result->fetch_assoc()) {
                $entries[] = $row;
            }
            
            // Calculate how many to eliminate
            $totalEntries = count($entries);
            $toEliminate = min($threshold, $totalEntries);
            $eliminatedCount = 0;
            
            if ($toEliminate > 0) {
                // Eliminate bottom entries
                for ($i = 0; $i < $toEliminate; $i++) {
                    $entry = $entries[$i];
                    
                    $stmt = $conn->prepare("
                        UPDATE contest_entries
                        SET is_disqualified = 1,
                            disqualification_reason = ?
                        WHERE id = ?
                    ");
                    $reason = "Automatically eliminated in contest on " . date('M d, Y') . " (" . ucfirst($frequency) . " elimination round)";
                    $stmt->bind_param("si", $reason, $entry['id']);
                    $stmt->execute();
                    
                    // Create notification for user
                    $userId = $entry['user_id'];
                    $notifyTitle = "Contest Elimination";
                    $notifyMessage = "You have been eliminated from the contest: " . $contest['title'] . ". Your final position: " . ($totalEntries - $i) . "/" . $totalEntries . ".";
                    
                    $stmt = $conn->prepare("
                        INSERT INTO notifications
                        (user_id, title, message, type, is_read)
                        VALUES (?, ?, ?, 'warning', 0)
                    ");
                    $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
                    $stmt->execute();
                    
                    $eliminatedCount++;
                    logMessage("Eliminated user ID {$entry['user_id']} ({$entry['username']}) from contest ID $contestId");
                }
                
                // Create elimination log
                $stmt = $conn->prepare("
                    INSERT INTO contest_elimination_logs
                    (contest_id, elimination_date, elimination_threshold, users_eliminated)
                    VALUES (?, NOW(), ?, ?)
                ");
                $stmt->bind_param("iii", $contestId, $threshold, $eliminatedCount);
                $stmt->execute();
                
                logMessage("Eliminated $eliminatedCount users from contest ID $contestId");
            } else {
                logMessage("No participants to eliminate for contest ID $contestId");
            }
        }
    }
    
    // Commit all changes
    $conn->commit();
    logMessage("All referrals and contests processed successfully");
    
} catch (Exception $e) {
    // Rollback on error
    $conn->rollback();
    logMessage("Error: " . $e->getMessage());
}
?>