<?php
// File: /dashboard/ajax/validate_promo.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'You must be logged in']);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get input
$promoCode = isset($_POST['promo_code']) ? sanitizeInput($_POST['promo_code']) : '';
$amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
$serviceType = isset($_POST['service_type']) ? sanitizeInput($_POST['service_type']) : '';

// Important: We only validate here but do NOT increment the usage counter
// The increment will happen in the process files after successful purchase

if (empty($promoCode) || $amount <= 0) {
    echo json_encode(['success' => false, 'message' => 'Invalid parameters']);
    exit;
}

// Get current date in MySQL format
$currentDate = date('Y-m-d H:i:s');

// Query for promo code
$stmt = $conn->prepare("
    SELECT * FROM promo_codes 
    WHERE code = ? 
    AND status = 'active' 
    AND (expiry_date IS NULL OR expiry_date >= ?) 
    AND (max_uses = 0 OR current_uses < max_uses)
");
$stmt->bind_param("ss", $promoCode, $currentDate);
$stmt->execute();
$result = $stmt->get_result();
$promo = $result->fetch_assoc();

if (!$promo) {
    echo json_encode(['success' => false, 'message' => 'Invalid or expired promo code']);
    exit;
}

// Get user's registration date to check if they qualify as a new or existing user
$stmt = $conn->prepare("SELECT created_at FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$userData = $result->fetch_assoc();
$userCreatedAt = $userData['created_at'] ?? '';

// Check if promo is restricted to new or existing users
$userType = isset($promo['user_type']) ? $promo['user_type'] : 'all';
$promoCreatedAt = $promo['created_at'] ?? '';

if ($userType == 'new' && $userCreatedAt && $promoCreatedAt && strtotime($userCreatedAt) < strtotime($promoCreatedAt)) {
    echo json_encode(['success' => false, 'message' => 'This promo code is only valid for new users']);
    exit;
}

if ($userType == 'existing' && $userCreatedAt && $promoCreatedAt && strtotime($userCreatedAt) > strtotime($promoCreatedAt)) {
    echo json_encode(['success' => false, 'message' => 'This promo code is only valid for existing users']);
    exit;
}

// Check if user has already used this promo code (if not unlimited)
if ($promo['max_uses_per_user'] > 0) {
    $stmt = $conn->prepare("
        SELECT COUNT(*) as used_count 
        FROM promo_code_usage 
        WHERE promo_code_id = ? AND user_id = ?
    ");
    $promoId = $promo['id'];
    $stmt->bind_param("ii", $promoId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $usageData = $result->fetch_assoc();
    
    if ($usageData && $usageData['used_count'] >= $promo['max_uses_per_user']) {
        echo json_encode(['success' => false, 'message' => 'You have already used this promo code the maximum number of times']);
        exit;
    }
}

// Check if service type matches with applicable services
$applicableServices = json_decode($promo['applicable_services'], true);
if (!empty($applicableServices) && !in_array($serviceType, $applicableServices) && !in_array('all', $applicableServices)) {
    echo json_encode(['success' => false, 'message' => 'This promo code is not valid for this service']);
    exit;
}

// Check minimum order amount
$minOrderAmount = isset($promo['min_amount']) ? floatval($promo['min_amount']) : 0;
if ($amount < $minOrderAmount) {
    echo json_encode([
        'success' => false, 
        'message' => "Minimum amount for this promo code is " . formatAmount($minOrderAmount)
    ]);
    exit;
}

// Calculate discount
$discount = 0;
$discountType = isset($promo['type']) ? $promo['type'] : 'fixed';
$discountValue = isset($promo['discount']) ? floatval($promo['discount']) : 0;

if ($discountType == 'percentage') {
    $discount = ($amount * $discountValue) / 100;
    
    // Apply max discount if set
    if (isset($promo['max_amount']) && $promo['max_amount'] > 0 && $discount > $promo['max_amount']) {
        $discount = $promo['max_amount'];
    }
} else {
    // Fixed amount discount
    $discount = $discountValue;
}

// Return success with discount info and promo ID
echo json_encode([
    'success' => true,
    'message' => 'Promo code applied successfully',
    'promo_id' => $promo['id'],
    'discount' => $discount,
    'final_amount' => $amount - $discount,
    'discount_type' => $discountType,
    'discount_value' => $discountValue,
    'formatted_discount' => formatAmount($discount),
    'formatted_final' => formatAmount($amount - $discount)
]);

?>