<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/api/APIManager.php';

// Check if user is logged in
if (!isLoggedIn()) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized access'
    ]);
    exit;
}

// Get post data
$providerId = isset($_POST['provider_id']) ? (int)$_POST['provider_id'] : 0;
$smartCard = isset($_POST['smart_card']) ? sanitizeInput($_POST['smart_card']) : '';

if (empty($providerId)) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Provider ID is required'
    ]);
    exit;
}

if (empty($smartCard)) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Smart Card/IUC number is required'
    ]);
    exit;
}

// Get user ID
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info for price type
$stmt = $conn->prepare("SELECT user_type FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'User not found'
    ]);
    exit;
}

// Get provider details
$stmt = $conn->prepare("SELECT * FROM cable_providers WHERE id = ? AND status = 'active'");
$stmt->bind_param("i", $providerId);
$stmt->execute();
$result = $stmt->get_result();
$provider = $result->fetch_assoc();

if (!$provider) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'Provider not found or inactive'
    ]);
    exit;
}

// Initialize API Manager
$apiManager = new APIManager($db);
$apiProvider = $apiManager->getProviderForService('cable');

if (!$apiProvider) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'No API provider available for cable TV services'
    ]);
    exit;
}

// Prepare verification parameters
$params = [
    'provider' => $provider['api_name'],
    'smart_card' => $smartCard
];

// Log API request
$reference = 'VERIFY_' . uniqid() . '_' . time();
$apiTxnId = $apiManager->logApiTransaction([
    'provider' => $apiProvider->getProviderName(),
    'service' => 'cable_verify',
    'request' => $params,
    'response' => null,
    'status' => 'pending',
    'reference' => $reference,
    'user_id' => $userId
]);

try {
    // Make API call to verify smart card
    // This is a placeholder method - you'll need to implement this in your API provider class
    $result = $apiProvider->verifyCableCustomer($params);
    
    // Update API transaction log
    $apiManager->updateApiTransaction($apiTxnId, $result['success'] ? 'successful' : 'failed', $result);
    
    if ($result['success']) {
        // Get cable TV plans
        $stmt = $conn->prepare("
            SELECT id, name, price_smart, price_vendor, price_api, duration
            FROM cable_plans
            WHERE provider_id = ? AND status = 'active'
            ORDER BY price_smart ASC
        ");
        $stmt->bind_param("i", $providerId);
        $stmt->execute();
        $plansResult = $stmt->get_result();
        
        $plans = [];
        while ($plan = $plansResult->fetch_assoc()) {
            // Determine price based on user type
            $price = $plan['price_smart']; // Default to smart user price
            if ($user['user_type'] === 'vendor') {
                $price = $plan['price_vendor'];
            } elseif ($user['user_type'] === 'api') {
                $price = $plan['price_api'];
            }
            
            $plans[] = [
                'id' => $plan['id'],
                'name' => $plan['name'],
                'price' => $price,
                'duration' => $plan['duration']
            ];
        }
        
        header('Content-Type: application/json');
        echo json_encode([
            'success' => true,
            'message' => 'Smart card verified successfully',
            'customer_name' => $result['data']['customer_name'] ?? 'Unknown',
            'plans' => $plans
        ]);
    } else {
        header('Content-Type: application/json');
        echo json_encode([
            'success' => false,
            'message' => $result['message'] ?? 'Failed to verify smart card'
        ]);
    }
} catch (Exception $e) {
    // Log error
    error_log('Error verifying cable smart card: ' . $e->getMessage());
    
    // Update API transaction log
    $apiManager->updateApiTransaction($apiTxnId, 'failed', ['error' => $e->getMessage()]);
    
    header('Content-Type: application/json');
    echo json_encode([
        'success' => false,
        'message' => 'An error occurred while verifying the smart card: ' . $e->getMessage()
    ]);
}
?>