<?php
// File: /dashboard/api_docs.php
$pageTitle = 'API Documentation';
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Define generateApiKey function if it doesn't exist
if (!function_exists('generateApiKey')) {
    function generateApiKey() {
        return bin2hex(random_bytes(32));
    }
}

// Check if user is API user
$userId = $_SESSION['user_id'] ?? 0;
$stmt = $conn->prepare("SELECT user_type, api_key FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

// Redirect non-API users with a flash message
if (!$user || $user['user_type'] !== 'api') {
    setFlashMessage('You need to upgrade to an API account to access API documentation.', 'error');
    header("Location: " . SITE_URL . "/dashboard/upgrade.php");
    exit;
}

// If API key is missing, generate one
if (empty($user['api_key'])) {
    $apiKey = generateApiKey();
    $stmt = $conn->prepare("UPDATE users SET api_key = ? WHERE id = ?");
    $stmt->bind_param("si", $apiKey, $userId);
    $stmt->execute();
    
    // Refresh user data
    $stmt = $conn->prepare("SELECT api_key FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
}

// Get the API key to use in examples
$apiKey = $user['api_key'];

// Get all networks
$networks = [];
$simpleNetworkId = 1;
$stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
$stmt->execute();
$result = $stmt->get_result();
while ($row = $result->fetch_assoc()) {
    $networks[] = [
        'api_id' => $simpleNetworkId,
        'internal_id' => $row['id'],
        'name' => $row['name']
    ];
    $simpleNetworkId++;
}

// Get active data plans with simplified IDs
$dataPlans = [];
$simplePlanId = 1;
$stmt = $conn->prepare("
    SELECT p.id, p.name, p.size as value, p.validity, 
           IF(p.amount_api > 0, p.amount_api, p.price) as price, 
           dt.name as data_type, n.id as network_id, n.name as network_name
    FROM data_plans p
    JOIN data_types dt ON p.data_type_id = dt.id
    JOIN networks n ON dt.network_id = n.id
    WHERE p.status = 'active'
    ORDER BY n.name, dt.name, p.price
");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    // Find the simplified network ID
    $apiNetworkId = 0;
    foreach ($networks as $network) {
        if ($network['internal_id'] === $row['network_id']) {
            $apiNetworkId = $network['api_id'];
            break;
        }
    }
    
    $dataPlans[] = [
        'api_id' => $simplePlanId,
        'internal_id' => $row['id'],
        'network_id' => $apiNetworkId,
        'network_name' => $row['network_name'],
        'name' => $row['name'],
        'data_type' => $row['data_type'],
        'size' => $row['value'],
        'validity' => $row['validity'],
        'price' => floatval($row['price'])
    ];
    $simplePlanId++;
}

// Group data plans by network
$plansByNetwork = [];
foreach ($dataPlans as $plan) {
    if (!isset($plansByNetwork[$plan['network_name']])) {
        $plansByNetwork[$plan['network_name']] = [];
    }
    $plansByNetwork[$plan['network_name']][] = $plan;
}

// Continue with page rendering
require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">API Documentation</h1>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/api_tokens.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm flex items-center">
            <i class="fas fa-key mr-2"></i> Manage API Keys
        </a>
    </div>
    
    <div class="text-sm text-gray-400 mb-6">
        This documentation covers all the endpoints available in our API, along with request and response formats. Use your API key to authenticate all requests.
    </div>
    
    <!-- API Base URL Card -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <h2 class="text-lg font-semibold text-white mb-2">API Base URL</h2>
        <div class="flex items-center bg-gray-900 rounded p-3">
            <code class="font-mono text-indigo-400"><?php echo SITE_URL; ?>/api/v1</code>
            <button class="copy-btn ml-2 text-gray-400 hover:text-white" data-copy="<?php echo SITE_URL; ?>/api/v1">
                <i class="fas fa-copy"></i>
            </button>
        </div>
    </div>
    
    <!-- Authentication -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <h2 class="text-lg font-semibold text-white mb-4">Authentication</h2>
        <p class="text-gray-400 mb-4">
            All API requests must include your API key in the request headers.
        </p>
        
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">HTTP Header</h3>
            <div class="bg-gray-900 rounded p-3 flex items-center">
                <code class="font-mono text-indigo-400">X-API-KEY: your_api_key</code>
                <button class="copy-btn ml-2 text-gray-400 hover:text-white" data-copy="X-API-KEY: <?php echo $apiKey; ?>">
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">Example Request with cURL</h3>
            <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/balance" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/balance" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="bg-yellow-800 bg-opacity-30 border border-yellow-700 rounded-md p-4 mt-4">
            <div class="flex">
                <div class="flex-shrink-0">
                    <i class="fas fa-exclamation-triangle text-yellow-400"></i>
                </div>
                <div class="ml-3">
                    <p class="text-sm text-yellow-300">
                        Keep your API key secure. Do not share it in public repositories or client-side code. If your key is compromised, regenerate it immediately.
                    </p>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Available Networks -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <h2 class="text-lg font-semibold text-white mb-4">Available Networks</h2>
        <p class="text-gray-400 mb-4">
            These are the network IDs you can use in your API calls:
        </p>
        
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-900">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network ID</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network Name</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-800">
                    <?php foreach ($networks as $network): ?>
                    <tr class="hover:bg-gray-700">
                        <td class="px-6 py-4 whitespace-nowrap text-sm font-medium text-white"><?php echo $network['api_id']; ?></td>
                        <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $network['name']; ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <!-- Available Data Plans -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <h2 class="text-lg font-semibold text-white mb-4">Available Data Plans</h2>
        <p class="text-gray-400 mb-4">
            These are the data plans available for purchase:
        </p>
        
        <!-- Network tabs -->
        <div class="mb-6">
            <div class="border-b border-gray-700">
                <nav class="-mb-px flex space-x-4 overflow-x-auto" id="network-tabs">
                    <?php $firstNetwork = true; 
                    foreach (array_keys($plansByNetwork) as $network): ?>
                        <button class="network-tab <?php echo $firstNetwork ? 'text-white border-indigo-500' : 'text-gray-400 border-transparent hover:text-white hover:border-gray-400'; ?> border-b-2 px-3 py-2 font-medium text-sm whitespace-nowrap" data-network="<?php echo htmlspecialchars($network); ?>">
                            <?php echo htmlspecialchars($network); ?>
                        </button>
                    <?php $firstNetwork = false; endforeach; ?>
                </nav>
            </div>
            
            <!-- Tab content -->
            <?php $firstNetwork = true; 
            foreach ($plansByNetwork as $networkName => $plans): ?>
                <div id="network-<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>" class="network-tab-content <?php echo $firstNetwork ? '' : 'hidden'; ?>">
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="bg-gray-900">
                                <tr>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan ID</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Type</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Size</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Validity</th>
                                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Price</th>
                                </tr>
                            </thead>
                            <tbody class="divide-y divide-gray-800">
                                <?php foreach ($plans as $plan): ?>
                                <tr class="hover:bg-gray-700">
                                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium text-white"><?php echo $plan['api_id']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $plan['network_name']; ?> (ID: <?php echo $plan['network_id']; ?>)</td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $plan['data_type']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $plan['name']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $plan['size']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo $plan['validity']; ?></td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300"><?php echo getSetting('currency') . number_format($plan['price'], 2); ?></td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php $firstNetwork = false; endforeach; ?>
        </div>
    </div>
    
    <!-- Endpoints -->
    <div class="bg-gray-800 rounded-lg p-6">
        <h2 class="text-lg font-semibold text-white mb-6">API Endpoints</h2>
        
        <!-- Endpoints Tabs -->
        <div class="border-b border-gray-700 mb-6">
            <nav class="-mb-px flex space-x-4" aria-label="Tabs">
                <button class="api-tab text-white border-b-2 border-indigo-500 px-3 py-2 font-medium text-sm" data-tab="account">
                    Account
                </button>
                <button class="api-tab text-gray-400 hover:text-white border-b-2 border-transparent hover:border-gray-400 px-3 py-2 font-medium text-sm" data-tab="services">
                    Services
                </button>
                <button class="api-tab text-gray-400 hover:text-white border-b-2 border-transparent hover:border-gray-400 px-3 py-2 font-medium text-sm" data-tab="transactions">
                    Transactions
                </button>
            </nav>
        </div>
        
        <!-- Account Endpoints -->
        <div id="account-tab" class="api-tab-content">
            <!-- Get Balance Endpoint -->
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <span class="px-2 py-1 text-xs rounded-full bg-blue-500 bg-opacity-20 text-blue-400 mr-2">GET</span>
                    <h3 class="text-white font-semibold">/balance</h3>
                </div>
                <p class="text-gray-400 mb-4">Get your current account balance.</p>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Example Request</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/balance" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/balance" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
                
                <div>
                    <h4 class="text-white font-medium mb-2">Example Response</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Balance retrieved successfully",
    "data": {
        "balance": 5000.50,
        "currency": "₦"
    }
}</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Balance retrieved successfully",
    "data": {
        "balance": 5000.50,
        "currency": "₦"
    }
}'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
            </div>
            
            <!-- Get Profile Endpoint -->
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <span class="px-2 py-1 text-xs rounded-full bg-blue-500 bg-opacity-20 text-blue-400 mr-2">GET</span>
                    <h3 class="text-white font-semibold">/profile</h3>
                </div>
                <p class="text-gray-400 mb-4">Get your account profile information.</p>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Example Request</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/profile" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/profile" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
                
                <div>
                    <h4 class="text-white font-medium mb-2">Example Response</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Profile retrieved successfully",
    "data": {
        "id": 123,
        "username": "johndoe",
        "email": "john@example.com",
        "phone": "1234567890",
        "balance": 5000.50,
        "user_type": "api",
        "created_at": "2023-01-01T12:00:00Z"
    }
}</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Profile retrieved successfully",
    "data": {
        "id": 123,
        "username": "johndoe",
        "email": "john@example.com",
        "phone": "1234567890",
        "balance": 5000.50,
        "user_type": "api",
        "created_at": "2023-01-01T12:00:00Z"
    }
}'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Services Endpoints -->
        <div id="services-tab" class="api-tab-content hidden">
            <!-- Data Services -->
            <div class="mb-8">
                <h3 class="text-white font-semibold text-lg mb-4">Data Services</h3>
                
                <!-- Get Data Plans Endpoint -->
                <div class="mb-8">
                    <div class="flex items-center mb-4">
                        <span class="px-2 py-1 text-xs rounded-full bg-blue-500 bg-opacity-20 text-blue-400 mr-2">GET</span>
                        <h3 class="text-white font-semibold">/data/plans</h3>
                    </div>
                    <p class="text-gray-400 mb-4">Get available data plans.</p>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Query Parameters</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                            <table class="min-w-full">
                                <thead>
                                    <tr>
                                        <th class="text-left text-gray-300 font-medium">Parameter</th>
                                        <th class="text-left text-gray-300 font-medium">Type</th>
                                        <th class="text-left text-gray-300 font-medium">Required</th>
                                        <th class="text-left text-gray-300 font-medium">Description</th>
                                    </tr>
                                </thead>
                                <tbody class="text-gray-400 text-sm">
                                    <tr>
                                        <td>network_id</td>
                                        <td>integer</td>
                                        <td>Optional</td>
                                        <td>Filter plans by network ID</td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Example Request</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/data/plans?network_id=1" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/data/plans?network_id=1" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                    
                    <div>
                        <h4 class="text-white font-medium mb-2">Example Response</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Data plans retrieved successfully",
    "data": [
        {
            "id": 1,
            "network_id": 1,
            "network_name": "MTN",
            "name": "Daily Plan",
            "data_type": "SME",
            "size": "1GB",
            "validity": "1 day",
            "price": 300.00
        },
        {
            "id": 2,
            "network_id": 1,
            "network_name": "MTN",
            "name": "Weekly Plan",
            "data_type": "SME",
            "size": "2GB",
            "validity": "7 days",
            "price": 500.00
        }
    ]
}</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Data plans retrieved successfully",
    "data": [
        {
            "id": 1,
            "network_id": 1,
            "network_name": "MTN",
            "name": "Daily Plan",
            "data_type": "SME",
            "size": "1GB", 
            "validity": "1 day",
            "price": 300.00
        },
        {
            "id": 2,
            "network_id": 1,
            "network_name": "MTN",
            "name": "Weekly Plan",
            "data_type": "SME",
            "size": "2GB",
            "validity": "7 days",
            "price": 500.00
        }
    ]
}'>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                </div>
                
                <!-- Buy Data Endpoint -->
                <div class="mb-8">
                    <div class="flex items-center mb-4">
                        <span class="px-2 py-1 text-xs rounded-full bg-green-500 bg-opacity-20 text-green-400 mr-2">POST</span>
                        <h3 class="text-white font-semibold">/data/buy</h3>
                    </div>
                    <p class="text-gray-400 mb-4">Purchase a data plan.</p>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Request Body Parameters</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                            <table class="min-w-full">
                                <thead>
                                    <tr>
                                        <th class="text-left text-gray-300 font-medium">Parameter</th>
                                        <th class="text-left text-gray-300 font-medium">Type</th>
                                        <th class="text-left text-gray-300 font-medium">Required</th>
                                        <th class="text-left text-gray-300 font-medium">Description</th>
                                    </tr>
                                </thead>
                                <tbody class="text-gray-400 text-sm">
                                    <tr>
                                        <td>plan_id</td>
                                        <td>integer</td>
                                        <td>Yes</td>
                                        <td>ID of the data plan (from the list above)</td>
                                    </tr>
                                    <tr>
                                        <td>phone</td>
                                        <td>string</td>
                                        <td>Yes</td>
                                        <td>Phone number to receive data</td>
                                    </tr>
                                    <tr>
                                        <td>reference</td>
                                        <td>string</td>
                                        <td>Optional</td>
                                        <td>Your custom reference</td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Example Request</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>curl -X POST "<?php echo SITE_URL; ?>/api/v1/data/buy" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>" \
     -H "Content-Type: application/json" \
     -d '{
         "plan_id": 1,
         "phone": "09012345678",
         "reference": "your-reference-12345"
     }'</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X POST "<?php echo SITE_URL; ?>/api/v1/data/buy" -H "X-API-KEY: <?php echo $apiKey; ?>" -H "Content-Type: application/json" -d '{
    "plan_id": 1,
    "phone": "09012345678",
    "reference": "your-reference-12345"
}''>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                    
                    <div>
                        <h4 class="text-white font-medium mb-2">Example Response</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Data purchase successful",
    "data": {
        "transaction_id": 12345,
        "reference": "DATA_67890_1234567890",
        "amount": 300.00,
        "phone": "09012345678",
        "plan": "1GB Data",
        "network": "MTN",
        "client_reference": "your-reference-12345"
    }
}</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Data purchase successful",
    "data": {
        "transaction_id": 12345,
        "reference": "DATA_67890_1234567890",
        "amount": 300.00,
        "phone": "09012345678",
        "plan": "1GB Data",
        "network": "MTN",
        "client_reference": "your-reference-12345"
    }
}'>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Airtime Services -->
            <div class="mb-8">
                <h3 class="text-white font-semibold text-lg mb-4">Airtime Services</h3>
                
                <!-- Buy Airtime Endpoint -->
                <div class="mb-8">
                    <div class="flex items-center mb-4">
                        <span class="px-2 py-1 text-xs rounded-full bg-green-500 bg-opacity-20 text-green-400 mr-2">POST</span>
                        <h3 class="text-white font-semibold">/airtime/buy</h3>
                    </div>
                    <p class="text-gray-400 mb-4">Purchase airtime.</p>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Request Body Parameters</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                            <table class="min-w-full">
                                <thead>
                                    <tr>
                                        <th class="text-left text-gray-300 font-medium">Parameter</th>
                                        <th class="text-left text-gray-300 font-medium">Type</th>
                                        <th class="text-left text-gray-300 font-medium">Required</th>
                                        <th class="text-left text-gray-300 font-medium">Description</th>
                                    </tr>
                                </thead>
                                <tbody class="text-gray-400 text-sm">
                                    <tr>
                                        <td>network_id</td>
                                        <td>integer</td>
                                        <td>Yes</td>
                                        <td>ID of the network (from the list above)</td>
                                    </tr>
                                    <tr>
                                        <td>phone</td>
                                        <td>string</td>
                                        <td>Yes</td>
                                        <td>Phone number to receive airtime</td>
                                    </tr>
                                    <tr>
                                        <td>amount</td>
                                        <td>number</td>
                                        <td>Yes</td>
                                        <td>Amount of airtime to purchase (minimum: 50)</td>
                                    </tr>
                                    <tr>
                                        <td>reference</td>
                                        <td>string</td>
                                        <td>Optional</td>
                                        <td>Your custom reference</td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <h4 class="text-white font-medium mb-2">Example Request</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>curl -X POST "<?php echo SITE_URL; ?>/api/v1/airtime/buy" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>" \
     -H "Content-Type: application/json" \
     -d '{
         "network_id": 1,
         "phone": "09012345678",
         "amount": 500,
         "reference": "your-reference-67890"
     }'</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X POST "<?php echo SITE_URL; ?>/api/v1/airtime/buy" -H "X-API-KEY: <?php echo $apiKey; ?>" -H "Content-Type: application/json" -d '{
    "network_id": 1,
    "phone": "09012345678",
    "amount": 500,
    "reference": "your-reference-67890"
}''>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                    
                    <div>
                        <h4 class="text-white font-medium mb-2">Example Response</h4>
                        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                            <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Airtime purchase successful",
    "data": {
        "transaction_id": 12346,
        "reference": "AIRTIME_67891_1234567890",
        "amount": 500.00,
        "phone": "09012345678",
        "network": "MTN",
        "client_reference": "your-reference-67890"
    }
}</code></pre>
                            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Airtime purchase successful",
    "data": {
        "transaction_id": 12346,
        "reference": "AIRTIME_67891_1234567890",
        "amount": 500.00,
        "phone": "09012345678",
        "network": "MTN",
        "client_reference": "your-reference-67890"
    }
}'>
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Transactions Endpoints -->
        <div id="transactions-tab" class="api-tab-content hidden">
            <!-- Get Transactions Endpoint -->
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <span class="px-2 py-1 text-xs rounded-full bg-blue-500 bg-opacity-20 text-blue-400 mr-2">GET</span>
                    <h3 class="text-white font-semibold">/transactions</h3>
                </div>
                <p class="text-gray-400 mb-4">Get your transaction history.</p>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Query Parameters</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                        <table class="min-w-full">
                            <thead>
                                <tr>
                                    <th class="text-left text-gray-300 font-medium">Parameter</th>
                                    <th class="text-left text-gray-300 font-medium">Type</th>
                                    <th class="text-left text-gray-300 font-medium">Required</th>
                                    <th class="text-left text-gray-300 font-medium">Description</th>
                                </tr>
                            </thead>
                            <tbody class="text-gray-400 text-sm">
                                <tr>
                                    <td>page</td>
                                    <td>integer</td>
                                    <td>Optional</td>
                                    <td>Page number (default: 1)</td>
                                </tr>
                                <tr>
                                    <td>limit</td>
                                    <td>integer</td>
                                    <td>Optional</td>
                                    <td>Number of results per page (default: 20, max: 100)</td>
                                </tr>
                                <tr>
                                    <td>type</td>
                                    <td>string</td>
                                    <td>Optional</td>
                                    <td>Filter by transaction type (e.g., fund, data, airtime)</td>
                                </tr>
                                <tr>
                                    <td>reference</td>
                                    <td>string</td>
                                    <td>Optional</td>
                                    <td>Filter by transaction reference or client reference</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Example Request</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/transactions?page=1&limit=10&type=data" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/transactions?page=1&limit=10&type=data" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
                
                <div>
                    <h4 class="text-white font-medium mb-2">Example Response</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Transactions retrieved successfully",
    "data": {
        "transactions": [
            {
                "id": 12345,
                "reference": "DATA_67890_1234567890",
                "type": "data",
                "amount": 300.00,
                "fee": 0,
                "status": "successful",
                "description": "1GB Data Purchase",
                "created_at": "2023-01-01T12:00:00Z",
                "client_reference": "your-reference-12345"
            },
            {
                "id": 12344,
                "reference": "DATA_67889_1234567890",
                "type": "data",
                "amount": 500.00,
                "fee": 0,
                "status": "successful",
                "description": "2GB Data Purchase",
                "created_at": "2022-12-30T10:15:00Z"
            }
        ],
        "pagination": {
            "current_page": 1,
            "total_pages": 5,
            "total_items": 45,
            "limit": 10
        }
    }
}</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Transactions retrieved successfully",
    "data": {
        "transactions": [
            {
                "id": 12345,
                "reference": "DATA_67890_1234567890",
                "type": "data",
                "amount": 300.00,
                "fee": 0,
                "status": "successful",
                "description": "1GB Data Purchase",
                "created_at": "2023-01-01T12:00:00Z",
                "client_reference": "your-reference-12345"
            },
            {
                "id": 12344,
                "reference": "DATA_67889_1234567890",
                "type": "data",
                "amount": 500.00,
                "fee": 0,
                "status": "successful",
                "description": "2GB Data Purchase",
                "created_at": "2022-12-30T10:15:00Z"
            }
        ],
        "pagination": {
            "current_page": 1,
            "total_pages": 5,
            "total_items": 45,
            "limit": 10
        }
    }
}'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
            </div>
            
            <!-- Get Transaction Endpoint -->
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <span class="px-2 py-1 text-xs rounded-full bg-blue-500 bg-opacity-20 text-blue-400 mr-2">GET</span>
                    <h3 class="text-white font-semibold">/transactions/{id}</h3>
                </div>
                <p class="text-gray-400 mb-4">Get details of a specific transaction.</p>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Path Parameters</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto">
                        <table class="min-w-full">
                            <thead>
                                <tr>
                                    <th class="text-left text-gray-300 font-medium">Parameter</th>
                                    <th class="text-left text-gray-300 font-medium">Type</th>
                                    <th class="text-left text-gray-300 font-medium">Required</th>
                                    <th class="text-left text-gray-300 font-medium">Description</th>
                                </tr>
                            </thead>
                            <tbody class="text-gray-400 text-sm">
                                <tr>
                                    <td>id</td>
                                    <td>integer</td>
                                    <td>Yes</td>
                                    <td>Transaction ID</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
                
                <div class="mb-4">
                    <h4 class="text-white font-medium mb-2">Example Request</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>curl -X GET "<?php echo SITE_URL; ?>/api/v1/transactions/12345" \
     -H "X-API-KEY: <?php echo substr($apiKey, 0, 8) . '...' . substr($apiKey, -8); ?>"</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl -X GET "<?php echo SITE_URL; ?>/api/v1/transactions/12345" -H "X-API-KEY: <?php echo $apiKey; ?>"'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
                
                <div>
                    <h4 class="text-white font-medium mb-2">Example Response</h4>
                    <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
                        <pre class="text-gray-300"><code>{
    "status": "success",
    "message": "Transaction retrieved successfully",
    "data": {
        "id": 12345,
        "reference": "DATA_67890_1234567890",
        "type": "data",
        "amount": 300.00,
        "fee": 0,
        "status": "successful",
        "description": "1GB Data Purchase",
        "created_at": "2023-01-01T12:00:00Z",
        "client_reference": "your-reference-12345",
        "meta_data": {
            "phone": "09012345678",
            "network_id": 1,
            "network_name": "MTN",
            "plan_id": 1,
            "plan_name": "1GB Data"
        }
    }
}</code></pre>
                        <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
    "status": "success",
    "message": "Transaction retrieved successfully",
    "data": {
        "id": 12345,
        "reference": "DATA_67890_1234567890",
        "type": "data",
        "amount": 300.00,
        "fee": 0,
        "status": "successful",
        "description": "1GB Data Purchase",
        "created_at": "2023-01-01T12:00:00Z",
        "client_reference": "your-reference-12345",
        "meta_data": {
            "phone": "09012345678",
            "network_id": 1,
            "network_name": "MTN",
            "plan_id": 1,
            "plan_name": "1GB Data"
        }
    }
}'>
                            <i class="fas fa-copy"></i>
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Error Codes -->
<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h2 class="text-xl font-bold text-white mb-4">Error Codes</h2>
    
    <div class="overflow-x-auto">
        <table class="min-w-full">
            <thead class="bg-gray-800">
                <tr>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status Code</th>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Error Type</th>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Description</th>
                </tr>
            </thead>
            <tbody class="divide-y divide-gray-700">
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">400</td>
                    <td class="py-3 px-4 text-sm text-red-400">BAD_REQUEST</td>
                    <td class="py-3 px-4 text-sm text-gray-300">The request was invalid or cannot be served.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">401</td>
                    <td class="py-3 px-4 text-sm text-red-400">UNAUTHORIZED</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Authentication failed or credentials not provided.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">403</td>
                    <td class="py-3 px-4 text-sm text-red-400">FORBIDDEN</td>
                    <td class="py-3 px-4 text-sm text-gray-300">You do not have permission to access the requested resource.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">404</td>
                    <td class="py-3 px-4 text-sm text-red-400">NOT_FOUND</td>
                    <td class="py-3 px-4 text-sm text-gray-300">The requested resource was not found.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">409</td>
                    <td class="py-3 px-4 text-sm text-red-400">CONFLICT</td>
                    <td class="py-3 px-4 text-sm text-gray-300">The request could not be completed due to a conflict.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">422</td>
                    <td class="py-3 px-4 text-sm text-red-400">VALIDATION_ERROR</td>
                    <td class="py-3 px-4 text-sm text-gray-300">The request was well-formed but contains validation errors.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">429</td>
                    <td class="py-3 px-4 text-sm text-red-400">TOO_MANY_REQUESTS</td>
                    <td class="py-3 px-4 text-sm text-gray-300">You have exceeded the rate limit.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">500</td>
                    <td class="py-3 px-4 text-sm text-red-400">INTERNAL_SERVER_ERROR</td>
                    <td class="py-3 px-4 text-sm text-gray-300">An unexpected error occurred on the server.</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">503</td>
                    <td class="py-3 px-4 text-sm text-red-400">SERVICE_UNAVAILABLE</td>
                    <td class="py-3 px-4 text-sm text-gray-300">The service is temporarily unavailable.</td>
                </tr>
            </tbody>
        </table>
    </div>
</div>

<!-- Rate Limits -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Rate Limits</h2>
    
    <p class="text-gray-400 mb-4">
        To ensure system stability and fair usage, API requests are subject to rate limiting. When you exceed the rate limit, you'll receive a 429 Too Many Requests response.
    </p>
    
    <div class="overflow-x-auto">
        <table class="min-w-full">
            <thead class="bg-gray-800">
                <tr>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Endpoint</th>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Rate Limit</th>
                </tr>
            </thead>
            <tbody class="divide-y divide-gray-700">
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">GET endpoints</td>
                    <td class="py-3 px-4 text-sm text-gray-300">60 requests per minute</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">POST endpoints</td>
                    <td class="py-3 px-4 text-sm text-gray-300">30 requests per minute</td>
                </tr>
            </tbody>
        </table>
    </div>
    
    <div class="bg-gray-700 rounded-lg p-4 mt-6">
        <h3 class="text-white font-semibold mb-2">Rate Limit Headers</h3>
        <p class="text-gray-400 mb-3">
            Each API response includes headers that indicate your current rate limit status:
        </p>
        
        <div class="bg-gray-900 rounded p-3 overflow-x-auto relative">
            <pre class="text-gray-300"><code>X-RateLimit-Limit: 60          # Total number of requests allowed per minute
X-RateLimit-Remaining: 58     # Remaining requests in the current minute
X-RateLimit-Reset: 1612345678 # Timestamp when the rate limit will reset</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='X-RateLimit-Limit: 60          # Total number of requests allowed per minute
X-RateLimit-Remaining: 58     # Remaining requests in the current minute
X-RateLimit-Reset: 1612345678 # Timestamp when the rate limit will reset'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // API Endpoint Tab Switching
        const apiTabs = document.querySelectorAll('.api-tab');
        const apiTabContents = document.querySelectorAll('.api-tab-content');
        
        apiTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const tabName = this.getAttribute('data-tab');
                
                // Hide all tab contents
                apiTabContents.forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all tabs
                apiTabs.forEach(tab => {
                    tab.classList.remove('text-white', 'border-indigo-500');
                    tab.classList.add('text-gray-400', 'border-transparent', 'hover:border-gray-400');
                });
                
                // Show selected tab content
                document.getElementById(tabName + '-tab').classList.remove('hidden');
                
                // Highlight selected tab
                this.classList.remove('text-gray-400', 'border-transparent', 'hover:border-gray-400');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
        
        // Network Tab Switching for data plans
        const networkTabs = document.querySelectorAll('.network-tab');
        
        networkTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const networkName = this.getAttribute('data-network');
                const tabId = 'network-' + networkName.toLowerCase().replace(/ /g, '-');
                
                // Hide all network contents
                document.querySelectorAll('.network-tab-content').forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all network tabs
                networkTabs.forEach(tab => {
                    tab.classList.remove('text-white', 'border-indigo-500');
                    tab.classList.add('text-gray-400', 'border-transparent', 'hover:text-white', 'hover:border-gray-400');
                });
                
                // Show selected network content
                document.getElementById(tabId).classList.remove('hidden');
                
                // Highlight selected tab
                this.classList.remove('text-gray-400', 'border-transparent', 'hover:text-white', 'hover:border-gray-400');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
        
        // Copy functionality
        const copyButtons = document.querySelectorAll('.copy-btn');
        
        copyButtons.forEach(button => {
            button.addEventListener('click', function() {
                const textToCopy = this.getAttribute('data-copy');
                
                // Create a temporary textarea to copy from
                const textarea = document.createElement('textarea');
                textarea.value = textToCopy;
                textarea.style.position = 'fixed';  // Prevent scrolling to the bottom
                document.body.appendChild(textarea);
                textarea.select();
                
                try {
                    // Execute copy command
                    document.execCommand('copy');
                    this.innerHTML = '<i class="fas fa-check"></i>';
                    setTimeout(() => {
                        this.innerHTML = '<i class="fas fa-copy"></i>';
                    }, 2000);
                } catch (err) {
                    console.error('Could not copy text: ', err);
                    this.innerHTML = '<i class="fas fa-times"></i>';
                    setTimeout(() => {
                        this.innerHTML = '<i class="fas fa-copy"></i>';
                    }, 2000);
                }
                
                // Clean up
                document.body.removeChild(textarea);
            });
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>