<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// If user is not an API user, redirect to dashboard
if ($user['user_type'] !== 'api') {
    redirect(SITE_URL . '/dashboard');
}

$db = getDB();
$conn = $db->getConnection();

$errors = [];
$success = '';

// Process token regeneration
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['regenerate_token'])) {
    // Get form data
    $pin = isset($_POST['pin']) ? $_POST['pin'] : '';
    
    // Validate inputs
    if (empty($pin)) {
        $errors[] = 'Transaction PIN is required';
    } elseif (empty($user['pin'])) {
        $errors[] = 'You need to set a transaction PIN first. <a href="set_pin.php" class="text-indigo-400 underline">Set PIN now</a>';
    } elseif (!password_verify($pin, $user['pin'])) {
        $errors[] = 'Invalid transaction PIN';
    }
    
    // If no errors, regenerate token
    if (empty($errors)) {
        // Generate new API token
        $newToken = generateApiToken();
        
        // Update user record
        $stmt = $conn->prepare("UPDATE users SET api_token = ? WHERE id = ?");
        $stmt->bind_param("si", $newToken, $userId);
        
        if ($stmt->execute()) {
            $success = 'API token regenerated successfully!';
            
            // Refresh user data
            $user = getUserById($userId);
            
            // Send email notification
            $emailSubject = 'API Token Regenerated';
            $emailMessage = "Hello " . $user['full_name'] . ",\n\nYour API token has been regenerated. If you did not request this change, please contact our support team immediately.\n\nBest regards,\n" . getSetting('site_name') . " Team";
            
            sendEmail($user['email'], $emailSubject, $emailMessage);
        } else {
            $errors[] = 'Failed to regenerate token: ' . $conn->error;
        }
    }
}

// Get data plans for documentation
$dataPlans = [];
$stmt = $conn->prepare("SELECT dp.id, dp.name, dp.size, dp.validity, dp.api_plan_id, n.name as network_name
                      FROM data_plans dp
                      JOIN networks n ON dp.network_id = n.id
                      WHERE dp.status = 'active'
                      ORDER BY n.name, dp.amount");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $dataPlans[] = $row;
}

// Get networks for documentation
$networks = [];
$stmt = $conn->prepare("SELECT id, name, api_id FROM networks WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>API Documentation - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.4.0/styles/atom-one-dark.min.css">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.4.0/highlight.min.js"></script>
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .code-block {
            background-color: #1a1a1a;
            border: 1px solid #333;
            border-radius: 0.375rem;
            font-family: monospace;
            overflow-x: auto;
        }
        
        .api-token {
            font-family: monospace;
            word-break: break-all;
        }
        
        .api-method {
            display: inline-block;
            padding: 0.25rem 0.5rem;
            border-radius: 0.25rem;
            font-weight: 600;
            font-size: 0.875rem;
            margin-right: 0.5rem;
        }
        
        .api-method.post {
            background-color: #10B981;
            color: #ffffff;
        }
        
        .api-method.get {
            background-color: #3B82F6;
            color: #ffffff;
        }
        
        .api-endpoint {
            font-family: monospace;
            font-weight: 500;
        }
        
        .api-param-table th, .api-param-table td {
            padding: 0.5rem 1rem;
            text-align: left;
            border-bottom: 1px solid #333;
        }
        
        .api-param-table th {
            background-color: #1a1a1a;
            font-weight: 500;
        }
        
        .api-section {
            scroll-margin-top: 1rem;
        }
        
        .pin-input {
            font-size: 1.875rem;
            letter-spacing: 0.5rem;
            text-align: center;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <?php echo substr($user['username'], 0, 1); ?>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($user['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="change_password.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Change Password</a>
                        <a href="set_pin.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Set Transaction PIN</a>
                        <a href="api_tokens.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Tokens</a>
                        <a href="../login/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="dashboard-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <ul class="space-y-2">
                    <li>
                        <a href="index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-home mr-3"></i>
                            <span>Dashboard</span>
                        </a>
                    </li>
                    <li>
                        <a href="fund_wallet.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wallet mr-3"></i>
                            <span>Fund Wallet</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_data.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wifi mr-3"></i>
                            <span>Buy Data</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_airtime.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-phone mr-3"></i>
                            <span>Buy Airtime</span>
                        </a>
                    </li>
                    <li>
                        <a href="transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-exchange-alt mr-3"></i>
                            <span>Transactions</span>
                        </a>
                    </li>
                    
                    <!-- Show upgrade option only for smart users -->
                    <?php if ($user['user_type'] === 'smart'): ?>
                    <li>
                        <a href="upgrade.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-arrow-up mr-3"></i>
                            <span>Upgrade Account</span>
                        </a>
                    </li>
                    <?php endif; ?>
                    
                    <!-- Show developer section for API users -->
                    <?php if ($user['user_type'] === 'api'): ?>
                    <li>
                        <a href="api_documentation.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                            <i class="fas fa-code mr-3"></i>
                            <span>API Documentation</span>
                        </a>
                    </li>
                    <?php endif; ?>
                </ul>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4 overflow-y-auto">
            <div class="flex flex-col md:flex-row md:justify-between md:items-center mb-6">
                <h1 class="text-2xl font-bold text-white mb-4 md:mb-0">API Documentation</h1>
                <div class="text-right">
                    <p class="text-sm text-gray-400">Wallet Balance</p>
                    <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
                </div>
            </div>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-6 mb-6">
                <!-- API Token -->
                <div class="dashboard-card rounded-lg shadow-md p-6 md:col-span-2">
                    <h2 class="text-xl font-semibold text-white mb-3">Your API Token</h2>
                    
                    <div class="flex items-center mb-4">
                        <div class="api-token bg-gray-800 p-3 rounded-md flex-grow mr-2 overflow-x-auto">
                            <code id="apiToken"><?php echo $user['api_token']; ?></code>
                        </div>
                        <button id="copyTokenBtn" class="p-2 rounded-md hover:bg-gray-700 transition-colors" title="Copy to clipboard">
                            <i class="fas fa-copy text-gray-400"></i>
                        </button>
                    </div>
                    
                    <p class="text-gray-400 text-sm mb-4">
                        This token is used to authenticate all your API requests. Keep it secret and secure.
                    </p>
                    
                    <form method="POST" action="" id="regenerateForm" class="hidden">
                        <div class="mb-4">
                            <label for="pin" class="block text-sm font-medium text-gray-400 mb-1">Transaction PIN</label>
                            <input type="password" id="pin" name="pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                        </div>
                        
                        <div class="mb-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                            <p class="text-yellow-300 text-sm">
                                <i class="fas fa-exclamation-triangle mr-2"></i> Regenerating your token will invalidate the previous one. All applications using the old token will need to be updated.
                            </p>
                        </div>
                        
                        <div class="flex space-x-3">
                            <button type="button" id="cancelBtn" class="py-2 px-4 border border-gray-600 rounded-md shadow-sm text-sm font-medium text-gray-300 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Cancel
                            </button>
                            <button type="submit" name="regenerate_token" class="accent-button py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Confirm Regenerate
                            </button>
                        </div>
                    </form>
                    
                    <div id="regenerateBtn" class="mt-2">
                        <button type="button" class="text-indigo-400 hover:text-indigo-300 text-sm">
                            <i class="fas fa-refresh mr-1"></i> Regenerate Token
                        </button>
                    </div>
                </div>
                
                <!-- API Quick Links -->
                <div class="dashboard-card rounded-lg shadow-md p-6">
                    <h2 class="text-xl font-semibold text-white mb-3">Quick Links</h2>
                    
                    <nav class="space-y-2">
                        <a href="#introduction" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Introduction
                        </a>
                        <a href="#authentication" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Authentication
                        </a>
                        <a href="#data-endpoints" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Data Endpoints
                        </a>
                        <a href="#airtime-endpoints" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Airtime Endpoints
                        </a>
                        <a href="#data-plans" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Data Plans
                        </a>
                        <a href="#network-ids" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                            Network IDs
                        </a>
                    </nav>
                </div>
            </div>
            
            <!-- API Documentation -->
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="introduction">
                <h2 class="text-2xl font-semibold text-white mb-4">Introduction</h2>
                
                <p class="text-gray-300 mb-4">
                    Welcome to the <?php echo getSetting('site_name'); ?> API documentation. This API allows you to programmatically purchase data bundles and airtime from your account.
                </p>
                
                <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                    <h3 class="font-semibold text-indigo-300 mb-2">Base URL</h3>
                    <p class="text-gray-300 font-mono"><?php echo SITE_URL; ?>/api/v1</p>
                </div>
                
                <h3 class="text-xl font-semibold text-white mt-6 mb-3">Request Format</h3>
                <p class="text-gray-300 mb-3">
                    All requests should be sent as HTTP POST requests with a JSON body.
                </p>
                
                <h3 class="text-xl font-semibold text-white mt-6 mb-3">Response Format</h3>
                <p class="text-gray-300 mb-3">
                    All responses are returned in JSON format. A typical response has the following structure:
                </p>
                
                <div class="code-block p-4 mb-6">
<pre><code class="language-json">{
  "status": true,
  "message": "Success message",
  "data": {
    // Response data here
  }
}</code></pre>
                </div>
                
                <h3 class="text-xl font-semibold text-white mt-6 mb-3">Error Handling</h3>
                <p class="text-gray-300 mb-3">
                    When an error occurs, the response will have a <code>status</code> field set to <code>false</code> and an error message:
                </p>
                
                <div class="code-block p-4 mb-6">
<pre><code class="language-json">{
  "status": false,
  "message": "Error message",
  "error_code": "ERROR_CODE"
}</code></pre>
                </div>
                
                <h3 class="text-xl font-semibold text-white mt-6 mb-3">Rate Limiting</h3>
                <p class="text-gray-300 mb-3">
                    API requests are limited to 100 requests per minute. If you exceed this limit, you'll receive a 429 Too Many Requests response.
                </p>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="authentication">
                <h2 class="text-2xl font-semibold text-white mb-4">Authentication</h2>
                
                <p class="text-gray-300 mb-4">
                    All API requests require authentication using your API token. Include your token in the request headers as follows:
                </p>
                
                <div class="code-block p-4 mb-6">
<pre><code class="language-plaintext">Authorization: Bearer YOUR_API_TOKEN</code></pre>
                </div>
                
                <h3 class="text-xl font-semibold text-white mt-6 mb-3">Example Request with Authentication</h3>
                
                <div class="code-block p-4 mb-6">
<pre><code class="language-php">// PHP Example
$ch = curl_init('<?php echo SITE_URL; ?>/api/v1/data');
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
    'network' => 1,
    'phone' => '09167408768',
    'data_plan' => '111',
    'bypass' => false,
    'request_id' => 'DATA_' . time()
]));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Authorization: Bearer <?php echo $user['api_token']; ?>',
    'Content-Type: application/json'
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);
print_r($data);</code></pre>
                </div>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="data-endpoints">
                <h2 class="text-2xl font-semibold text-white mb-4">Data Endpoints</h2>
                
                <div class="mb-6">
                    <div class="flex items-center mb-3">
                        <span class="api-method post">POST</span>
                        <span class="api-endpoint">/api/v1/data</span>
                    </div>
                    
                    <p class="text-gray-300 mb-4">
                        Purchase a data bundle for a specified phone number.
                    </p>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Request Parameters</h3>
                    <div class="overflow-x-auto">
                        <table class="w-full api-param-table mb-4">
                            <thead>
                                <tr>
                                    <th>Parameter</th>
                                    <th>Type</th>
                                    <th>Required</th>
                                    <th>Description</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td>network</td>
                                    <td>integer</td>
                                    <td>Yes</td>
                                    <td>Network ID (See Network IDs section)</td>
                                </tr>
                                <tr>
                                    <td>phone</td>
                                    <td>string</td>
                                    <td>Yes</td>
                                    <td>Phone number to receive the data bundle</td>
                                </tr>
                                <tr>
                                    <td>data_plan</td>
                                    <td>string</td>
                                    <td>Yes</td>
                                    <td>Data plan ID (See Data Plans section)</td>
                                </tr>
                                <tr>
                                    <td>bypass</td>
                                    <td>boolean</td>
                                    <td>No</td>
                                    <td>Whether to bypass network validation (default: false)</td>
                                </tr>
                                <tr>
                                    <td>request_id</td>
                                    <td>string</td>
                                    <td>Yes</td>
                                    <td>Unique request identifier to prevent duplicate transactions</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
                    <div class="code-block p-4 mb-4">
<pre><code class="language-json">{
  "network": 1,
  "phone": "09167408768",
  "data_plan": "111",
  "bypass": false,
  "request_id": "DATA_1234567890"
}</code></pre>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Success Response</h3>
                    <div class="code-block p-4 mb-4">
<pre><code class="language-json">{
  "status": true,
  "message": "Data purchase successful",
  "data": {
    "transaction_reference": "TRX_1234567890",
    "amount": 500.00,
    "phone": "09167408768",
    "network": "MTN",
    "data_plan": "500MB for 30 days",
    "date": "2023-03-15 14:30:45"
  }
}</code></pre>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Error Response</h3>
                    <div class="code-block p-4">
<pre><code class="language-json">{
  "status": false,
  "message": "Insufficient balance",
  "error_code": "INSUFFICIENT_BALANCE"
}</code></pre>
                    </div>
                </div>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="airtime-endpoints">
                <h2 class="text-2xl font-semibold text-white mb-4">Airtime Endpoints</h2>
                
                <div class="mb-6">
                    <div class="flex items-center mb-3">
                        <span class="api-method post">POST</span>
                        <span class="api-endpoint">/api/v1/airtime</span>
                    </div>
                    
                    <p class="text-gray-300 mb-4">
                        Purchase airtime for a specified phone number.
                    </p>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Request Parameters</h3>
                    <div class="overflow-x-auto">
                        <table class="w-full api-param-table mb-4">
                            <thead>
                                <tr>
                                    <th>Parameter</th>
                                    <th>Type</th>
                                    <th>Required</th>
                                    <th>Description</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td>network</td>
                                    <td>integer</td>
                                    <td>Yes</td>
                                    <td>Network ID (See Network IDs section)</td>
                                </tr>
                                <tr>
                                    <td>phone</td>
                                    <td>string</td>
                                    <td>Yes</td>
                                    <td>Phone number to receive the airtime</td>
                                </tr>
                                <tr>
                                    <td>amount</td>
                                    <td>number</td>
                                    <td>Yes</td>
                                    <td>Amount of airtime to purchase (min: 50, max: 5000)</td>
                                </tr>
                                <tr>
                                    <td>plan_type</td>
                                    <td>string</td>
                                    <td>No</td>
                                    <td>Plan type (default: "VTU")</td>
                                </tr>
                                <tr>
                                    <td>bypass</td>
                                    <td>boolean</td>
                                    <td>No</td>
                                    <td>Whether to bypass network validation (default: false)</td>
                                </tr>
                                <tr>
                                    <td>request_id</td>
                                    <td>string</td>
                                    <td>Yes</td>
                                    <td>Unique request identifier to prevent duplicate transactions</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
                    <div class="code-block p-4 mb-4">
<pre><code class="language-json">{
  "network": 1,
  "phone": "09167408768",
  "amount": 500,
  "plan_type": "VTU",
  "bypass": false,
  "request_id": "AIRTIME_1234567890"
}</code></pre>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Success Response</h3>
                    <div class="code-block p-4 mb-4">
<pre><code class="language-json">{
  "status": true,
  "message": "Airtime purchase successful",
  "data": {
    "transaction_reference": "TRX_1234567890",
    "amount": 500.00,
    "phone": "09167408768",
    "network": "MTN",
    "date": "2023-03-15 14:30:45"
  }
}</code></pre>
                    </div>
                    
                    <h3 class="text-lg font-semibold text-white mb-2">Example Error Response</h3>
                    <div class="code-block p-4">
<pre><code class="language-json">{
  "status": false,
  "message": "Invalid amount. Amount must be between 50 and 5000",
  "error_code": "INVALID_AMOUNT"
}</code></pre>
                    </div>
                </div>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="data-plans">
                <h2 class="text-2xl font-semibold text-white mb-4">Data Plans</h2>
                
                <p class="text-gray-300 mb-4">
                    The following data plans are available for purchase:
                </p>
                
                <div class="overflow-x-auto">
                    <table class="w-full api-param-table mb-4">
                        <thead>
                            <tr>
                                <th>Plan ID</th>
                                <th>Network</th>
                                <th>Name</th>
                                <th>Size</th>
                                <th>Validity</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($dataPlans as $plan): ?>
                                <tr>
                                    <td><?php echo $plan['api_plan_id']; ?></td>
                                    <td><?php echo $plan['network_name']; ?></td>
                                    <td><?php echo $plan['name']; ?></td>
                                    <td><?php echo $plan['size']; ?></td>
                                    <td><?php echo $plan['validity']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                
                <div class="flex items-center mb-3 mt-6">
                    <span class="api-method get">GET</span>
                    <span class="api-endpoint">/api/v1/data/plans</span>
                </div>
                
                <p class="text-gray-300 mb-4">
                    You can also retrieve the latest data plans programmatically using this endpoint.
                </p>
                
                <h3 class="text-lg font-semibold text-white mb-2">Query Parameters</h3>
                <div class="overflow-x-auto">
                    <table class="w-full api-param-table mb-4">
                        <thead>
                            <tr>
                                <th>Parameter</th>
                                <th>Type</th>
                                <th>Required</th>
                                <th>Description</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>network</td>
                                <td>integer</td>
                                <td>No</td>
                                <td>Filter plans by network ID</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 api-section" id="network-ids">
                <h2 class="text-2xl font-semibold text-white mb-4">Network IDs</h2>
                
                <p class="text-gray-300 mb-4">
                    Use the following network IDs when making API requests:
                </p>
                
                <div class="overflow-x-auto">
                    <table class="w-full api-param-table mb-4">
                        <thead>
                            <tr>
                                <th>Network</th>
                                <th>ID</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($networks as $network): ?>
                                <tr>
                                    <td><?php echo $network['name']; ?></td>
                                    <td><?php echo $network['api_id']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                
                <div class="flex items-center mb-3 mt-6">
                    <span class="api-method get">GET</span>
                    <span class="api-endpoint">/api/v1/networks</span>
                </div>
                
                <p class="text-gray-300 mb-4">
                    You can also retrieve the latest network IDs programmatically using this endpoint.
                </p>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Initialize code highlighting
            hljs.highlightAll();
            
            // Toggle profile dropdown
            const profileButton = document.getElementById('profileDropdownButton');
            const profileDropdown = document.getElementById('profileDropdown');
            
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
            
            // Copy API token to clipboard
            const copyTokenBtn = document.getElementById('copyTokenBtn');
            const apiToken = document.getElementById('apiToken');
            
            copyTokenBtn.addEventListener('click', () => {
                const tempTextArea = document.createElement('textarea');
                tempTextArea.value = apiToken.textContent;
                document.body.appendChild(tempTextArea);
                tempTextArea.select();
                document.execCommand('copy');
                document.body.removeChild(tempTextArea);
                
                // Show success indicator
                copyTokenBtn.innerHTML = '<i class="fas fa-check text-green-500"></i>';
                setTimeout(() => {
                    copyTokenBtn.innerHTML = '<i class="fas fa-copy text-gray-400"></i>';
                }, 2000);
            });
            
            // Toggle regenerate token form
            const regenerateBtn = document.getElementById('regenerateBtn');
            const regenerateForm = document.getElementById('regenerateForm');
            const cancelBtn = document.getElementById('cancelBtn');
            
            regenerateBtn.addEventListener('click', () => {
                regenerateBtn.classList.add('hidden');
                regenerateForm.classList.remove('hidden');
            });
            
            cancelBtn.addEventListener('click', () => {
                regenerateForm.classList.add('hidden');
                regenerateBtn.classList.remove('hidden');
            });
            
            // Numeric input validation for PIN
            const pinInput = document.getElementById('pin');
            if (pinInput) {
                pinInput.addEventListener('input', (e) => {
                    e.target.value = e.target.value.replace(/[^0-9]/g, '').substring(0, 4);
                });
            }
            
            // Smooth scrolling for anchor links
            document.querySelectorAll('a[href^="#"]').forEach(anchor => {
                anchor.addEventListener('click', function(e) {
                    e.preventDefault();
                    
                    const targetId = this.getAttribute('href').substring(1);
                    const targetElement = document.getElementById(targetId);
                    
                    if (targetElement) {
                        window.scrollTo({
                            top: targetElement.offsetTop - 20,
                            behavior: 'smooth'
                        });
                    }
                });
            });
        });
    </script>
</body>
</html>