<?php
$pageTitle = 'API Tokens';
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Define generateApiKey function if it doesn't exist
if (!function_exists('generateApiKey')) {
    /**
     * Generate a random API key
     * 
     * @return string Random API key
     */
    function generateApiKey() {
        return bin2hex(random_bytes(32));
    }
}

// Check if user is API user before rendering the page
$userId = $_SESSION['user_id'] ?? 0;
$stmt = $conn->prepare("SELECT user_type, api_key FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

// Redirect non-API users with a flash message
if (!$user || $user['user_type'] !== 'api') {
    setFlashMessage('You need to upgrade to an API account to access API tokens.', 'error');
    header("Location: " . SITE_URL . "/dashboard/upgrade.php");
    exit;
}

// Continue with the rest of the page for API users
require_once './includes/header.php';

// Generate API key if not exists
if (empty($user['api_key'])) {
    $apiKey = generateApiKey();
    
    // Save API key to user
    $stmt = $conn->prepare("UPDATE users SET api_key = ? WHERE id = ?");
    $stmt->bind_param("si", $apiKey, $userId);
    $stmt->execute();
    
    // Refresh user data
    $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
}

// The rest of the api_tokens.php code remains the same

// Process regenerate API key
if (isset($_POST['regenerate_api_key']) && isset($_POST['confirm_regenerate']) && $_POST['confirm_regenerate'] === 'yes') {
    $newApiKey = generateApiKey();
    
    // Save new API key to user
    $stmt = $conn->prepare("UPDATE users SET api_key = ? WHERE id = ?");
    $stmt->bind_param("si", $newApiKey, $userId);
    
    if ($stmt->execute()) {
        // Create notification
        $title = "API Key Regenerated";
        $message = "Your API key has been regenerated successfully. Please update your applications with the new key.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications 
            (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'warning', 0)
        ");
        $stmt->bind_param("iss", $userId, $title, $message);
        $stmt->execute();
        
        // Refresh user data
        $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        // Set success message
        $successMessage = "API key regenerated successfully. Be sure to update all your applications with the new key.";
    } else {
        // Set error message
        $errorMessage = "Failed to regenerate API key. Please try again.";
    }
}

// Get API logs
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

$apiLogs = [];
$totalLogs = 0;

// Check if api_logs table exists
$tableExists = false;
try {
    $result = $conn->query("SHOW TABLES LIKE 'api_logs'");
    $tableExists = $result->num_rows > 0;
} catch (Exception $e) {
    // Table doesn't exist
    $tableExists = false;
}

if ($tableExists) {
    $stmt = $conn->prepare("
        SELECT * FROM api_logs 
        WHERE user_id = ? 
        ORDER BY created_at DESC
        LIMIT ? OFFSET ?
    ");
    $stmt->bind_param("iii", $userId, $limit, $offset);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($row = $result->fetch_assoc()) {
        $apiLogs[] = $row;
    }

    // Get total logs count for pagination
    $stmt = $conn->prepare("SELECT COUNT(*) as count FROM api_logs WHERE user_id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    $totalLogs = $row['count'];
}

$totalPages = ceil($totalLogs / $limit);
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">API Access</h1>
    
    <?php if (isset($successMessage)): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4">
            <?php echo $successMessage; ?>
        </div>
    <?php endif; ?>
    
    <?php if (isset($errorMessage)): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4">
            <?php echo $errorMessage; ?>
        </div>
    <?php endif; ?>
    
    <div class="text-sm text-gray-400 mb-6">
        Your API key allows your applications to interact with our services. Keep it secret and secure. Use this key to authenticate API requests.
    </div>
    
    <!-- API Key Card -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <h2 class="text-lg font-semibold text-white mb-4">Your API Key</h2>
        
        <div class="bg-gray-900 rounded-lg p-4 mb-4">
            <div class="flex items-center">
                <div id="apiKeyContainer" class="font-mono text-white bg-gray-900 flex-grow truncate">
                    <span id="apiKeyDisplay"><?php echo substr($user['api_key'], 0, 8) . '************************'; ?></span>
                    <span id="apiKeyFull" class="hidden"><?php echo $user['api_key']; ?></span>
                </div>
                <button id="toggleApiKey" class="ml-2 bg-gray-700 hover:bg-gray-600 text-white px-3 py-2 rounded-md">
                    <i class="fas fa-eye"></i>
                </button>
                <button id="copyApiKey" class="ml-2 bg-gray-700 hover:bg-gray-600 text-white px-3 py-2 rounded-md">
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="flex items-center mb-4">
            <i class="fas fa-exclamation-triangle text-yellow-400 mr-2"></i>
            <p class="text-gray-400 text-sm">
                Keep your API key secure and never share it publicly. If your key is compromised, regenerate it immediately.
            </p>
        </div>
        
        <form method="POST" action="" id="regenerateForm" class="mt-4">
    <input type="hidden" name="regenerate_api_key" value="1">
    <input type="hidden" name="confirm_regenerate" id="confirmRegenerate" value="no">
    <button type="button" id="regenerateBtn" class="py-2 px-4 bg-red-600 hover:bg-red-700 text-white rounded-md flex items-center">
        <i class="fas fa-sync-alt mr-2"></i> Regenerate API v1 Key
    </button>
</form>
    </div>
    
    <!-- API Documentation Link -->
    <div class="bg-gray-800 rounded-lg p-6">
        <h2 class="text-lg font-semibold text-white mb-4">API Documentation</h2>
        
        <p class="text-gray-400 mb-4">
            Learn how to use our API to integrate our services into your applications. The documentation includes examples, endpoints, and request/response formats.
        </p>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/api_docs.php" class="accent-button py-2 px-4 rounded-md text-white inline-flex items-center">
            <i class="fas fa-book mr-2"></i> View API Documentation
        </a>
    </div>
</div>

<!-- API Logs -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">API Request Logs</h2>
    
    <?php if (empty($apiLogs)): ?>
        <div class="text-center py-10">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-history text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-gray-400 mb-1">No API Logs Yet</h3>
            <p class="text-gray-500 text-sm">API request logs will appear here once you start using the API</p>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date/Time</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Endpoint</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Method</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Execution Time</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">IP Address</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($apiLogs as $log): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, Y, g:i:s a', strtotime($log['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo htmlspecialchars($log['endpoint']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm">
                                <span class="px-2 py-1 text-xs rounded-full 
                                    <?php echo $log['method'] === 'GET' ? 'bg-blue-500 bg-opacity-20 text-blue-400' : 
                                    ($log['method'] === 'POST' ? 'bg-green-500 bg-opacity-20 text-green-400' : 
                                    'bg-purple-500 bg-opacity-20 text-purple-400'); ?>">
                                    <?php echo $log['method']; ?>
                                </span>
                            </td>
                            <td class="py-3 px-4">
                                <span class="px-2 py-1 text-xs rounded-full 
                                    <?php echo $log['status'] === 'successful' ? 'bg-green-500 bg-opacity-20 text-green-400' : 
                                    'bg-red-500 bg-opacity-20 text-red-400'; ?>">
                                    <?php echo ucfirst($log['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo $log['execution_time'] ? round($log['execution_time'], 2) . ' ms' : 'N/A'; ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($log['ip_address'] ?? 'Unknown'); ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        
        <!-- Pagination -->
        <?php if ($totalPages > 1): ?>
            <div class="flex justify-center mt-6">
                <nav class="inline-flex rounded-md shadow">
                    <?php if ($page > 1): ?>
                        <a href="?page=<?php echo $page - 1; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-l-md hover:bg-gray-600">
                            <i class="fas fa-chevron-left"></i>
                        </a>
                    <?php else: ?>
                        <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-l-md cursor-not-allowed">
                            <i class="fas fa-chevron-left"></i>
                        </span>
                    <?php endif; ?>
                    
                    <?php
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $startPage + 4);
                    if ($endPage - $startPage < 4 && $startPage > 1) {
                        $startPage = max(1, $endPage - 4);
                    }
                    
                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?>" class="py-2 px-4 <?php echo $i === $page ? 'bg-indigo-600' : 'bg-gray-700 hover:bg-gray-600'; ?> text-white <?php echo $i === $startPage ? '' : 'border-l border-gray-600'; ?> <?php echo $i === $endPage ? 'rounded-r-md' : ''; ?>">
                            <?php echo $i; ?>
                        </a>
                    <?php endfor; ?>
                    
                    <?php if ($endPage < $totalPages): ?>
                        <span class="py-2 px-4 bg-gray-700 text-gray-300 border-l border-gray-600">...</span>
                        <a href="?page=<?php echo $totalPages; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-r-md hover:bg-gray-600 border-l border-gray-600">
                            <?php echo $totalPages; ?>
                        </a>
                    <?php endif; ?>
                    
                    <?php if ($page < $totalPages): ?>
                        <a href="?page=<?php echo $page + 1; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-r-md hover:bg-gray-600 border-l border-gray-600">
                            <i class="fas fa-chevron-right"></i>
                        </a>
                    <?php else: ?>
                        <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-r-md cursor-not-allowed border-l border-gray-600">
                            <i class="fas fa-chevron-right"></i>
                        </span>
                    <?php endif; ?>
                </nav>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- Confirmation Modal -->
<div id="confirmModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-yellow-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-yellow-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Regenerate API Key?</h3>
            <p class="text-gray-400 mt-2">
                Are you sure you want to regenerate your API key? Your current key will be invalidated, and all applications using it will need to be updated with the new key.
            </p>
        </div>
        <div class="flex justify-end space-x-3">
            <button type="button" id="cancelRegenerate" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600">
                Cancel
            </button>
            <button type="button" id="confirmRegenerate" class="py-2 px-4 bg-red-600 text-white rounded-md hover:bg-red-700">
                Yes, Regenerate
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // API Key Toggle
        const toggleApiKeyBtn = document.getElementById('toggleApiKey');
        const apiKeyDisplay = document.getElementById('apiKeyDisplay');
        const apiKeyFull = document.getElementById('apiKeyFull');
        
        toggleApiKeyBtn.addEventListener('click', function() {
            if (apiKeyDisplay.classList.contains('hidden')) {
                apiKeyDisplay.classList.remove('hidden');
                apiKeyFull.classList.add('hidden');
                toggleApiKeyBtn.innerHTML = '<i class="fas fa-eye"></i>';
            } else {
                apiKeyDisplay.classList.add('hidden');
                apiKeyFull.classList.remove('hidden');
                toggleApiKeyBtn.innerHTML = '<i class="fas fa-eye-slash"></i>';
            }
        });
        
        // Copy API Key
        const copyApiKeyBtn = document.getElementById('copyApiKey');
        
        copyApiKeyBtn.addEventListener('click', function() {
            const apiKey = apiKeyFull.textContent;
            
            // Create a temporary textarea to copy from
            const textarea = document.createElement('textarea');
            textarea.value = apiKey;
            textarea.style.position = 'fixed';  // Prevent scrolling to the bottom
            document.body.appendChild(textarea);
            textarea.select();
            
            try {
                // Execute copy command
                document.execCommand('copy');
                copyApiKeyBtn.innerHTML = '<i class="fas fa-check"></i>';
                setTimeout(function() {
                    copyApiKeyBtn.innerHTML = '<i class="fas fa-copy"></i>';
                }, 2000);
            } catch (err) {
                console.error('Could not copy text: ', err);
                copyApiKeyBtn.innerHTML = '<i class="fas fa-times"></i>';
                setTimeout(function() {
                    copyApiKeyBtn.innerHTML = '<i class="fas fa-copy"></i>';
                }, 2000);
            }
            
            // Clean up
            document.body.removeChild(textarea);
        });
        
        // Regenerate API Key
        const regenerateForm = document.getElementById('regenerateForm');
        const regenerateBtn = document.getElementById('regenerateBtn');
        const confirmRegenerate = document.getElementById('confirmRegenerate');
        const cancelRegenerate = document.getElementById('cancelRegenerate');
        const confirmRegenerateInput = document.getElementById('confirmRegenerate');
        const confirmModal = document.getElementById('confirmModal');
        
        regenerateBtn.addEventListener('click', function() {
            confirmModal.classList.remove('hidden');
        });
        
        confirmRegenerate.addEventListener('click', function() {
            confirmRegenerateInput.value = 'yes';
            regenerateForm.submit();
        });
        
        cancelRegenerate.addEventListener('click', function() {
            confirmModal.classList.add('hidden');
        });
        
        // Close modal when clicking outside
        window.addEventListener('click', function(e) {
            if (e.target === confirmModal) {
                confirmModal.classList.add('hidden');
            }
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>