<?php
// File: /dashboard/api_v2_documentation.php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// If user is not an API user, redirect to dashboard
if ($user['user_type'] !== 'api') {
    redirect(SITE_URL . '/dashboard');
}

$db = getDB();
$conn = $db->getConnection();

$errors = [];
$success = '';

// Process token regeneration
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['regenerate_token'])) {
    // Get form data
    $pin = isset($_POST['pin']) ? $_POST['pin'] : '';
    
    // Validate inputs
    if (empty($pin)) {
        $errors[] = 'Transaction PIN is required';
    } elseif (empty($user['pin'])) {
        $errors[] = 'You need to set a transaction PIN first. <a href="set_pin.php" class="text-indigo-400 underline">Set PIN now</a>';
    } elseif (!password_verify($pin, $user['pin'])) {
        $errors[] = 'Invalid transaction PIN';
    }
    
    // If no errors, regenerate token
    if (empty($errors)) {
        // Generate new API token
        $newToken = generateApiToken();
        
        // Update user record
        $stmt = $conn->prepare("UPDATE users SET api_token = ? WHERE id = ?");
        $stmt->bind_param("si", $newToken, $userId);
        
        if ($stmt->execute()) {
            $success = 'API token regenerated successfully!';
            
            // Refresh user data
            $user = getUserById($userId);
            
            // Send email notification
            $emailSubject = 'API Token Regenerated';
            $emailMessage = "Hello " . $user['full_name'] . ",\n\nYour API token has been regenerated. If you did not request this change, please contact our support team immediately.\n\nBest regards,\n" . getSetting('site_name') . " Team";
            
            sendEmail($user['email'], $emailSubject, $emailMessage);
        } else {
            $errors[] = 'Failed to regenerate token: ' . $conn->error;
        }
    }
}

// Get data plans for documentation
$dataPlans = [];
$stmt = $conn->prepare("SELECT dp.id, dp.name, dp.size, dp.validity, dp.api_plan_id, n.name as network_name, n.api_id as network_id
                      FROM data_plans dp
                      JOIN networks n ON dp.network_id = n.id
                      WHERE dp.status = 'active'
                      ORDER BY n.name, dp.price");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $dataPlans[] = $row;
}

// Get networks for documentation
$networks = [];
$stmt = $conn->prepare("SELECT id, name, api_id FROM networks WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $networks[] = $row;
}

// Group data plans by network
$plansByNetwork = [];
foreach ($dataPlans as $plan) {
    if (!isset($plansByNetwork[$plan['network_name']])) {
        $plansByNetwork[$plan['network_name']] = [];
    }
    $plansByNetwork[$plan['network_name']][] = $plan;
}

// Include header
require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">API v2 Documentation</h1>
        
        <a href="<?php echo SITE_URL; ?>/dashboard/api_tokens.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm flex items-center">
            <i class="fas fa-key mr-2"></i> Manage API Keys
        </a>
    </div>
    
    <div class="text-sm text-gray-400 mb-6">
        API v2 supports provider-compatible formats with the same plan/network IDs as v1. This makes integrating with existing systems easier.
    </div>
    
    <!-- API Token Section -->
    <div class="grid grid-cols-1 md:grid-cols-3 gap-6 mb-6">
        <!-- API Token -->
        <div class="dashboard-card rounded-lg shadow-md p-6 md:col-span-2">
            <h2 class="text-xl font-semibold text-white mb-3">Your API Token</h2>
            
            <div class="flex items-center mb-4">
                <div class="api-token bg-gray-800 p-3 rounded-md flex-grow mr-2 overflow-x-auto">
                    <code id="apiToken"><?php echo $user['api_token']; ?></code>
                </div>
                <button id="copyTokenBtn" class="p-2 rounded-md hover:bg-gray-700 transition-colors" title="Copy to clipboard">
                    <i class="fas fa-copy text-gray-400"></i>
                </button>
            </div>
            
            <p class="text-gray-400 text-sm mb-4">
                This token is used to authenticate all your API requests. Keep it secret and secure.
            </p>
            
            <form method="POST" action="" id="regenerateForm" class="hidden">
                <div class="mb-4">
                    <label for="pin" class="block text-sm font-medium text-gray-400 mb-1">Transaction PIN</label>
                    <input type="password" id="pin" name="pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                </div>
                
                <div class="mb-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> Regenerating your token will invalidate the previous one. All applications using the old token will need to be updated.
                    </p>
                </div>
                
                <div class="flex space-x-3">
                    <button type="button" id="cancelBtn" class="py-2 px-4 border border-gray-600 rounded-md shadow-sm text-sm font-medium text-gray-300 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Cancel
                    </button>
                    <button type="submit" name="regenerate_token" class="accent-button py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Confirm Regenerate
                    </button>
                </div>
            </form>
            
            <div id="regenerateBtn" class="mt-2">
                <button type="button" class="text-indigo-400 hover:text-indigo-300 text-sm">
                    <i class="fas fa-refresh mr-1"></i> Regenerate Token
                </button>
            </div>
        </div>
        
        <!-- API Quick Links -->
        <div class="dashboard-card rounded-lg shadow-md p-6">
            <h2 class="text-xl font-semibold text-white mb-3">Quick Links</h2>
            
            <nav class="space-y-2">
                <a href="#introduction" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Introduction
                </a>
                <a href="#dual-format" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Dual Format Support
                </a>
                <a href="#authentication" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Authentication
                </a>
                <a href="#user-endpoint" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    User & Balance Endpoints
                </a>
                <a href="#data-endpoint" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Data Purchase
                </a>
                <a href="#airtime-endpoint" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Airtime Purchase
                </a>
                <a href="#data-plans" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Available Data Plans
                </a>
                <a href="#network-ids" class="block px-3 py-2 rounded-md text-gray-300 hover:bg-gray-800 hover:text-white transition-colors">
                    Network IDs
                </a>
            </nav>
        </div>
    </div>
    
    <!-- API Documentation -->
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="introduction">
        <h2 class="text-2xl font-semibold text-white mb-4">Introduction</h2>
        
        <p class="text-gray-300 mb-4">
            The <?php echo getSetting('site_name'); ?> API v2 allows you to programmatically purchase data bundles and airtime using provider-compatible formats. This API is designed to make integration easier by supporting formats similar to common VTU providers.
        </p>
        
        <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
            <h3 class="font-semibold text-indigo-300 mb-2">Base URL</h3>
            <p class="text-gray-300 font-mono"><?php echo SITE_URL; ?>/api/v2</p>
        </div>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Request Format</h3>
        <p class="text-gray-300 mb-3">
            Most requests should be sent as HTTP POST requests with a JSON body. GET requests are used for retrieving information like account balance and available plans.
        </p>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Response Format</h3>
        <p class="text-gray-300 mb-3">
            All responses are returned in JSON format with both <code>data</code> and <code>user</code> keys for compatibility with different systems. A typical success response has the following structure:
        </p>
        
        <div class="code-block p-4 mb-6 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Success message",
  "data": {
    // Response data here
  },
  "user": {
    // Same data for compatibility
  }
}</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Success message",
  "data": {
    // Response data here
  },
  "user": {
    // Same data for compatibility
  }
}'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Error Handling</h3>
        <p class="text-gray-300 mb-3">
            When an error occurs, the response will have a <code>status</code> field set to <code>false</code> and an error message:
        </p>
        
        <div class="code-block p-4 mb-6 relative">
<pre><code class="language-json">{
  "status": false,
  "message": "Error message",
  "error_code": "ERROR_CODE"
}</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": false,
  "message": "Error message",
  "error_code": "ERROR_CODE"
}'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Rate Limiting</h3>
        <p class="text-gray-300 mb-3">
            API requests are limited to 120 GET requests and 60 POST requests per minute. If you exceed this limit, you'll receive a 429 Too Many Requests response.
        </p>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">API v2 vs API v1</h3>
        <p class="text-gray-300 mb-3">
            API v2 is designed to be compatible with popular VTU provider formats, while using the same simplified IDs as v1:
        </p>
        
        <div class="overflow-x-auto">
            <table class="w-full api-param-table mb-4">
                <thead>
                    <tr>
                        <th>Feature</th>
                        <th>API v1</th>
                        <th>API v2</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td>Authentication</td>
                        <td>X-API-KEY Header</td>
                        <td>Token-based Header</td>
                    </tr>
                    <tr>
                        <td>Data Purchase Endpoint</td>
                        <td>/api/v1/data/buy</td>
                        <td>/api/v2/data</td>
                    </tr>
                    <tr>
                        <td>Airtime Purchase Endpoint</td>
                        <td>/api/v1/airtime/buy</td>
                        <td>/api/v2/topup or /api/v2/airtime</td>
                    </tr>
                    <tr>
                        <td>Balance Check</td>
                        <td>/api/v1/balance</td>
                        <td>/api/v2/user or /api/v2/balance</td>
                    </tr>
                    <tr>
                        <td>Network/Plan IDs</td>
                        <td>Sequential IDs (1, 2, 3...)</td>
                        <td>Same sequential IDs (1, 2, 3...)</td>
                    </tr>
                    <tr>
                        <td>Response Format</td>
                        <td>Single data object</td>
                        <td>Contains both data and user objects</td>
                    </tr>
                </tbody>
            </table>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="dual-format">
        <h2 class="text-2xl font-semibold text-white mb-4">Dual Format Support</h2>
        
        <p class="text-gray-300 mb-4">
            The API v2 supports two response formats to ensure backward compatibility with existing integrations while offering a more structured format for new applications.
        </p>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Format Types</h3>
        
        <div class="grid grid-cols-1 md:grid-cols-2 gap-6 mb-6">
            <div class="dashboard-card rounded-lg shadow-md p-4">
                <h4 class="text-lg font-semibold text-white mb-2">1. MaskwaSub Format (Legacy)</h4>
                <p class="text-gray-300 mb-3">
                    The original format used by many existing VTU systems. This is the default format to ensure backward compatibility.
                </p>
                <div class="code-block p-4 mb-2 relative">
<pre><code class="language-json">{
  "id": 50917119,
  "network": 1,
  "ident": "10637d01dd8-cc33-4a",
  "balance_before": "60219.20000000001",
  "balance_after": "59445.20000000001",
  "mobile_number": "07048294626",
  "plan": 384,
  "Status": "successful",
  "api_response": "You have successfully...",
  "plan_network": "MTN",
  "plan_name": "1.0GB",
  "plan_type": "GIFTING",
  "plan_amount": "774.0",
  "create_date": "2025-04-23T17:45:38.805079",
  "Ported_number": true
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "id": 50917119,
  "network": 1,
  "ident": "10637d01dd8-cc33-4a",
  "balance_before": "60219.20000000001",
  "balance_after": "59445.20000000001",
  "mobile_number": "07048294626",
  "plan": 384,
  "Status": "successful",
  "api_response": "You have successfully...",
  "plan_network": "MTN",
  "plan_name": "1.0GB",
  "plan_type": "GIFTING",
  "plan_amount": "774.0",
  "create_date": "2025-04-23T17:45:38.805079",
  "Ported_number": true
}'>
                <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="dashboard-card rounded-lg shadow-md p-4">
            <h4 class="text-lg font-semibold text-white mb-2">2. New API v2 Format</h4>
            <p class="text-gray-300 mb-3">
                A more structured format with clear status indicators and error codes for new integrations.
            </p>
            <div class="code-block p-4 mb-2 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Data purchase successful",
  "data": {
    "transaction_reference": "DATA_1234567890",
    "amount": 774.0,
    "phone": "07048294626",
    "network": "MTN",
    "data_plan": "1.0GB",
    "date": "2025-04-23 17:45:38",
    "request_id": "DATA_1234567890",
    "balance_before": 60219.20,
    "balance_after": 59445.20
  }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Data purchase successful",
  "data": {
    "transaction_reference": "DATA_1234567890",
    "amount": 774.0,
    "phone": "07048294626",
    "network": "MTN",
    "data_plan": "1.0GB",
    "date": "2025-04-23 17:45:38",
    "request_id": "DATA_1234567890",
    "balance_before": 60219.20,
    "balance_after": 59445.20
  }
}'>
                <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
    </div>
    
    <h3 class="text-xl font-semibold text-white mt-6 mb-3">How Format Detection Works</h3>
    
    <p class="text-gray-300 mb-4">
        By default, all responses use the MaskwaSub format for backward compatibility. You can request the new format using one of these methods:
    </p>
    
    <div class="overflow-x-auto">
        <table class="w-full api-param-table mb-4">
            <thead>
                <tr>
                    <th>Method</th>
                    <th>Description</th>
                    <th>Example</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td>API Version Parameter</td>
                    <td>Add <code>api_version=2</code> to your request</td>
                    <td><code>{"network": 1, "mobile_number": "09012345678", "amount": 500, "api_version": "2"}</code></td>
                </tr>
                <tr>
                    <td>Format Parameter</td>
                    <td>Add <code>format=new</code> to your request</td>
                    <td><code>{"network": 1, "mobile_number": "09012345678", "amount": 500, "format": "new"}</code></td>
                </tr>
            </tbody>
        </table>
    </div>
    
    <div class="bg-blue-800 bg-opacity-30 border border-blue-700 rounded-md p-4 mt-4 mb-6">
        <div class="flex">
            <div class="flex-shrink-0">
                <i class="fas fa-info-circle text-blue-400"></i>
            </div>
            <div class="ml-3">
                <p class="text-sm text-blue-300">
                    <strong>Best Practice:</strong> For new integrations, we recommend using the new format by including <code>api_version=2</code> in your requests. This provides more structured responses and better error handling.
                </p>
            </div>
        </div>
    </div>
    
    <h3 class="text-xl font-semibold text-white mt-6 mb-3">Error Response Examples</h3>
    
    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
        <div class="dashboard-card rounded-lg shadow-md p-4">
            <h4 class="text-lg font-semibold text-white mb-2">MaskwaSub Format Error</h4>
            <div class="code-block p-4 mb-2 relative">
<pre><code class="language-json">{
  "Status": "failed",
  "message": "Insufficient balance"
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "Status": "failed",
  "message": "Insufficient balance"
}'>
                <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="dashboard-card rounded-lg shadow-md p-4">
            <h4 class="text-lg font-semibold text-white mb-2">New Format Error</h4>
            <div class="code-block p-4 mb-2 relative">
<pre><code class="language-json">{
  "status": false,
  "message": "Insufficient balance",
  "error_code": "INSUFFICIENT_BALANCE"
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": false,
  "message": "Insufficient balance",
  "error_code": "INSUFFICIENT_BALANCE"
}'>
                <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
    </div>
    
    <h3 class="text-xl font-semibold text-white mt-6 mb-3">Example Implementation</h3>
    
    <div class="code-block p-4 mb-4 relative">
<pre><code class="language-php">// Example client code showing how to use both formats
$ch = curl_init('<?php echo SITE_URL; ?>/api/v2/topup');
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);

// Choose the format you want:
$useNewFormat = true; // Change to false for MaskwaSub format

$requestData = [
    'network' => 1,
    'mobile_number' => '09012345678',
    'amount' => 500,
    'request_id' => 'AIRTIME_' . time()
];

// Add format indicator if using new format
if ($useNewFormat) {
    $requestData['api_version'] = '2';
}

curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($requestData));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Authorization: Token YOUR_API_TOKEN',
    'Content-Type: application/json'
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);

// Handle different response formats
if ($useNewFormat) {
    if ($data['status'] === true) {
        echo "Transaction successful: " . $data['message'] . "\n";
        echo "Amount: " . $data['data']['amount'] . "\n";
        echo "Phone: " . $data['data']['phone'] . "\n";
        echo "Reference: " . $data['data']['transaction_reference'] . "\n";
    } else {
        echo "Error: " . $data['message'] . "\n";
        echo "Error code: " . $data['error_code'] . "\n";
    }
} else {
    if ($data['Status'] === "successful") {
        echo "Transaction successful\n";
        echo "Amount: " . $data['amount'] . "\n";
        echo "Phone: " . $data['mobile_number'] . "\n";
        echo "Reference: " . $data['ident'] . "\n";
    } else {
        echo "Error: " . $data['message'] . "\n";
    }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='// Example client code showing how to use both formats
$ch = curl_init("<?php echo SITE_URL; ?>/api/v2/topup");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);

// Choose the format you want:
$useNewFormat = true; // Change to false for MaskwaSub format

$requestData = [
    "network" => 1,
    "mobile_number" => "09012345678",
    "amount" => 500,
    "request_id" => "AIRTIME_" . time()
];

// Add format indicator if using new format
if ($useNewFormat) {
    $requestData["api_version"] = "2";
}

curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($requestData));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    "Authorization: Token YOUR_API_TOKEN",
    "Content-Type: application/json"
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);

// Handle different response formats
if ($useNewFormat) {
    if ($data["status"] === true) {
        echo "Transaction successful: " . $data["message"] . "\n";
        echo "Amount: " . $data["data"]["amount"] . "\n";
        echo "Phone: " . $data["data"]["phone"] . "\n";
        echo "Reference: " . $data["data"]["transaction_reference"] . "\n";
    } else {
        echo "Error: " . $data["message"] . "\n";
        echo "Error code: " . $data["error_code"] . "\n";
    }
} else {
    if ($data["Status"] === "successful") {
        echo "Transaction successful\n";
        echo "Amount: " . $data["amount"] . "\n";
        echo "Phone: " . $data["mobile_number"] . "\n";
        echo "Reference: " . $data["ident"] . "\n";
    } else {
        echo "Error: " . $data["message"] . "\n";
    }
}'>
                <i class="fas fa-copy"></i>
                </button>
            </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="authentication">
        <h2 class="text-2xl font-semibold text-white mb-4">Authentication</h2>
        
        <p class="text-gray-300 mb-4">
            All API requests require authentication using your API token. Include your token in the request headers as follows:
        </p>
        
        <div class="code-block p-4 mb-6 relative">
<pre><code class="language-plaintext">Authorization: Token YOUR_API_TOKEN</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='Authorization: Token <?php echo $user['api_token']; ?>'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-xl font-semibold text-white mt-6 mb-3">Example Request with Authentication</h3>
        
        <div class="code-block p-4 mb-6 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/user' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json'</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/user" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json"'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <div class="bg-yellow-800 bg-opacity-30 border border-yellow-700 rounded-md p-4 mt-4">
            <div class="flex">
                <div class="flex-shrink-0">
                    <i class="fas fa-exclamation-triangle text-yellow-400"></i>
                </div>
                <div class="ml-3">
                    <p class="text-sm text-yellow-300">
                        Keep your API token secure. Do not share it in publicly accessible code or repositories. If your token is compromised, regenerate it immediately.
                    </p>
                </div>
            </div>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="user-endpoint">
        <h2 class="text-2xl font-semibold text-white mb-4">User & Balance Endpoints</h2>
        
        <div class="mb-6">
            <div class="flex items-center mb-3">
                <span class="api-method get">GET</span>
                <span class="api-endpoint">/api/v2/user</span>
            </div>
            
            <p class="text-gray-300 mb-4">
                Retrieves your account information including balance and other account details.
            </p>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/user' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json'</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/user" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json"'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Response</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "User information retrieved successfully",
  "user": {
    "id": 123,
    "username": "johndoe",
    "email": "john@example.com",
    "phone": "1234567890",
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "account_type": "api",
    "created_at": "2023-01-01 12:00:00",
    "currency": "₦"
  },
  "data": {
    "id": 123,
    "username": "johndoe",
    "email": "john@example.com",
    "phone": "1234567890",
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "account_type": "api",
    "created_at": "2023-01-01 12:00:00",
    "currency": "₦"
  }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "User information retrieved successfully",
  "user": {
    "id": 123,
    "username": "johndoe",
    "email": "john@example.com",
    "phone": "1234567890",
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "account_type": "api",
    "created_at": "2023-01-01 12:00:00",
    "currency": "₦"
  },
  "data": {
    "id": 123,
    "username": "johndoe",
    "email": "john@example.com",
    "phone": "1234567890",
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "account_type": "api",
    "created_at": "2023-01-01 12:00:00",
    "currency": "₦"
  }
}'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
        
        <div class="mb-6">
            <div class="flex items-center mb-3">
                <span class="api-method get">GET</span>
                <span class="api-endpoint">/api/v2/balance</span>
            </div>
            
            <p class="text-gray-300 mb-4">
                Retrieves only your account balance. Simpler endpoint when you only need balance information.
            </p>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/balance' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json'</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/balance" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json"'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Response</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Balance retrieved successfully",
  "user": {
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "currency": "₦"
  },
  "data": {
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "currency": "₦"
  }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Balance retrieved successfully",
  "user": {
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "currency": "₦"
  },
  "data": {
    "balance": 5000.50,
    "account_balance": 5000.50,
    "wallet_balance": 5000.50,
    "Account_balance": 5000.50,
    "Wallet_balance": 5000.50,
    "Balance": 5000.50,
    "currency": "₦"
  }
}'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <div class="bg-blue-800 bg-opacity-30 border border-blue-700 rounded-md p-4 mt-4">
                <div class="flex">
                    <div class="flex-shrink-0">
                        <i class="fas fa-info-circle text-blue-400"></i>
                    </div>
                    <div class="ml-3">
                        <p class="text-sm text-blue-300">
                            Notice that the balance is provided in multiple formats (balance, account_balance, wallet_balance, etc.) for compatibility with different systems.
                        </p>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="data-endpoint">
        <h2 class="text-2xl font-semibold text-white mb-4">Data Purchase</h2>
        
        <div class="mb-6">
            <div class="flex items-center mb-3">
                <span class="api-method post">POST</span>
                <span class="api-endpoint">/api/v2/data</span>
            </div>
            
            <p class="text-gray-300 mb-4">
                Purchase a data bundle for a specified phone number.
            </p>
            
            <h3 class="text-lg font-semibold text-white mb-2">Request Parameters</h3>
            <div class="overflow-x-auto">
                <table class="w-full api-param-table mb-4">
                    <thead>
                        <tr>
                            <th>Parameter</th>
                            <th>Type</th>
                            <th>Required</th>
                            <th>Description</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>network</td>
                            <td>integer</td>
                            <td>Yes</td>
                            <td>Network ID (1=MTN, 2=Airtel, etc.)</td>
                        </tr>
                        <tr>
                            <td>mobile_number</td>
                            <td>string</td>
                            <td>Yes</td>
                            <td>Phone number to receive the data bundle</td>
                        </tr>
                        <tr>
                            <td>plan</td>
                            <td>integer</td>
                            <td>Yes</td>
                            <td>Data plan ID (1, 2, 3, etc.)</td>
                        </tr>
                        <tr>
                            <td>Ported_number</td>
                            <td>boolean</td>
                            <td>No</td>
                            <td>Whether the number is ported (default: false)</td>
                        </tr>
                        <tr>
                            <td>request_id</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Unique identifier to prevent duplicate transactions</td>
                        </tr>
                        <tr>
                            <td>api_version</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Set to "2" for new format response (default: MaskwaSub format)</td>
                        </tr>
                        <tr>
                            <td>format</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Set to "new" for new format response (alternative to api_version)</td>
                        </tr>
                    </tbody>
                </table>
            </div>
            
            <div class="bg-yellow-800 bg-opacity-30 border border-yellow-700 rounded-md p-4 mt-4 mb-4">
                <div class="flex">
                    <div class="flex-shrink-0">
                        <i class="fas fa-exclamation-triangle text-yellow-400"></i>
                    </div>
                    <div class="ml-3">
                        <p class="text-sm text-yellow-300">
                            <strong>IMPORTANT:</strong> The <code>plan</code> parameter expects a simple numeric ID (1, 2, 3, etc.) just like in API v1. These are <strong>not</strong> the provider's IDs, but our own sequential IDs.
                        </p>
                    </div>
                </div>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/data' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json' \
--data '{
    "network": 1,
    "mobile_number": "09012345678",
    "plan": 1,
    "Ported_number": true,
    "api_version": "2"
}'</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/data" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json" \
--data "{
    \"network\": 1,
    \"mobile_number\": \"09012345678\",
    \"plan\": 1,
    \"Ported_number\": true,
    \"api_version\": \"2\"
}"'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">PHP Example</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-php">$ch = curl_init('<?php echo SITE_URL; ?>/api/v2/data');
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
    'network' => 1,
    'mobile_number' => '09012345678',
    'plan' => 1,
    'Ported_number' => true,
    'request_id' => 'DATA_' . time(),
    'api_version' => '2' // Remove for MaskwaSub format
]));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...',
    'Content-Type: application/json'
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);
print_r($data);</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='$ch = curl_init("<?php echo SITE_URL; ?>/api/v2/data");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
    "network" => 1,
    "mobile_number" => "09012345678",
    "plan" => 1,
    "Ported_number" => true,
    "request_id" => "DATA_" . time(),
    "api_version" => "2" // Remove for MaskwaSub format
]));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    "Authorization: Token <?php echo $user['api_token']; ?>",
    "Content-Type: application/json"
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);
print_r($data);'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Success Response</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Data purchase successful",
  "data": {
    "transaction_reference": "DATA_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "data_plan": "1GB Daily",
    "date": "2023-03-15 14:30:45",
    "request_id": "DATA_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  },
  "user": {
    "transaction_reference": "DATA_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "data_plan": "1GB Daily",
    "date": "2023-03-15 14:30:45",
    "request_id": "DATA_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Data purchase successful",
  "data": {
    "transaction_reference": "DATA_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "data_plan": "1GB Daily",
    "date": "2023-03-15 14:30:45",
    "request_id": "DATA_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  },
  "user": {
    "transaction_reference": "DATA_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "data_plan": "1GB Daily",
    "date": "2023-03-15 14:30:45",
    "request_id": "DATA_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  }
}'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Error Response</h3>
            <div class="code-block p-4 relative">
<pre><code class="language-json">{
  "status": false,
  "message": "Insufficient balance",
  "error_code": "INSUFFICIENT_BALANCE"
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": false,
  "message": "Insufficient balance",
  "error_code": "INSUFFICIENT_BALANCE"
}'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="airtime-endpoint">
        <h2 class="text-2xl font-semibold text-white mb-4">Airtime Purchase</h2>
        
        <div class="mb-6">
            <div class="flex items-center mb-3">
                <span class="api-method post">POST</span>
                <span class="api-endpoint">/api/v2/topup or /api/v2/airtime</span>
            </div>
            
            <p class="text-gray-300 mb-4">
                Purchase airtime for a specified phone number. Both endpoints work identically.
            </p>
            
            <h3 class="text-lg font-semibold text-white mb-2">Request Parameters</h3>
            <div class="overflow-x-auto">
                <table class="w-full api-param-table mb-4">
                    <thead>
                        <tr>
                            <th>Parameter</th>
                            <th>Type</th>
                            <th>Required</th>
                            <th>Description</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>network</td>
                            <td>integer</td>
                            <td>Yes</td>
                            <td>Network ID (1=MTN, 2=Airtel, etc.)</td>
                        </tr>
                        <tr>
                            <td>mobile_number</td>
                            <td>string</td>
                            <td>Yes</td>
                            <td>Phone number to receive the airtime</td>
                        </tr>
                        <tr>
                            <td>amount</td>
                            <td>number</td>
                            <td>Yes</td>
                            <td>Amount of airtime to purchase (min: 50, max: 5000)</td>
                        </tr>
                        <tr>
                            <td>Ported_number</td>
                            <td>boolean</td>
                            <td>No</td>
                            <td>Whether the number is ported (default: false)</td>
                        </tr>
                        <tr>
                            <td>airtime_type</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Type of airtime (default: "VTU")</td>
                        </tr>
                        <tr>
                            <td>request_id</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Unique identifier to prevent duplicate transactions</td>
                        </tr>
                        <tr>
                            <td>api_version</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Set to "2" for new format response (default: MaskwaSub format)</td>
                        </tr>
                        <tr>
                            <td>format</td>
                            <td>string</td>
                            <td>No</td>
                            <td>Set to "new" for new format response (alternative to api_version)</td>
                        </tr>
                    </tbody>
                </table>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/topup' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json' \
--data '{
    "network": 1,
    "mobile_number": "09012345678",
    "amount": 500,
    "Ported_number": true,
    "airtime_type": "VTU",
    "api_version": "2"
}'</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/topup" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json" \
--data "{
    \"network\": 1,
    \"mobile_number\": \"09012345678\",
    \"amount\": 500,
    \"Ported_number\": true,
    \"airtime_type\": \"VTU\",
    \"api_version\": \"2\"
}"'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">PHP Example</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-php">$ch = curl_init('<?php echo SITE_URL; ?>/api/v2/topup');
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
    'network' => 1,
    'mobile_number' => '09012345678',
    'amount' => 500,
    'Ported_number' => true,
    'airtime_type' => 'VTU',
    'request_id' => 'AIRTIME_' . time(),
    'api_version' => '2' // Remove for MaskwaSub format
]));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...',
    'Content-Type: application/json'
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);
print_r($data);</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='$ch = curl_init("<?php echo SITE_URL; ?>/api/v2/topup");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
    "network" => 1,
    "mobile_number" => "09012345678",
    "amount" => 500,
    "Ported_number" => true,
    "airtime_type" => "VTU",
    "request_id" => "AIRTIME_" . time(),
    "api_version" => "2" // Remove for MaskwaSub format
]));
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    "Authorization: Token <?php echo $user['api_token']; ?>",
    "Content-Type: application/json"
]);

$response = curl_exec($ch);
curl_close($ch);

$data = json_decode($response, true);
print_r($data);'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
            
            <h3 class="text-lg font-semibold text-white mb-2">Example Success Response</h3>
            <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Airtime purchase successful",
  "data": {
    "transaction_reference": "AIRTIME_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "date": "2023-03-15 14:30:45",
    "request_id": "AIRTIME_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  },
  "user": {
    "transaction_reference": "AIRTIME_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "date": "2023-03-15 14:30:45",
    "request_id": "AIRTIME_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  }
}</code></pre>
                <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Airtime purchase successful",
  "data": {
    "transaction_reference": "AIRTIME_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "date": "2023-03-15 14:30:45",
    "request_id": "AIRTIME_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  },
  "user": {
    "transaction_reference": "AIRTIME_1234567890",
    "amount": 500.00,
    "phone": "09012345678",
    "network": "MTN",
    "date": "2023-03-15 14:30:45",
    "request_id": "AIRTIME_1234567890",
    "balance_before": 5500.50,
    "balance_after": 5000.50
  }
}'>
                    <i class="fas fa-copy"></i>
                </button>
            </div>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 api-section" id="data-plans">
        <h2 class="text-2xl font-semibold text-white mb-4">Available Data Plans</h2>
        
        <div class="flex items-center mb-3">
            <span class="api-method get">GET</span>
            <span class="api-endpoint">/api/v2/data-plans</span>
        </div>
        
        <p class="text-gray-300 mb-4">
            Retrieve all available data plans with real-time pricing.
        </p>
        
        <h3 class="text-lg font-semibold text-white mb-2">Query Parameters</h3>
        <div class="overflow-x-auto">
            <table class="w-full api-param-table mb-4">
                <thead>
                    <tr>
                        <th>Parameter</th>
                        <th>Type</th>
                        <th>Required</th>
                        <th>Description</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td>network</td>
                        <td>integer</td>
                        <td>No</td>
                        <td>Filter plans by network ID</td>
                    </tr>
                </tbody>
            </table>
        </div>
        
        <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
        <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/data-plans?network=1' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json'</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/data-plans?network=1" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json"'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-lg font-semibold text-white mb-2">Example Response</h3>
        <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Data plans retrieved successfully",
  "data": [
    {
      "id": 1,
      "name": "1GB Daily",
      "size": "1GB",
      "price": 300.00,
      "validity": "1 day",
      "network": "MTN",
      "network_id": 1
    },
    {
      "id": 2,
      "name": "2GB Weekly",
      "size": "2GB",
      "price": 500.00,
      "validity": "7 days",
      "network": "MTN",
      "network_id": 1
    }
    // More plans...
  ],
  "user": [
    {
      "id": 1,
      "name": "1GB Daily",
      "size": "1GB",
      "price": 300.00,
      "validity": "1 day",
      "network": "MTN",
      "network_id": 1
    },
    {
      "id": 2,
      "name": "2GB Weekly",
      "size": "2GB",
      "price": 500.00,
      "validity": "7 days",
      "network": "MTN",
      "network_id": 1
    }
    // More plans...
  ]
}</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Data plans retrieved successfully",
  "data": [
    {
      "id": 1,
      "name": "1GB Daily",
      "size": "1GB",
      "price": 300.00,
      "validity": "1 day",
      "network": "MTN",
      "network_id": 1
    },
    {
      "id": 2,
      "name": "2GB Weekly",
      "size": "2GB",
      "price": 500.00,
      "validity": "7 days",
      "network": "MTN",
      "network_id": 1
    }
  ],
  "user": [
    {
      "id": 1,
      "name": "1GB Daily",
      "size": "1GB",
      "price": 300.00,
      "validity": "1 day",
      "network": "MTN",
      "network_id": 1
    },
    {
      "id": 2,
      "name": "2GB Weekly",
      "size": "2GB",
      "price": 500.00,
      "validity": "7 days",
      "network": "MTN",
      "network_id": 1
    }
  ]
}'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <div class="bg-blue-800 bg-opacity-30 border border-blue-700 rounded-md p-4 mt-4 mb-6">
            <div class="flex">
                <div class="flex-shrink-0">
                    <i class="fas fa-info-circle text-blue-400"></i>
                </div>
                <div class="ml-3">
                    <p class="text-sm text-blue-300">
                        The plan IDs are sequential numeric IDs (1, 2, 3, etc.) - the same IDs used in API v1. The API returns real-time prices based on your account type.
                    </p>
                </div>
            </div>
        </div>
        
        <h3 class="text-xl font-semibold text-white mb-4">Current Data Plans</h3>
        
        <!-- Network tabs -->
        <div class="mb-6">
            <div class="border-b border-gray-700">
                <nav class="-mb-px flex space-x-4 overflow-x-auto" id="network-tabs">
                    <?php $firstNetwork = true; 
                    foreach (array_keys($plansByNetwork) as $networkName): ?>
                        <button class="network-tab <?php echo $firstNetwork ? 'text-white border-indigo-500' : 'text-gray-400 border-transparent hover:text-white hover:border-gray-400'; ?> border-b-2 px-3 py-2 font-medium text-sm whitespace-nowrap" data-network="<?php echo htmlspecialchars($networkName); ?>">
                            <?php echo htmlspecialchars($networkName); ?>
                        </button>
                    <?php $firstNetwork = false; endforeach; ?>
                </nav>
            </div>
            
            <!-- Tab content -->
            <?php $firstNetwork = true; 
            foreach ($plansByNetwork as $networkName => $plans): ?>
                <div id="network-<?php echo strtolower(str_replace(' ', '-', $networkName)); ?>" class="network-tab-content <?php echo $firstNetwork ? '' : 'hidden'; ?>">
                    <div class="overflow-x-auto">
                        <table class="w-full api-param-table mb-4">
                            <thead>
                                <tr>
                                    <th>Plan ID</th>
                                    <th>Network</th>
                                    <th>Name</th>
                                    <th>Size</th>
                                    <th>Validity</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($plans as $plan): ?>
                                    <tr>
                                        <td class="font-mono"><?php echo $plan['id']; ?></td>
                                        <td><?php echo $plan['network_name']; ?> (ID: <?php echo $plan['network_id']; ?>)</td>
                                        <td><?php echo $plan['name']; ?></td>
                                        <td><?php echo $plan['size']; ?></td>
                                        <td><?php echo $plan['validity']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php $firstNetwork = false; endforeach; ?>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 api-section" id="network-ids">
        <h2 class="text-2xl font-semibold text-white mb-4">Network IDs</h2>
        
        <div class="flex items-center mb-3">
            <span class="api-method get">GET</span>
            <span class="api-endpoint">/api/v2/networks</span>
        </div>
        
        <p class="text-gray-300 mb-4">
            Retrieve all available network IDs.
        </p>
        
        <h3 class="text-lg font-semibold text-white mb-2">Example Request</h3>
        <div class="code-block p-4 mb-4 relative">
<pre><code class="language-bash">curl --location '<?php echo SITE_URL; ?>/api/v2/networks' \
--header 'Authorization: Token <?php echo substr($user['api_token'], 0, 10); ?>...' \
--header 'Content-Type: application/json'</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='curl --location "<?php echo SITE_URL; ?>/api/v2/networks" \
--header "Authorization: Token <?php echo $user['api_token']; ?>" \
--header "Content-Type: application/json"'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-lg font-semibold text-white mb-2">Example Response</h3>
        <div class="code-block p-4 mb-4 relative">
<pre><code class="language-json">{
  "status": true,
  "message": "Networks retrieved successfully",
  "data": [
    {
      "id": 1,
      "name": "MTN"
    },
    {
      "id": 2,
      "name": "Airtel"
    },
    {
      "id": 3,
      "name": "GLO"
    },
    {
      "id": 4,
      "name": "9mobile"
    }
  ],
  "user": [
    {
      "id": 1,
      "name": "MTN"
    },
    {
      "id": 2,
      "name": "Airtel"
    },
    {
      "id": 3,
      "name": "GLO"
    },
    {
      "id": 4,
      "name": "9mobile"
    }
  ]
}</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='{
  "status": true,
  "message": "Networks retrieved successfully",
  "data": [
    {
      "id": 1,
      "name": "MTN"
    },
    {
      "id": 2,
      "name": "Airtel"
    },
    {
      "id": 3,
      "name": "GLO"
    },
    {
      "id": 4,
      "name": "9mobile"
    }
  ],
  "user": [
    {
      "id": 1,
      "name": "MTN"
    },
    {
      "id": 2,
      "name": "Airtel"
    },
    {
      "id": 3,
      "name": "GLO"
    },
    {
      "id": 4,
      "name": "9mobile"
    }
  ]
}'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
        
        <h3 class="text-xl font-semibold text-white mb-4">Current Network IDs</h3>
        
        <div class="overflow-x-auto">
            <table class="w-full api-param-table mb-4">
                <thead>
                    <tr>
                        <th>Network</th>
                        <th>ID</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($networks as $network): ?>
                        <tr>
                            <td><?php echo $network['name']; ?></td>
                            <td class="font-mono"><?php echo $network['id']; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Error Codes -->
<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h2 class="text-xl font-bold text-white mb-4">Error Codes</h2>
    
    <div class="overflow-x-auto">
        <table class="min-w-full">
            <thead class="bg-gray-800">
                <tr>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Error Code</th>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Description</th>
                </tr>
            </thead>
            <tbody class="divide-y divide-gray-700">
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">AUTHENTICATION_FAILED</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Invalid or missing API token</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">INSUFFICIENT_BALANCE</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Not enough balance to complete the transaction</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">INVALID_NETWORK</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Network ID not found or inactive</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">INVALID_PLAN</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Data plan ID not found or inactive</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">INVALID_PHONE_NUMBER</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Invalid phone number format</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">INVALID_AMOUNT</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Amount is outside the allowed range</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">MISSING_REQUIRED_FIELDS</td>
                    <td class="py-3 px-4 text-sm text-gray-300">One or more required fields are missing</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">DUPLICATE_TRANSACTION</td>
                    <td class="py-3 px-4 text-sm text-gray-300">A transaction with this request_id already exists</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">PROVIDER_ERROR</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Error from the service provider</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">RATE_LIMIT_EXCEEDED</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Too many requests in a short time period</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-red-400">SYSTEM_ERROR</td>
                    <td class="py-3 px-4 text-sm text-gray-300">Internal system error</td>
                </tr>
            </tbody>
        </table>
    </div>
</div>

<!-- Rate Limits -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">Rate Limits</h2>
    
    <p class="text-gray-400 mb-4">
        To ensure system stability and fair usage, API requests are subject to rate limiting:
    </p>
    
    <div class="overflow-x-auto">
        <table class="min-w-full">
            <thead class="bg-gray-800">
                <tr>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Endpoint</th>
                    <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Rate Limit</th>
                </tr>
            </thead>
            <tbody class="divide-y divide-gray-700">
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">GET endpoints</td>
                    <td class="py-3 px-4 text-sm text-gray-300">120 requests per minute</td>
                </tr>
                <tr class="hover:bg-gray-700">
                    <td class="py-3 px-4 text-sm text-white">POST endpoints</td>
                    <td class="py-3 px-4 text-sm text-gray-300">60 requests per minute</td>
                </tr>
            </tbody>
        </table>
    </div>
    
    <div class="bg-gray-700 rounded-lg p-4 mt-6">
        <h3 class="text-white font-semibold mb-2">Rate Limit Headers</h3>
        <p class="text-gray-400 mb-3">
            Each API response includes headers that indicate your current rate limit status:
        </p>
        
        <div class="bg-gray-800 rounded p-3 overflow-x-auto relative">
            <pre class="text-gray-300"><code>X-RateLimit-Limit: 60          # Total number of requests allowed per minute
X-RateLimit-Remaining: 58     # Remaining requests in the current minute
X-RateLimit-Reset: 1612345678 # Timestamp when the rate limit will reset</code></pre>
            <button class="copy-btn absolute top-3 right-3 text-gray-400 hover:text-white" data-copy='X-RateLimit-Limit: 60          # Total number of requests allowed per minute
X-RateLimit-Remaining: 58     # Remaining requests in the current minute
X-RateLimit-Reset: 1612345678 # Timestamp when the rate limit will reset'>
                <i class="fas fa-copy"></i>
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Initialize code highlighting
        if (typeof hljs !== 'undefined') {
            hljs.highlightAll();
        }
        
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        if (profileButton && profileDropdown) {
            profileButton.addEventListener('click', () => {
                profileDropdown.classList.toggle('hidden');
            });
            
            // Close dropdown when clicking outside
            document.addEventListener('click', (event) => {
                if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                    profileDropdown.classList.add('hidden');
                }
            });
        }
        
        // Copy API token to clipboard
        const copyTokenBtn = document.getElementById('copyTokenBtn');
        const apiToken = document.getElementById('apiToken');
        
        if (copyTokenBtn && apiToken) {
            copyTokenBtn.addEventListener('click', () => {
                const tempTextArea = document.createElement('textarea');
                tempTextArea.value = apiToken.textContent;
                document.body.appendChild(tempTextArea);
                tempTextArea.select();
                document.execCommand('copy');
                document.body.removeChild(tempTextArea);
                
                // Show success indicator
                copyTokenBtn.innerHTML = '<i class="fas fa-check text-green-500"></i>';
                setTimeout(() => {
                    copyTokenBtn.innerHTML = '<i class="fas fa-copy text-gray-400"></i>';
                }, 2000);
            });
        }
        
        // Copy code snippets
        const copyButtons = document.querySelectorAll('.copy-btn');
        
        copyButtons.forEach(button => {
            button.addEventListener('click', function() {
                const textToCopy = this.getAttribute('data-copy');
                
                const tempTextArea = document.createElement('textarea');
                tempTextArea.value = textToCopy;
                document.body.appendChild(tempTextArea);
                tempTextArea.select();
                document.execCommand('copy');
                document.body.removeChild(tempTextArea);
                
                // Show success indicator
                this.innerHTML = '<i class="fas fa-check text-green-500"></i>';
                setTimeout(() => {
                    this.innerHTML = '<i class="fas fa-copy text-gray-400"></i>';
                }, 2000);
            });
        });
        
        // Toggle regenerate token form
        const regenerateBtn = document.getElementById('regenerateBtn');
        const regenerateForm = document.getElementById('regenerateForm');
        const cancelBtn = document.getElementById('cancelBtn');
        
        if (regenerateBtn && regenerateForm && cancelBtn) {
            regenerateBtn.addEventListener('click', () => {
                regenerateBtn.classList.add('hidden');
                regenerateForm.classList.remove('hidden');
            });
            
            cancelBtn.addEventListener('click', () => {
                regenerateForm.classList.add('hidden');
                regenerateBtn.classList.remove('hidden');
            });
        }
        
        // Network Tab Switching
        const networkTabs = document.querySelectorAll('.network-tab');
        
        networkTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const networkName = this.getAttribute('data-network');
                const tabId = 'network-' + networkName.toLowerCase().replace(/ /g, '-');
                
                // Hide all network contents
                document.querySelectorAll('.network-tab-content').forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all network tabs
                networkTabs.forEach(tab => {
                    tab.classList.remove('text-white', 'border-indigo-500');
                    tab.classList.add('text-gray-400', 'border-transparent', 'hover:text-white', 'hover:border-gray-400');
                });
                
                // Show selected network content
                document.getElementById(tabId).classList.remove('hidden');
                
                // Highlight selected tab
                this.classList.remove('text-gray-400', 'border-transparent', 'hover:text-white', 'hover:border-gray-400');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
        
        // Numeric input validation for PIN
        const pinInput = document.getElementById('pin');
        if (pinInput) {
            pinInput.addEventListener('input', (e) => {
                e.target.value = e.target.value.replace(/[^0-9]/g, '').substring(0, 4);
            });
        }
        
        // Smooth scrolling for anchor links
        document.querySelectorAll('a[href^="#"]').forEach(anchor => {
            anchor.addEventListener('click', function(e) {
                e.preventDefault();
                
                const targetId = this.getAttribute('href').substring(1);
                const targetElement = document.getElementById(targetId);
                
                if (targetElement) {
                    window.scrollTo({
                        top: targetElement.offsetTop - 20,
                        behavior: 'smooth'
                    });
                }
            });
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>