<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

$db = getDB();
$conn = $db->getConnection();

$errors = [];
$success = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $currentPassword = $_POST['current_password'] ?? '';
    $newPassword = $_POST['new_password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';
    
    // Validate inputs
    if (empty($currentPassword)) {
        $errors[] = 'Current password is required';
    } elseif (!password_verify($currentPassword, $user['password'])) {
        $errors[] = 'Current password is incorrect';
    }
    
    if (empty($newPassword)) {
        $errors[] = 'New password is required';
    } elseif (strlen($newPassword) < 6) {
        $errors[] = 'New password must be at least 6 characters';
    }
    
    if (empty($confirmPassword)) {
        $errors[] = 'Confirm password is required';
    } elseif ($newPassword !== $confirmPassword) {
        $errors[] = 'Passwords do not match';
    }
    
    // If no errors, update password
    if (empty($errors)) {
        // Hash the new password
        $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);
        
        // Update user record
        $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
        $stmt->bind_param("si", $hashedPassword, $userId);
        
        if ($stmt->execute()) {
            $success = 'Password updated successfully!';
            
            // Send email notification
            $emailSubject = 'Password Changed';
            $emailMessage = "Hello " . $user['full_name'] . ",\n\nYour password has been successfully changed. If you did not request this change, please contact our support team immediately.\n\nBest regards,\n" . getSetting('site_name') . " Team";
            
            sendEmail($user['email'], $emailSubject, $emailMessage);
        } else {
            $errors[] = 'Failed to update password: ' . $conn->error;
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Change Password - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .password-strength-meter {
            height: 4px;
            margin-top: 8px;
            background-color: #444;
            border-radius: 2px;
            overflow: hidden;
        }
        
        .password-strength-meter > div {
            height: 100%;
            width: 0;
            transition: width 0.3s;
        }
        
        .strength-weak {
            background-color: #EF4444;
        }
        
        .strength-medium {
            background-color: #F59E0B;
        }
        
        .strength-strong {
            background-color: #10B981;
        }
        
        .strength-very-strong {
            background-color: #059669;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <?php echo substr($user['username'], 0, 1); ?>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($user['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="change_password.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Change Password</a>
                        <a href="set_pin.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Set Transaction PIN</a>
                        <a href="api_tokens.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Tokens</a>
                        <a href="../login/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="dashboard-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <ul class="space-y-2">
                    <li>
                        <a href="index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-home mr-3"></i>
                            <span>Dashboard</span>
                        </a>
                    </li>
                    <li>
                        <a href="fund_wallet.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wallet mr-3"></i>
                            <span>Fund Wallet</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_data.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wifi mr-3"></i>
                            <span>Buy Data</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_airtime.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-phone mr-3"></i>
                            <span>Buy Airtime</span>
                        </a>
                    </li>
                    <li>
                        <a href="transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-exchange-alt mr-3"></i>
                            <span>Transactions</span>
                        </a>
                    </li>
                    
                    <!-- Show upgrade option only for smart users -->
                    <?php if ($user['user_type'] === 'smart'): ?>
                    <li>
                        <a href="upgrade.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-arrow-up mr-3"></i>
                            <span>Upgrade Account</span>
                        </a>
                    </li>
                    <?php endif; ?>
                    
                    <!-- Show developer section for API users -->
                    <?php if ($user['user_type'] === 'api'): ?>
                    <li>
                        <a href="api_documentation.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-code mr-3"></i>
                            <span>API Documentation</span>
                        </a>
                    </li>
                    <?php endif; ?>
                </ul>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Change Password</h1>
                <div class="text-right">
                    <p class="text-sm text-gray-400">Wallet Balance</p>
                    <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
                </div>
            </div>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
                <form method="POST" action="">
                    <div class="mb-4">
                        <label for="current_password" class="block text-sm font-medium text-gray-400 mb-1">Current Password</label>
                        <input type="password" id="current_password" name="current_password" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                    </div>
                    
                    <div class="mb-4">
                        <label for="new_password" class="block text-sm font-medium text-gray-400 mb-1">New Password</label>
                        <input type="password" id="new_password" name="new_password" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required minlength="6">
                        <div class="password-strength-meter">
                            <div id="passwordStrengthBar"></div>
                        </div>
                        <p id="passwordStrengthText" class="mt-1 text-sm text-gray-500"></p>
                    </div>
                    
                    <div class="mb-6">
                        <label for="confirm_password" class="block text-sm font-medium text-gray-400 mb-1">Confirm New Password</label>
                        <input type="password" id="confirm_password" name="confirm_password" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required minlength="6">
                        <p id="passwordMatchText" class="mt-1 text-sm text-gray-500"></p>
                    </div>
                    
                    <div class="mb-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                        <h3 class="font-semibold text-yellow-300 mb-2">Password Tips:</h3>
                        <ul class="list-disc pl-5 space-y-1 text-sm text-yellow-200">
                            <li>Use at least 8 characters</li>
                            <li>Include uppercase and lowercase letters</li>
                            <li>Include numbers and special characters</li>
                            <li>Don't reuse passwords from other websites</li>
                        </ul>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Update Password
                        </button>
                    </div>
                </form>
            </div>
            
            <div class="dashboard-card rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold text-white mb-4">Account Security</h2>
                
                <div class="space-y-4">
                    <p class="text-gray-300">
                        <i class="fas fa-shield-alt text-indigo-400 mr-2"></i>
                        Your password is the primary way to protect your account. Make sure it's strong and unique.
                    </p>
                    
                    <p class="text-gray-300">
                        <i class="fas fa-lock text-indigo-400 mr-2"></i>
                        We also recommend setting up a transaction PIN to protect your purchases and sensitive operations.
                    </p>
                    
                    <div class="mt-4">
                        <a href="set_pin.php" class="text-indigo-400 hover:text-indigo-300">
                            <i class="fas fa-arrow-right mr-1"></i> Set or change your transaction PIN
                        </a>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Password strength meter
        const newPasswordInput = document.getElementById('new_password');
        const confirmPasswordInput = document.getElementById('confirm_password');
        const passwordStrengthBar = document.getElementById('passwordStrengthBar');
        const passwordStrengthText = document.getElementById('passwordStrengthText');
        const passwordMatchText = document.getElementById('passwordMatchText');
        
        function checkPasswordStrength(password) {
            let strength = 0;
            
            // Length check
            if (password.length >= 8) {
                strength += 25;
            } else if (password.length >= 6) {
                strength += 10;
            }
            
            // Contains lowercase letters
            if (password.match(/[a-z]+/)) {
                strength += 25;
            }
            
            // Contains uppercase letters
            if (password.match(/[A-Z]+/)) {
                strength += 25;
            }
            
            // Contains numbers
            if (password.match(/[0-9]+/)) {
                strength += 25;
            }
            
            // Contains special characters
            if (password.match(/[$@#&!]+/)) {
                strength += 25;
            }
            
            return strength;
        }
        
        function updatePasswordStrength() {
            const password = newPasswordInput.value;
            const strength = checkPasswordStrength(password);
            
            passwordStrengthBar.style.width = strength + '%';
            
            // Reset classes
            passwordStrengthBar.classList.remove('strength-weak', 'strength-medium', 'strength-strong', 'strength-very-strong');
            
            if (strength < 30) {
                passwordStrengthBar.classList.add('strength-weak');
                passwordStrengthText.textContent = 'Weak password';
                passwordStrengthText.className = 'mt-1 text-sm text-red-400';
            } else if (strength < 60) {
                passwordStrengthBar.classList.add('strength-medium');
                passwordStrengthText.textContent = 'Medium password';
                passwordStrengthText.className = 'mt-1 text-sm text-yellow-400';
            } else if (strength < 80) {
                passwordStrengthBar.classList.add('strength-strong');
                passwordStrengthText.textContent = 'Strong password';
                passwordStrengthText.className = 'mt-1 text-sm text-green-400';
            } else {
                passwordStrengthBar.classList.add('strength-very-strong');
                passwordStrengthText.textContent = 'Very strong password';
                passwordStrengthText.className = 'mt-1 text-sm text-green-400';
            }
        }
        
        function checkPasswordMatch() {
            const password = newPasswordInput.value;
            const confirmPassword = confirmPasswordInput.value;
            
            if (!confirmPassword) {
                passwordMatchText.textContent = '';
                return;
            }
            
            if (password === confirmPassword) {
                passwordMatchText.textContent = 'Passwords match';
                passwordMatchText.className = 'mt-1 text-sm text-green-400';
            } else {
                passwordMatchText.textContent = 'Passwords do not match';
                passwordMatchText.className = 'mt-1 text-sm text-red-400';
            }
        }
        
        newPasswordInput.addEventListener('input', updatePasswordStrength);
        newPasswordInput.addEventListener('input', checkPasswordMatch);
        confirmPasswordInput.addEventListener('input', checkPasswordMatch);
    </script>
</body>
</html>