<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get Paystack settings
$paystackKeys = getPaystackKeys();
$publicKey = $paystackKeys['public'];

// Get funding charges
$fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
$checkoutMinAmount = (float)getSetting('checkout_min_amount', 100);
$checkoutCharge = (float)getSetting('checkout_charge', 50);

// Initialize variables
$amount = isset($_POST['amount']) ? (float)$_POST['amount'] : '';
$errors = [];
$success = '';

// Check if Paystack account exists for user
$hasPaystackAccount = !empty($user['paystack_account_number']);

// Process create Paystack account request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_account'])) {
    // Here we would make an actual API call to Paystack's Dedicated Virtual Account API
    // For now, we'll simulate success and generate a random account number
    
    $accountNumber = '90' . rand(10000000, 99999999);
    $accountName = $user['username'] . ' - ' . getSetting('site_name');
    $bankName = 'Wema Bank';
    
    // Update user record with account details
    $stmt = $conn->prepare("UPDATE users SET 
                          paystack_account_number = ?, 
                          paystack_account_name = ?, 
                          paystack_bank_name = ? 
                          WHERE id = ?");
    $stmt->bind_param(
        "sssi",
        $accountNumber,
        $accountName,
        $bankName,
        $userId
    );
    
    if ($stmt->execute()) {
        // Refresh user data
        $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        $hasPaystackAccount = true;
        $success = 'Dedicated account created successfully!';
    } else {
        $errors[] = 'Failed to save account details';
    }
}

// Process checkout funding request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['checkout_fund'])) {
    // Validate amount
    if (empty($amount)) {
        $errors[] = 'Amount is required';
    } elseif ($amount < $checkoutMinAmount) {
        $errors[] = 'Minimum amount is ' . formatAmount($checkoutMinAmount);
    } elseif ($amount > 1000000) {
        $errors[] = 'Maximum amount is ' . formatAmount(1000000);
    }
    
    if (empty($errors)) {
        // Generate unique reference
        $reference = 'PS_' . time() . '_' . $userId . '_' . generateRandomString(8);
        
        // Calculate amount to be credited and charges
        $charge = $checkoutCharge;
        $amountToCredit = $amount - $charge;
        
        // Save transaction
        $description = "Wallet funding via Paystack checkout";
        $metadata = [
            'amount' => $amount,
            'charge' => $charge,
            'amount_to_credit' => $amountToCredit,
            'payment_method' => 'paystack_checkout',
            'reference' => $reference
        ];
        
        $metadataJson = json_encode($metadata);
        
        // Insert transaction record
        $stmt = $conn->prepare("
            INSERT INTO transactions 
            (user_id, txn_ref, type, amount, fee, description, status, metadata)
            VALUES (?, ?, 'fund', ?, ?, ?, 'pending', ?)
        ");
        $stmt->bind_param("isdiss", $userId, $reference, $amountToCredit, $charge, $description, $metadataJson);
        
        if ($stmt->execute()) {
            $txnId = $conn->insert_id;
            $txnRef = $reference;
            
            // Set up checkout session
            $_SESSION['paystack_checkout'] = [
                'txn_id' => $txnId,
                'txn_ref' => $txnRef,
                'amount' => $amount,
                'charge' => $charge,
                'amount_to_credit' => $amountToCredit,
                'reference' => $reference
            ];
            
            redirect('paystack_checkout.php');
        } else {
            $errors[] = 'Failed to initialize transaction';
        }
    }
}

// Check for success message in session
if (isset($_SESSION['funding_success'])) {
    $success = $_SESSION['funding_success'];
    unset($_SESSION['funding_success']);
}

// Helper function to generate a random string
function generateRandomString($length = 8) {
    $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[random_int(0, $charactersLength - 1)];
    }
    return $randomString;
}

// Helper function to format amount
function formatAmount($amount) {
    global $currency;
    return $currency . number_format($amount, 2);
}

require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">Fund Wallet</h1>
        <div class="text-right">
            <p class="text-sm text-gray-400">Wallet Balance</p>
            <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
        </div>
    </div>
    
    <?php if (!empty($errors)): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
            <ul class="list-disc pl-5">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>
    
    <?php if ($success): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
            <p><?php echo $success; ?></p>
        </div>
    <?php endif; ?>
    
    <!-- Funding Tabs -->
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
        <!-- Tab Navigation -->
        <div class="flex border-b border-gray-700 mb-6">
            <button id="accountTab" class="tab-button px-4 py-2 focus:outline-none active">Dedicated Account</button>
            <button id="checkoutTab" class="tab-button px-4 py-2 focus:outline-none">Checkout</button>
        </div>
        
        <!-- Dedicated Account Tab -->
        <div id="accountTabContent" class="tab-content">
            <?php if ($hasPaystackAccount): ?>
                <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                    <p class="text-indigo-300 text-sm">
                        <i class="fas fa-info-circle mr-2"></i> You can fund your wallet by transferring to the dedicated account below. Funds will reflect immediately in your wallet.
                    </p>
                </div>
                
                <div class="account-card rounded-lg p-6 mb-4 relative">
                    <div class="relative z-10">
                        <div class="mb-4">
                            <h3 class="text-lg font-semibold text-white mb-1">Bank Name</h3>
                            <p class="text-gray-300"><?php echo $user['paystack_bank_name']; ?></p>
                        </div>
                        
                        <div class="mb-4">
                            <h3 class="text-lg font-semibold text-white mb-1">Account Number</h3>
                            <div class="flex items-center">
                                <p id="accountNumber" class="text-gray-300 text-xl font-mono mr-2"><?php echo $user['paystack_account_number']; ?></p>
                                <button id="copyAccountBtn" class="copy-button p-2 rounded-md transition-colors" title="Copy account number">
                                    <i class="fas fa-copy text-gray-400"></i>
                                </button>
                            </div>
                        </div>
                        
                        <div class="mb-2">
                            <h3 class="text-lg font-semibold text-white mb-1">Account Name</h3>
                            <p class="text-gray-300"><?php echo $user['paystack_account_name']; ?></p>
                        </div>
                    </div>
                </div>
                
                <div class="mt-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> Note: A <?php echo $fundingChargePercentage; ?>% service charge applies to all transfers. For example, if you transfer ₦1,000, your wallet will be credited with ₦<?php echo 1000 - (1000 * $fundingChargePercentage / 100); ?>.
                    </p>
                </div>
            <?php else: ?>
                <div class="text-center py-6">
                    <div class="mb-4">
                        <i class="fas fa-university text-4xl text-gray-500 mb-3"></i>
                        <h3 class="text-xl font-semibold text-white">No Dedicated Account Yet</h3>
                        <p class="text-gray-400 mt-2">Create a dedicated Wema Bank account that you can transfer to anytime to fund your wallet.</p>
                    </div>
                    
                    <form method="POST" action="">
                        <button type="submit" name="create_account" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Create Dedicated Account
                        </button>
                    </form>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Checkout Tab -->
        <div id="checkoutTabContent" class="tab-content hidden">
            <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                <p class="text-indigo-300 text-sm">
                    <i class="fas fa-info-circle mr-2"></i> You can fund your wallet instantly using card, bank transfer, or other payment methods supported by Paystack.
                </p>
            </div>
            
            <form method="POST" action="" id="checkoutForm">
                <div class="mb-4">
                    <label for="amount" class="block text-sm font-medium text-gray-400 mb-1">Amount to Fund (₦)</label>
                    <input type="number" id="amount" name="amount" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter amount" value="<?php echo htmlspecialchars($amount); ?>" min="<?php echo $checkoutMinAmount; ?>" required>
                </div>
                
                <div class="mb-4">
                    <label class="block text-sm font-medium text-gray-400 mb-3">Quick Amounts</label>
                    <div class="grid grid-cols-2 sm:grid-cols-4 gap-3">
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="1000">₦1,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="2000">₦2,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="5000">₦5,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="10000">₦10,000</button>
                    </div>
                </div>
                
                <div class="mb-4 p-4 bg-opacity-10 bg-yellow-500 border border-yellow-500 rounded-md">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> A service charge of ₦<?php echo $checkoutCharge; ?> applies to checkout payments. Minimum amount is ₦<?php echo $checkoutMinAmount; ?>.
                    </p>
                </div>
                
                <div id="amountSummary" class="mb-4 p-4 bg-gray-800 rounded-md hidden">
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Amount:</span>
                        <span class="text-white" id="summaryAmount">₦0.00</span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Service Charge:</span>
                        <span class="text-white" id="summaryCharge">₦<?php echo number_format($checkoutCharge, 2); ?></span>
                    </div>
                    <div class="flex justify-between font-semibold">
                        <span class="text-gray-400">Amount to be Credited:</span>
                        <span class="text-white" id="summaryCredit">₦0.00</span>
                    </div>
                </div>
                
                <div class="flex justify-end">
                    <button type="submit" name="checkout_fund" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Proceed to Checkout
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6">
        <h2 class="text-xl font-semibold text-white mb-4">Funding Methods</h2>
        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Dedicated Account</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Get a dedicated Wema Bank account linked to your wallet</li>
                    <li>Transfer funds from any bank to this account</li>
                    <li>Funds reflect immediately in your wallet</li>
                    <li><?php echo $fundingChargePercentage; ?>% service charge applies</li>
                </ul>
            </div>
            
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Checkout</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Fund with card, bank transfer, USSD, etc.</li>
                    <li>Fast and secure payment processing</li>
                    <li>Minimum amount: ₦<?php echo number_format($checkoutMinAmount, 2); ?></li>
                    <li>Fixed charge: ₦<?php echo number_format($checkoutCharge, 2); ?></li>
                </ul>
            </div>
        </div>
        
        <div class="mt-4 p-4 bg-gray-800 rounded-md">
            <h3 class="font-medium text-white mb-2">Need Help?</h3>
            <p class="text-gray-400">If you have any issues with funding your wallet, please contact our support team for assistance.</p>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Tab switching
    const accountTab = document.getElementById('accountTab');
    const checkoutTab = document.getElementById('checkoutTab');
    const accountTabContent = document.getElementById('accountTabContent');
    const checkoutTabContent = document.getElementById('checkoutTabContent');
    
    accountTab.addEventListener('click', function() {
        accountTab.classList.add('active');
        checkoutTab.classList.remove('active');
        accountTabContent.classList.remove('hidden');
        checkoutTabContent.classList.add('hidden');
    });
    
    checkoutTab.addEventListener('click', function() {
        checkoutTab.classList.add('active');
        accountTab.classList.remove('active');
        checkoutTabContent.classList.remove('hidden');
        accountTabContent.classList.add('hidden');
    });
    
    // Copy account number
    const copyAccountBtn = document.getElementById('copyAccountBtn');
    if (copyAccountBtn) {
        copyAccountBtn.addEventListener('click', function() {
            const accountNumber = document.getElementById('accountNumber').textContent;
            navigator.clipboard.writeText(accountNumber).then(() => {
                // Show success indicator
                copyAccountBtn.innerHTML = '<i class="fas fa-check text-green-500"></i>';
                setTimeout(() => {
                    copyAccountBtn.innerHTML = '<i class="fas fa-copy text-gray-400"></i>';
                }, 2000);
            });
        });
    }
    
    // Amount preset buttons
    const amountPresets = document.querySelectorAll('.amount-preset');
    const amountInput = document.getElementById('amount');
    
    amountPresets.forEach(button => {
        button.addEventListener('click', function() {
            // Remove active class from all buttons
            amountPresets.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
            
            // Set amount input value
            amountInput.value = this.dataset.amount;
            
            // Update summary
            updateAmountSummary();
        });
    });
    
    // Update amount summary
    const amountSummary = document.getElementById('amountSummary');
    const summaryAmount = document.getElementById('summaryAmount');
    const summaryCredit = document.getElementById('summaryCredit');
    
    function updateAmountSummary() {
        const amount = parseFloat(amountInput.value) || 0;
        
        if (amount >= <?php echo $checkoutMinAmount; ?>) {
            amountSummary.classList.remove('hidden');
            const charge = <?php echo $checkoutCharge; ?>;
            const credit = amount - charge;
            
            summaryAmount.textContent = '₦' + amount.toLocaleString('en-NG', { minimumFractionDigits: 2, maximumFractionDigits: 2 });
            summaryCredit.textContent = '₦' + credit.toLocaleString('en-NG', { minimumFractionDigits: 2, maximumFractionDigits: 2 });
        } else {
            amountSummary.classList.add('hidden');
        }
    }
    
    amountInput.addEventListener('input', updateAmountSummary);
    
    // Initialize the summary on page load
    updateAmountSummary();
});
</script>

<?php require_once './includes/footer.php'; ?>