<?php
// File: /dashboard/fund_via_mnfy.php

require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once '../includes/monnify.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login.php');
}

// Get funding charges
$fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
$checkoutMinAmount = (float)getSetting('checkout_min_amount', 100);
$checkoutCharge = (float)getSetting('checkout_charge', 50);

// Initialize variables
$errors = [];
$success = '';

// Create Monnify instance
$monnify = new Monnify();

// Check if Monnify account exists for user
$hasMonnifyAccount = !empty($user['monnify_reserved_account_number']);

// Process create Monnify account request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_account'])) {
    // Call Monnify API to create reserved account
    $result = $monnify->createReservedAccount($user);
    
    if ($result['success']) {
        // Refresh user data
        $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        $hasMonnifyAccount = true;
        $success = 'Dedicated accounts created successfully!';
    } else {
        $errors[] = $result['message'] ?? 'Failed to create dedicated accounts';
    }
}

// Get recent Monnify transactions
$stmt = $conn->prepare("
    SELECT mt.*, t.amount, t.fee 
    FROM monnify_transactions mt
    JOIN transactions t ON t.meta_data LIKE CONCAT('%\"monnify_reference\":\"', mt.transaction_reference, '\"%')
    WHERE mt.user_id = ? 
    ORDER BY mt.created_at DESC LIMIT 5
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$recentTransactions = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);

// Helper function to get bank logo
function getBankLogo($bankCode) {
    $logos = [
        '035' => 'wema.png', // Wema Bank
        '50515' => 'moniepoint.png', // Moniepoint
        '232' => 'sterling.png', // Sterling Bank
        '070' => 'fidelity.png' // Fidelity Bank
    ];
    
    return isset($logos[$bankCode]) ? $logos[$bankCode] : 'bank.png';
}

// Helper function to get bank name
function getBankName($bankCode) {
    $banks = [
        '035' => 'Wema Bank',
        '50515' => 'Moniepoint MFB',
        '232' => 'Sterling Bank',
        '070' => 'Fidelity Bank'
    ];
    
    return isset($banks[$bankCode]) ? $banks[$bankCode] : 'Unknown Bank';
}

// Page title
$pageTitle = "Fund via Monnify";
require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">Fund via Monnify</h1>
        <div class="text-right">
            <p class="text-sm text-gray-400">Wallet Balance</p>
            <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
        </div>
    </div>
    
    <?php if (!empty($errors)): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
            <ul class="list-disc pl-5">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>
    
    <?php if ($success): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
            <p><?php echo $success; ?></p>
        </div>
    <?php endif; ?>
    
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
        <?php if ($hasMonnifyAccount): ?>
            <div class="mb-6 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                <p class="text-indigo-300 text-sm">
                    <i class="fas fa-info-circle mr-2"></i> Fund your wallet by transferring to any of the dedicated accounts below. Funds will reflect immediately in your wallet.
                </p>
            </div>
            
            <!-- Bank account cards -->
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                <?php
                // Define the banks to display
                $bankAccounts = [
                    [
                        'code' => '50515',
                        'name' => 'Moniepoint MFB',
                        'field' => 'monnify_moniepoint_account_number',
                        'color' => 'from-blue-600 to-blue-800'
                    ],
                    [
                        'code' => '035',
                        'name' => 'Wema Bank',
                        'field' => 'monnify_wema_account_number',
                        'color' => 'from-purple-600 to-purple-800'
                    ],
                    [
                        'code' => '232',
                        'name' => 'Sterling Bank',
                        'field' => 'monnify_sterling_account_number',
                        'color' => 'from-green-600 to-green-800'
                    ],
                    [
                        'code' => '070',
                        'name' => 'Fidelity Bank',
                        'field' => 'monnify_fidelity_account_number',
                        'color' => 'from-red-600 to-red-800'
                    ]
                ];
                
                foreach ($bankAccounts as $bank):
                    $accountNumber = $user[$bank['field']];
                    if (empty($accountNumber)) continue;
                ?>
                <div class="rounded-lg overflow-hidden">
                    <div class="relative bg-gradient-to-r <?php echo $bank['color']; ?> p-6 rounded-t-lg">
                        <div class="absolute top-0 right-0 mt-4 mr-4">
                            <img src="<?php echo SITE_URL; ?>/assets/images/banks/<?php echo getBankLogo($bank['code']); ?>" alt="<?php echo $bank['name']; ?>" class="h-8 w-auto">
                        </div>
                        <h3 class="text-white font-semibold text-lg"><?php echo $bank['name']; ?></h3>
                        <div class="flex items-center mt-2">
                            <p id="accountNumber_<?php echo $bank['code']; ?>" class="text-white text-xl font-mono"><?php echo $accountNumber; ?></p>
                            <button class="copy-button ml-2 p-2 rounded-md bg-white bg-opacity-20 hover:bg-opacity-30 transition-colors" 
                                    onclick="copyToClipboard('accountNumber_<?php echo $bank['code']; ?>')" 
                                    title="Copy account number">
                                <i class="fas fa-copy text-white"></i>
                            </button>
                        </div>
                        <p class="text-white text-opacity-80 text-sm mt-2"><?php echo $user['monnify_account_name']; ?></p>
                    </div>
                    <div class="bg-gray-800 p-4 rounded-b-lg">
                        <div class="flex justify-between items-center">
                            <span class="text-gray-400 text-sm">Transfer to this account to fund your wallet</span>
                            <span class="text-gray-400 text-sm">Instant funding</span>
                        </div>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
            
            <div class="mt-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                <p class="text-yellow-300 text-sm">
                    <i class="fas fa-exclamation-triangle mr-2"></i> Note: A <?php echo $fundingChargePercentage; ?>% service charge applies to all transfers. For example, if you transfer ₦1,000, your wallet will be credited with ₦<?php echo 1000 - (1000 * $fundingChargePercentage / 100); ?>.
                </p>
            </div>
            
            <!-- Recent Transactions -->
            <?php if (count($recentTransactions) > 0): ?>
            <div class="mt-8">
                <h3 class="text-lg font-semibold text-white mb-4">Recent Transactions</h3>
                <div class="overflow-x-auto">
                    <table class="min-w-full">
                        <thead class="bg-gray-800">
                            <tr>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Bank</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount Paid</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Fee</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount Credited</th>
                                <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                            </tr>
                        </thead>
                        <tbody class="divide-y divide-gray-700">
                            <?php foreach ($recentTransactions as $tx): ?>
                            <tr>
                                <td class="py-3 px-4 text-sm text-gray-300">
                                    <?php echo date('M d, H:i', strtotime($tx['created_at'])); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-white">
                                    <?php echo getBankName($tx['bank_code']); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-white">
                                    <?php echo formatAmount($tx['amount_paid']); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-white">
                                    <?php echo formatAmount($tx['fee']); ?>
                                </td>
                                <td class="py-3 px-4 text-sm text-white font-medium">
                                    <?php echo formatAmount($tx['amount']); ?>
                                </td>
                                <td class="py-3 px-4">
                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">
                                        <?php echo $tx['payment_status']; ?>
                                    </span>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php endif; ?>
            
        <?php else: ?>
            <div class="text-center py-6">
                <div class="mb-4">
                    <i class="fas fa-university text-4xl text-gray-500 mb-3"></i>
                    <h3 class="text-xl font-semibold text-white">No Dedicated Accounts Yet</h3>
                    <p class="text-gray-400 mt-2">Create dedicated bank accounts (including Moniepoint) that you can transfer to anytime to fund your wallet.</p>
                </div>
                
                <form method="POST" action="">
                    <button type="submit" name="create_account" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Create Dedicated Accounts
                    </button>
                </form>
            </div>
        <?php endif; ?>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6">
        <h2 class="text-xl font-semibold text-white mb-4">Funding Information</h2>
        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Dedicated Accounts</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Get dedicated bank accounts (Moniepoint, Wema, Sterling, Fidelity) linked to your wallet</li>
                    <li>Transfer funds from any bank to these accounts</li>
                    <li>Funds reflect immediately in your wallet</li>
                    <li><?php echo $fundingChargePercentage; ?>% service charge applies</li>
                    <li>Available 24/7 for transfers</li>
                </ul>
            </div>
            
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Benefits</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Multiple bank options for your convenience</li>
                    <li>Instant crediting to your wallet</li>
                    <li>Secure and reliable transfers</li>
                    <li>No need to log in each time to fund</li>
                    <li>Accounts are permanently linked to your wallet</li>
                </ul>
            </div>
        </div>
        
        <div class="mt-4 p-4 bg-gray-800 rounded-md">
            <h3 class="font-medium text-white mb-2">Need Help?</h3>
            <p class="text-gray-400">If you have any issues with funding your wallet, please contact our support team for assistance.</p>
        </div>
    </div>
</div>

<script>
function copyToClipboard(elementId) {
    const accountNumber = document.getElementById(elementId).textContent;
    navigator.clipboard.writeText(accountNumber).then(() => {
        // Show a toast notification
        showToast('Account number copied!');
    }).catch(err => {
        console.error('Could not copy text: ', err);
    });
}

function showToast(message) {
    // Create toast element if it doesn't exist
    let toast = document.getElementById('toast-notification');
    if (!toast) {
        toast = document.createElement('div');
        toast.id = 'toast-notification';
        toast.className = 'fixed top-4 right-4 bg-green-500 text-white px-4 py-2 rounded shadow-lg transform transition-transform duration-300 translate-y-[-100px]';
        document.body.appendChild(toast);
    }
    
    // Set message and show toast
    toast.textContent = message;
    toast.style.transform = 'translateY(0)';
    
    // Hide toast after 3 seconds
    setTimeout(() => {
        toast.style.transform = 'translateY(-100px)';
    }, 3000);
}
</script>

<?php require_once './includes/footer.php'; ?>