<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once '../includes/monnify.php'; // Add Monnify include

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get Paystack settings
$paystackKeys = getPaystackKeys();
$publicKey = $paystackKeys['public'];

// Get funding charges
$fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
$checkoutMinAmount = (float)getSetting('checkout_min_amount', 100);
$checkoutCharge = (float)getSetting('checkout_charge', 50);

// Initialize variables
$amount = isset($_POST['amount']) ? (float)$_POST['amount'] : '';
$errors = [];
$success = '';

// Check if Paystack account exists for user
$hasPaystackAccount = !empty($user['paystack_account_number']);

// Check if Monnify account exists for user
$hasMonnifyAccount = !empty($user['monnify_reserved_account_number']);

// Create Monnify instance
$monnify = new Monnify();

// Process create Paystack account request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_paystack_account'])) {
    // Here we would make an actual API call to Paystack's Dedicated Virtual Account API
    // For now, we'll simulate success and generate a random account number
    
    $accountNumber = '90' . rand(10000000, 99999999);
    $accountName = $user['username'] . ' - ' . getSetting('site_name');
    $bankName = 'Wema Bank';
    
    // Update user record with account details
    $stmt = $conn->prepare("UPDATE users SET 
                          paystack_account_number = ?, 
                          paystack_account_name = ?, 
                          paystack_bank_name = ? 
                          WHERE id = ?");
    $stmt->bind_param(
        "sssi",
        $accountNumber,
        $accountName,
        $bankName,
        $userId
    );
    
    if ($stmt->execute()) {
        // Refresh user data
        $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        $hasPaystackAccount = true;
        $success = 'Paystack dedicated account created successfully!';
    } else {
        $errors[] = 'Failed to save Paystack account details';
    }
}

// Process create Monnify account request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_monnify_account'])) {
    // Call Monnify API to create reserved account
    $result = $monnify->createReservedAccount($user);
    
    if ($result['success']) {
        // Refresh user data
        $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        $hasMonnifyAccount = true;
        $success = 'Monnify dedicated accounts created successfully!';
    } else {
        $errors[] = $result['message'] ?? 'Failed to create Monnify dedicated accounts';
    }
}

// Process checkout funding request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['checkout_fund'])) {
    // Validate amount
    if (empty($amount)) {
        $errors[] = 'Amount is required';
    } elseif ($amount < $checkoutMinAmount) {
        $errors[] = 'Minimum amount is ' . formatAmount($checkoutMinAmount);
    } elseif ($amount > 1000000) {
        $errors[] = 'Maximum amount is ' . formatAmount(1000000);
    }
    
    if (empty($errors)) {
        // Generate unique reference
        $reference = 'PS_' . time() . '_' . $userId . '_' . generateRandomString(8);
        
        // Calculate amount to be credited and charges
        $charge = $checkoutCharge;
        $amountToCredit = $amount - $charge;
        
        // Save transaction
        $description = "Wallet funding via Paystack checkout";
        $metadata = [
            'amount' => $amount,
            'charge' => $charge,
            'amount_to_credit' => $amountToCredit,
            'payment_method' => 'paystack_checkout',
            'reference' => $reference
        ];
        
        $metadataJson = json_encode($metadata);
        
        // Insert transaction record
        $stmt = $conn->prepare("
            INSERT INTO transactions 
            (user_id, txn_ref, type, amount, fee, description, status, metadata)
            VALUES (?, ?, 'fund', ?, ?, ?, 'pending', ?)
        ");
        $stmt->bind_param("isdiss", $userId, $reference, $amountToCredit, $charge, $description, $metadataJson);
        
        if ($stmt->execute()) {
            $txnId = $conn->insert_id;
            $txnRef = $reference;
            
            // Set up checkout session
            $_SESSION['paystack_checkout'] = [
                'txn_id' => $txnId,
                'txn_ref' => $txnRef,
                'amount' => $amount,
                'charge' => $charge,
                'amount_to_credit' => $amountToCredit,
                'reference' => $reference
            ];
            
            redirect('paystack_checkout.php');
        } else {
            $errors[] = 'Failed to initialize transaction';
        }
    }
}

// Check for success message in session
if (isset($_SESSION['funding_success'])) {
    $success = $_SESSION['funding_success'];
    unset($_SESSION['funding_success']);
}

// Get recent Monnify transactions
$recentMonnifyTransactions = [];
if ($hasMonnifyAccount) {
    $stmt = $conn->prepare("
        SELECT mt.*, t.amount, t.fee 
        FROM monnify_transactions mt
        JOIN transactions t ON t.meta_data LIKE CONCAT('%\"monnify_reference\":\"', mt.transaction_reference, '\"%')
        WHERE mt.user_id = ? 
        ORDER BY mt.created_at DESC LIMIT 5
    ");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $recentMonnifyTransactions = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
}

// Helper function to generate a random string
function generateRandomString($length = 8) {
    $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[random_int(0, $charactersLength - 1)];
    }
    return $randomString;
}

// Helper function to get bank logo
function getBankLogo($bankCode) {
    $logos = [
        '035' => 'wema.png', // Wema Bank
        '50515' => 'moniepoint.png', // Moniepoint
        '232' => 'sterling.png', // Sterling Bank
        '070' => 'fidelity.png' // Fidelity Bank
    ];
    
    return isset($logos[$bankCode]) ? $logos[$bankCode] : 'bank.png';
}

// Helper function to get bank name
function getBankName($bankCode) {
    $banks = [
        '035' => 'Wema Bank',
        '50515' => 'Moniepoint MFB',
        '232' => 'Sterling Bank',
        '070' => 'Fidelity Bank'
    ];
    
    return isset($banks[$bankCode]) ? $banks[$bankCode] : 'Unknown Bank';
}

// Helper function to format amount
function formatAmount($amount) {
    global $currency;
    return $currency . number_format($amount, 2);
}

require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">Fund Wallet</h1>
        <div class="text-right">
            <p class="text-sm text-gray-400">Wallet Balance</p>
            <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
        </div>
    </div>
    
    <?php if (!empty($errors)): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
            <ul class="list-disc pl-5">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>
    
    <?php if ($success): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
            <p><?php echo $success; ?></p>
        </div>
    <?php endif; ?>
    
    <!-- Funding Tabs -->
    <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
        <!-- Main Tab Navigation -->
        <div class="flex border-b border-gray-700 mb-6">
            <button id="accountTab" class="tab-button px-4 py-2 focus:outline-none active">Dedicated Account</button>
            <button id="checkoutTab" class="tab-button px-4 py-2 focus:outline-none">Checkout</button>
        </div>
        
        <!-- Dedicated Account Tab -->
        <div id="accountTabContent" class="tab-content">
            <!-- Sub-tabs for account options -->
            <div class="flex border-b border-gray-700 mb-6">
                <button id="paystackAccountTab" class="subtab-button px-4 py-2 focus:outline-none active">Paystack</button>
                <button id="monnifyAccountTab" class="subtab-button px-4 py-2 focus:outline-none">Monnify</button>
                <button id="manualAccountTab" class="subtab-button px-4 py-2 focus:outline-none">Manual Transfer</button>
            </div>
            
            <!-- Paystack Account Tab Content -->
            <div id="paystackAccountContent" class="subtab-content">
                <?php if ($hasPaystackAccount): ?>
                    <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                        <p class="text-indigo-300 text-sm">
                            <i class="fas fa-info-circle mr-2"></i> You can fund your wallet by transferring to the Paystack dedicated account below. Funds will reflect immediately in your wallet.
                        </p>
                    </div>
                    
                    <div class="account-card rounded-lg p-6 mb-4 relative">
                        <div class="relative z-10">
                            <div class="mb-4">
                                <h3 class="text-lg font-semibold text-white mb-1">Bank Name</h3>
                                <p class="text-gray-300"><?php echo $user['paystack_bank_name']; ?></p>
                            </div>
                            
                            <div class="mb-4">
                                <h3 class="text-lg font-semibold text-white mb-1">Account Number</h3>
                                <div class="flex items-center">
                                    <p id="paystackAccountNumber" class="text-gray-300 text-xl font-mono mr-2"><?php echo $user['paystack_account_number']; ?></p>
                                    <button id="copyPaystackAccountBtn" class="copy-button p-2 rounded-md transition-colors" title="Copy account number" onclick="copyToClipboard('paystackAccountNumber')">
                                        <i class="fas fa-copy text-gray-400"></i>
                                    </button>
                                </div>
                            </div>
                            
                            <div class="mb-2">
                                <h3 class="text-lg font-semibold text-white mb-1">Account Name</h3>
                                <p class="text-gray-300"><?php echo $user['paystack_account_name']; ?></p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                        <p class="text-yellow-300 text-sm">
                            <i class="fas fa-exclamation-triangle mr-2"></i> Note: A <?php echo $fundingChargePercentage; ?>% service charge applies to all transfers. For example, if you transfer ₦1,000, your wallet will be credited with ₦<?php echo 1000 - (1000 * $fundingChargePercentage / 100); ?>.
                        </p>
                    </div>
                <?php else: ?>
                    <div class="text-center py-6">
                        <div class="mb-4">
                            <i class="fas fa-university text-4xl text-gray-500 mb-3"></i>
                            <h3 class="text-xl font-semibold text-white">No Paystack Dedicated Account Yet</h3>
                            <p class="text-gray-400 mt-2">Create a dedicated Wema Bank account that you can transfer to anytime to fund your wallet.</p>
                        </div>
                        
                        <form method="POST" action="">
                            <button type="submit" name="create_paystack_account" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Create Paystack Account
                            </button>
                        </form>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Monnify Account Tab Content -->
            <div id="monnifyAccountContent" class="subtab-content hidden">
                <?php if ($hasMonnifyAccount): ?>
                    <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                        <p class="text-indigo-300 text-sm">
                            <i class="fas fa-info-circle mr-2"></i> Fund your wallet by transferring to any of the Monnify dedicated accounts below. Funds will reflect immediately in your wallet.
                        </p>
                    </div>
                    
                    <!-- Bank account cards -->
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <?php
                        // Define the banks to display
                        $bankAccounts = [
                            [
                                'code' => '50515',
                                'name' => 'Moniepoint MFB',
                                'field' => 'monnify_moniepoint_account_number',
                                'color' => 'from-blue-600 to-blue-800'
                            ],
                            [
                                'code' => '035',
                                'name' => 'Wema Bank',
                                'field' => 'monnify_wema_account_number',
                                'color' => 'from-purple-600 to-purple-800'
                            ],
                            [
                                'code' => '232',
                                'name' => 'Sterling Bank',
                                'field' => 'monnify_sterling_account_number',
                                'color' => 'from-green-600 to-green-800'
                            ],
                            [
                                'code' => '070',
                                'name' => 'Fidelity Bank',
                                'field' => 'monnify_fidelity_account_number',
                                'color' => 'from-red-600 to-red-800'
                            ]
                        ];
                        
                        foreach ($bankAccounts as $bank):
                            $accountNumber = $user[$bank['field']] ?? '';
                            if (empty($accountNumber)) continue;
                        ?>
                        <div class="rounded-lg overflow-hidden">
                            <div class="relative bg-gradient-to-r <?php echo $bank['color']; ?> p-6 rounded-t-lg">
                                <div class="absolute top-0 right-0 mt-4 mr-4">
                                    <img src="<?php echo SITE_URL; ?>/assets/images/banks/<?php echo getBankLogo($bank['code']); ?>" alt="<?php echo $bank['name']; ?>" class="h-8 w-auto">
                                </div>
                                <h3 class="text-white font-semibold text-lg"><?php echo $bank['name']; ?></h3>
                                <div class="flex items-center mt-2">
                                    <p id="accountNumber_<?php echo $bank['code']; ?>" class="text-white text-xl font-mono"><?php echo $accountNumber; ?></p>
                                    <button class="copy-button ml-2 p-2 rounded-md bg-white bg-opacity-20 hover:bg-opacity-30 transition-colors" 
                                            onclick="copyToClipboard('accountNumber_<?php echo $bank['code']; ?>')" 
                                            title="Copy account number">
                                        <i class="fas fa-copy text-white"></i>
                                    </button>
                                </div>
                                <p class="text-white text-opacity-80 text-sm mt-2"><?php echo $user['monnify_account_name'] ?? $user['username']; ?></p>
                            </div>
                            <div class="bg-gray-800 p-4 rounded-b-lg">
                                <div class="flex justify-between items-center">
                                    <span class="text-gray-400 text-sm">Transfer to this account to fund your wallet</span>
                                    <span class="text-gray-400 text-sm">Instant funding</span>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                    
                    <div class="mt-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                        <p class="text-yellow-300 text-sm">
                            <i class="fas fa-exclamation-triangle mr-2"></i> Note: A <?php echo $fundingChargePercentage; ?>% service charge applies to all transfers. For example, if you transfer ₦1,000, your wallet will be credited with ₦<?php echo 1000 - (1000 * $fundingChargePercentage / 100); ?>.
                        </p>
                    </div>
                    
                    <!-- Recent Monnify Transactions -->
                    <?php if (count($recentMonnifyTransactions) > 0): ?>
                    <div class="mt-8">
                        <h3 class="text-lg font-semibold text-white mb-4">Recent Monnify Transactions</h3>
                        <div class="overflow-x-auto">
                            <table class="min-w-full">
                                <thead class="bg-gray-800">
                                    <tr>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Date</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Bank</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount Paid</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Fee</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount Credited</th>
                                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                    </tr>
                                </thead>
                                <tbody class="divide-y divide-gray-700">
                                    <?php foreach ($recentMonnifyTransactions as $tx): ?>
                                    <tr>
                                        <td class="py-3 px-4 text-sm text-gray-300">
                                            <?php echo date('M d, H:i', strtotime($tx['created_at'])); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white">
                                            <?php echo getBankName($tx['bank_code']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white">
                                            <?php echo formatAmount($tx['amount_paid']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white">
                                            <?php echo formatAmount($tx['fee']); ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm text-white font-medium">
                                            <?php echo formatAmount($tx['amount']); ?>
                                        </td>
                                        <td class="py-3 px-4">
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800">
                                                <?php echo $tx['payment_status']; ?>
                                            </span>
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    <?php endif; ?>
                <?php else: ?>
                    <div class="text-center py-6">
                        <div class="mb-4">
                            <i class="fas fa-university text-4xl text-gray-500 mb-3"></i>
                            <h3 class="text-xl font-semibold text-white">No Monnify Dedicated Accounts Yet</h3>
                            <p class="text-gray-400 mt-2">Create dedicated bank accounts (including Moniepoint) that you can transfer to anytime to fund your wallet.</p>
                        </div>
                        
                        <form method="POST" action="">
                            <button type="submit" name="create_monnify_account" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Create Monnify Accounts
                            </button>
                        </form>
                    </div>
                <?php endif; ?>
            </div>
            
            <!-- Manual Transfer Tab Content -->
            <div id="manualAccountContent" class="subtab-content hidden">
                <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                    <p class="text-indigo-300 text-sm">
                        <i class="fas fa-info-circle mr-2"></i> You can fund your wallet by transferring to our official bank account below and providing proof of payment.
                    </p>
                </div>
                
                <div class="account-card rounded-lg p-6 mb-4 relative">
                    <div class="relative z-10">
                        <div class="mb-4">
                            <h3 class="text-lg font-semibold text-white mb-1">Bank Name</h3>
                            <p class="text-gray-300">Access Bank</p>
                        </div>
                        
                        <div class="mb-4">
                            <h3 class="text-lg font-semibold text-white mb-1">Account Number</h3>
                            <div class="flex items-center">
                                <p id="manualAccountNumber" class="text-gray-300 text-xl font-mono mr-2">0123456789</p>
                                <button class="copy-button p-2 rounded-md transition-colors" title="Copy account number" onclick="copyToClipboard('manualAccountNumber')">
                                    <i class="fas fa-copy text-gray-400"></i>
                                </button>
                            </div>
                        </div>
                        
                        <div class="mb-2">
                            <h3 class="text-lg font-semibold text-white mb-1">Account Name</h3>
                            <p class="text-gray-300">Company Official Account</p>
                        </div>
                    </div>
                </div>
                
                <div class="mb-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> Important: After making your transfer, please submit your payment details using the form below. Manual transfers will be verified and credited within 24 hours.
                    </p>
                </div>
                
                <form method="POST" action="" enctype="multipart/form-data" class="bg-gray-800 p-6 rounded-lg">
                    <h3 class="text-lg font-semibold text-white mb-4">Submit Payment Details</h3>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                        <div>
                            <label for="manual_amount" class="block text-sm font-medium text-gray-400 mb-1">Amount Transferred</label>
                            <input type="number" id="manual_amount" name="manual_amount" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter amount" required>
                        </div>
                        
                        <div>
                            <label for="manual_date" class="block text-sm font-medium text-gray-400 mb-1">Date of Transfer</label>
                            <input type="date" id="manual_date" name="manual_date" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="manual_reference" class="block text-sm font-medium text-gray-400 mb-1">Transfer Reference/Description</label>
                        <input type="text" id="manual_reference" name="manual_reference" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter bank reference or description" required>
                    </div>
                    
                    <div class="mb-4">
                        <label for="manual_proof" class="block text-sm font-medium text-gray-400 mb-1">Proof of Payment (Screenshot/PDF)</label>
                        <input type="file" id="manual_proof" name="manual_proof" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" accept="image/*,.pdf" required>
                        <p class="text-xs text-gray-500 mt-1">Upload a screenshot or PDF of your payment receipt (Max size: 2MB)</p>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="manual_fund" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Submit Payment Details
                        </button>
                    </div>
                </form>
            </div>
        </div>
        
        <!-- Checkout Tab -->
        <div id="checkoutTabContent" class="tab-content hidden">
            <div class="mb-4 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                <p class="text-indigo-300 text-sm">
                    <i class="fas fa-info-circle mr-2"></i> You can fund your wallet instantly using card, bank transfer, or other payment methods supported by Paystack.
                </p>
            </div>
            
            <form method="POST" action="" id="checkoutForm">
                <div class="mb-4">
                    <label for="amount" class="block text-sm font-medium text-gray-400 mb-1">Amount to Fund (₦)</label>
                    <input type="number" id="amount" name="amount" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="Enter amount" value="<?php echo htmlspecialchars($amount); ?>" min="<?php echo $checkoutMinAmount; ?>" required>
                </div>
                
                <div class="mb-4">
                    <label class="block text-sm font-medium text-gray-400 mb-3">Quick Amounts</label>
                    <div class="grid grid-cols-2 sm:grid-cols-4 gap-3">
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="1000">₦1,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="2000">₦2,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="5000">₦5,000</button>
                        <button type="button" class="amount-preset rounded-md py-2 px-4 text-center" data-amount="10000">₦10,000</button>
                    </div>
                </div>
                
                <div class="mb-4 p-4 bg-opacity-10 bg-yellow-500 border border-yellow-500 rounded-md">
                    <p class="text-yellow-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> A service charge of ₦<?php echo $checkoutCharge; ?> applies to checkout payments. Minimum amount is ₦<?php echo $checkoutMinAmount; ?>.
                    </p>
                </div>
                
                <div id="amountSummary" class="mb-4 p-4 bg-gray-800 rounded-md hidden">
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Amount:</span>
                        <span class="text-white" id="summaryAmount">₦0.00</span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Service Charge:</span>
                        <span class="text-white" id="summaryCharge">₦<?php echo number_format($checkoutCharge, 2); ?></span>
                    </div>
                    <div class="flex justify-between font-semibold">
                        <span class="text-gray-400">Amount to be Credited:</span>
                        <span class="text-white" id="summaryCredit">₦0.00</span>
                    </div>
                </div>
                
                <div class="flex justify-end">
                    <button type="submit" name="checkout_fund" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Proceed to Checkout
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <div class="dashboard-card rounded-lg shadow-md p-6">
        <h2 class="text-xl font-semibold text-white mb-4">Funding Methods</h2>
        <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Paystack Account</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Get a dedicated Wema Bank account linked to your wallet</li>
                    <li>Transfer funds from any bank to this account</li>
                    <li>Funds reflect immediately in your wallet</li>
                    <li><?php echo $fundingChargePercentage; ?>% service charge applies</li>
                </ul>
            </div>
            
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Monnify Accounts</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Multiple bank options (Moniepoint, Wema, Sterling, Fidelity)</li>
                    <li>Transfer funds from any bank to these accounts</li>
                    <li>Instant crediting to your wallet</li>
                    <li><?php echo $fundingChargePercentage; ?>% service charge applies</li>
                </ul>
            </div>
            
            <div>
                <h3 class="text-lg font-medium text-white mb-2">Checkout</h3>
                <ul class="list-disc pl-5 space-y-2 text-gray-300">
                    <li>Fund with card, bank transfer, USSD, etc.</li>
                    <li>Fast and secure payment processing</li>
                    <li>Minimum amount: ₦<?php echo number_format($checkoutMinAmount, 2); ?></li>
                    <li>Fixed charge: ₦<?php echo number_format($checkoutCharge, 2); ?></li>
                </ul>
            </div>
        </div>
        
        <div class="mt-4 p-4 bg-gray-800 rounded-md">
            <h3 class="font-medium text-white mb-2">Need Help?</h3>
            <p class="text-gray-400">If you have any issues with funding your wallet, please contact our support team for assistance.</p>
        </div>
    </div>
</div>

<style>
/* Additional CSS for tab styling */
.tab-button, .subtab-button {
    position: relative;
    color: var(--text-secondary);
}

.tab-button.active, .subtab-button.active {
    color: var(--accent-color);
    font-weight: 500;
}

.tab-button.active:after, .subtab-button.active:after {
    content: '';
    position: absolute;
    bottom: -1px;
    left: 0;
    width: 100%;
    height: 2px;
    background-color: var(--accent-color);
}

.amount-preset {
    background-color: var(--bg-card);
    border: 1px solid var(--border-color);
    color: var(--text-primary);
    transition: all 0.2s;
}

.amount-preset:hover {
    border-color: var(--accent-color);
}

.amount-preset.active {
    background-color: var(--accent-color);
    border-color: var(--accent-color);
    color: white;
}

.copy-button:hover {
    background-color: rgba(255, 255, 255, 0.1);
}

/* Gradient backgrounds for bank cards */
.account-card {
    background-color: var(--bg-card);
    border: 1px solid var(--border-color);
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Toast notification function
    function showToast(message) {
        // Create toast element if it doesn't exist
        let toast = document.getElementById('toast-notification');
        if (!toast) {
            toast = document.createElement('div');
            toast.id = 'toast-notification';
            toast.className = 'fixed top-4 right-4 bg-green-500 text-white px-4 py-2 rounded shadow-lg transform transition-transform duration-300 translate-y-[-100px]';
            document.body.appendChild(toast);
        }
        
        // Set message and show toast
        toast.textContent = message;
        toast.style.transform = 'translateY(0)';
        
        // Hide toast after 3 seconds
        setTimeout(() => {
            toast.style.transform = 'translateY(-100px)';
        }, 3000);
    }
    
    // Copy to clipboard function
    window.copyToClipboard = function(elementId) {
        const text = document.getElementById(elementId).textContent;
        navigator.clipboard.writeText(text).then(() => {
            showToast('Account number copied!');
        }).catch(err => {
            console.error('Could not copy text: ', err);
        });
    };
    
    // Main Tab switching
    const accountTab = document.getElementById('accountTab');
    const checkoutTab = document.getElementById('checkoutTab');
    const accountTabContent = document.getElementById('accountTabContent');
    const checkoutTabContent = document.getElementById('checkoutTabContent');
    
    accountTab.addEventListener('click', function() {
        accountTab.classList.add('active');
        checkoutTab.classList.remove('active');
        accountTabContent.classList.remove('hidden');
        checkoutTabContent.classList.add('hidden');
    });
    
    checkoutTab.addEventListener('click', function() {
        checkoutTab.classList.add('active');
        accountTab.classList.remove('active');
        checkoutTabContent.classList.remove('hidden');
        accountTabContent.classList.add('hidden');
    });
    
    // Sub-Tab switching for account options
    const paystackAccountTab = document.getElementById('paystackAccountTab');
    const monnifyAccountTab = document.getElementById('monnifyAccountTab');
    const manualAccountTab = document.getElementById('manualAccountTab');
    
    const paystackAccountContent = document.getElementById('paystackAccountContent');
    const monnifyAccountContent = document.getElementById('monnifyAccountContent');
    const manualAccountContent = document.getElementById('manualAccountContent');
    
    paystackAccountTab.addEventListener('click', function() {
        paystackAccountTab.classList.add('active');
        monnifyAccountTab.classList.remove('active');
        manualAccountTab.classList.remove('active');
        
        paystackAccountContent.classList.remove('hidden');
        monnifyAccountContent.classList.add('hidden');
        manualAccountContent.classList.add('hidden');
    });
    
    monnifyAccountTab.addEventListener('click', function() {
        monnifyAccountTab.classList.add('active');
        paystackAccountTab.classList.remove('active');
        manualAccountTab.classList.remove('active');
        
        monnifyAccountContent.classList.remove('hidden');
        paystackAccountContent.classList.add('hidden');
        manualAccountContent.classList.add('hidden');
    });
    
    manualAccountTab.addEventListener('click', function() {
        manualAccountTab.classList.add('active');
        paystackAccountTab.classList.remove('active');
        monnifyAccountTab.classList.remove('active');
        
        manualAccountContent.classList.remove('hidden');
        paystackAccountContent.classList.add('hidden');
        monnifyAccountContent.classList.add('hidden');
    });
    
    // Amount preset buttons
    const amountPresets = document.querySelectorAll('.amount-preset');
    const amountInput = document.getElementById('amount');
    
    amountPresets.forEach(button => {
        button.addEventListener('click', function() {
            // Remove active class from all buttons
            amountPresets.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
            
            // Set amount input value
            amountInput.value = this.dataset.amount;
            
            // Update summary
            updateAmountSummary();
        });
    });
    
    // Update amount summary
    const amountSummary = document.getElementById('amountSummary');
    const summaryAmount = document.getElementById('summaryAmount');
    const summaryCredit = document.getElementById('summaryCredit');
    
    function updateAmountSummary() {
        const amount = parseFloat(amountInput.value) || 0;
        
        if (amount >= <?php echo $checkoutMinAmount; ?>) {
            amountSummary.classList.remove('hidden');
            const charge = <?php echo $checkoutCharge; ?>;
            const credit = amount - charge;
            
            summaryAmount.textContent = '₦' + amount.toLocaleString('en-NG', { minimumFractionDigits: 2, maximumFractionDigits: 2 });
            summaryCredit.textContent = '₦' + credit.toLocaleString('en-NG', { minimumFractionDigits: 2, maximumFractionDigits: 2 });
        } else {
            amountSummary.classList.add('hidden');
        }
    }
    
    amountInput.addEventListener('input', updateAmountSummary);
    
    // Initialize the summary on page load
    updateAmountSummary();
});
</script>

<?php require_once './includes/footer.php'; ?>