<?php
ob_start(); // Add this as the very first line in header.php
// Rest of your header.php code
// Start session if not already started
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: " . SITE_URL . "/login");
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    header("Location: " . SITE_URL . "/login");
    exit;
}

// Check if account is suspended
if ($user['status'] !== 'active') {
    // Log the user out
    session_destroy();
    header("Location: " . SITE_URL . "/login?message=Your account has been suspended. Please contact support for assistance.");
    exit;
}

// Check for low balance warning (for Vendor and API users)
$lowBalanceWarning = false;
$minBalance = 0;

if ($user['user_type'] === 'api' && $user['balance'] < 5000) {
    $lowBalanceWarning = true;
    $minBalance = 5000;
} elseif ($user['user_type'] === 'vendor' && $user['balance'] < 2000) {
    $lowBalanceWarning = true;
    $minBalance = 2000;
}

// Get unread notifications count
$stmt = $conn->prepare("SELECT COUNT(*) as count FROM notifications WHERE user_id = ? AND is_read = 0");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$notificationsCount = $result->fetch_assoc()['count'];

// Determine active page
$currentPage = basename($_SERVER['PHP_SELF']);

// Get flash message
$flashMessage = getFlashMessage();

// Get site settings
$siteName = getSetting('site_name') ?: 'VTU Platform';
$siteLogo = getSetting('site_logo') ?: SITE_URL . '/assets/images/logo.png';
$currency = getSetting('currency') ?: '₦';
// Get site settings
// Get current system version
$versionQuery = "SELECT version FROM changelog_entries ORDER BY STR_TO_DATE(CONCAT('01-', REPLACE(version, '.', '-')), '%d-%m-%Y') DESC, id DESC LIMIT 1";
$versionResult = $conn->query($versionQuery);
$currentVersion = "1.0.0"; // Default version
if ($versionResult && $versionResult->num_rows > 0) {
    $currentVersion = $versionResult->fetch_assoc()['version'];
}

// Function to check if current page is active
function isPageActive($page) {
    global $currentPage;
    return ($currentPage === $page) ? 'active' : '';
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle ?? 'Dashboard'; ?> - <?php echo $siteName; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        /* Dashboard specific styles */
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-select, .form-input, .form-textarea {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-select:focus, .form-input:focus, .form-textarea:focus {
            border-color: var(--accent-color);
        }
        
        .tab-button {
            color: var(--text-secondary);
            border-bottom: 2px solid transparent;
        }
        
        .tab-button.active {
            color: var(--accent-color);
            border-bottom-color: var(--accent-color);
        }
        
        .tab-button:hover {
            color: var(--text-primary);
        }
        
        .user-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .user-badge.smart {
            background-color: rgba(37, 99, 235, 0.3);
            color: #93c5fd;
        }
        
        .user-badge.vendor {
            background-color: rgba(22, 163, 74, 0.3);
            color: #86efac;
        }
        
        .user-badge.api {
            background-color: rgba(244, 63, 94, 0.3);
            color: #fda4af;
        }
        
        .status-badge {
            padding: 2px 8px;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
        }
        
        .status-successful, .status-completed {
            background-color: rgba(34, 197, 94, 0.3);
            color: #86efac;
        }
        
        .status-pending {
            background-color: rgba(234, 179, 8, 0.3);
            color: #fde047;
        }
        
        .status-failed {
            background-color: rgba(239, 68, 68, 0.3);
            color: #fca5a5;
        }
        
        .network-card {
            transition: all 0.3s ease;
        }
        
        .network-card:hover, .network-card.selected {
            transform: translateY(-5px);
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            border-color: var(--accent-color);
        }
        
        .network-card.selected {
            background-color: rgba(93, 92, 222, 0.1);
        }
        
        .mobile-nav-button {
            color: var(--text-secondary);
        }
        
        .mobile-nav-button:hover, .mobile-nav-button.active {
            color: var(--accent-color);
        }
        
        /* Low balance warning animation */
        @keyframes balanceWarning {
            0% { color: white; }
            50% { color: #EF4444; }
            100% { color: white; }
        }
        
        .balance-low-warning {
            animation: balanceWarning 1s infinite;
            font-weight: bold;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow sticky top-0 z-10">
        <div class="container mx-auto px-4 py-3">
            <div class="flex justify-between items-center">
                <!-- Logo & Menu Button -->
                <div class="flex items-center">
                    <button id="sidebarToggle" class="lg:hidden mr-3 text-gray-300 hover:text-white">
                        <i class="fas fa-bars"></i>
                    </button>
                    <a href="<?php echo SITE_URL; ?>/dashboard/" class="font-bold text-xl flex items-center">
                        <span class="text-indigo-400 mr-1"><i class="fas fa-bolt"></i></span>
                        <?php echo $siteName; ?>
                    </a>
                </div>
                
                <!-- User Menu -->
                <div class="flex items-center space-x-4">
                    <!-- Wallet Balance -->
                    <div class="hidden md:flex items-center px-3 py-1 bg-gray-700 rounded-md">
                        <span class="text-gray-400 mr-1">Balance:</span>
                        <span class="font-semibold <?php echo $lowBalanceWarning ? 'balance-low-warning' : ''; ?>">
                            <?php echo $currency . number_format($user['balance'], 2); ?>
                        </span>
                    </div>
                    
                    <!-- Fund Button -->
                    <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php" class="hidden md:block accent-button py-1 px-3 rounded-md text-white text-sm hover:bg-indigo-600">
                        Fund Wallet
                    </a>
                    
                    <!-- Notification Bell -->
                    <div class="relative">
                        <a href="<?php echo SITE_URL; ?>/dashboard/notifications.php" class="text-gray-300 hover:text-white">
                            <i class="fas fa-bell"></i>
                            <?php if ($notificationsCount > 0): ?>
                                <span class="absolute -top-1 -right-1 bg-red-500 text-white text-xs rounded-full h-4 w-4 flex items-center justify-center">
                                    <?php echo $notificationsCount > 9 ? '9+' : $notificationsCount; ?>
                                </span>
                            <?php endif; ?>
                        </a>
                    </div>
                    
                    <!-- User Dropdown -->
                    <div class="relative">
                        <button id="userDropdownButton" class="flex items-center text-white focus:outline-none">
                            <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-1 lg:mr-2">
                                <span class="text-sm"><?php echo strtoupper(substr($user['username'], 0, 1)); ?></span>
                            </div>
                            <span class="hidden lg:inline-block"><?php echo htmlspecialchars($user['username']); ?></span>
                            <svg class="w-4 h-4 ml-1" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                            </svg>
                        </button>
                        
                        <div id="userDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                            <div class="py-1">
                                <div class="px-4 py-2 border-b border-gray-600">
                                    <span class="user-badge <?php echo $user['user_type']; ?>">
                                        <?php echo ucfirst($user['user_type']); ?> User
                                    </span>
                                </div>
                                <a href="<?php echo SITE_URL; ?>/dashboard/profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a> 
                                <a href="<?php echo SITE_URL; ?>/dashboard/api_tokens.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Tokens</a>
                                <a href="<?php echo SITE_URL; ?>/dashboard/transactions.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Transactions</a>
                                <a href="<?php echo SITE_URL; ?>/dashboard/settings.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Settings</a>
                                <?php if ($user['user_type'] === 'api'): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/api_docs.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Documentation</a>
                                <?php elseif ($user['user_type'] === 'smart'): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/upgrade.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Upgrade Account</a>
                                <?php endif; ?>
                                <div class="border-t border-gray-600 mt-1">
                                    <a href="<?php echo SITE_URL; ?>/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content Container -->
    <div class="flex flex-1">
        <!-- Sidebar Navigation (desktop) -->
        <aside id="sidebar" class="dashboard-nav w-64 fixed lg:relative inset-y-0 left-0 z-20 transform -translate-x-full lg:translate-x-0 transition-transform duration-300 ease-in-out">
            <div class="h-full overflow-y-auto">
                <nav class="py-4 px-3">
                    <!-- Balance & Fund Button (Mobile Only) -->
                    <div class="lg:hidden px-4 py-3 mb-4 bg-gray-700 rounded-md flex flex-col space-y-2">
                        <div class="flex justify-between">
                            <span class="text-gray-400">Balance:</span>
                            <span class="font-semibold <?php echo $lowBalanceWarning ? 'balance-low-warning' : ''; ?>">
                                <?php echo $currency . number_format($user['balance'], 2); ?>
                            </span>
                        </div>
                        <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php" class="accent-button py-1 px-3 rounded-md text-white text-sm text-center hover:bg-indigo-600">
                            Fund Wallet
                        </a>
                    </div>
                    
                    <!-- Main Menu -->
                    <h2 class="text-sm font-semibold text-gray-400 uppercase px-2 mb-2">Main Menu</h2>
                    <ul class="space-y-1">
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('index.php'); ?>">
                                <i class="fas fa-tachometer-alt w-5"></i>
                                <span class="ml-3">Dashboard</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('fund_wallet.php'); ?>">
                                <i class="fas fa-wallet w-5"></i>
                                <span class="ml-3">Fund Wallet</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('transactions.php'); ?>">
                                <i class="fas fa-exchange-alt w-5"></i>
                                <span class="ml-3">Transactions</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/profile.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('profile.php'); ?>">
                                <i class="fas fa-user w-5"></i>
                                <span class="ml-3">Profile</span>
                            </a>
                        </li> 
                        <h2 class="text-sm font-semibold text-gray-400 uppercase px-2 mb-2">Resell Our Service </h2>
                         <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/reseller_panel.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('transactions.php'); ?>">
                                <i class="fas fa-exchange-alt w-5"></i>
                                <span class="ml-3">Reseller Panel</span>
                            </a>
                        </li>
                    </ul>
                    
                    <!-- Services Menu -->
                    <h2 class="text-sm font-semibold text-gray-400 uppercase px-2 mt-6 mb-2">Services</h2>
                    <ul class="space-y-1">
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('buy_data.php'); ?>">
                                <i class="fas fa-wifi w-5"></i>
                                <span class="ml-3">Buy Data</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('buy_airtime.php'); ?>">
                                <i class="fas fa-phone w-5"></i>
                                <span class="ml-3">Buy Airtime</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('cable_tv.php'); ?>">
                                <i class="fas fa-tv w-5"></i>
                                <span class="ml-3">Cable TV</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('electricity.php'); ?>">
                                <i class="fas fa-bolt w-5"></i>
                                <span class="ml-3">Electricity</span>
                            </a>
                        </li>
                    </ul>
                    
                    <!-- Tools Menu -->
                    <h2 class="text-sm font-semibold text-gray-400 uppercase px-2 mt-6 mb-2">Tools</h2>
                    <ul class="space-y-1">
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/price_list.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('price_list.php'); ?>">
                                <i class="fas fa-tags w-5"></i>
                                <span class="ml-3">Price List</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/saved_beneficiaries.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('saved_beneficiaries.php'); ?>">
                                <i class="fas fa-address-book w-5"></i>
                                <span class="ml-3">Saved Beneficiaries</span>
                            </a>
                        </li>
                        <?php if ($user['user_type'] === 'api'): ?>
                            <li>
                                <a href="<?php echo SITE_URL; ?>/dashboard/api_docs.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('api_docs.php'); ?>">
                                    <i class="fas fa-code w-5"></i>
                                    <span class="ml-3">API Documentation</span>
                                </a>
                            </li>
                        <?php endif; ?>
                    </ul>
                    
                    <!-- Help Menu -->
                    <h2 class="text-sm font-semibold text-gray-400 uppercase px-2 mt-6 mb-2">Help</h2>
                    <ul class="space-y-1">
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/support.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('support.php'); ?>">
                                <i class="fas fa-headset w-5"></i>
                                <span class="ml-3">Support</span>
                            </a>
                        </li>
                        <li>
                            <a href="<?php echo SITE_URL; ?>/dashboard/faqs.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('faqs.php'); ?>">
                                <i class="fas fa-question-circle w-5"></i>
                                <span class="ml-3">FAQs</span>
                            </a>
                        </li>
                        <?php if ($user['user_type'] === 'smart'): ?>
                            <li>
                                <a href="<?php echo SITE_URL; ?>/dashboard/upgrade.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors <?php echo isPageActive('upgrade.php'); ?>">
                                    <i class="fas fa-arrow-circle-up w-5"></i>
                                    <span class="ml-3">Upgrade Account</span>
                                </a>
                            </li>
                        <?php endif; ?>
                    </ul>
                    
                    <!-- Version display at bottom of sidebar -->
                    <div class="mt-8 pt-4 border-t border-gray-700 text-center">
                        <i class="fas fa-code-branch mr-1"></i>
                        <span>Version <?php echo htmlspecialchars($currentVersion); ?></span>
                    </div>
                </nav>
            </div>
        </aside>
        
        <!-- Main Content Area -->
        <main class="flex-1 p-4 overflow-x-hidden">
            <?php if ($flashMessage): ?>
                <div class="mb-4 <?php echo $flashMessage['type'] === 'success' ? 'bg-green-500' : 'bg-red-500'; ?> text-white p-4 rounded-md">
                    <?php echo $flashMessage['message']; ?>
                </div>
            <?php endif; ?>