<?php
require_once '../includes/config.php';
require_once '../includes/functions.php'; 
require_once './includes/header.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get user's unread notifications
$stmt = $conn->prepare("SELECT * FROM notifications WHERE user_id = ? AND is_read = 0 ORDER BY created_at DESC LIMIT 1");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$notification = $result->fetch_assoc();

// Check for low balance warning (for Vendor and API users)
$lowBalanceWarning = false;
$minBalance = 0;

if ($user['user_type'] === 'api' && $user['balance'] < 5000) {
    $lowBalanceWarning = true;
    $minBalance = 5000;
} elseif ($user['user_type'] === 'vendor' && $user['balance'] < 2000) {
    $lowBalanceWarning = true;
    $minBalance = 2000;
}

// Get the hide_low_balance_warning setting from database
$hideWarning = $user['hide_low_balance_warning'] == 1;

// Create a session-based temporary dismissal that doesn't persist across page sessions
// This lets users dismiss for the current session without checking "don't show again"
if (isset($_SESSION['temp_hide_low_balance_warning']) && $_SESSION['temp_hide_low_balance_warning'] === true) {
    $hideWarning = true;
}

// If the balance is now above the threshold, reset the hide warning flag
if (!$lowBalanceWarning && $user['hide_low_balance_warning'] == 1) {
    $updateStmt = $conn->prepare("UPDATE users SET hide_low_balance_warning = 0 WHERE id = ?");
    $updateStmt->bind_param("i", $userId);
    $updateStmt->execute();
    $hideWarning = false;
    
    // Also clear the session temp dismissal
    unset($_SESSION['temp_hide_low_balance_warning']);
}

// AJAX handler for updating warning status (called via fetch API)
if (isset($_GET['action']) && $_GET['action'] === 'update_warning_status') {
    header('Content-Type: application/json');
    
    if (isset($_GET['dont_show_again']) && $_GET['dont_show_again'] === 'true') {
        // Permanent dismissal - update the database
        $updateStmt = $conn->prepare("UPDATE users SET hide_low_balance_warning = 1 WHERE id = ?");
        $updateStmt->bind_param("i", $userId);
        $success = $updateStmt->execute();
        
        echo json_encode(['success' => $success]);
    } else {
        // Temporary dismissal - just set a session variable
        $_SESSION['temp_hide_low_balance_warning'] = true;
        echo json_encode(['success' => true]);
    }
    
    exit; // Stop execution after handling the AJAX request
}

// AJAX handler for notification status (called via fetch API)
if (isset($_GET['action']) && $_GET['action'] === 'mark_notification_read') {
    header('Content-Type: application/json');
    
    if (isset($_GET['notification_id']) && is_numeric($_GET['notification_id'])) {
        $notificationId = (int)$_GET['notification_id'];
        $stmt = $conn->prepare("UPDATE notifications SET is_read = 1 WHERE id = ? AND user_id = ?");
        $stmt->bind_param("ii", $notificationId, $userId);
        $success = $stmt->execute();
        
        echo json_encode(['success' => $success]);
    } else {
        echo json_encode(['success' => false, 'error' => 'Invalid notification ID']);
    }
    
    exit; // Stop execution after handling the AJAX request
}

// Get flash message
$flashMessage = getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard - <?php echo getSetting('site_name'); ?></title>
    <!-- Add your CSS styles and other head content here -->
    <style>
        /* Low balance warning animation */
        @keyframes balanceWarning {
            0% { color: white; }
            50% { color: #EF4444; }
            100% { color: white; }
        }
        
        .balance-low-warning {
            animation: balanceWarning 1s infinite;
            font-weight: bold;
        }
        
        /* Modal styles */
        .modal-backdrop {
            backdrop-filter: blur(3px);
        }
        
        /* Add transition for smooth modal closing */
        .modal-transition {
            transition: opacity 0.2s ease-in-out;
        }
        
        /* Close button styles */
        .modal-close-btn {
            cursor: pointer;
            transition: transform 0.2s;
        }
        
        .modal-close-btn:hover {
            transform: scale(1.1);
            color: #ff6b6b;
        }
    </style>
</head>
<body>
    <!-- Content Area -->
    <main class="flex-grow p-4">
        <?php if ($flashMessage): ?>
            <div class="mb-4 p-4 rounded-md <?php echo $flashMessage['type'] === 'success' ? 'bg-green-500 text-white' : 'bg-red-500 text-white'; ?>">
                <?php echo $flashMessage['message']; ?>
            </div>
        <?php endif; ?>
        
        <!-- Balance Card -->
        <div class="dashboard-card rounded-lg shadow-md p-6 mb-6 text-center">
            <h2 class="text-xl font-semibold text-gray-300 mb-2">Wallet Balance</h2>
            <p id="balanceAmount" class="text-3xl font-bold <?php echo $lowBalanceWarning ? 'balance-low-warning text-white' : 'text-white'; ?>">
                <?php echo formatAmount($user['balance']); ?>
            </p>
            <a href="fund_wallet.php" class="accent-button mt-4 inline-block px-6 py-2 rounded-md text-white font-medium hover:bg-indigo-600 transition-colors">Fund Wallet</a>
        </div>
        
        <!-- Services Grid -->
        <h2 class="text-xl font-semibold text-gray-300 mb-4">Our Services</h2>
        <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
            <a href="buy_data.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-wifi text-indigo-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Buy Data</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">Purchase data bundles at affordable rates</p>
            </a>
            
            <a href="buy_airtime.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-phone text-green-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Buy Airtime</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">Recharge any network at discounted rates</p>
            </a>
            
            <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-bolt text-yellow-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Electricity</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">Pay electricity bills instantly</p>
            </a>
            
            <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-red-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-tv text-red-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Cable TV</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">Subscribe to DSTV, GOTV & Startimes</p>
            </a>
            
            <a href="#" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-blue-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-exchange-alt text-blue-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Airtime to Cash</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">Convert airtime to cash instantly</p>
            </a>
            
            <a href="transactions.php" class="dashboard-card rounded-lg shadow-md p-6 flex flex-col items-center transition-transform transform hover:scale-105">
                <div class="h-16 w-16 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mb-4">
                    <i class="fas fa-history text-purple-400 text-2xl"></i>
                </div>
                <h3 class="text-lg font-medium text-white">Transactions</h3>
                <p class="mt-2 text-gray-400 text-sm text-center">View your transaction history</p>
            </a>
        </div>
    </main>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Low Balance Warning Modal -->
    <?php if ($lowBalanceWarning && !$hideWarning): ?>
    <div id="lowBalanceModal" class="fixed inset-0 z-50 flex items-center justify-center modal-transition">
        <div class="modal-backdrop fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6 relative z-10">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white flex items-center">
                    <i class="fas fa-exclamation-triangle text-red-500 mr-2"></i>
                    Low Balance Warning
                </h3>
                <div class="modal-close-btn text-gray-400 text-xl" onclick="dismissLowBalanceWarning(false)">
                    <i class="fas fa-times"></i>
                </div>
            </div>
            
            <div class="p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md mb-4">
                <p class="text-white mb-2">Your current balance is <span class="font-bold balance-low-warning"><?php echo formatAmount($user['balance']); ?></span></p>
                <p class="text-white">
                    As a <span class="font-bold"><?php echo ucfirst($user['user_type']); ?> user</span>, your account balance is below the recommended minimum of <span class="font-bold"><?php echo formatAmount($minBalance); ?></span>.
                </p>
            </div>
            
            <p class="text-gray-300 mb-6">
                Please fund your wallet to ensure uninterrupted service. Low balance may affect your ability to perform transactions.
            </p>
            
            <div>
                <div class="flex items-center mb-4">
                    <input type="checkbox" id="dont_show_again" class="form-checkbox h-4 w-4 text-indigo-600 rounded focus:ring-indigo-500 focus:ring-offset-gray-800">
                    <label for="dont_show_again" class="ml-2 text-gray-300">Don't show this warning again</label>
                </div>
                
                <div class="flex justify-end space-x-3">
                    <a href="fund_wallet.php" class="accent-button py-2 px-4 rounded-md text-white">
                        Fund Wallet
                    </a>
                    <button type="button" onclick="dismissLowBalanceWarning()" class="py-2 px-4 bg-gray-700 text-white rounded-md hover:bg-gray-600">
                        Dismiss
                    </button>
                </div>
            </div>
        </div>
    </div>
    <?php endif; ?>
    
    <!-- Admin Notification Modal -->
    <?php if ($notification): ?>
    <div id="notificationModal" class="fixed inset-0 z-50 flex items-center justify-center modal-transition">
        <div class="modal-backdrop fixed inset-0 bg-black bg-opacity-50"></div>
        <div class="modal-content bg-gray-800 rounded-lg shadow-lg max-w-md w-full mx-auto p-6 relative z-10">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-semibold text-white flex items-center">
                    <?php 
                    $iconClass = 'info';
                    switch($notification['type']) {
                        case 'success':
                            $iconClass = 'check-circle text-green-500';
                            break;
                        case 'warning':
                            $iconClass = 'exclamation-circle text-yellow-500';
                            break;
                        case 'error':
                            $iconClass = 'times-circle text-red-500';
                            break;
                        default:
                            $iconClass = 'info-circle text-blue-500';
                    }
                    ?>
                    <i class="fas fa-<?php echo $iconClass; ?> mr-2"></i>
                    <?php echo htmlspecialchars($notification['title']); ?>
                </h3>
                <div class="modal-close-btn text-gray-400 text-xl" onclick="dismissNotification()">
                    <i class="fas fa-times"></i>
                </div>
            </div>
            
            <div class="mb-6">
                <p class="text-gray-300"><?php echo nl2br(htmlspecialchars($notification['message'])); ?></p>
                <p class="text-gray-400 text-sm mt-4">
                    <i class="fas fa-clock mr-1"></i>
                    <?php echo date('M d, Y h:i A', strtotime($notification['created_at'])); ?>
                </p>
            </div>
            
            <div class="flex justify-end">
                <button type="button" onclick="dismissNotification()" class="accent-button py-2 px-4 rounded-md text-white">
                    Close
                </button>
            </div>
        </div>
    </div>
    <?php endif; ?>
    
    <!-- JavaScript -->
    <script>
        // Check if the balance is low and should have the warning effect
        document.addEventListener('DOMContentLoaded', function() {
            // Force the animation to be applied - sometimes the class application isn't enough
            const balanceElement = document.getElementById('balanceAmount');
            if (balanceElement && balanceElement.classList.contains('balance-low-warning')) {
                // Setting it through style directly in case the CSS class isn't applying
                balanceElement.style.animation = 'balanceWarning 1s infinite';
            }
        });
        
        // Function to dismiss low balance warning
        function dismissLowBalanceWarning() {
            // Get the modal element
            const modal = document.getElementById('lowBalanceModal');
            
            // Get checkbox status
            const dontShowAgain = document.getElementById('dont_show_again').checked;
            
            // Hide the modal immediately with a fade effect
            modal.style.opacity = '0';
            
            // After the fade animation, remove the modal from the DOM
            setTimeout(() => {
                modal.style.display = 'none';
            }, 200);
            
            // Make the AJAX call to update the warning status in the background
            fetch(`<?php echo SITE_URL; ?>/dashboard/index.php?action=update_warning_status&dont_show_again=${dontShowAgain}`)
                .then(response => response.json())
                .then(data => {
                    console.log('Warning status updated:', data);
                })
                .catch(error => {
                    console.error('Error updating warning status:', error);
                });
        }
        
        // Function to dismiss notification
        function dismissNotification() {
            // Get the modal element
            const modal = document.getElementById('notificationModal');
            
            // Get notification ID from modal data attribute
            const notificationId = <?php echo $notification ? $notification['id'] : 'null'; ?>;
            
            // Hide the modal immediately with a fade effect
            modal.style.opacity = '0';
            
            // After the fade animation, remove the modal from the DOM
            setTimeout(() => {
                modal.style.display = 'none';
            }, 200);
            
            if (notificationId) {
                // Make the AJAX call to mark the notification as read in the background
                fetch(`<?php echo SITE_URL; ?>/dashboard/index.php?action=mark_notification_read&notification_id=${notificationId}`)
                    .then(response => response.json())
                    .then(data => {
                        console.log('Notification marked as read:', data);
                    })
                    .catch(error => {
                        console.error('Error marking notification as read:', error);
                    });
            }
        }
        
        // Function to check for new notifications (you can implement AJAX here if needed)
        function checkForNewNotifications() {
            // The PHP already loaded the latest notification, this is just a placeholder
            // for future AJAX implementation if needed
            console.log("Checking for new notifications...");
        }
        
        // Check for new notifications every minute
        setInterval(checkForNewNotifications, 60000);
    </script>
    
    <?php require_once './includes/footer.php'; ?>
</body>
</html>