<?php
$pageTitle = 'Notifications';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Mark notification as read if ID provided
if (isset($_GET['id']) && is_numeric($_GET['id'])) {
    $notificationId = (int)$_GET['id'];
    
    // Check if notification belongs to user
    $stmt = $conn->prepare("SELECT * FROM notifications WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $notificationId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Mark as read
        $stmt = $conn->prepare("UPDATE notifications SET is_read = 1 WHERE id = ?");
        $stmt->bind_param("i", $notificationId);
        $stmt->execute();
    }
}

// Handle mark all as read action
if (isset($_GET['action']) && $_GET['action'] === 'mark_all_read') {
    $stmt = $conn->prepare("UPDATE notifications SET is_read = 1 WHERE user_id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    
    // Redirect to remove the action from URL
    header("Location: " . SITE_URL . "/dashboard/notifications.php");
    exit;
}

// Delete notification if requested
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $notificationId = (int)$_GET['delete'];
    
    // Check if notification belongs to user
    $stmt = $conn->prepare("SELECT * FROM notifications WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $notificationId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Delete notification
        $stmt = $conn->prepare("DELETE FROM notifications WHERE id = ?");
        $stmt->bind_param("i", $notificationId);
        $stmt->execute();
        
        // Set success message
        $success = "Notification deleted successfully.";
    }
}

// Get notifications
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 15;
$offset = ($page - 1) * $limit;

$stmt = $conn->prepare("
    SELECT * FROM notifications 
    WHERE user_id = ? 
    ORDER BY created_at DESC
    LIMIT ? OFFSET ?
");
$stmt->bind_param("iii", $userId, $limit, $offset);
$stmt->execute();
$result = $stmt->get_result();
$notifications = [];

while ($row = $result->fetch_assoc()) {
    $notifications[] = $row;
}

// Get total notifications count for pagination
$stmt = $conn->prepare("SELECT COUNT(*) as count FROM notifications WHERE user_id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$row = $result->fetch_assoc();
$totalNotifications = $row['count'];
$totalPages = ceil($totalNotifications / $limit);
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex flex-col md:flex-row md:items-center md:justify-between mb-6">
        <h1 class="text-2xl font-bold text-white mb-4 md:mb-0">Notifications</h1>
        
        <?php if (!empty($notifications)): ?>
            <div class="flex space-x-2">
                <a href="?action=mark_all_read" class="py-2 px-4 bg-gray-700 hover:bg-gray-600 text-white rounded-md text-sm">
                    <i class="fas fa-check-double mr-1"></i> Mark All as Read
                </a>
            </div>
        <?php endif; ?>
    </div>
    
    <?php if (isset($success)): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4">
            <?php echo $success; ?>
        </div>
    <?php endif; ?>
    
    <?php if (empty($notifications)): ?>
        <div class="text-center py-10">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-bell text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-gray-400 mb-1">No Notifications Yet</h3>
            <p class="text-gray-500 text-sm">Your notifications will appear here</p>
        </div>
    <?php else: ?>
        <div class="space-y-4">
            <?php foreach ($notifications as $notification): ?>
                <div class="bg-gray-800 rounded-lg p-4 <?php echo $notification['is_read'] ? '' : 'border-l-4 border-indigo-500'; ?>">
                    <div class="flex items-start">
                        <?php
                        $icon = 'info-circle';
                        $bgColor = 'bg-blue-500';
                        $textColor = 'text-blue-400';
                        
                        if ($notification['type'] === 'success') {
                            $icon = 'check-circle';
                            $bgColor = 'bg-green-500';
                            $textColor = 'text-green-400';
                        } elseif ($notification['type'] === 'warning') {
                            $icon = 'exclamation-triangle';
                            $bgColor = 'bg-yellow-500';
                            $textColor = 'text-yellow-400';
                        } elseif ($notification['type'] === 'error') {
                            $icon = 'times-circle';
                            $bgColor = 'bg-red-500';
                            $textColor = 'text-red-400';
                        }
                        ?>
                        <div class="h-10 w-10 rounded-full <?php echo $bgColor; ?> bg-opacity-20 flex-shrink-0 flex items-center justify-center mr-3">
                            <i class="fas fa-<?php echo $icon; ?> <?php echo $textColor; ?>"></i>
                        </div>
                        <div class="flex-grow">
                            <div class="flex justify-between items-start">
                                <h3 class="font-medium text-white"><?php echo htmlspecialchars($notification['title']); ?></h3>
                                <div class="flex items-center space-x-2 ml-2">
                                    <?php if (!$notification['is_read']): ?>
                                        <a href="?id=<?php echo $notification['id']; ?>" class="text-indigo-400 hover:text-indigo-300" title="Mark as Read">
                                            <i class="fas fa-check"></i>
                                        </a>
                                    <?php endif; ?>
                                    <a href="?delete=<?php echo $notification['id']; ?>" class="text-red-500 hover:text-red-400" title="Delete" onclick="return confirm('Are you sure you want to delete this notification?');">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="text-sm text-gray-300 mt-1"><?php echo nl2br(htmlspecialchars($notification['message'])); ?></div>
                            <div class="text-xs text-gray-500 mt-2">
                                <?php echo date('F j, Y, g:i a', strtotime($notification['created_at'])); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        
        <!-- Pagination -->
        <?php if ($totalPages > 1): ?>
            <div class="flex justify-center mt-6">
                <nav class="inline-flex rounded-md shadow">
                    <?php if ($page > 1): ?>
                        <a href="?page=<?php echo $page - 1; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-l-md hover:bg-gray-600">
                            <i class="fas fa-chevron-left"></i>
                        </a>
                    <?php else: ?>
                        <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-l-md cursor-not-allowed">
                            <i class="fas fa-chevron-left"></i>
                        </span>
                    <?php endif; ?>
                    
                    <?php
                    $startPage = max(1, $page - 2);
                    $endPage = min($totalPages, $startPage + 4);
                    if ($endPage - $startPage < 4 && $startPage > 1) {
                        $startPage = max(1, $endPage - 4);
                    }
                    
                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?>" class="py-2 px-4 <?php echo $i === $page ? 'bg-indigo-600' : 'bg-gray-700 hover:bg-gray-600'; ?> text-white <?php echo $i === $startPage ? '' : 'border-l border-gray-600'; ?> <?php echo $i === $endPage ? 'rounded-r-md' : ''; ?>">
                            <?php echo $i; ?>
                        </a>
                    <?php endfor; ?>
                    
                    <?php if ($endPage < $totalPages): ?>
                        <span class="py-2 px-4 bg-gray-700 text-gray-300 border-l border-gray-600">...</span>
                        <a href="?page=<?php echo $totalPages; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-r-md hover:bg-gray-600 border-l border-gray-600">
                            <?php echo $totalPages; ?>
                        </a>
                    <?php endif; ?>
                    
                    <?php if ($page < $totalPages): ?>
                        <a href="?page=<?php echo $page + 1; ?>" class="py-2 px-4 bg-gray-700 text-white rounded-r-md hover:bg-gray-600 border-l border-gray-600">
                            <i class="fas fa-chevron-right"></i>
                        </a>
                    <?php else: ?>
                        <span class="py-2 px-4 bg-gray-800 text-gray-500 rounded-r-md cursor-not-allowed border-l border-gray-600">
                            <i class="fas fa-chevron-right"></i>
                        </span>
                    <?php endif; ?>
                </nav>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<?php require_once './includes/footer.php'; ?>