<?php
$pageTitle = 'Reseller Panel';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Get reseller panels
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE status = 'active'");
$stmt->execute();
$result = $stmt->get_result();
$panels = [];

while ($row = $result->fetch_assoc()) {
    $row['features'] = json_decode($row['features'], true);
    $row['images'] = json_decode($row['images'], true) ?: [];
    $row['setup_fee'] = $row['setup_fee'] ?? 0;
    $row['domain_price'] = $row['domain_price'] ?? 0;
    $row['whois_price'] = $row['whois_price'] ?? 0;
    $row['extensions'] = json_decode($row['extensions'], true) ?: [];
    $panels[] = $row;
}

// Get user's reseller panel orders
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro
    JOIN reseller_panels rp ON ro.panel_id = rp.id
    WHERE ro.user_id = ?
    ORDER BY ro.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$orders = [];

while ($row = $result->fetch_assoc()) {
    $orders[] = $row;
}

// Get form field settings
$stmt = $conn->prepare("
    SELECT * FROM form_field_settings 
    WHERE form_name = 'reseller_order' AND is_visible = 1
    ORDER BY display_order ASC
");
$stmt->execute();
$result = $stmt->get_result();
$formFields = [];

while ($row = $result->fetch_assoc()) {
    $formFields[$row['field_name']] = $row;
}

// If form_field_settings table doesn't exist or no settings found, use default fields
if (empty($formFields)) {
    $formFields = [
        'domain_name' => [
            'field_name' => 'domain_name',
            'field_label' => 'Domain Name',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1,
            'display_order' => 1
        ],
        'company_name' => [
            'field_name' => 'company_name',
            'field_label' => 'Company Name',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1,
            'display_order' => 2
        ],
        'company_email' => [
            'field_name' => 'company_email',
            'field_label' => 'Company Email',
            'field_type' => 'email',
            'is_required' => 1,
            'is_visible' => 1,
            'display_order' => 3
        ],
        'company_phone' => [
            'field_name' => 'company_phone',
            'field_label' => 'Company Phone',
            'field_type' => 'text',
            'is_required' => 1,
            'is_visible' => 1,
            'display_order' => 4
        ],
        'company_address' => [
            'field_name' => 'company_address',
            'field_label' => 'Company Address',
            'field_type' => 'textarea',
            'is_required' => 0,
            'is_visible' => 1,
            'display_order' => 5
        ],
        'additional_info' => [
            'field_name' => 'additional_info',
            'field_label' => 'Additional Information',
            'field_type' => 'textarea',
            'is_required' => 0,
            'is_visible' => 1,
            'display_order' => 6
        ]
    ];
}

// Default panel if only one is available
$defaultPanel = !empty($panels) ? $panels[0] : null;

// Get any "panel_id" from URL parameter
$selectedPanelId = isset($_GET['panel_id']) ? (int)$_GET['panel_id'] : null;

// Find the selected panel
$selectedPanel = null;
if ($selectedPanelId) {
    foreach ($panels as $panel) {
        if ($panel['id'] == $selectedPanelId) {
            $selectedPanel = $panel;
            break;
        }
    }
}

// If no panel is selected, use the default panel
if (!$selectedPanel && $defaultPanel) {
    $selectedPanel = $defaultPanel;
}

// Get available domain extensions
$availableExtensions = [];
if ($selectedPanel && !empty($selectedPanel['extensions'])) {
    $availableExtensions = $selectedPanel['extensions'];
} else {
    // Default extensions if not specified
    $availableExtensions = [
        '.com' => 10.99,
        '.net' => 12.99,
        '.org' => 11.99,
        '.info' => 9.99
    ];
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h1 class="text-2xl font-bold text-white mb-4">Reseller Panel</h1>
    
    <div class="text-sm text-gray-400 mb-6">
        Get your own VTU reseller panel with all features and services. Customize it with your brand and start earning.
    </div>
    
    <?php if (empty($panels)): ?>
        <div class="bg-gray-800 rounded-lg p-8 text-center">
            <div class="h-16 w-16 mx-auto mb-4 bg-gray-700 rounded-full flex items-center justify-center">
                <i class="fas fa-store-slash text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-white text-lg font-medium mb-2">No Reseller Panels Available</h3>
            <p class="text-gray-400 mb-4">Reseller panels are currently unavailable. Please check back later.</p>
        </div>
    <?php else: ?>
        <!-- Reseller Panel Selection - Horizontal Scrollable -->
        <?php if (count($panels) > 1): ?>
            <div class="mb-6">
                <h2 class="text-lg font-semibold text-white mb-4">Select a Reseller Plan</h2>
                <div class="relative">
                    <div class="overflow-x-auto pb-2 flex gap-4 snap-x scroll-px-4" id="panelSelector">
                        <?php foreach ($panels as $panel): ?>
                            <a href="?panel_id=<?php echo $panel['id']; ?>" 
                               class="snap-start flex-shrink-0 w-full sm:w-80 block transition-transform hover:scale-105">
                                <div class="bg-gray-800 border border-gray-700 rounded-lg p-4 h-full <?php echo ($selectedPanel && $selectedPanel['id'] == $panel['id']) ? 'border-indigo-500 ring-2 ring-indigo-500 ring-opacity-50' : 'hover:border-gray-600'; ?>">
                                    <div class="font-bold text-white mb-2"><?php echo htmlspecialchars($panel['name']); ?></div>
                                    <div class="text-2xl font-bold text-white mb-3"><?php echo $currency . number_format($panel['price'], 2); ?></div>
                                    <div class="text-sm text-gray-400 mb-3"><?php echo htmlspecialchars($panel['description']); ?></div>
                                    
                                    <?php if (!empty($panel['images']) && isset($panel['images'][0])): ?>
                                        <div class="w-full h-24 bg-gray-900 rounded overflow-hidden mb-3">
                                            <img src="<?php echo htmlspecialchars($panel['images'][0]); ?>" alt="Panel Preview" class="w-full h-full object-cover">
                                        </div>
                                    <?php endif; ?>
                                    
                                    <div class="flex justify-between items-center">
                                        <span class="text-indigo-400 text-sm">
                                            <?php echo count($panel['features']); ?> Features
                                        </span>
                                        <span class="text-gray-400 text-sm">
                                            <i class="fas fa-calendar-alt mr-1"></i> 1 Year
                                        </span>
                                    </div>
                                </div>
                            </a>
                        <?php endforeach; ?>
                    </div>
                    
                    <!-- Scroll Buttons -->
                    <button id="scrollLeft" class="absolute left-0 top-1/2 -translate-y-1/2 -ml-4 bg-gray-800 hover:bg-gray-700 rounded-full p-2 shadow-lg hidden sm:block">
                        <i class="fas fa-chevron-left text-white"></i>
                    </button>
                    <button id="scrollRight" class="absolute right-0 top-1/2 -translate-y-1/2 -mr-4 bg-gray-800 hover:bg-gray-700 rounded-full p-2 shadow-lg hidden sm:block">
                        <i class="fas fa-chevron-right text-white"></i>
                    </button>
                </div>
                
                <!-- Scroll Indicators -->
                <div class="flex justify-center mt-4 gap-2">
                    <?php foreach ($panels as $index => $panel): ?>
                        <button class="panel-indicator h-2 rounded-full w-8 <?php echo ($selectedPanel && $selectedPanel['id'] == $panel['id']) ? 'bg-indigo-500' : 'bg-gray-600'; ?>" data-index="<?php echo $index; ?>"></button>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <?php if ($selectedPanel): ?>
            <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
                <!-- Panel Details -->
                <div class="lg:col-span-1">
                    <div class="bg-gray-800 rounded-lg p-6 sticky top-24">
                        <h2 class="text-xl font-bold text-white mb-4"><?php echo htmlspecialchars($selectedPanel['name']); ?></h2>
                        <div class="text-3xl font-bold text-white mb-3"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></div>
                        <div class="text-sm text-gray-400 mb-4"><?php echo htmlspecialchars($selectedPanel['description']); ?></div>
                        
                        <!-- Panel Preview Images -->
                        <?php if (!empty($selectedPanel['images'])): ?>
                            <div class="mb-4">
                                <div class="panel-main-image mb-2 bg-gray-900 rounded-lg overflow-hidden">
                                    <img src="<?php echo htmlspecialchars($selectedPanel['images'][0]); ?>" alt="Panel Preview" id="mainPanelImage" class="w-full h-auto object-contain">
                                </div>
                                
                                <?php if (count($selectedPanel['images']) > 1): ?>
                                    <div class="flex space-x-2 overflow-x-auto pb-2">
                                        <?php foreach ($selectedPanel['images'] as $index => $image): ?>
                                            <div class="thumbnail-image w-16 h-12 bg-gray-900 rounded overflow-hidden flex-shrink-0 cursor-pointer <?php echo $index === 0 ? 'ring-2 ring-indigo-500' : ''; ?>" data-src="<?php echo htmlspecialchars($image); ?>">
                                                <img src="<?php echo htmlspecialchars($image); ?>" alt="Thumbnail" class="w-full h-full object-cover">
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                <?php endif; ?>
                            </div>
                        <?php endif; ?>
                        
                        <h3 class="text-lg font-semibold text-white mb-3">Features</h3>
                        <div class="space-y-3 mb-6">
                            <?php if (!empty($selectedPanel['features'])): ?>
                                <?php foreach ($selectedPanel['features'] as $feature): ?>
                                    <div class="flex items-start">
                                        <div class="h-5 w-5 rounded-full bg-indigo-500 bg-opacity-20 flex-shrink-0 flex items-center justify-center mt-0.5 mr-3">
                                            <i class="fas fa-check text-xs text-indigo-400"></i>
                                        </div>
                                        <div>
                                            <div class="font-medium text-white"><?php echo htmlspecialchars($feature['title']); ?></div>
                                            <div class="text-xs text-gray-400"><?php echo htmlspecialchars($feature['description']); ?></div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p class="text-gray-400">No specific features listed.</p>
                            <?php endif; ?>
                        </div>
                        
                        <div class="text-sm text-gray-400">
                            <div class="flex items-center mb-2">
                                <i class="fas fa-calendar-alt text-indigo-400 mr-2"></i>
                                <span>Valid for 1 Year</span>
                            </div>
                            <div class="flex items-center">
                                <i class="fas fa-sync-alt text-indigo-400 mr-2"></i>
                                <span>Renewable Annually</span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Order Form -->
                <div class="lg:col-span-2">
                    <div class="bg-gray-800 rounded-lg p-6">
                        <h2 class="text-xl font-bold text-white mb-4">Order Reseller Panel</h2>
                        
                        <form method="POST" action="process/order_reseller.php" id="resellerOrderForm" class="space-y-4">
                            <input type="hidden" name="panel_id" value="<?php echo $selectedPanel['id']; ?>">
                            
                            <!-- Domain Options Section -->
                            <div class="bg-gray-900 p-4 rounded-lg mb-4">
                                <h3 class="text-lg font-medium text-white mb-3">Domain Settings</h3>
                                
                                <div class="mb-4">
                                    <label class="flex items-center space-x-2 cursor-pointer">
                                        <input type="radio" name="domain_option" value="own" class="form-radio text-indigo-600" checked>
                                        <span class="text-gray-300">I have my own domain</span>
                                    </label>
                                    <div class="mt-2 domain-option-section" id="own-domain-section">
                                        <input type="text" name="own_domain" class="form-input text-base block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="yourdomain.com">
                                        <p class="mt-1 text-xs text-gray-500">Enter your existing domain name without http:// or www</p>
                                    </div>
                                </div>
                                
                                <div class="mb-4">
                                    <label class="flex items-center space-x-2 cursor-pointer">
                                        <input type="radio" name="domain_option" value="register" class="form-radio text-indigo-600">
                                        <span class="text-gray-300">Register a new domain for me</span>
                                    </label>
                                    <div class="mt-2 domain-option-section hidden" id="register-domain-section">
                                        <div class="flex flex-wrap md:flex-nowrap gap-2">
                                            <input type="text" name="new_domain" class="form-input text-base block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="yourbusiness">
                                            
                                            <select name="domain_extension" class="form-select block w-full md:w-auto rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                                <?php foreach ($availableExtensions as $ext => $price): ?>
                                                    <option value="<?php echo $ext; ?>"><?php echo $ext; ?> (<?php echo $currency . number_format($price, 2); ?>)</option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        
                                        <div class="mt-3">
                                            <label class="flex items-center space-x-2 cursor-pointer">
                                                <input type="checkbox" name="whois_protection" value="1" class="form-checkbox text-indigo-600">
                                                <span class="text-gray-300">Add WHOIS protection</span>
                                                <span class="text-xs text-indigo-400 ml-1">(+<?php echo $currency . number_format($selectedPanel['whois_price'], 2); ?>)</span>
                                            </label>
                                            <p class="mt-1 text-xs text-gray-500">WHOIS protection hides your personal information from the public WHOIS database</p>
                                        </div>
                                    </div>
                                </div>
                                
                                <div>
                                    <label class="flex items-center space-x-2 cursor-pointer">
                                        <input type="radio" name="domain_option" value="subdomain" class="form-radio text-indigo-600">
                                        <span class="text-gray-300">Use a free subdomain</span>
                                    </label>
                                    <div class="mt-2 domain-option-section hidden" id="subdomain-section">
                                        <div class="flex flex-wrap md:flex-nowrap items-center gap-2">
                                            <input type="text" name="subdomain" class="form-input text-base block w-full md:w-auto rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="yourbusiness">
                                            <span class="text-gray-400">.<?php echo htmlspecialchars(getSetting('site_domain', 'example.com')); ?></span>
                                        </div>
                                        <p class="mt-1 text-xs text-gray-500">Free subdomain hosted on our servers</p>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Dynamic form fields based on settings -->
                            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                                <?php foreach ($formFields as $fieldName => $field): ?>
                                    <?php if ($field['field_type'] !== 'textarea'): ?>
                                        <div class="form-group <?php echo ($fieldName == 'company_email' || $fieldName == 'company_phone') ? 'col-span-1' : 'md:col-span-2'; ?>">
                                            <label for="<?php echo $fieldName; ?>" class="block text-sm font-medium text-gray-400 mb-2">
                                                <?php echo htmlspecialchars($field['field_label']); ?>
                                                <?php if ($field['is_required']): ?>
                                                    <span class="text-red-500">*</span>
                                                <?php endif; ?>
                                            </label>
                                            
                                            <input type="<?php echo ($field['field_type'] == 'email') ? 'email' : ($field['field_type'] == 'number' ? 'number' : 'text'); ?>" 
                                                   id="<?php echo $fieldName; ?>" 
                                                   name="<?php echo $fieldName; ?>" 
                                                   class="form-input text-base block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                                   <?php echo $field['is_required'] ? 'required' : ''; ?>>
                                        </div>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </div>
                            
                            <!-- Textarea fields in their own section -->
                            <?php foreach ($formFields as $fieldName => $field): ?>
                                <?php if ($field['field_type'] === 'textarea'): ?>
                                    <div class="form-group">
                                        <label for="<?php echo $fieldName; ?>" class="block text-sm font-medium text-gray-400 mb-2">
                                            <?php echo htmlspecialchars($field['field_label']); ?>
                                            <?php if ($field['is_required']): ?>
                                                <span class="text-red-500">*</span>
                                            <?php endif; ?>
                                        </label>
                                        
                                        <textarea id="<?php echo $fieldName; ?>" 
                                                  name="<?php echo $fieldName; ?>" 
                                                  rows="<?php echo ($fieldName === 'additional_info') ? '3' : '2'; ?>" 
                                                  class="form-input text-base block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" 
                                                  <?php echo $field['is_required'] ? 'required' : ''; ?>></textarea>
                                    </div>
                                <?php endif; ?>
                            <?php endforeach; ?>
                            
                            <!-- Terms and Conditions -->
                            <div class="form-group">
                                <label class="inline-flex items-center cursor-pointer">
                                    <input type="checkbox" id="agree_terms" name="agree_terms" class="rounded border-gray-600 text-indigo-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-4 w-4" required>
                                    <span class="ml-2 text-gray-400">I agree to the <a href="<?php echo SITE_URL; ?>/terms.php" target="_blank" class="text-indigo-400 hover:text-indigo-300">Terms and Conditions</a></span>
                                </label>
                            </div>
                            
                            <!-- Payment Summary -->
                            <div class="p-4 bg-gray-900 rounded-md mb-4">
                                <h3 class="text-white font-medium mb-3">Order Summary</h3>
                                <div class="space-y-2 mb-3" id="orderSummary">
                                    <div class="flex justify-between">
                                        <span class="text-gray-400">Reseller Panel:</span>
                                        <span class="text-white font-medium"><?php echo $currency . number_format($selectedPanel['price'], 2); ?></span>
                                    </div>
                                    <div class="flex justify-between domain-price-row hidden">
                                        <span class="text-gray-400">Domain Registration:</span>
                                        <span class="text-white font-medium" id="domainPriceDisplay">$0.00</span>
                                    </div>
                                    <div class="flex justify-between whois-price-row hidden">
                                        <span class="text-gray-400">WHOIS Protection:</span>
                                        <span class="text-white font-medium" id="whoisPriceDisplay"><?php echo $currency . number_format($selectedPanel['whois_price'], 2); ?></span>
                                    </div>
                                    <div class="flex justify-between setup-fee-row <?php echo ($selectedPanel['setup_fee'] > 0) ? '' : 'hidden'; ?>">
                                        <span class="text-gray-400">Setup Fee:</span>
                                        <span class="text-white font-medium"><?php echo $currency . number_format($selectedPanel['setup_fee'], 2); ?></span>
                                    </div>
                                </div>
                                <div class="flex justify-between pt-2 border-t border-gray-700">
                                    <span class="text-gray-300 font-medium">Total Amount:</span>
                                    <span class="text-white font-bold" id="totalPriceDisplay"><?php echo $currency . number_format($selectedPanel['price'] + $selectedPanel['setup_fee'], 2); ?></span>
                                </div>
                            </div>
                            
                            <!-- Submit Button -->
                            <div class="flex justify-end">
                                <button type="submit" id="orderBtn" class="accent-button py-2 px-6 rounded-md text-white font-medium focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                    Order Now
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- My Reseller Panels -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">My Reseller Panels</h2>
    
    <?php if (empty($orders)): ?>
        <div class="text-center py-10 text-gray-400">
            <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                <i class="fas fa-store text-2xl text-gray-500"></i>
            </div>
            <h3 class="text-lg font-medium mb-1">No Reseller Panels Yet</h3>
            <p class="text-sm mb-4">You haven't ordered any reseller panels yet.</p>
            <?php if (!empty($panels)): ?>
                <a href="#resellerOrderForm" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                    Order Reseller Panel
                </a>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full">
                <thead class="bg-gray-800">
                    <tr>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Order Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Panel</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Domain</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Amount</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Expiry Date</th>
                        <th class="py-3 px-4 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Action</th>
                    </tr>
                </thead>
                <tbody class="divide-y divide-gray-700">
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo date('M d, Y', strtotime($order['created_at'])); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white">
                                <?php echo htmlspecialchars($order['panel_name']); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php echo htmlspecialchars($order['domain_name'] ?: 'Not specified'); ?>
                            </td>
                            <td class="py-3 px-4 text-sm text-white font-medium">
                                <?php echo $currency . number_format($order['amount'], 2); ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php
                                $statusColors = [
                                    'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-400',
                                    'processing' => 'bg-blue-500 bg-opacity-20 text-blue-400',
                                    'completed' => 'bg-green-500 bg-opacity-20 text-green-400',
                                    'cancelled' => 'bg-red-500 bg-opacity-20 text-red-400'
                                ];
                                $statusColor = $statusColors[$order['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-400';
                                ?>
                                <span class="px-2 py-1 text-xs rounded-full <?php echo $statusColor; ?>">
                                    <?php echo ucfirst($order['status']); ?>
                                </span>
                            </td>
                            <td class="py-3 px-4 text-sm text-gray-300">
                                <?php 
                                if ($order['status'] === 'completed' && $order['expiry_date']) {
                                    echo date('M d, Y', strtotime($order['expiry_date']));
                                    
                                    // Check if expiry date is within 30 days
                                    $expiryDays = (strtotime($order['expiry_date']) - time()) / (60 * 60 * 24);
                                    if ($expiryDays <= 30 && $expiryDays > 0) {
                                        echo ' <span class="text-xs text-red-400">(' . round($expiryDays) . ' days left)</span>';
                                    }
                                } else {
                                    echo 'N/A';
                                }
                                ?>
                            </td>
                            <td class="py-3 px-4">
                                <?php if ($order['status'] === 'completed'): ?>
                                    <a href="<?php echo isset($order['domain_name']) && $order['domain_name'] ? 'https://' . $order['domain_name'] : '#'; ?>" class="text-indigo-400 hover:text-indigo-300" <?php echo isset($order['domain_name']) && $order['domain_name'] ? 'target="_blank"' : ''; ?>>
                                        <i class="fas fa-external-link-alt mr-1"></i> Access Panel
                                    </a>
                                <?php elseif ($order['status'] === 'pending'): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/view_order.php?id=<?php echo $order['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                        <i class="fas fa-eye mr-1"></i> View Details
                                    </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<!-- Loading Modal -->
<div id="loadingModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md text-center">
        <div class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-indigo-500 mx-auto mb-4"></div>
        <p class="text-white text-lg font-medium mb-2">Processing Your Order</p>
        <p class="text-gray-400">Please wait while we process your reseller panel order...</p>
    </div>
</div>

<!-- Success Modal -->
<div id="successModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-check-circle text-3xl text-green-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Submitted Successfully!</h3>
            <p class="text-gray-400 mt-2" id="successMessage">Your reseller panel order has been submitted successfully. Our team will review your order and contact you shortly.</p>
        </div>
        <div class="p-4 bg-gray-700 rounded-md mb-4">
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Order Reference:</span>
                <span id="orderReference" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Panel:</span>
                <span id="panelName" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between mb-2">
                <span class="text-gray-400">Amount:</span>
                <span id="orderAmount" class="text-white font-medium"></span>
            </div>
            <div class="flex justify-between">
                <span class="text-gray-400">Date:</span>
                <span id="orderDate" class="text-white font-medium"></span>
            </div>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeSuccessModal" class="accent-button py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<!-- Error Modal -->
<div id="errorModal" class="fixed inset-0 z-50 flex items-center justify-center hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg p-6 w-full max-w-md">
        <div class="text-center mb-4">
            <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                <i class="fas fa-exclamation-triangle text-3xl text-red-500"></i>
            </div>
            <h3 class="text-xl font-semibold text-white">Order Failed</h3>
            <p class="text-gray-400 mt-2" id="errorMessage">Sorry, we couldn't process your reseller panel order at this time.</p>
        </div>
        <div class="flex justify-end">
            <button type="button" id="closeErrorModal" class="bg-red-600 hover:bg-red-700 py-2 px-4 rounded-md text-white">
                Close
            </button>
        </div>
    </div>
</div>

<?php
$extraScripts = <<<'EOT'
<script>
document.addEventListener('DOMContentLoaded', function() {
    // Panel horizontal scroll functionality
    const panelSelector = document.getElementById('panelSelector');
    const scrollLeft = document.getElementById('scrollLeft');
    const scrollRight = document.getElementById('scrollRight');
    const panelIndicators = document.querySelectorAll('.panel-indicator');
    
    if (scrollLeft && scrollRight && panelSelector) {
        scrollLeft.addEventListener('click', function() {
            panelSelector.scrollBy({ left: -320, behavior: 'smooth' });
        });
        
        scrollRight.addEventListener('click', function() {
            panelSelector.scrollBy({ left: 320, behavior: 'smooth' });
        });
        
        // Update indicators on scroll
        panelSelector.addEventListener('scroll', function() {
            const scrollPosition = panelSelector.scrollLeft;
            const panelWidth = 320; // Approximate width of each panel
            const activeIndex = Math.round(scrollPosition / panelWidth);
            
            panelIndicators.forEach((indicator, index) => {
                if (index === activeIndex) {
                    indicator.classList.add('bg-indigo-500');
                    indicator.classList.remove('bg-gray-600');
                } else {
                    indicator.classList.remove('bg-indigo-500');
                    indicator.classList.add('bg-gray-600');
                }
            });
        });
        
        // Click on indicators to scroll
        panelIndicators.forEach((indicator, index) => {
            indicator.addEventListener('click', function() {
                const panelWidth = 320; // Approximate width of each panel
                panelSelector.scrollTo({ left: index * panelWidth, behavior: 'smooth' });
            });
        });
    }
    
    // Panel thumbnails functionality
    const thumbnails = document.querySelectorAll('.thumbnail-image');
    const mainImage = document.getElementById('mainPanelImage');
    
    if (thumbnails.length > 0 && mainImage) {
        thumbnails.forEach(thumbnail => {
            thumbnail.addEventListener('click', function() {
                // Update main image
                mainImage.src = this.getAttribute('data-src');
                
                // Update selection styling
                thumbnails.forEach(thumb => {
                    thumb.classList.remove('ring-2', 'ring-indigo-500');
                });
                this.classList.add('ring-2', 'ring-indigo-500');
            });
        });
    }
    
    // Domain option toggling
    const domainOptions = document.querySelectorAll('input[name="domain_option"]');
    const domainSections = document.querySelectorAll('.domain-option-section');
    
    domainOptions.forEach(option => {
        option.addEventListener('change', function() {
            // Hide all sections
            domainSections.forEach(section => {
                section.classList.add('hidden');
            });
            
            // Show selected section
            const selectedOption = this.value;
            document.getElementById(`${selectedOption}-domain-section`).classList.remove('hidden');
            
            // Update pricing display
            updateTotalPrice();
        });
    });
    
    // Handle domain extension change
    const domainExtensionSelect = document.querySelector('select[name="domain_extension"]');
    if (domainExtensionSelect) {
        domainExtensionSelect.addEventListener('change', updateTotalPrice);
    }
    
    // Handle whois protection toggle
    const whoisCheckbox = document.querySelector('input[name="whois_protection"]');
    if (whoisCheckbox) {
        whoisCheckbox.addEventListener('change', updateTotalPrice);
    }
    
    // Price calculation function
    function updateTotalPrice() {
        const panelPrice = <?php echo $selectedPanel ? $selectedPanel['price'] : 0; ?>;
        const setupFee = <?php echo $selectedPanel ? $selectedPanel['setup_fee'] : 0; ?>;
        const whoisPrice = <?php echo $selectedPanel ? $selectedPanel['whois_price'] : 0; ?>;
        const currency = '<?php echo $currency; ?>';
        
        let totalPrice = panelPrice + setupFee;
        let domainPrice = 0;
        
        // Get selected domain option
        const selectedDomainOption = document.querySelector('input[name="domain_option"]:checked').value;
        
        // Show/hide relevant price rows
        const domainPriceRow = document.querySelector('.domain-price-row');
        const whoisPriceRow = document.querySelector('.whois-price-row');
        
        if (selectedDomainOption === 'register') {
            // Get selected extension price
            const domainExtension = document.querySelector('select[name="domain_extension"]');
            const selectedOption = domainExtension.options[domainExtension.selectedIndex];
            const extensionText = selectedOption.text;
            
            // Extract price from text like ".com ($10.99)"
            const priceMatch = extensionText.match(/\(\$?([\d.]+)\)/);
            if (priceMatch && priceMatch[1]) {
                domainPrice = parseFloat(priceMatch[1]);
            }
            
            // Show domain price in summary
            domainPriceRow.classList.remove('hidden');
            document.getElementById('domainPriceDisplay').textContent = currency + domainPrice.toFixed(2);
            
            // Handle WHOIS protection
            const whoisEnabled = document.querySelector('input[name="whois_protection"]').checked;
            if (whoisEnabled) {
                whoisPriceRow.classList.remove('hidden');
                totalPrice += whoisPrice;
            } else {
                whoisPriceRow.classList.add('hidden');
            }
            
            totalPrice += domainPrice;
        } else {
            // Hide domain-related prices
            domainPriceRow.classList.add('hidden');
            whoisPriceRow.classList.add('hidden');
        }
        
        // Update total price display
        document.getElementById('totalPriceDisplay').textContent = currency + totalPrice.toFixed(2);
    }
    
    // Initial price calculation
    updateTotalPrice();
    
    // Form submission
    const orderForm = document.getElementById('resellerOrderForm');
    const loadingModal = document.getElementById('loadingModal');
    const successModal = document.getElementById('successModal');
    const errorModal = document.getElementById('errorModal');
    
    if (orderForm) {
        orderForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Show loading state
            loadingModal.classList.remove('hidden');
            
            // Collect form data based on chosen domain option
            const formData = new FormData(orderForm);
            const domainOption = formData.get('domain_option');
            
            // Add domain_name based on selected option
            if (domainOption === 'own') {
                formData.set('domain_name', formData.get('own_domain'));
            } else if (domainOption === 'register') {
                formData.set('domain_name', formData.get('new_domain') + formData.get('domain_extension'));
            } else if (domainOption === 'subdomain') {
                formData.set('domain_name', formData.get('subdomain') + '.<?php echo getSetting('site_domain', 'example.com'); ?>');
            }
            
            // Submit form using fetch API
            fetch(orderForm.action, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                // Hide loading modal
                loadingModal.classList.add('hidden');
                
                if (data.success) {
                    // Show success modal
                    document.getElementById('orderReference').textContent = data.data.reference;
                    document.getElementById('panelName').textContent = data.data.panel_name;
                    document.getElementById('orderAmount').textContent = '<?php echo $currency; ?>' + parseFloat(data.data.amount).toFixed(2);
                    document.getElementById('orderDate').textContent = new Date().toLocaleDateString();
                    document.getElementById('successMessage').textContent = data.message;
                    successModal.classList.remove('hidden');
                    
                    // Reset form
                    orderForm.reset();
                    
                    // Refresh the page after 5 seconds
                    setTimeout(() => {
                        window.location.reload();
                    }, 5000);
                } else {
                    // Show error modal
                    document.getElementById('errorMessage').textContent = data.message;
                    errorModal.classList.remove('hidden');
                }
            })
            .catch(error => {
                // Hide loading modal
                loadingModal.classList.add('hidden');
                
                // Show error modal
                document.getElementById('errorMessage').textContent = 'An error occurred while processing your order. Please try again later.';
                errorModal.classList.remove('hidden');
                
                console.error('Error:', error);
            });
        });
    }
    
    // Modal close buttons
    document.getElementById('closeSuccessModal').addEventListener('click', function() {
        successModal.classList.add('hidden');
        window.location.reload();
    });
    
    document.getElementById('closeErrorModal').addEventListener('click', function() {
        errorModal.classList.add('hidden');
    });
    
    // Close modals when clicking outside
    window.addEventListener('click', function(event) {
        if (event.target === successModal) {
            successModal.classList.add('hidden');
        }
        if (event.target === errorModal) {
            errorModal.classList.add('hidden');
        }
    });
});
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>