<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Check if checkout session exists
if (!isset($_SESSION['paystack_checkout'])) {
    redirect('fund_wallet.php');
}

// Get checkout data
$checkoutData = $_SESSION['paystack_checkout'];
$txnId = $checkoutData['txn_id'];
$txnRef = $checkoutData['txn_ref'];
$amount = $checkoutData['amount'];
$charge = $checkoutData['charge'];
$amountToCredit = $checkoutData['amount_to_credit'];
$reference = $checkoutData['reference'];

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get Paystack settings from database
$paystackLive = getSetting('paystack_live', '0');
$paystackLivePublicKey = getSetting('paystack_live_public_key', '');
$paystackTestPublicKey = getSetting('paystack_test_public_key', '');

// Choose the appropriate key based on live mode setting
$paystackPublicKey = ($paystackLive == '1') ? $paystackLivePublicKey : $paystackTestPublicKey;

// Check if the key is set
if (empty($paystackPublicKey)) {
    $error = "Paystack API key is not configured. Please contact administrator.";
}

// Convert amount to kobo (Paystack uses the smallest currency unit)
$amountInKobo = $amount * 100;

// Get currency code from settings or default to NGN
$currencyCode = getSetting('currency_code', 'NGN');

// Set page title and currency symbol
$siteName = getSetting('site_name', 'VTU System');
$currency = getSetting('currency', '₦');
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Payment Checkout - <?php echo $siteName; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script src="https://js.paystack.co/v1/inline.js"></script>
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .checkout-card {
            background-color: #1e1e1e;
            position: relative;
            overflow: hidden;
            z-index: 0;
        }
        
        .checkout-card::before {
            content: '';
            position: absolute;
            top: -50%;
            left: -50%;
            width: 200%;
            height: 200%;
            background: linear-gradient(45deg, transparent, rgba(93, 92, 222, 0.1), transparent);
            transform: rotate(45deg);
            z-index: -1;
        }
        
        .loader {
            border-top-color: var(--accent-color);
            animation: spinner 1s linear infinite;
        }
        
        @keyframes spinner {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    </style>
</head>
<body class="min-h-screen flex flex-col bg-gray-900">
    <!-- Header -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3">
            <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo $siteName; ?></a>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex items-center justify-center p-4">
        <div class="max-w-md w-full">
            <div class="checkout-card rounded-lg shadow-lg p-6">
                <div class="mb-6 text-center">
                    <h1 class="text-2xl font-bold text-white mb-2">Payment Checkout</h1>
                    <p class="text-gray-400">Complete your wallet funding</p>
                </div>
                
                <?php if (isset($error)): ?>
                <div class="mb-6 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md">
                    <p class="text-red-300 text-sm">
                        <i class="fas fa-exclamation-triangle mr-2"></i> <?php echo $error; ?>
                    </p>
                </div>
                <?php else: ?>
                <div class="mb-6 p-4 bg-gray-800 rounded-md">
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Amount:</span>
                        <span class="text-white"><?php echo $currency; ?><?php echo number_format($amount, 2); ?></span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Service Charge:</span>
                        <span class="text-white"><?php echo $currency; ?><?php echo number_format($charge, 2); ?></span>
                    </div>
                    <div class="flex justify-between font-semibold">
                        <span class="text-gray-400">Amount to be Credited:</span>
                        <span class="text-white"><?php echo $currency; ?><?php echo number_format($amountToCredit, 2); ?></span>
                    </div>
                </div>
                
                <div class="mb-6 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                    <p class="text-indigo-300 text-sm">
                        <i class="fas fa-info-circle mr-2"></i> You'll be redirected to Paystack to complete your payment securely.
                    </p>
                </div>
                
                <div class="flex space-x-4">
                    <a href="fund_wallet.php" class="flex-1 py-2 px-4 border border-gray-600 rounded-md shadow-sm text-sm font-medium text-gray-300 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 text-center">
                        Cancel
                    </a>
                    <button type="button" id="payButton" class="flex-1 accent-button py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Pay Now
                    </button>
                </div>
                
                <div id="loadingIndicator" class="hidden mt-4 flex items-center justify-center">
                    <div class="loader w-5 h-5 border-2 border-gray-600 rounded-full mr-3"></div>
                    <span class="text-gray-400">Processing payment...</span>
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo $siteName; ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <?php if (!isset($error)): ?>
    <script>
        const payButton = document.getElementById('payButton');
        const loadingIndicator = document.getElementById('loadingIndicator');
        
        payButton.addEventListener('click', function() {
            // Show loading indicator
            payButton.disabled = true;
            loadingIndicator.classList.remove('hidden');
            
            // Initialize Paystack payment
            const handler = PaystackPop.setup({
                key: '<?php echo $paystackPublicKey; ?>',
                email: '<?php echo $user['email']; ?>',
                amount: <?php echo $amountInKobo; ?>,
                currency: '<?php echo $currencyCode; ?>',
                ref: '<?php echo $reference; ?>',
                metadata: {
                    custom_fields: [
                        {
                            display_name: "Transaction Reference",
                            variable_name: "txn_ref",
                            value: "<?php echo $txnRef; ?>"
                        },
                        {
                            display_name: "User ID",
                            variable_name: "user_id",
                            value: "<?php echo $userId; ?>"
                        }
                    ]
                },
                callback: function(response) {
                    // Redirect to verification page
                    window.location.href = 'verify_payment.php?reference=' + response.reference;
                },
                onClose: function() {
                    // Reset button and hide loading indicator
                    payButton.disabled = false;
                    loadingIndicator.classList.add('hidden');
                }
            });
            
            handler.openIframe();
        });
    </script>
    <?php endif; ?>
</body>
</html>