<?php
// File: /dashboard/process/buy_airtime.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/airtime_purchase.php';

// Enable error logging
ini_set('display_errors', 0);
ini_set('log_errors', 1);
error_log("Airtime purchase request received: " . json_encode($_POST));

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'You must be logged in to purchase airtime']);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Validate input
$phone = isset($_POST['phone']) ? sanitizeInput($_POST['phone']) : '';
$amount = isset($_POST['amount']) ? (float)$_POST['amount'] : 0;
$networkId = isset($_POST['network_id']) ? (int)$_POST['network_id'] : 0;
$promoCode = isset($_POST['promo_code']) ? sanitizeInput($_POST['promo_code']) : '';
$saveBeneficiary = isset($_POST['beneficiary']) && !empty($_POST['beneficiary']);
$beneficiaryName = isset($_POST['beneficiary']) ? sanitizeInput($_POST['beneficiary']) : '';
$clientReference = isset($_POST['client_reference']) ? sanitizeInput($_POST['client_reference']) : '';

// Log for debugging
error_log("Parsed parameters - Amount: $amount, Phone: $phone, Network: $networkId");

// Basic validation
if (empty($phone)) {
    echo json_encode(['success' => false, 'message' => 'Phone number is required']);
    exit;
}

if (strlen($phone) < 10 || strlen($phone) > 15) {
    echo json_encode(['success' => false, 'message' => 'Please enter a valid phone number']);
    exit;
}

if ($amount < 50) {
    echo json_encode(['success' => false, 'message' => 'Minimum airtime amount is ₦50']);
    exit;
}

if ($networkId <= 0) {
    echo json_encode(['success' => false, 'message' => 'Please select a network']);
    exit;
}

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode(['success' => false, 'message' => 'User not found']);
    exit;
}

// Save beneficiary if requested (do this early, before any transactions)
if ($saveBeneficiary && !empty($beneficiaryName)) {
    try {
        // Check if beneficiary already exists
        $stmt = $conn->prepare("SELECT id FROM beneficiaries WHERE user_id = ? AND type = 'airtime' AND identifier = ?");
        $stmt->bind_param("is", $userId, $phone);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows == 0) {
            // Insert new beneficiary
            $stmt = $conn->prepare("INSERT INTO beneficiaries (user_id, type, name, identifier, provider_id, created_at) VALUES (?, 'airtime', ?, ?, ?, NOW())");
            $stmt->bind_param("issi", $userId, $beneficiaryName, $phone, $networkId);
            $stmt->execute();
            error_log("Saved airtime beneficiary: $beneficiaryName, $phone");
        } else {
            error_log("Beneficiary already exists for phone number: $phone");
        }
    } catch (Exception $e) {
        error_log("Error saving beneficiary: " . $e->getMessage());
        // Continue with the purchase even if saving beneficiary fails
    }
}

// Get network details
$stmt = $conn->prepare("SELECT * FROM networks WHERE id = ? AND status = 'active'");
$stmt->bind_param("i", $networkId);
$stmt->execute();
$result = $stmt->get_result();
$network = $result->fetch_assoc();

if (!$network) {
    echo json_encode(['success' => false, 'message' => 'Selected network not found or not active']);
    exit;
}

// Get provider for this network
$stmt = $conn->prepare("
    SELECT p.* FROM network_providers np
    JOIN providers p ON np.provider_id = p.id
    WHERE np.network_id = ? AND np.service_type = 'airtime' AND p.status = 'active'
    ORDER BY np.is_default DESC
    LIMIT 1
");
$stmt->bind_param("i", $networkId);
$stmt->execute();
$result = $stmt->get_result();
$provider = $result->fetch_assoc();

if (!$provider) {
    error_log("No provider found for network: $networkId, service: airtime");
    echo json_encode(['success' => false, 'message' => 'No active provider available for this network']);
    exit;
}

// Apply discount based on user type
$discountKey = 'airtime_discount_' . $user['user_type'];
$discountPercent = (float)getSetting($discountKey, 0);
$discount = 0;

if ($discountPercent > 0) {
    $discount = ($amount * $discountPercent) / 100;
}

// Apply promo code if provided
$promoDiscount = 0;
if (!empty($promoCode)) {
    // Get current date in MySQL format
    $currentDate = date('Y-m-d H:i:s');
    
    $stmt = $conn->prepare("
        SELECT * FROM promo_codes 
        WHERE code = ? 
        AND status = 'active' 
        AND (start_date IS NULL OR start_date <= ?) 
        AND (end_date IS NULL OR end_date >= ?) 
        AND (max_uses = 0 OR current_uses < max_uses)
    ");
    $stmt->bind_param("sss", $promoCode, $currentDate, $currentDate);
    $stmt->execute();
    $result = $stmt->get_result();
    $promo = $result->fetch_assoc();
    
    if ($promo) {
        // Check if this promo is applicable to airtime
        $applicableServices = json_decode($promo['applicable_services'], true);
        if (is_array($applicableServices) && (in_array('airtime', $applicableServices) || in_array('all', $applicableServices))) {
            // Check minimum order amount
            $minAmount = isset($promo['min_amount']) ? (float)$promo['min_amount'] : 0;
            
            if ($amount >= $minAmount) {
                $discountType = isset($promo['type']) ? $promo['type'] : 'fixed';
                $discountValue = isset($promo['discount']) ? (float)$promo['discount'] : 0;
                
                if ($discountType == 'percentage') {
                    $promoDiscount = ($amount * $discountValue) / 100;
                    // Apply max discount if set
                    if (isset($promo['max_amount']) && $promo['max_amount'] > 0 && $promoDiscount > $promo['max_amount']) {
                        $promoDiscount = $promo['max_amount'];
                    }
                } else {
                    // Fixed amount discount
                    $promoDiscount = $discountValue;
                }
                
                error_log("Applied promo code: $promoCode, Type: $discountType, Value: $discountValue, Discount: $promoDiscount");
            } else {
                error_log("Promo code minimum amount not met: $minAmount");
            }
        } else {
            error_log("Promo code not applicable to airtime service");
        }
    } else {
        error_log("Invalid or expired promo code: $promoCode");
    }
}

// Calculate final amount
$discountTotal = $discount + $promoDiscount;
$finalAmount = $amount - $discountTotal;

// Ensure the final amount is at least 50
if ($finalAmount < 50) {
    echo json_encode(['success' => false, 'message' => 'After applying discounts, the final amount must be at least ₦50']);
    exit;
}

// Check if user has sufficient balance
if ($user['balance'] < $finalAmount) {
    echo json_encode(['success' => false, 'message' => 'Insufficient balance. Please fund your wallet and try again.']);
    exit;
}

// Begin transaction
$conn->begin_transaction();

try {
    // Generate reference
    $reference = 'AIRTIME_' . time() . '_' . rand(1000, 9999);
    
    // Create transaction record
    $stmt = $conn->prepare("
        INSERT INTO transactions (user_id, txn_ref, type, amount, description, status, meta_data)
        VALUES (?, ?, 'airtime', ?, ?, 'pending', ?)
    ");
    
    $description = "Airtime purchase of {$amount} for {$phone} on {$network['name']}";
    $metaData = json_encode([
        'network_id' => $networkId,
        'phone' => $phone,
        'amount' => $amount,
        'discount' => $discountTotal,
        'promo_code' => $promoCode,
        'promo_discount' => $promoDiscount,
        'user_discount' => $discount,
        'final_amount' => $finalAmount,
        'client_reference' => $clientReference
    ]);
    
    $stmt->bind_param("isdss", $userId, $reference, $finalAmount, $description, $metaData);
    $stmt->execute();
    $txnId = $conn->insert_id;
    
    // Deduct from user's balance
    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
    $stmt->bind_param("di", $finalAmount, $userId);
    $stmt->execute();
    
    // Process the API purchase
    $purchaseResult = purchaseAirtimeWithProvider($provider, $network, $phone, $amount);
    
    if ($purchaseResult['success']) {
        // Update transaction record
        $stmt = $conn->prepare("UPDATE transactions SET status = 'successful', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult['details']);
        $stmt->bind_param("si", $apiResponse, $txnId);
        $stmt->execute();
        
        // Update promo code usage if used
        if (!empty($promoCode) && isset($promo) && $promo) {
            $stmt = $conn->prepare("UPDATE promo_codes SET usage_count = usage_count + 1 WHERE id = ?");
            $stmt->bind_param("i", $promo['id']);
            $stmt->execute();
        }
        
        // Create notification for user
        $notifyTitle = 'Airtime Purchase Successful';
        $notifyMessage = "Your purchase of {$amount} airtime for {$phone} was successful.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => true,
            'message' => 'Airtime purchase successful!',
            'data' => [
                'reference' => $reference,
                'phone' => $phone,
                'network' => $network['name'],
                'amount' => $amount,
                'discount' => $discountTotal,
                'paid' => $finalAmount,
                'client_reference' => $clientReference
            ]
        ]);
    } else {
        // Update transaction record to failed
        $stmt = $conn->prepare("UPDATE transactions SET status = 'failed', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult);
        $stmt->bind_param("si", $apiResponse, $txnId);
        $stmt->execute();
        
        // Refund user's balance
        $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->bind_param("di", $finalAmount, $userId);
        $stmt->execute();
        
        // Create notification for user
        $notifyTitle = 'Airtime Purchase Failed';
        $notifyMessage = "Your purchase of {$amount} airtime for {$phone} failed. Your account has been refunded.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'error', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => false,
            'message' => 'Airtime purchase failed: ' . $purchaseResult['message'],
            'error_details' => $purchaseResult
        ]);
    }
} catch (Exception $e) {
    // Rollback transaction on error
    $conn->rollback();
    
    // Log the error
    error_log("Airtime purchase exception: " . $e->getMessage());
    
    echo json_encode([
        'success' => false,
        'message' => 'An error occurred while processing your request: ' . $e->getMessage()
    ]);
}
?>