<?php
// File: /dashboard/process/buy_data.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/data_purchase.php';

// Enable error logging
ini_set('display_errors', 0);
ini_set('log_errors', 1);
error_log("Data purchase request received: " . json_encode($_POST));

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'You must be logged in to purchase data']);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Validate input
$phone = isset($_POST['phone']) ? sanitizeInput($_POST['phone']) : '';
$planId = isset($_POST['plan_id']) ? (int)$_POST['plan_id'] : 0;
$networkId = isset($_POST['network_id']) ? (int)$_POST['network_id'] : 0;
$dataTypeId = isset($_POST['data_type_id']) ? (int)$_POST['data_type_id'] : 0;
$pin = isset($_POST['pin']) ? sanitizeInput($_POST['pin']) : '';

// Log for debugging
error_log("Parsed parameters - Plan ID: $planId, Phone: $phone, Network: $networkId, Data Type: $dataTypeId");

// Basic validation
if (empty($phone)) {
    echo json_encode(['success' => false, 'message' => 'Phone number is required']);
    exit;
}

if (strlen($phone) < 10 || strlen($phone) > 15) {
    echo json_encode(['success' => false, 'message' => 'Please enter a valid phone number']);
    exit;
}

if ($planId <= 0) {
    echo json_encode(['success' => false, 'message' => 'Please select a data plan']);
    exit;
}

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode(['success' => false, 'message' => 'User not found']);
    exit;
}

// Verify transaction PIN if required
if (getSetting('require_pin_for_purchases', '1') == '1') {
    if (empty($pin)) {
        echo json_encode(['success' => false, 'message' => 'Transaction PIN is required']);
        exit;
    }
    
    if (empty($user['pin']) || !password_verify($pin, $user['pin'])) {
        echo json_encode(['success' => false, 'message' => 'Invalid transaction PIN']);
        exit;
    }
}

// Get plan details with price based on user type
$priceField = 'price';
switch ($user['user_type']) {
    case 'smart':
        $priceField = 'IF(smart_price > 0, smart_price, price)';
        break;
    case 'api':
        $priceField = 'IF(api_price > 0, api_price, price)';
        break;
    case 'vendor':
        $priceField = 'IF(vendor_price > 0, vendor_price, price)';
        break;
}

$stmt = $conn->prepare("
    SELECT p.*, dt.name as data_type, n.name as network_name, ($priceField) as user_price,
    dt.id as data_type_id, n.id as network_id
    FROM data_plans p
    JOIN data_types dt ON p.data_type_id = dt.id
    JOIN networks n ON dt.network_id = n.id
    WHERE p.id = ? AND p.status = 'active'
");
$stmt->bind_param("i", $planId);
$stmt->execute();
$result = $stmt->get_result();
$plan = $result->fetch_assoc();

if (!$plan) {
    echo json_encode(['success' => false, 'message' => 'Selected plan not found or not active']);
    exit;
}

// Double-check that the data type and network match what was selected
if ($dataTypeId > 0 && $plan['data_type_id'] != $dataTypeId) {
    error_log("Data type mismatch - Expected: {$plan['data_type_id']}, Received: $dataTypeId");
}

if ($networkId > 0 && $plan['network_id'] != $networkId) {
    error_log("Network mismatch - Expected: {$plan['network_id']}, Received: $networkId");
}

// Check if user has sufficient balance
if ($user['balance'] < $plan['user_price']) {
    echo json_encode(['success' => false, 'message' => 'Insufficient balance. Please fund your wallet and try again.']);
    exit;
}

// Begin transaction
$conn->begin_transaction();

try {
    // Generate reference
    $reference = 'DATA_' . time() . '_' . rand(1000, 9999);
    
    // Create transaction record
    $stmt = $conn->prepare("
        INSERT INTO transactions (user_id, txn_ref, type, amount, description, status, meta_data)
        VALUES (?, ?, 'data', ?, ?, 'pending', ?)
    ");
    
    $description = "{$plan['network_name']} {$plan['data_type']} {$plan['name']} - {$plan['size']} for {$phone}";
    $metaData = json_encode([
        'network_id' => $plan['network_id'],
        'data_type_id' => $plan['data_type_id'],
        'plan_id' => $planId,
        'phone' => $phone,
        'plan_size' => $plan['size'],
        'plan_name' => $plan['name']
    ]);
    
    $stmt->bind_param("isdss", $userId, $reference, $plan['user_price'], $description, $metaData);
    $stmt->execute();
    $txnId = $conn->insert_id;
    
    // Create data purchase record
    $stmt = $conn->prepare("
        INSERT INTO data_purchases (
            user_id, transaction_id, network_id, data_type_id, plan_id, phone, amount, 
            status, reference, purchase_date
        ) VALUES (?, ?, ?, ?, ?, ?, ?, 'pending', ?, NOW())
    ");
    
    $networkId = $plan['network_id'];
    $dataTypeId = $plan['data_type_id'];
    $stmt->bind_param(
        "iiiiisds", 
        $userId, $txnId, $networkId, $dataTypeId, $planId, 
        $phone, $plan['user_price'], $reference
    );
    $stmt->execute();
    $purchaseId = $conn->insert_id;
    
    // Deduct from user's balance
    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
    $stmt->bind_param("di", $plan['user_price'], $userId);
    $stmt->execute();
    
    // Process the API purchase
    $purchaseResult = purchaseDataWithLegitDataWay($planId, $phone);
    
    if ($purchaseResult['success']) {
        // Update data purchase record
        $stmt = $conn->prepare("UPDATE data_purchases SET status = 'successful', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult['details']);
        $stmt->bind_param("si", $apiResponse, $purchaseId);
        $stmt->execute();
        
        // Update transaction record
        $stmt = $conn->prepare("UPDATE transactions SET status = 'successful' WHERE id = ?");
        $stmt->bind_param("i", $txnId);
        $stmt->execute();
        
        // Create notification for user
        $notifyTitle = 'Data Purchase Successful';
        $notifyMessage = "Your purchase of {$plan['network_name']} {$plan['size']} data for {$phone} was successful.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => true,
            'message' => 'Data purchase successful! ' . $plan['size'] . ' data has been credited to ' . $phone,
            'data' => [
                'reference' => $reference,
                'phone' => $phone,
                'network' => $plan['network_name'],
                'plan' => $plan['name'],
                'value' => $plan['size'],
                'amount' => $plan['user_price']
            ]
        ]);
    } else {
        // Update data purchase record
        $stmt = $conn->prepare("UPDATE data_purchases SET status = 'failed', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult);
        $stmt->bind_param("si", $apiResponse, $purchaseId);
        $stmt->execute();
        
        // Update transaction record
        $stmt = $conn->prepare("UPDATE transactions SET status = 'failed' WHERE id = ?");
        $stmt->bind_param("i", $txnId);
        $stmt->execute();
        
        // Refund user's balance
        $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->bind_param("di", $plan['user_price'], $userId);
        $stmt->execute();
        
        // Create notification for user
        $notifyTitle = 'Data Purchase Failed';
        $notifyMessage = "Your purchase of {$plan['network_name']} {$plan['size']} data for {$phone} failed. Your account has been refunded.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'error', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => false,
            'message' => 'Data purchase failed: ' . $purchaseResult['message'],
            'error_details' => $purchaseResult
        ]);
    }
} catch (Exception $e) {
    // Rollback transaction on error
    $conn->rollback();
    
    // Log the error
    error_log("Data purchase exception: " . $e->getMessage());
    
    echo json_encode([
        'success' => false,
        'message' => 'An error occurred while processing your request: ' . $e->getMessage()
    ]);
}
?>