<?php
// File: /dashboard/process/buy_data.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/data_purchase.php';

// Enable error logging
ini_set('display_errors', 0);
ini_set('log_errors', 1);
error_log("Data purchase request received: " . json_encode($_POST));

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode(['success' => false, 'message' => 'You must be logged in to purchase data']);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Validate input
$phone = isset($_POST['phone']) ? sanitizeInput($_POST['phone']) : '';
$planId = isset($_POST['plan_id']) ? (int)$_POST['plan_id'] : 0;
$networkId = isset($_POST['network_id']) ? (int)$_POST['network_id'] : 0;
$dataTypeId = isset($_POST['data_type_id']) ? (int)$_POST['data_type_id'] : 0;
$pin = isset($_POST['pin']) ? sanitizeInput($_POST['pin']) : '';
$clientReference = isset($_POST['client_reference']) ? sanitizeInput($_POST['client_reference']) : '';

// Log for debugging
error_log("Parsed parameters - Plan ID: $planId, Phone: $phone, Network: $networkId, Data Type: $dataTypeId");

// Basic validation
if (empty($phone)) {
    echo json_encode(['success' => false, 'message' => 'Phone number is required']);
    exit;
}

if (strlen($phone) < 10 || strlen($phone) > 15) {
    echo json_encode(['success' => false, 'message' => 'Please enter a valid phone number']);
    exit;
}

if ($planId <= 0) {
    echo json_encode(['success' => false, 'message' => 'Please select a data plan']);
    exit;
}

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode(['success' => false, 'message' => 'User not found']);
    exit;
}

// Verify transaction PIN if required
if (getSetting('require_pin_for_purchases', '1') == '1') {
    if (empty($pin)) {
        echo json_encode(['success' => false, 'message' => 'Transaction PIN is required']);
        exit;
    }
    
    if (empty($user['pin']) || !password_verify($pin, $user['pin'])) {
        echo json_encode(['success' => false, 'message' => 'Invalid transaction PIN']);
        exit;
    }
}

// Check if beneficiary should be saved
$saveBeneficiary = false;
$beneficiaryName = '';
if (isset($_POST['beneficiary']) && !empty($_POST['beneficiary'])) {
    $saveBeneficiary = true;
    $beneficiaryName = sanitizeInput($_POST['beneficiary']);
    
    // Save beneficiary regardless of transaction outcome
    try {
        // Check if beneficiary already exists
        $stmt = $conn->prepare("SELECT id FROM beneficiaries WHERE user_id = ? AND type = 'data' AND identifier = ?");
        $stmt->bind_param("is", $userId, $phone);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows == 0) {
            // Beneficiary doesn't exist, save it
            $stmt = $conn->prepare("
                INSERT INTO beneficiaries (user_id, type, name, identifier, provider_id, created_at)
                VALUES (?, 'data', ?, ?, ?, NOW())
            ");
            $stmt->bind_param("issi", $userId, $beneficiaryName, $phone, $networkId);
            $stmt->execute();
            
            // Log success
            error_log("Beneficiary saved successfully: " . $beneficiaryName);
        } else {
            // Log that beneficiary already exists
            error_log("Beneficiary already exists for this phone number");
        }
    } catch (Exception $e) {
        // Log error but continue with transaction
        error_log("Error saving beneficiary: " . $e->getMessage());
    }
}

// Get plan details with price based on user type
$priceField = 'price';
switch ($user['user_type']) {
    case 'smart':
        $priceField = 'IF(p.amount_smart > 0, p.amount_smart, p.price)';
        break;
    case 'api':
        $priceField = 'IF(p.amount_api > 0, p.amount_api, p.price)';
        break;
    case 'vendor':
        $priceField = 'IF(p.amount_vendor > 0, p.amount_vendor, p.price)';
        break;
}

$stmt = $conn->prepare("
    SELECT p.*, dt.name as data_type, n.name as network_name, $priceField as user_price,
    dt.id as data_type_id, n.id as network_id
    FROM data_plans p
    JOIN data_types dt ON p.data_type_id = dt.id
    JOIN networks n ON dt.network_id = n.id
    WHERE p.id = ? AND p.status = 'active'
");
$stmt->bind_param("i", $planId);
$stmt->execute();
$result = $stmt->get_result();
$plan = $result->fetch_assoc();

if (!$plan) {
    echo json_encode(['success' => false, 'message' => 'Selected plan not found or not active']);
    exit;
}

// Double-check that the data type and network match what was selected
if ($dataTypeId > 0 && $plan['data_type_id'] != $dataTypeId) {
    error_log("Data type mismatch - Expected: {$plan['data_type_id']}, Received: $dataTypeId");
}

if ($networkId > 0 && $plan['network_id'] != $networkId) {
    error_log("Network mismatch - Expected: {$plan['network_id']}, Received: $networkId");
}

// Check if user has sufficient balance
if ($user['balance'] < $plan['user_price']) {
    echo json_encode(['success' => false, 'message' => 'Insufficient balance. Please fund your wallet and try again.']);
    exit;
}

// Apply promo code if provided
$promoDiscount = 0;
$promoId = 0;
$promoCode = isset($_POST['promo_code']) ? sanitizeInput($_POST['promo_code']) : '';

if (!empty($promoCode)) {
    // Get current date in MySQL format
    $currentDate = date('Y-m-d H:i:s');
    
    $stmt = $conn->prepare("
        SELECT * FROM promo_codes 
        WHERE code = ? 
        AND status = 'active' 
        AND (expiry_date IS NULL OR expiry_date >= ?) 
        AND (max_uses = 0 OR current_uses < max_uses)
    ");
    $stmt->bind_param("ss", $promoCode, $currentDate);
    $stmt->execute();
    $result = $stmt->get_result();
    $promo = $result->fetch_assoc();
    
    if ($promo) {
        $promoId = $promo['id'];
        
        // Check user eligibility based on promo user_type
        $isEligible = true;
        $userType = isset($promo['user_type']) ? $promo['user_type'] : 'all';
        
        if ($userType != 'all') {
            // Get user's registration date
            $stmt = $conn->prepare("SELECT created_at FROM users WHERE id = ?");
            $stmt->bind_param("i", $userId);
            $stmt->execute();
            $result = $stmt->get_result();
            $userData = $result->fetch_assoc();
            $userCreatedAt = $userData['created_at'] ?? '';
            $promoCreatedAt = $promo['created_at'] ?? '';
            
            if ($userType == 'new' && $userCreatedAt && $promoCreatedAt && strtotime($userCreatedAt) < strtotime($promoCreatedAt)) {
                $isEligible = false;
                error_log("User $userId not eligible for promo code: $promoCode (not a new user)");
            }
            
            if ($userType == 'existing' && $userCreatedAt && $promoCreatedAt && strtotime($userCreatedAt) > strtotime($promoCreatedAt)) {
                $isEligible = false;
                error_log("User $userId not eligible for promo code: $promoCode (not an existing user)");
            }
        }
        
        // Check if user has already used this promo code
        if ($isEligible && isset($promo['max_uses_per_user']) && $promo['max_uses_per_user'] > 0) {
            $stmt = $conn->prepare("
                SELECT COUNT(*) as used_count 
                FROM promo_code_usage 
                WHERE promo_code_id = ? AND user_id = ?
            ");
            $stmt->bind_param("ii", $promoId, $userId);
            $stmt->execute();
            $result = $stmt->get_result();
            $usageData = $result->fetch_assoc();
            
            if ($usageData && $usageData['used_count'] >= $promo['max_uses_per_user']) {
                $isEligible = false;
                error_log("User $userId has already used promo code: $promoCode maximum number of times");
            }
        }
        
        if ($isEligible) {
            // Check if this promo is applicable to data service
            $applicableServices = json_decode($promo['applicable_services'], true);
            if (is_array($applicableServices) && (in_array('data', $applicableServices) || in_array('all', $applicableServices))) {
                // Check minimum order amount
                $minOrderAmount = isset($promo['min_amount']) ? $promo['min_amount'] : 0;
                
                if ($plan['user_price'] >= $minOrderAmount) {
                    // Check if discount_type exists
                    $discountType = isset($promo['type']) ? $promo['type'] : 'fixed';
                    
                    // Check if discount_value exists
                    $discountValue = isset($promo['discount']) ? $promo['discount'] : 0;
                    
                    if ($discountType == 'percentage') {
                        $promoDiscount = ($plan['user_price'] * $discountValue) / 100;
                        // Apply max discount if set
                        if (isset($promo['max_amount']) && $promo['max_amount'] > 0 && $promoDiscount > $promo['max_amount']) {
                            $promoDiscount = $promo['max_amount'];
                        }
                    } else {
                        // Fixed amount discount
                        $promoDiscount = $discountValue;
                    }
                    
                    // Log discount application
                    error_log("Applied promo code: $promoCode, Discount: $promoDiscount");
                } else {
                    error_log("Promo code minimum amount not met: $minOrderAmount");
                }
            } else {
                error_log("Promo code not applicable to data service");
            }
        }
    } else {
        error_log("Invalid or expired promo code: $promoCode");
    }
}

// Calculate final amount after discount
$finalAmount = $plan['user_price'] - $promoDiscount;

// Check if user has sufficient balance (after promo discount)
if ($user['balance'] < $finalAmount) {
    echo json_encode(['success' => false, 'message' => 'Insufficient balance. Please fund your wallet and try again.']);
    exit;
}

// Begin transaction
$conn->begin_transaction();

try {
    // Generate reference
    $reference = 'DATA_' . time() . '_' . rand(1000, 9999);
    
    // Create transaction record
    $stmt = $conn->prepare("
        INSERT INTO transactions (user_id, txn_ref, type, amount, description, status, meta_data)
        VALUES (?, ?, 'data', ?, ?, 'pending', ?)
    ");
    
    $description = "{$plan['network_name']} {$plan['data_type']} {$plan['name']} - {$plan['size']} for {$phone}";
    $metaData = json_encode([
        'network_id' => $plan['network_id'],
        'data_type_id' => $plan['data_type_id'],
        'plan_id' => $planId,
        'phone' => $phone,
        'plan_size' => $plan['size'],
        'plan_name' => $plan['name'],
        'promo_code' => $promoCode,
        'promo_discount' => $promoDiscount,
        'original_price' => $plan['user_price'],
        'final_price' => $finalAmount,
        'client_reference' => $clientReference
    ]);
    
    $stmt->bind_param("isdss", $userId, $reference, $finalAmount, $description, $metaData);
    $stmt->execute();
    $txnId = $conn->insert_id;
    
    // Create data purchase record
    $stmt = $conn->prepare("
        INSERT INTO data_purchases (
            user_id, transaction_id, network_id, data_type_id, plan_id, phone, amount, 
            status, reference, purchase_date
        ) VALUES (?, ?, ?, ?, ?, ?, ?, 'pending', ?, NOW())
    ");
    
    $networkId = $plan['network_id'];
    $dataTypeId = $plan['data_type_id'];
    $stmt->bind_param(
        "iiiiisds", 
        $userId, $txnId, $networkId, $dataTypeId, $planId, 
        $phone, $finalAmount, $reference
    );
    $stmt->execute();
    $purchaseId = $conn->insert_id;
    
    // Deduct from user's balance
    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
    $stmt->bind_param("di", $finalAmount, $userId);
    $stmt->execute();
    
    // Process the API purchase
    $purchaseResult = purchaseDataWithProvider($planId, $phone);
    
    if ($purchaseResult['success']) {
        // Update data purchase record
        $stmt = $conn->prepare("UPDATE data_purchases SET status = 'successful', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult['details']);
        $stmt->bind_param("si", $apiResponse, $purchaseId);
        $stmt->execute();
        
        // Update transaction record
        $stmt = $conn->prepare("UPDATE transactions SET status = 'successful' WHERE id = ?");
        $stmt->bind_param("i", $txnId);
        $stmt->execute();
        
        // Update promo code usage if used - ONLY done here after successful purchase
        if (!empty($promoCode) && isset($promo) && $promo && $promoId > 0) {
            // Increment the usage counter
            $stmt = $conn->prepare("UPDATE promo_codes SET current_uses = current_uses + 1 WHERE id = ?");
            $stmt->bind_param("i", $promoId);
            $stmt->execute();
            
            // Log the usage in promo_code_usage table
            $stmt = $conn->prepare("
                INSERT INTO promo_code_usage (promo_code_id, user_id, used_at, amount, discount_amount, service_type) 
                VALUES (?, ?, NOW(), ?, ?, 'data')
            ");
            $stmt->bind_param("iidd", $promoId, $userId, $plan['user_price'], $promoDiscount);
            $stmt->execute();
            
            error_log("Updated promo code usage for code ID: $promoId, user: $userId");
        }
        
        // Create notification for user
        $notifyTitle = 'Data Purchase Successful';
        $notifyMessage = "Your purchase of {$plan['network_name']} {$plan['size']} data for {$phone} was successful.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => true,
            'message' => 'Data purchase successful! ' . $plan['size'] . ' data has been credited to ' . $phone,
            'data' => [
                'reference' => $reference,
                'phone' => $phone,
                'network' => $plan['network_name'],
                'plan' => $plan['name'],
                'value' => $plan['size'],
                'original_amount' => $plan['user_price'],
                'discount' => $promoDiscount,
                'final_amount' => $finalAmount,
                'client_reference' => $clientReference
            ]
        ]);
    } else {
        // Update data purchase record
        $stmt = $conn->prepare("UPDATE data_purchases SET status = 'failed', api_response = ? WHERE id = ?");
        $apiResponse = json_encode($purchaseResult);
        $stmt->bind_param("si", $apiResponse, $purchaseId);
        $stmt->execute();
        
        // Update transaction record
        $stmt = $conn->prepare("UPDATE transactions SET status = 'failed' WHERE id = ?");
        $stmt->bind_param("i", $txnId);
        $stmt->execute();
        
        // Refund user's balance
        $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->bind_param("di", $finalAmount, $userId);
        $stmt->execute();
        
        // Create notification for user
        $notifyTitle = 'Data Purchase Failed';
        $notifyMessage = "Your purchase of {$plan['network_name']} {$plan['size']} data for {$phone} failed. Your account has been refunded.";
        
        $stmt = $conn->prepare("
            INSERT INTO notifications (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'error', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        echo json_encode([
            'success' => false,
            'message' => 'Data purchase failed: ' . $purchaseResult['message'],
            'error_details' => $purchaseResult
        ]);
    }
} catch (Exception $e) {
    // Rollback transaction on error
    $conn->rollback();
    
    // Log the error
    error_log("Data purchase exception: " . $e->getMessage());
    
    echo json_encode([
        'success' => false,
        'message' => 'An error occurred while processing your request: ' . $e->getMessage()
    ]);
}
?>