<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    jsonResponse(false, 'You must be logged in to perform this action');
}

// Get request method
$requestMethod = $_SERVER["REQUEST_METHOD"];

if ($requestMethod !== "POST") {
    jsonResponse(false, 'Invalid request method');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    jsonResponse(false, 'User not found');
}

// Get post data
$amount = isset($_POST['amount']) ? (float)$_POST['amount'] : 0;
$paymentMethod = isset($_POST['payment_method']) ? sanitizeInput($_POST['payment_method']) : '';

// Validate inputs
if ($amount <= 0) {
    jsonResponse(false, 'Amount must be greater than zero');
}

if (empty($paymentMethod)) {
    jsonResponse(false, 'Please select a payment method');
}

// Generate reference
$reference = 'FUND_' . uniqid() . '_' . time();

// Begin transaction
$conn->begin_transaction();

try {
    // Create transaction record
    $stmt = $conn->prepare("
        INSERT INTO transactions 
        (user_id, txn_ref, type, amount, fee, description, status)
        VALUES (?, ?, 'fund', ?, 0, ?, 'pending')
    ");
    
    $description = "Wallet funding via {$paymentMethod}";
    
    $stmt->bind_param("isds", $userId, $reference, $amount, $description);
    $stmt->execute();
    $transactionId = $conn->insert_id;
    
    // Process payment based on method
    switch ($paymentMethod) {
        case 'paystack':
            // Commit the transaction before redirecting to Paystack
            $conn->commit();
            
            // Get Paystack settings
            $paystackPublicKey = getSetting('paystack_public_key');
            
            if (empty($paystackPublicKey)) {
                jsonResponse(false, 'Paystack is not properly configured. Please contact support.');
            }
            
            // Log the Paystack public key being used (for debugging)
            error_log("Using Paystack public key: " . $paystackPublicKey);
            
            $email = $user['email'];
            $amountInKobo = $amount * 100; // Convert to kobo for Paystack
            
            // Prepare Paystack initialization data
            $paystackData = [
                'reference' => $reference,
                'amount' => $amountInKobo,
                'email' => $email,
                'currency' => 'NGN',
                'callback_url' => SITE_URL . '/dashboard/verify_payment.php?reference=' . $reference,
                'metadata' => [
                    'transaction_id' => $transactionId,
                    'user_id' => $userId,
                    'custom_fields' => [
                        [
                            'display_name' => 'Payment For',
                            'variable_name' => 'payment_for',
                            'value' => 'Wallet Funding'
                        ]
                    ]
                ]
            ];
            
            jsonResponse(true, 'Redirecting to payment gateway', [
                'transaction_id' => $transactionId,
                'reference' => $reference,
                'amount' => $amount,
                'paystack_key' => $paystackPublicKey,
                'paystack_data' => $paystackData
            ]);
            break;
            
        case 'bank_transfer':
            // Get bank details
            $bankName = getSetting('bank_name');
            $accountName = getSetting('account_name');
            $accountNumber = getSetting('account_number');
            
            if (empty($bankName) || empty($accountName) || empty($accountNumber)) {
                $conn->rollback();
                jsonResponse(false, 'Bank details are not properly configured. Please contact support.');
            }
            
            // Update transaction status to awaiting confirmation
            $stmt = $conn->prepare("UPDATE transactions SET status = 'awaiting' WHERE id = ?");
            $stmt->bind_param("i", $transactionId);
            $stmt->execute();
            
            // Create notification
            $title = "Bank Transfer Instructions";
            $message = "Please transfer {$currency}{$amount} to the following account:\n\nBank: {$bankName}\nAccount Name: {$accountName}\nAccount Number: {$accountNumber}\n\nUse {$reference} as reference. Your wallet will be credited once the payment is confirmed.";
            
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'info', 0)
            ");
            $stmt->bind_param("iss", $userId, $title, $message);
            $stmt->execute();
            
            // Commit the transaction
            $conn->commit();
            
            jsonResponse(true, 'Bank transfer instructions sent', [
                'transaction_id' => $transactionId,
                'reference' => $reference,
                'amount' => $amount,
                'bank_name' => $bankName,
                'account_name' => $accountName,
                'account_number' => $accountNumber
            ]);
            break;
            
        case 'ussd':
            // Commit the transaction before redirecting to USSD
            $conn->commit();
            
            // Get USSD settings
            $ussdCode = getSetting('ussd_code');
            
            if (empty($ussdCode)) {
                jsonResponse(false, 'USSD is not properly configured. Please contact support.');
            }
            
            jsonResponse(true, 'USSD payment initiated', [
                'transaction_id' => $transactionId,
                'reference' => $reference,
                'amount' => $amount,
                'ussd_code' => $ussdCode
            ]);
            break;
            
        default:
            $conn->rollback();
            jsonResponse(false, 'Unsupported payment method');
    }
} catch (Exception $e) {
    // Rollback the transaction
    $conn->rollback();
    jsonResponse(false, 'An error occurred: ' . $e->getMessage());
}

/**
 * Send JSON response
 * 
 * @param bool $success Success status
 * @param string $message Response message
 * @param array $data Additional data
 */
function jsonResponse($success, $message, $data = []) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => $success,
        'message' => $message,
        'data' => $data
    ]);
    exit;
}
?>