<?php
// This file should be placed at /dashboard/process/order_reseller.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

header('Content-Type: application/json');

// Check if user is logged in
if (!isLoggedIn()) {
    echo json_encode([
        'success' => false,
        'message' => 'You must be logged in to place an order'
    ]);
    exit;
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user data
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo json_encode([
        'success' => false,
        'message' => 'User not found'
    ]);
    exit;
}

// Check if POST request with required fields
if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['panel_id'])) {
    echo json_encode([
        'success' => false,
        'message' => 'Invalid request: Missing panel_id'
    ]);
    exit;
}

// Get panel ID
$panelId = (int)$_POST['panel_id'];

// Get panel details
$stmt = $conn->prepare("SELECT * FROM reseller_panels WHERE id = ? AND status = 'active'");
$stmt->bind_param("i", $panelId);
$stmt->execute();
$result = $stmt->get_result();
$panel = $result->fetch_assoc();

if (!$panel) {
    echo json_encode([
        'success' => false,
        'message' => 'Panel not found or not active'
    ]);
    exit;
}

// Check if user has enough balance
if ($user['balance'] < $panel['price']) {
    echo json_encode([
        'success' => false,
        'message' => 'Insufficient balance to order this panel. Please fund your wallet and try again.'
    ]);
    exit;
}

// Validate required fields
$domainName = isset($_POST['domain_name']) ? sanitizeInput($_POST['domain_name']) : '';
$companyName = isset($_POST['company_name']) ? sanitizeInput($_POST['company_name']) : '';
$companyEmail = isset($_POST['company_email']) ? sanitizeInput($_POST['company_email']) : '';
$companyPhone = isset($_POST['company_phone']) ? sanitizeInput($_POST['company_phone']) : '';
$companyAddress = isset($_POST['company_address']) ? sanitizeInput($_POST['company_address']) : '';
$additionalInfo = isset($_POST['additional_info']) ? sanitizeInput($_POST['additional_info']) : '';
$agreeTerms = isset($_POST['agree_terms']);

// Validate the required fields
$errors = [];
if (empty($domainName)) {
    $errors[] = 'Domain name is required';
}
if (empty($companyName)) {
    $errors[] = 'Company name is required';
}
if (empty($companyEmail)) {
    $errors[] = 'Company email is required';
} elseif (!filter_var($companyEmail, FILTER_VALIDATE_EMAIL)) {
    $errors[] = 'Invalid email format';
}
if (empty($companyPhone)) {
    $errors[] = 'Company phone is required';
}
if (!$agreeTerms) {
    $errors[] = 'You must agree to the terms and conditions';
}

// Return errors if any
if (!empty($errors)) {
    echo json_encode([
        'success' => false,
        'message' => implode('. ', $errors)
    ]);
    exit;
}

// Generate unique order ID
$orderRef = 'RSL_' . strtoupper(substr(uniqid(), -6)) . date('mdY');

// Begin transaction
$conn->begin_transaction();

try {
    // Create order in reseller_orders table
    $stmt = $conn->prepare("
        INSERT INTO reseller_orders (
            user_id, panel_id, order_ref, amount, domain_name, company_name, 
            company_email, company_phone, company_address, additional_info, status
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 'pending')
    ");
    
    $stmt->bind_param(
        "iisdssssss",
        $userId,
        $panelId,
        $orderRef,
        $panel['price'],
        $domainName,
        $companyName,
        $companyEmail,
        $companyPhone,
        $companyAddress,
        $additionalInfo
    );
    
    $stmt->execute();
    $orderId = $conn->insert_id;
    
    // Deduct amount from user's wallet
    $stmt = $conn->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
    $stmt->bind_param("di", $panel['price'], $userId);
    $stmt->execute();
    
    // Get the currency symbol from settings
    $currency = getSetting('currency', '₦');
    
    // Create transaction record
    $txnRef = 'TXN_' . time() . rand(1000, 9999);
    $description = "Payment for " . $panel['name'] . " reseller panel";
    
    $stmt = $conn->prepare("
        INSERT INTO transactions (
            user_id, txn_ref, type, amount, fee, description, status
        ) VALUES (?, ?, 'debit', ?, 0, ?, 'successful')
    ");
    
    $stmt->bind_param("isds", $userId, $txnRef, $panel['price'], $description);
    $stmt->execute();
    
    // Create user notification
    $title = 'Reseller Panel Order Placed';
    $message = 'Your order for ' . $panel['name'] . ' reseller panel has been placed successfully. We will process your order shortly.';
    
    $stmt = $conn->prepare("
        INSERT INTO notifications (
            user_id, title, message, type, is_read
        ) VALUES (?, ?, ?, 'success', 0)
    ");
    
    $stmt->bind_param("iss", $userId, $title, $message);
    $stmt->execute();
    
    // Create admin notification
    // First check if admin_notifications table exists
    $adminNotifTable = false;
    $stmt = $conn->prepare("SHOW TABLES LIKE 'admin_notifications'");
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $adminNotifTable = true;
    }
    
    if ($adminNotifTable) {
        $adminNotifTitle = 'New Reseller Panel Order';
        $adminNotifMessage = 'User ' . $user['username'] . ' has placed an order for ' . $panel['name'] . ' reseller panel.';
        
        // Get admin IDs
        $stmt = $conn->prepare("SELECT id FROM admins WHERE role = 'super_admin' OR role = 'admin'");
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($admin = $result->fetch_assoc()) {
            $stmt = $conn->prepare("
                INSERT INTO admin_notifications (
                    admin_id, title, message, type, is_read
                ) VALUES (?, ?, ?, 'info', 0)
            ");
            
            $stmt->bind_param("iss", $admin['id'], $adminNotifTitle, $adminNotifMessage);
            $stmt->execute();
        }
    }
    
    // Send email notification to admin
    $adminEmail = getSetting('admin_email');
    if ($adminEmail) {
        $subject = 'New Reseller Panel Order - ' . getSetting('site_name');
        $emailMsg = "
            <p>Hello Admin,</p>
            <p>A new reseller panel order has been placed.</p>
            <p><strong>Order Details:</strong></p>
            <p>
                User: {$user['username']} (ID: {$user['id']})<br>
                Panel: {$panel['name']}<br>
                Amount: {$currency}{$panel['price']}<br>
                Domain: {$domainName}<br>
                Company: {$companyName}<br>
                Email: {$companyEmail}<br>
                Phone: {$companyPhone}
            </p>
            <p>Please login to the admin dashboard to process this order.</p>
            <p>Regards,<br>" . getSetting('site_name') . " Team</p>
        ";
        
        sendEmail($adminEmail, $subject, $emailMsg);
    }
    
    // Send confirmation email to user
    if (!empty($user['email'])) {
        $subject = 'Reseller Panel Order Confirmation - ' . getSetting('site_name');
        $emailMsg = "
            <p>Hello {$user['username']},</p>
            <p>Your order for {$panel['name']} reseller panel has been placed successfully.</p>
            <p><strong>Order Details:</strong></p>
            <p>
                Order Reference: {$orderRef}<br>
                Panel: {$panel['name']}<br>
                Amount: {$currency}{$panel['price']}<br>
                Domain: {$domainName}<br>
                Status: Pending
            </p>
            <p>We will review your order and process it as soon as possible. You will receive a notification once your panel is ready.</p>
            <p>Thank you for choosing " . getSetting('site_name') . "!</p>
            <p>Regards,<br>" . getSetting('site_name') . " Team</p>
        ";
        
        sendEmail($user['email'], $subject, $emailMsg);
    }
    
    // Commit transaction
    $conn->commit();
    
    // Store success message in session
    $_SESSION['order_success'] = 'Your order has been placed successfully. We will process it shortly.';
    
    // Return success response
    echo json_encode([
        'success' => true,
        'message' => 'Your order has been placed successfully. We will process it shortly.',
        'data' => [
            'order_id' => $orderId,
            'reference' => $orderRef,
            'panel_name' => $panel['name'],
            'amount' => $panel['price']
        ]
    ]);
} catch (Exception $e) {
    // Rollback transaction on error
    $conn->rollback();
    
    // Return error response
    echo json_encode([
        'success' => false,
        'message' => 'An error occurred while processing your order. Please try again later.',
        'error' => $e->getMessage()
    ]);
}
?>