<?php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';
require_once '../../includes/api/APIManager.php';

// Check if user is logged in
if (!isLoggedIn()) {
    jsonResponse(false, 'You must be logged in to perform this action');
}

// Get request method
$requestMethod = $_SERVER["REQUEST_METHOD"];

if ($requestMethod !== "POST") {
    jsonResponse(false, 'Invalid request method');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    jsonResponse(false, 'User not found');
}

// Get post data
$providerId = isset($_POST['provider_id']) ? (int)$_POST['provider_id'] : 0;
$planId = isset($_POST['plan_id']) ? (int)$_POST['plan_id'] : 0;
$smartCard = isset($_POST['smart_card']) ? sanitizeInput($_POST['smart_card']) : '';
$customerName = isset($_POST['customer_name']) ? sanitizeInput($_POST['customer_name']) : '';
$phone = isset($_POST['phone']) ? sanitizeInput($_POST['phone']) : '';
$beneficiary = isset($_POST['beneficiary']) ? sanitizeInput($_POST['beneficiary']) : '';
$promoCode = isset($_POST['promo_code']) ? sanitizeInput($_POST['promo_code']) : '';

// Validate inputs
if (empty($providerId)) {
    jsonResponse(false, 'Please select a provider');
}

if (empty($planId)) {
    jsonResponse(false, 'Please select a subscription plan');
}

if (empty($smartCard)) {
    jsonResponse(false, 'Please enter a Smart Card/IUC number');
}

// Get provider info
$stmt = $conn->prepare("SELECT * FROM cable_providers WHERE id = ? AND status = 'active'");
$stmt->bind_param("i", $providerId);
$stmt->execute();
$result = $stmt->get_result();
$provider = $result->fetch_assoc();

if (!$provider) {
    jsonResponse(false, 'Selected provider is not available');
}

// Get plan info
$stmt = $conn->prepare("
    SELECT * FROM cable_plans 
    WHERE id = ? AND provider_id = ? AND status = 'active'
");
$stmt->bind_param("ii", $planId, $providerId);
$stmt->execute();
$result = $stmt->get_result();
$plan = $result->fetch_assoc();

if (!$plan) {
    jsonResponse(false, 'Selected plan is not available');
}

// Determine the price based on user type
$price = $plan['price_smart']; // Default to smart user price
if ($user['user_type'] === 'vendor') {
    $price = $plan['price_vendor'];
} elseif ($user['user_type'] === 'api') {
    $price = $plan['price_api'];
}

// Apply promo code if provided
$discount = 0;
if (!empty($promoCode)) {
    // Check if promo code is valid
    $promoResult = applyPromoCode($promoCode, $price, 'cable', $userId);
    
    if ($promoResult['success']) {
        $discount = $promoResult['discount'];
    } else {
        jsonResponse(false, $promoResult['message']);
    }
}

// Calculate final price
$finalPrice = $price - $discount;

// Check if user has enough balance
if ($user['balance'] < $finalPrice) {
    jsonResponse(false, 'Insufficient balance. Please fund your wallet and try again');
}

// Begin transaction
$conn->begin_transaction();

try {
    // Generate reference
    $reference = 'CABLE_' . uniqid() . '_' . time();
    
    // Deduct from user's balance
    $newBalance = $user['balance'] - $finalPrice;
    $stmt = $conn->prepare("UPDATE users SET balance = ? WHERE id = ?");
    $stmt->bind_param("di", $newBalance, $userId);
    $stmt->execute();
    
    // Record transaction
    $metaData = [
        'provider_id' => $providerId,
        'provider_name' => $provider['name'],
        'plan_id' => $planId,
        'plan_name' => $plan['name'],
        'smart_card' => $smartCard,
        'customer_name' => $customerName,
        'phone' => $phone
    ];
    
    if ($discount > 0) {
        $metaData['promo_code'] = $promoCode;
        $metaData['discount'] = $discount;
    }
    
    $metaDataJson = json_encode($metaData);
    
    $stmt = $conn->prepare("
        INSERT INTO transactions 
        (user_id, txn_ref, type, amount, fee, description, meta_data, status)
        VALUES (?, ?, 'cable', ?, 0, ?, ?, 'pending')
    ");
    
    $description = "Cable TV subscription: {$plan['name']} for {$smartCard} ({$provider['name']})";
    
    $stmt->bind_param("isdss", $userId, $reference, $finalPrice, $description, $metaDataJson);
    $stmt->execute();
    $transactionId = $conn->insert_id;
    
    // Save beneficiary if requested
    if (!empty($beneficiary)) {
        // Check if beneficiary already exists
        $stmt = $conn->prepare("
            SELECT id FROM beneficiaries 
            WHERE user_id = ? AND type = 'cable' AND identifier = ?
        ");
        $stmt->bind_param("is", $userId, $smartCard);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows == 0) {
            // Add new beneficiary
            $stmt = $conn->prepare("
                INSERT INTO beneficiaries (user_id, type, name, identifier, provider_id)
                VALUES (?, 'cable', ?, ?, ?)
            ");
            $stmt->bind_param("issi", $userId, $beneficiary, $smartCard, $providerId);
            $stmt->execute();
        }
    }
    
    // Update promo code usage if applicable
    if (!empty($promoCode) && $discount > 0) {
        updatePromoCodeUsage($promoCode);
    }
    
    // Commit the transaction
    $conn->commit();
    
    // Now process the payment through the API
    $apiManager = new APIManager($db);
    $apiProvider = $apiManager->getProviderForService('cable');
    
    if (!$apiProvider) {
        // No API provider available, mark transaction as pending for manual processing
        jsonResponse(true, 'Cable TV subscription payment submitted successfully. It will be processed shortly.', [
            'transaction_id' => $transactionId,
            'reference' => $reference,
            'status' => 'pending'
        ]);
    }
    
    // Prepare payment parameters
    $params = [
        'provider' => $provider['api_name'],
        'plan_id' => $plan['api_plan_id'],
        'smart_card' => $smartCard,
        'reference' => $reference
    ];
    
    if (!empty($phone)) {
        $params['phone'] = $phone;
    }
    
    // Log API request
    $apiTxnId = $apiManager->logApiTransaction([
        'provider' => $apiProvider->getProviderName(),
        'service' => 'cable',
        'request' => $params,
        'response' => null,
        'status' => 'pending',
        'reference' => $reference,
        'user_id' => $userId
    ]);
    
    // Make API call
    $result = $apiProvider->payCableTv($params);
    
    // Update API transaction log
    $apiManager->updateApiTransaction($apiTxnId, $result['success'] ? 'successful' : 'failed', $result);
    
    if ($result['success']) {
        // Update transaction status to successful
        $stmt = $conn->prepare("UPDATE transactions SET status = 'successful' WHERE id = ?");
        $stmt->bind_param("i", $transactionId);
        $stmt->execute();
        
        // Send success email
        $userEmail = $user['email'];
        $userName = $user['full_name'] ?: $user['username'];
        
        $emailVars = [
            'user_name' => $userName,
            'txn_ref' => $reference,
            'date' => date('Y-m-d H:i:s'),
            'type' => 'Cable TV Subscription',
            'amount' => formatAmount($finalPrice),
            'status' => 'Successful',
            'description' => $description
        ];
        
        sendTemplateEmail($userEmail, 'transaction_receipt', $emailVars);
        
        jsonResponse(true, 'Cable TV subscription payment successful', [
            'transaction_id' => $transactionId,
            'reference' => $reference,
            'status' => 'successful',
            'details' => $result['data']
        ]);
    } else {
        // Refund the user
        $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->bind_param("di", $finalPrice, $userId);
        $stmt->execute();
        
        // Update transaction status to failed
        $stmt = $conn->prepare("UPDATE transactions SET status = 'failed' WHERE id = ?");
        $stmt->bind_param("i", $transactionId);
        $stmt->execute();
        
        // Return promo code usage if applicable
        if (!empty($promoCode) && $discount > 0) {
            reversePromoCodeUsage($promoCode);
        }
        
        jsonResponse(false, 'Cable TV subscription payment failed: ' . $result['message'], [
            'transaction_id' => $transactionId,
            'reference' => $reference,
            'status' => 'failed'
        ]);
    }
} catch (Exception $e) {
    // Rollback the transaction
    $conn->rollback();
    jsonResponse(false, 'An error occurred: ' . $e->getMessage());
}

/**
 * Send JSON response
 * 
 * @param bool $success Success status
 * @param string $message Response message
 * @param array $data Additional data
 */
function jsonResponse($success, $message, $data = []) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => $success,
        'message' => $message,
        'data' => $data
    ]);
    exit;
}
?>