<?php
require_once '../includes/config.php';
require_once '../includes/functions.php'; 
require_once './includes/header.php';


// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

$db = getDB();
$conn = $db->getConnection();

$errors = [];
$success = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $fullName = sanitizeInput($_POST['full_name'] ?? '');
    $phone = sanitizeInput($_POST['phone'] ?? '');
    
    // Validate inputs
    if (empty($fullName)) {
        $errors[] = 'Full name is required';
    }
    
    if (empty($phone)) {
        $errors[] = 'Phone number is required';
    } elseif (!preg_match('/^[0-9]{11}$/', $phone)) {
        $errors[] = 'Phone number must be 11 digits';
    }
    
    // If no errors, update profile
    if (empty($errors)) {
        $stmt = $conn->prepare("UPDATE users SET full_name = ?, phone = ? WHERE id = ?");
        $stmt->bind_param("ssi", $fullName, $phone, $userId);
        
        if ($stmt->execute()) {
            $success = 'Profile updated successfully!';
            
            // Refresh user data
            $user = getUserById($userId);
        } else {
            $errors[] = 'Failed to update profile: ' . $conn->error;
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Profile - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .user-badge {
            background-color: rgba(93, 92, 222, 0.3);
            color: #ffffff;
            padding: 0.25rem 0.75rem;
            border-radius: 9999px;
            font-size: 0.875rem;
            font-weight: 500;
        }
        
        .user-badge.smart {
            background-color: rgba(37, 99, 235, 0.3);
        }
        
        .user-badge.vendor {
            background-color: rgba(22, 163, 74, 0.3);
        }
        
        .user-badge.api {
            background-color: rgba(244, 63, 94, 0.3);
        }
        
        .status-badge {
            padding: 0.25rem 0.75rem;
            border-radius: 9999px;
            font-size: 0.875rem;
            font-weight: 500;
        }
        
        .status-active {
            background-color: rgba(34, 197, 94, 0.3);
            color: #ffffff;
        }
        
        .status-suspended {
            background-color: rgba(239, 68, 68, 0.3);
            color: #ffffff;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <h1 class="text-2xl font-bold text-white mb-6">My Profile</h1>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                <!-- Profile Overview -->
                <div class="dashboard-card rounded-lg shadow-md p-6 col-span-1">
                    <div class="flex flex-col items-center">
                        <div class="w-24 h-24 rounded-full bg-gray-600 flex items-center justify-center mb-4 text-white text-3xl font-semibold">
                            <?php echo substr($user['username'], 0, 1); ?>
                        </div>
                        
                        <h2 class="text-xl font-semibold text-white mb-1"><?php echo htmlspecialchars($user['username']); ?></h2>
                        <p class="text-gray-400 mb-3"><?php echo htmlspecialchars($user['email']); ?></p>
                        
                        <div class="flex flex-wrap justify-center gap-2 mb-4">
                            <span class="user-badge <?php echo $user['user_type']; ?>">
                                <?php echo ucfirst($user['user_type']); ?> User
                            </span>
                            
                            <span class="status-badge <?php echo 'status-' . $user['status']; ?>">
                                <?php echo ucfirst($user['status']); ?>
                            </span>
                        </div>
                        
                        <div class="w-full p-4 bg-gray-800 rounded-md mb-4">
                            <div class="flex justify-between mb-2">
                                <span class="text-gray-400">Wallet Balance:</span>
                                <span class="text-white font-semibold"><?php echo formatAmount($user['balance']); ?></span>
                            </div>
                            <div class="flex justify-between">
                                <span class="text-gray-400">Joined:</span>
                                <span class="text-white"><?php echo date('M d, Y', strtotime($user['created_at'])); ?></span>
                            </div>
                        </div>
                        
                        <div class="flex flex-wrap justify-center gap-2">
                            <a href="change_password.php" class="text-sm text-indigo-400 hover:text-indigo-300">
                                <i class="fas fa-key mr-1"></i> Change Password
                            </a>
                            <a href="set_pin.php" class="text-sm text-indigo-400 hover:text-indigo-300">
                                <i class="fas fa-lock mr-1"></i> <?php echo empty($user['pin']) ? 'Set PIN' : 'Change PIN'; ?>
                            </a>
                        </div>
                    </div>
                </div>
                
                <!-- Profile Form -->
                <div class="dashboard-card rounded-lg shadow-md p-6 col-span-2">
                    <h2 class="text-xl font-semibold text-white mb-4">Edit Profile</h2>
                    
                    <form method="POST" action="">
                        <div class="mb-4">
                            <label for="username" class="block text-sm font-medium text-gray-400 mb-1">Username</label>
                            <input type="text" id="username" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700" value="<?php echo htmlspecialchars($user['username']); ?>" disabled>
                            <p class="mt-1 text-sm text-gray-500">Username cannot be changed</p>
                        </div>
                        
                        <div class="mb-4">
                            <label for="email" class="block text-sm font-medium text-gray-400 mb-1">Email Address</label>
                            <input type="email" id="email" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 bg-gray-700" value="<?php echo htmlspecialchars($user['email']); ?>" disabled>
                            <p class="mt-1 text-sm text-gray-500">Email address cannot be changed</p>
                        </div>
                        
                        <div class="mb-4">
                            <label for="full_name" class="block text-sm font-medium text-gray-400 mb-1">Full Name</label>
                            <input type="text" id="full_name" name="full_name" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($user['full_name']); ?>" required>
                        </div>
                        
                        <div class="mb-6">
                            <label for="phone" class="block text-sm font-medium text-gray-400 mb-1">Phone Number</label>
                            <input type="text" id="phone" name="phone" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" value="<?php echo htmlspecialchars($user['phone']); ?>" required maxlength="11">
                        </div>
                        
                        <div class="flex justify-end">
                            <button type="submit" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Update Profile
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- Account Information -->
                <div class="dashboard-card rounded-lg shadow-md p-6 md:col-span-3">
                    <h2 class="text-xl font-semibold text-white mb-4">Account Information</h2>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <div>
                            <h3 class="font-medium text-white mb-3">Account Type Benefits</h3>
                            
                            <?php if ($user['user_type'] === 'smart'): ?>
                                <div class="p-4 bg-gray-800 rounded-md">
                                    <p class="mb-3 text-gray-300">You're currently on the <span class="text-blue-400 font-semibold">Smart</span> plan. Upgrade to get better rates!</p>
                                    <ul class="list-disc pl-5 space-y-1 text-gray-400">
                                        <li>Standard data and airtime rates</li>
                                        <li>Limited access to premium features</li>
                                    </ul>
                                    <div class="mt-3">
                                        <a href="upgrade.php" class="accent-button py-1 px-4 rounded-md text-sm font-medium text-white inline-block">
                                            Upgrade Now
                                        </a>
                                    </div>
                                </div>
                            <?php elseif ($user['user_type'] === 'vendor'): ?>
                                <div class="p-4 bg-gray-800 rounded-md">
                                    <p class="mb-3 text-gray-300">You're on the <span class="text-green-400 font-semibold">Vendor</span> plan. Enjoy these benefits:</p>
                                    <ul class="list-disc pl-5 space-y-1 text-gray-400">
                                        <li>Discounted data and airtime rates</li>
                                        <li>Access to vendor-exclusive offers</li>
                                        <li>Priority customer support</li>
                                    </ul>
                                </div>
                            <?php else: ?>
                                <div class="p-4 bg-gray-800 rounded-md">
                                    <p class="mb-3 text-gray-300">You're on the <span class="text-red-400 font-semibold">API</span> plan. Enjoy these benefits:</p>
                                    <ul class="list-disc pl-5 space-y-1 text-gray-400">
                                        <li>Lowest data and airtime rates</li>
                                        <li>API access for integration</li>
                                        <li>Unlimited transactions</li>
                                        <li>Priority customer support</li>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                        
                        <div>
                            <h3 class="font-medium text-white mb-3">Account Security</h3>
                            
                            <div class="p-4 bg-gray-800 rounded-md">
                                <ul class="space-y-3">
                                    <li class="flex items-center justify-between">
                                        <span class="text-gray-300">Email Verification</span>
                                        <?php if ($user['email_verified']): ?>
                                            <span class="text-green-400">
                                                <i class="fas fa-check-circle mr-1"></i> Verified
                                            </span>
                                        <?php else: ?>
                                            <a href="../login/resend_verification.php?email=<?php echo urlencode($user['email']); ?>" class="text-yellow-400 hover:text-yellow-300">
                                                <i class="fas fa-exclamation-circle mr-1"></i> Verify Now
                                            </a>
                                        <?php endif; ?>
                                    </li>
                                    
                                    <li class="flex items-center justify-between">
                                        <span class="text-gray-300">Transaction PIN</span>
                                        <?php if (empty($user['pin'])): ?>
                                            <a href="set_pin.php" class="text-yellow-400 hover:text-yellow-300">
                                                <i class="fas fa-exclamation-circle mr-1"></i> Set PIN
                                            </a>
                                        <?php else: ?>
                                            <span class="text-green-400">
                                                <i class="fas fa-check-circle mr-1"></i> Set
                                            </span>
                                        <?php endif; ?>
                                    </li>
                                    
                                    <li class="flex items-center justify-between">
                                        <span class="text-gray-300">Last Login</span>
                                        <span class="text-gray-400">
                                            <?php echo date('M d, Y h:i A'); ?> <!-- Placeholder, implement actual last login tracking -->
                                        </span>
                                    </li>
                                </ul>
                            </div>
                            
                            <div class="mt-4 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                                <p class="text-yellow-300 text-sm">
                                    <i class="fas fa-shield-alt mr-2"></i> For your security, always log out when using shared devices and never share your transaction PIN.
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Phone number input validation
        const phoneInput = document.getElementById('phone');
        phoneInput.addEventListener('input', (e) => {
            e.target.value = e.target.value.replace(/[^0-9]/g, '').substring(0, 11);
        });
    </script>
     <?php require_once './includes/footer.php'; ?>
</body>
</html>