<?php
// File: dashboard/reward/achievement.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

// Handle "Go" button click - Start achievement tracking
if (isset($_POST['start_achievement'])) {
    $achievementId = (int)$_POST['achievement_id'];
    
    // Check if this achievement exists
    $stmt = $conn->prepare("SELECT * FROM achievements WHERE id = ? AND is_active = 1");
    $stmt->bind_param("i", $achievementId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $achievement = $result->fetch_assoc();
        
        // Check if user_achievement record exists
        $stmt = $conn->prepare("SELECT * FROM user_achievements WHERE user_id = ? AND achievement_id = ?");
        $stmt->bind_param("ii", $userId, $achievementId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            // Update existing record - reset progress
            $stmt = $conn->prepare("
                UPDATE user_achievements 
                SET progress = 0, 
                    progress_data = NULL, 
                    is_completed = 0, 
                    completed_at = NULL,
                    is_tracking = 1,
                    tracking_started_at = NOW(),
                    last_calculated_at = NOW()
                WHERE user_id = ? AND achievement_id = ?
            ");
            $stmt->bind_param("ii", $userId, $achievementId);
            $stmt->execute();
        } else {
            // Create new user_achievement record
            $stmt = $conn->prepare("
                INSERT INTO user_achievements 
                (user_id, achievement_id, progress, is_completed, is_tracking, tracking_started_at, last_calculated_at)
                VALUES (?, ?, 0, 0, 1, NOW(), NOW())
            ");
            $stmt->bind_param("ii", $userId, $achievementId);
            $stmt->execute();
        }
        
        // Create notification
        $notifyTitle = "Achievement Tracking Started";
        $notifyMessage = "You've started working on the achievement: " . $achievement['title'];
        
        $stmt = $conn->prepare("
            INSERT INTO notifications
            (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'info', 0)
        ");
        $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
        $stmt->execute();
        
        // Redirect to the relevant page based on achievement type
        $redirectUrl = SITE_URL . '/dashboard/';
        switch ($achievement['requirement_type']) {
            case 'transaction_count':
                $redirectUrl .= 'buy_data.php';
                break;
            case 'airtime_purchase':
                $redirectUrl .= 'buy_airtime.php';
                break;
            case 'data_purchase':
                $redirectUrl .= 'buy_data.php';
                break;
            case 'wallet_balance':
                $redirectUrl .= 'fund_wallet.php';
                break;
            case 'funding_total':
                $redirectUrl .= 'fund_wallet.php';
                break;
            case 'specific_plan':
                $redirectUrl .= 'buy_data.php';
                break;
            case 'consecutive_days':
                $redirectUrl .= 'buy_data.php';
                break;
        }
        
        redirect($redirectUrl);
    }
}

// Handle achievement claim request
$claimSuccess = '';
$claimError = '';

if (isset($_POST['claim_achievement'])) {
    $achievementId = (int)$_POST['achievement_id'];
    
    // Check if achievement exists and is completed
    $stmt = $conn->prepare("
        SELECT ua.*, a.title, a.reward_type, a.reward_amount 
        FROM user_achievements ua
        JOIN achievements a ON ua.achievement_id = a.id
        WHERE ua.user_id = ? AND ua.achievement_id = ? AND ua.is_completed = 1 AND ua.last_reward_at IS NULL
    ");
    $stmt->bind_param("ii", $userId, $achievementId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $claimError = "This achievement is not available to claim";
    } else {
        $achievement = $result->fetch_assoc();
        
        // Start transaction
        $conn->begin_transaction();
        
        try {
            // Update user_achievements
            $stmt = $conn->prepare("
                UPDATE user_achievements 
                SET last_reward_at = NOW(), times_completed = times_completed + 1
                WHERE user_id = ? AND achievement_id = ?
            ");
            $stmt->bind_param("ii", $userId, $achievementId);
            if (!$stmt->execute()) {
                throw new Exception("Failed to update achievement record: " . $conn->error);
            }
            
            // Process reward based on type
            switch ($achievement['reward_type']) {
                case 'cash':
                    // Add cash to user's wallet
                    $amount = (float)$achievement['reward_amount'];
                    
                    // Create transaction record for the reward
                    $txnRef = 'ACH_' . time() . '_' . $userId . '_' . generateRandomString(6);
                    $description = "Achievement reward: " . $achievement['title'];
                    
                    $stmt = $conn->prepare("
                        INSERT INTO transactions 
                        (user_id, txn_ref, type, amount, description, status)
                        VALUES (?, ?, 'bonus', ?, ?, 'successful')
                    ");
                    $stmt->bind_param("isds", $userId, $txnRef, $amount, $description);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create transaction record: " . $conn->error);
                    }
                    $transactionId = $conn->insert_id;
                    
                    // Store original balance for verification
                    $originalBalance = $user['balance'];
                    
                    // Update user balance
                    $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                    $stmt->bind_param("di", $amount, $userId);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to update user balance: " . $conn->error);
                    }
                    
                    // Verify balance update
                    $verify = $conn->prepare("SELECT balance FROM users WHERE id = ?");
                    $verify->bind_param("i", $userId);
                    $verify->execute();
                    $verifyResult = $verify->get_result();
                    $newBalance = $verifyResult->fetch_assoc()['balance'];
                    
                    // Log if balance didn't change as expected
                    if (abs($newBalance - ($originalBalance + $amount)) > 0.001) {  // Allow for floating point imprecision
                        error_log("Balance update verification failed for user $userId. Expected: " . 
                                ($originalBalance + $amount) . ", Got: $newBalance");
                    }
                    
                    // Save reward record
                    $stmt = $conn->prepare("
                        INSERT INTO achievement_rewards
                        (user_id, achievement_id, transaction_id, reward_type, reward_amount, status)
                        VALUES (?, ?, ?, ?, ?, 'completed')
                    ");
                    $stmt->bind_param("iiisd", $userId, $achievementId, $transactionId, $achievement['reward_type'], $amount);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create achievement reward record: " . $conn->error);
                    }
                    
                    $claimSuccess = "Congratulations! ₦" . number_format($amount) . " has been added to your wallet.";
                    break;
                    
                case 'discount':
                    // Create a discount coupon
                    $couponCode = 'ACH' . strtoupper(substr(md5(time() . $userId . $achievementId), 0, 8));
                    $discountPercent = (float)$achievement['reward_amount'];
                    $expiryDate = date('Y-m-d H:i:s', strtotime('+30 days'));
                    
                    // Set up services the coupon can be used for
                    $services = ['data', 'airtime', 'cable', 'electricity'];
                    $servicesJson = json_encode($services);
                    
                    $stmt = $conn->prepare("
                        INSERT INTO promo_codes
                        (code, discount_type, discount_value, min_amount, max_uses, user_specific, specific_user_id, 
                         applicable_services, expiry_date, status, description)
                        VALUES (?, 'percentage', ?, 0, 1, 1, ?, ?, ?, 'active', ?)
                    ");
                    $description = "Achievement reward for completing: " . $achievement['title'];
                    $stmt->bind_param("sdisss", $couponCode, $discountPercent, $userId, $servicesJson, $expiryDate, $description);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create promo code: " . $conn->error);
                    }
                    $promoId = $conn->insert_id;
                    
                    // Save reward record
                    $stmt = $conn->prepare("
                        INSERT INTO achievement_rewards
                        (user_id, achievement_id, reward_type, reward_amount, promo_code_id, status)
                        VALUES (?, ?, ?, ?, ?, 'completed')
                    ");
                    $stmt->bind_param("iisdi", $userId, $achievementId, $achievement['reward_type'], $discountPercent, $promoId);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create achievement reward record: " . $conn->error);
                    }
                    
                    $claimSuccess = "Congratulations! You've received a " . number_format($discountPercent) . "% discount coupon: " . $couponCode;
                    break;
                    
                case 'point':
                    // Add points to user's account
                    $points = (int)$achievement['reward_amount'];
                    
                    // Check if points table exists, if not this is a placeholder
                    try {
                        $stmt = $conn->prepare("
                            INSERT INTO user_points
                            (user_id, points, source, source_id, description)
                            VALUES (?, ?, 'achievement', ?, ?)
                        ");
                        $description = "Achievement reward: " . $achievement['title'];
                        $stmt->bind_param("iiis", $userId, $points, $achievementId, $description);
                        if (!$stmt->execute()) {
                            error_log("Failed to insert user points: " . $conn->error);
                            // Not throwing exception as points might be optional
                        }
                        
                        // Update user total points
                        $stmt = $conn->prepare("UPDATE users SET reward_points = reward_points + ? WHERE id = ?");
                        $stmt->bind_param("ii", $points, $userId);
                        if (!$stmt->execute()) {
                            error_log("Failed to update user reward points: " . $conn->error);
                            // Not throwing exception as points might be optional
                        }
                    } catch (Exception $e) {
                        // Points system might not be implemented yet
                        error_log("Points system error: " . $e->getMessage());
                        // Just log the reward
                    }
                    
                    // Save reward record
                    $stmt = $conn->prepare("
                        INSERT INTO achievement_rewards
                        (user_id, achievement_id, reward_type, reward_amount, status)
                        VALUES (?, ?, ?, ?, 'completed')
                    ");
                    $stmt->bind_param("iisd", $userId, $achievementId, $achievement['reward_type'], $points);
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create achievement reward record: " . $conn->error);
                    }
                    
                    $claimSuccess = "Congratulations! You've earned " . number_format($points) . " reward points!";
                    break;
            }
            
            // Create notification
            $notifyTitle = "Achievement Reward Claimed";
            $notifyMessage = "You have successfully claimed the reward for completing the achievement: " . $achievement['title'];
            
            $stmt = $conn->prepare("
                INSERT INTO notifications
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'success', 0)
            ");
            $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
            if (!$stmt->execute()) {
                error_log("Failed to create notification: " . $conn->error);
                // Not throwing exception as notification is not critical
            }
            
            // If achievement is repeatable, reset progress
            $stmt = $conn->prepare("
                SELECT a.is_repeatable FROM achievements a WHERE a.id = ?
            ");
            $stmt->bind_param("i", $achievementId);
            $stmt->execute();
            $result = $stmt->get_result();
            $isRepeatable = $result->fetch_assoc()['is_repeatable'];
            
            if ($isRepeatable) {
                $stmt = $conn->prepare("
                    UPDATE user_achievements
                    SET progress = 0, 
                        progress_data = NULL, 
                        is_completed = 0, 
                        completed_at = NULL,
                        is_tracking = 0
                    WHERE user_id = ? AND achievement_id = ?
                ");
                $stmt->bind_param("ii", $userId, $achievementId);
                if (!$stmt->execute()) {
                    error_log("Failed to reset repeatable achievement: " . $conn->error);
                    // Not throwing exception as this is not critical
                }
            }
            
            $conn->commit();
        } catch (Exception $e) {
            $conn->rollback();
            error_log("Achievement claim error: " . $e->getMessage());
            $claimError = "Error processing reward: " . $e->getMessage();
        }
    }
}

// Get user achievements with progress
$stmt = $conn->prepare("
    SELECT a.*, ua.progress, ua.is_completed, ua.completed_at, ua.last_reward_at, ua.times_completed, ua.is_tracking
    FROM achievements a
    LEFT JOIN user_achievements ua ON a.id = ua.achievement_id AND ua.user_id = ?
    WHERE a.is_active = 1
    ORDER BY CASE 
        WHEN ua.is_completed = 1 AND ua.last_reward_at IS NULL THEN 1 
        WHEN ua.is_tracking = 1 AND ua.is_completed = 0 THEN 2
        WHEN ua.is_tracking = 0 AND ua.is_completed = 0 THEN 3
        ELSE 4 
    END, a.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

$achievements = [];
$inProgressAchievements = [];
$notStartedAchievements = [];
$completedAchievements = [];
$claimableAchievements = [];

while ($row = $result->fetch_assoc()) {
    // Set progress to 0 if no user achievement record
    if ($row['progress'] === null) {
        $row['progress'] = 0;
    }
    
    // Calculate progress percentage
    $row['progress_percent'] = min(($row['progress'] / $row['requirement_value']) * 100, 100);
    
    // Categorize achievements
    if ($row['is_completed'] && $row['last_reward_at'] === null) {
        $claimableAchievements[] = $row;
    } elseif ($row['is_completed']) {
        $completedAchievements[] = $row;
    } elseif (isset($row['is_tracking']) && $row['is_tracking'] == 1) {
        $inProgressAchievements[] = $row;
    } else {
        $notStartedAchievements[] = $row;
    }
    
    // Add to all achievements list
    $achievements[] = $row;
}

// Page title
$pageTitle = 'Achievements';
require_once '../includes/header.php';
?>

<div class="container px-4 py-6 mx-auto">
    <div class="dashboard-card shadow rounded-lg p-6 mb-6">
        <div class="flex justify-between items-center mb-6">
            <h1 class="text-2xl font-bold text-white">Achievements</h1>
            
            <div class="flex items-center">
                <div class="relative w-10 h-10 rounded-full bg-indigo-900 bg-opacity-20 flex items-center justify-center mr-2">
                    <i class="fas fa-trophy text-indigo-400"></i>
                </div>
                <span class="text-gray-400 text-sm">Your completed achievements: <strong class="text-white"><?php echo count($completedAchievements) + count($claimableAchievements); ?></strong></span>
            </div>
        </div>
        
        <?php if ($claimSuccess): ?>
            <div class="bg-green-900 bg-opacity-20 border border-green-500 text-green-300 px-4 py-3 rounded mb-6" role="alert">
                <p><?php echo $claimSuccess; ?></p>
            </div>
        <?php endif; ?>
        
        <?php if ($claimError): ?>
            <div class="bg-red-900 bg-opacity-20 border border-red-500 text-red-300 px-4 py-3 rounded mb-6" role="alert">
                <p><?php echo $claimError; ?></p>
            </div>
        <?php endif; ?>
        
        <?php if (count($claimableAchievements) > 0): ?>
            <!-- Claimable Achievements Section -->
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <h2 class="text-lg font-semibold text-white">Ready to Claim</h2>
                    <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300">
                        <?php echo count($claimableAchievements); ?> available
                    </span>
                </div>
                
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach ($claimableAchievements as $achievement): ?>
                        <div class="bg-indigo-900 bg-opacity-10 border border-indigo-500 rounded-lg p-4 relative overflow-hidden">
                            <!-- Achievement Icon -->
                            <div class="absolute top-3 right-3 w-8 h-8 rounded-full bg-<?php echo $achievement['badge_color']; ?>-900 bg-opacity-20 flex items-center justify-center">
                                <i class="fas fa-<?php echo $achievement['icon']; ?> text-<?php echo $achievement['badge_color']; ?>-400 text-sm"></i>
                            </div>
                            
                            <!-- Achievement Title & Description -->
                            <h3 class="text-white font-semibold mb-1 pr-8"><?php echo htmlspecialchars($achievement['title']); ?></h3>
                            <p class="text-gray-400 text-sm mb-3"><?php echo htmlspecialchars($achievement['description']); ?></p>
                            
                            <!-- Achievement Progress Bar -->
                            <div class="h-2 bg-gray-700 rounded-full mb-2 overflow-hidden">
                                <div class="h-full bg-<?php echo $achievement['badge_color']; ?>-500 rounded-full" style="width: <?php echo $achievement['progress_percent']; ?>%"></div>
                            </div>
                            
                            <!-- Achievement Progress Text -->
                            <div class="flex justify-between text-xs text-gray-400 mb-3">
                                <span>Progress: <?php echo number_format($achievement['progress']) . ' / ' . number_format($achievement['requirement_value']); ?></span>
                                <span><?php echo number_format($achievement['progress_percent']); ?>% Complete</span>
                            </div>
                            
                            <!-- Achievement Reward -->
                            <div class="flex items-center mb-3">
                                <div class="flex-shrink-0 w-6 h-6 rounded-full bg-green-900 bg-opacity-20 flex items-center justify-center mr-2">
                                    <i class="fas fa-gift text-green-400 text-xs"></i>
                                </div>
                                <span class="text-white text-sm">
                                    <?php 
                                        $rewardText = '';
                                        switch ($achievement['reward_type']) {
                                            case 'cash':
                                                $rewardText = '₦' . number_format($achievement['reward_amount']) . ' cash reward';
                                                break;
                                            case 'discount':
                                                $rewardText = number_format($achievement['reward_amount']) . '% discount coupon';
                                                break;
                                            case 'point':
                                                $rewardText = number_format($achievement['reward_amount']) . ' reward points';
                                                break;
                                        }
                                        echo $rewardText;
                                    ?>
                                </span>
                            </div>
                            
                            <!-- Claim Button -->
                            <form method="POST" action="">
                                <input type="hidden" name="achievement_id" value="<?php echo $achievement['id']; ?>">
                                <button type="submit" name="claim_achievement" class="w-full py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white font-medium rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 transition">
                                    <i class="fas fa-award mr-1"></i> Claim Reward
                                </button>
                            </form>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <!-- In Progress Achievements -->
        <?php if (count($inProgressAchievements) > 0): ?>
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <h2 class="text-lg font-semibold text-white">In Progress</h2>
                    <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-300">
                        <?php echo count($inProgressAchievements); ?> achievements
                    </span>
                </div>
                
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach ($inProgressAchievements as $achievement): ?>
                        <div class="bg-blue-900 bg-opacity-10 border border-blue-700 rounded-lg p-4 relative overflow-hidden">
                            <!-- Achievement Icon -->
                            <div class="absolute top-3 right-3 w-8 h-8 rounded-full bg-<?php echo $achievement['badge_color']; ?>-900 bg-opacity-20 flex items-center justify-center">
                                <i class="fas fa-<?php echo $achievement['icon']; ?> text-<?php echo $achievement['badge_color']; ?>-400 text-sm"></i>
                            </div>
                            
                            <!-- Achievement Title & Description -->
                            <h3 class="text-white font-semibold mb-1 pr-8"><?php echo htmlspecialchars($achievement['title']); ?></h3>
                            <p class="text-gray-400 text-sm mb-3"><?php echo htmlspecialchars($achievement['description']); ?></p>
                            
                            <!-- Achievement Progress Bar -->
                            <div class="h-2 bg-gray-700 rounded-full mb-2 overflow-hidden">
                                <div class="h-full bg-<?php echo $achievement['badge_color']; ?>-500 rounded-full" style="width: <?php echo $achievement['progress_percent']; ?>%"></div>
                            </div>
                            
                            <!-- Achievement Progress Text -->
                            <div class="flex justify-between text-xs text-gray-400 mb-3">
                                <span>Progress: <?php echo number_format($achievement['progress']) . ' / ' . number_format($achievement['requirement_value']); ?></span>
                                <span><?php echo number_format($achievement['progress_percent']); ?>% Complete</span>
                            </div>
                            
                            <!-- Achievement Reward -->
                            <div class="flex items-center mb-3">
                                <div class="flex-shrink-0 w-6 h-6 rounded-full bg-green-900 bg-opacity-20 flex items-center justify-center mr-2">
                                    <i class="fas fa-gift text-green-400 text-xs"></i>
                                </div>
                                <span class="text-white text-sm">
                                    <?php 
                                        $rewardText = '';
                                        switch ($achievement['reward_type']) {
                                            case 'cash':
                                                $rewardText = '₦' . number_format($achievement['reward_amount']) . ' cash reward';
                                                break;
                                            case 'discount':
                                                $rewardText = number_format($achievement['reward_amount']) . '% discount coupon';
                                                break;
                                            case 'point':
                                                $rewardText = number_format($achievement['reward_amount']) . ' reward points';
                                                break;
                                        }
                                        echo $rewardText;
                                    ?>
                                </span>
                            </div>
                            
                            <!-- Action Button based on requirement type -->
                            <?php
                                $actionText = '';
                                $actionUrl = '';
                                
                                switch ($achievement['requirement_type']) {
                                    case 'transaction_count':
                                        $actionText = 'Make Transactions';
                                        $actionUrl = SITE_URL . '/dashboard/buy_data.php';
                                        break;
                                    case 'airtime_purchase':
                                        $actionText = 'Buy Airtime';
                                        $actionUrl = SITE_URL . '/dashboard/buy_airtime.php';
                                        break;
                                    case 'data_purchase':
                                        $actionText = 'Buy Data';
                                        $actionUrl = SITE_URL . '/dashboard/buy_data.php';
                                        break;
                                    case 'wallet_balance':
                                        $actionText = 'Fund Wallet';
                                        $actionUrl = SITE_URL . '/dashboard/fund_wallet.php';
                                        break;
                                    case 'funding_total':
                                        $actionText = 'Fund Wallet';
                                        $actionUrl = SITE_URL . '/dashboard/fund_wallet.php';
                                        break;
                                    case 'specific_plan':
                                        $actionText = 'Buy Data';
                                        $actionUrl = SITE_URL . '/dashboard/buy_data.php';
                                        break;
                                    case 'consecutive_days':
                                        $actionText = 'Make Transactions';
                                        $actionUrl = SITE_URL . '/dashboard/buy_data.php';
                                        break;
                                }
                            ?>
                            
                            <a href="<?php echo $actionUrl; ?>" class="w-full py-2 px-4 bg-blue-600 hover:bg-blue-700 text-center text-white font-medium rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500 transition">
                                <i class="fas fa-arrow-right mr-1"></i> <?php echo $actionText; ?>
                            </a>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <!-- Available Achievements (Not Started) -->
        <?php if (count($notStartedAchievements) > 0): ?>
            <div class="mb-8">
                <div class="flex items-center mb-4">
                    <h2 class="text-lg font-semibold text-white">Available Achievements</h2>
                    <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-purple-100 text-purple-800 dark:bg-purple-900 dark:text-purple-300">
                        <?php echo count($notStartedAchievements); ?> achievements
                    </span>
                </div>
                
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach ($notStartedAchievements as $achievement): ?>
                        <div class="bg-gray-800 border border-gray-700 rounded-lg p-4 relative overflow-hidden">
                            <!-- Achievement Icon -->
                            <div class="absolute top-3 right-3 w-8 h-8 rounded-full bg-<?php echo $achievement['badge_color']; ?>-900 bg-opacity-20 flex items-center justify-center">
                                <i class="fas fa-<?php echo $achievement['icon']; ?> text-<?php echo $achievement['badge_color']; ?>-400 text-sm"></i>
                            </div>
                            
                            <!-- Achievement Title & Description -->
                            <h3 class="text-white font-semibold mb-1 pr-8"><?php echo htmlspecialchars($achievement['title']); ?></h3>
                            <p class="text-gray-400 text-sm mb-3"><?php echo htmlspecialchars($achievement['description']); ?></p>
                            
                            <!-- Achievement Reward -->
                            <div class="flex items-center mb-3">
                                <div class="flex-shrink-0 w-6 h-6 rounded-full bg-gray-700 flex items-center justify-center mr-2">
                                    <i class="fas fa-gift text-gray-400 text-xs"></i>
                                </div>
                                <span class="text-gray-300 text-sm">
                                    <?php 
                                        $rewardText = '';
                                        switch ($achievement['reward_type']) {
                                            case 'cash':
                                                $rewardText = '₦' . number_format($achievement['reward_amount']) . ' cash reward';
                                                break;
                                            case 'discount':
                                                $rewardText = number_format($achievement['reward_amount']) . '% discount coupon';
                                                break;
                                            case 'point':
                                                $rewardText = number_format($achievement['reward_amount']) . ' reward points';
                                                break;
                                        }
                                        echo $rewardText;
                                    ?>
                                </span>
                            </div>
                            
                            <!-- Go Button to start achievement -->
                            <form method="POST" action="">
                                <input type="hidden" name="achievement_id" value="<?php echo $achievement['id']; ?>">
                                <button type="submit" name="start_achievement" class="w-full py-2 px-4 bg-purple-600 hover:bg-purple-700 text-white font-medium rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-purple-500 transition">
                                    <i class="fas fa-play mr-1"></i> Go
                                </button>
                            </form>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <!-- Completed Achievements -->
        <?php if (count($completedAchievements) > 0): ?>
            <div>
                <div class="flex items-center mb-4">
                    <h2 class="text-lg font-semibold text-white">Completed</h2>
                    <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300">
                        <?php echo count($completedAchievements); ?> achievements
                    </span>
                </div>
                
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach ($completedAchievements as $achievement): ?>
                        <div class="bg-gray-800 border border-gray-700 rounded-lg p-4 relative overflow-hidden opacity-90">
                            <!-- Achievement Icon -->
                            <div class="absolute top-3 right-3 w-8 h-8 rounded-full bg-<?php echo $achievement['badge_color']; ?>-900 bg-opacity-20 flex items-center justify-center">
                                <i class="fas fa-<?php echo $achievement['icon']; ?> text-<?php echo $achievement['badge_color']; ?>-400 text-sm"></i>
                            </div>
                            
                            <!-- Completed Badge -->
                            <div class="absolute top-0 left-0 w-0 h-0 border-solid border-t-[50px] border-r-[50px] border-t-green-500 border-r-transparent">
                                <i class="fas fa-check absolute -top-[40px] left-[7px] text-white text-xs"></i>
                            </div>
                            
                            <!-- Achievement Title & Description -->
                            <h3 class="text-white font-semibold mb-1 pr-8 mt-5"><?php echo htmlspecialchars($achievement['title']); ?></h3>
                            <p class="text-gray-400 text-sm mb-3"><?php echo htmlspecialchars($achievement['description']); ?></p>
                            
                            <!-- Achievement Progress Bar (completed) -->
                            <div class="h-2 bg-gray-700 rounded-full mb-2 overflow-hidden">
                                <div class="h-full bg-green-500 rounded-full" style="width: 100%"></div>
                            </div>
                            
                            <!-- Achievement Progress Text -->
                            <div class="flex justify-between text-xs text-gray-400 mb-3">
                                <span>Completed</span>
                                <span><?php echo date('M d, Y', strtotime($achievement['completed_at'])); ?></span>
                            </div>
                            
                            <!-- Achievement Reward -->
                            <div class="flex items-center">
                                <div class="flex-shrink-0 w-6 h-6 rounded-full bg-gray-700 flex items-center justify-center mr-2">
                                    <i class="fas fa-gift text-gray-400 text-xs"></i>
                                </div>
                                <span class="text-gray-300 text-sm">
                                    <?php 
                                        $rewardText = '';
                                        switch ($achievement['reward_type']) {
                                            case 'cash':
                                                $rewardText = '₦' . number_format($achievement['reward_amount']) . ' cash reward';
                                                break;
                                            case 'discount':
                                                $rewardText = number_format($achievement['reward_amount']) . '% discount coupon';
                                                break;
                                            case 'point':
                                                $rewardText = number_format($achievement['reward_amount']) . ' reward points';
                                                break;
                                        }
                                        echo $rewardText;
                                    ?>
                                </span>
                                <?php if ($achievement['times_completed'] > 1): ?>
                                    <span class="ml-2 inline-flex items-center px-2 py-0.5 rounded text-xs font-medium bg-purple-900 bg-opacity-40 text-purple-300">
                                        <?php echo $achievement['times_completed']; ?>x
                                    </span>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>