<?php
// File: dashboard/reward/contest.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

// Process contest join request
$success = "";
$error = "";

if (isset($_POST['join_contest']) && isset($_POST['contest_id'])) {
    $contestId = (int)$_POST['contest_id'];
    
    // Check if contest exists and is active
    $stmt = $conn->prepare("
        SELECT * FROM referral_contests
        WHERE id = ? AND is_active = 1
        AND NOW() BETWEEN start_date AND end_date
    ");
    $stmt->bind_param("i", $contestId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = "Contest not found or not active.";
    } else {
        $contest = $result->fetch_assoc();
        $entryFee = $contest['entry_fee'];
        
        // Check if user already joined
        $stmt = $conn->prepare("
            SELECT * FROM contest_entries
            WHERE user_id = ? AND contest_id = ?
        ");
        $stmt->bind_param("ii", $userId, $contestId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $entry = $result->fetch_assoc();
            
            if ($entry['entry_fee_paid']) {
                $error = "You have already joined this contest.";
            } else {
                // User joined but hasn't paid - check if they have enough balance
                if ($user['balance'] < $entryFee) {
                    $error = "Insufficient balance to join this contest. Required: " . formatAmount($entryFee);
                } else {
                    try {
                        // Start transaction
                        $conn->begin_transaction();
                        
                        // Create transaction for entry fee
                        $txnRef = 'CONTEST_FEE_' . time() . '_' . $userId . '_' . generateRandomString(6);
                        $description = "Entry fee for contest: " . $contest['title'];
                        
                        $stmt = $conn->prepare("
                            INSERT INTO transactions 
                            (user_id, txn_ref, type, amount, fee, description, status)
                            VALUES (?, ?, 'fee', ?, 0, ?, 'successful')
                        ");
                        $stmt->bind_param("isds", $userId, $txnRef, $entryFee, $description);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to create transaction record.");
                        }
                        
                        $transactionId = $conn->insert_id;
                        
                        // Update contest entry
                        $stmt = $conn->prepare("
                            UPDATE contest_entries
                            SET entry_fee_paid = 1,
                                payment_transaction_id = ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("ii", $transactionId, $entry['id']);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update contest entry.");
                        }
                        
                        // Update user's balance
                        $stmt = $conn->prepare("
                            UPDATE users
                            SET balance = balance - ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("di", $entryFee, $userId);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update user balance.");
                        }
                        
                        // Commit transaction
                        $conn->commit();
                        
                        $success = "You have successfully joined the contest: " . $contest['title'];
                        
                    } catch (Exception $e) {
                        $conn->rollback();
                        $error = "Failed to join contest: " . $e->getMessage();
                    }
                }
            }
        } else {
            // New entry - check if they have enough balance
            if ($entryFee > 0 && $user['balance'] < $entryFee) {
                $error = "Insufficient balance to join this contest. Required: " . formatAmount($entryFee);
            } else {
                try {
                    // Start transaction
                    $conn->begin_transaction();
                    
                    if ($entryFee > 0) {
                        // Create transaction for entry fee
                        $txnRef = 'CONTEST_FEE_' . time() . '_' . $userId . '_' . generateRandomString(6);
                        $description = "Entry fee for contest: " . $contest['title'];
                        
                        $stmt = $conn->prepare("
                            INSERT INTO transactions 
                            (user_id, txn_ref, type, amount, fee, description, status)
                            VALUES (?, ?, 'fee', ?, 0, ?, 'successful')
                        ");
                        $stmt->bind_param("isds", $userId, $txnRef, $entryFee, $description);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to create transaction record.");
                        }
                        
                        $transactionId = $conn->insert_id;
                        
                        // Update user's balance
                        $stmt = $conn->prepare("
                            UPDATE users
                            SET balance = balance - ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("di", $entryFee, $userId);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update user balance.");
                        }
                    } else {
                        $transactionId = null;
                    }
                    
                    // Create new contest entry
                    $stmt = $conn->prepare("
                        INSERT INTO contest_entries
                        (user_id, contest_id, entry_fee_paid, payment_transaction_id)
                        VALUES (?, ?, 1, ?)
                    ");
                    $stmt->bind_param("iii", $userId, $contestId, $transactionId);
                    
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create contest entry.");
                    }
                    
                    // Commit transaction
                    $conn->commit();
                    
                    $success = "You have successfully joined the contest: " . $contest['title'];
                    
                } catch (Exception $e) {
                    $conn->rollback();
                    $error = "Failed to join contest: " . $e->getMessage();
                }
            }
        }
    }
}

// Get active and upcoming contests
$stmt = $conn->prepare("
    SELECT c.*, 
           (SELECT COUNT(*) FROM contest_entries WHERE contest_id = c.id) as participants_count,
           (SELECT entry_fee_paid FROM contest_entries WHERE user_id = ? AND contest_id = c.id) as has_joined,
           (SELECT is_disqualified FROM contest_entries WHERE user_id = ? AND contest_id = c.id) as is_disqualified
    FROM referral_contests c
    WHERE c.is_active = 1
    ORDER BY 
        CASE 
            WHEN c.start_date <= NOW() AND c.end_date >= NOW() THEN 1
            WHEN c.start_date > NOW() THEN 2
            ELSE 3
        END,
        c.start_date ASC
");
$stmt->bind_param("ii", $userId, $userId);
$stmt->execute();
$result = $stmt->get_result();
$contests = [];

while ($row = $result->fetch_assoc()) {
    $contests[] = $row;
}

// Get user's active contests
$userActiveContests = [];
foreach ($contests as $contest) {
    if ($contest['has_joined'] && !$contest['is_disqualified'] && $contest['start_date'] <= date('Y-m-d H:i:s') && $contest['end_date'] >= date('Y-m-d H:i:s')) {
        $userActiveContests[] = $contest;
    }
}

// Get user's past contests
$stmt = $conn->prepare("
    SELECT c.*, ce.position, ce.referral_count, ce.is_disqualified,
           (ce.referral_count + ce.manual_adjustment) as adjusted_count
    FROM contest_entries ce
    JOIN referral_contests c ON ce.contest_id = c.id
    WHERE ce.user_id = ? AND c.end_date < NOW()
    ORDER BY c.end_date DESC
    LIMIT 10
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$pastContests = [];

while ($row = $result->fetch_assoc()) {
    $pastContests[] = $row;
}

// Generate referral links for active contests
$referralLinks = [];
foreach ($userActiveContests as $contest) {
    $baseLink = SITE_URL . '/register?ref=' . urlencode($user['username']);
    if (!empty($contest['prefix'])) {
        $referralLinks[$contest['id']] = SITE_URL . '/register?ref=' . urlencode($contest['prefix'] . $user['username']);
    } elseif (!empty($contest['suffix'])) {
        $referralLinks[$contest['id']] = SITE_URL . '/register?ref=' . urlencode($user['username'] . $contest['suffix']);
    } else {
        $referralLinks[$contest['id']] = $baseLink;
    }
}

// Page title
$pageTitle = 'Referral Contests';
require_once '../includes/header.php';

// Helper function to generate a random string
function generateRandomString($length = 8) {
    $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return $randomString;
}
?>

<div class="container px-4 py-6 mx-auto">
    <div class="mb-6">
        <div class="flex items-center mb-4">
            <a href="<?php echo SITE_URL; ?>/dashboard/reward/index.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                <i class="fas fa-arrow-left"></i> Back to Rewards
            </a>
            <h1 class="text-2xl font-bold text-white">Referral Contests</h1>
        </div>
        
        <?php if ($success): ?>
            <div class="bg-green-900 bg-opacity-20 border border-green-500 text-green-300 p-4 rounded-md mb-4">
                <?php echo $success; ?>
            </div>
        <?php endif; ?>
        
        <?php if ($error): ?>
            <div class="bg-red-900 bg-opacity-20 border border-red-500 text-red-300 p-4 rounded-md mb-4">
                <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <!-- Active Contests Section -->
        <?php if (count($userActiveContests) > 0): ?>
            <div class="dashboard-card shadow rounded-lg p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">Your Active Contests</h2>
                
                <div class="grid grid-cols-1 lg:grid-cols-2 gap-6">
                    <?php foreach ($userActiveContests as $contest): 
                        $now = time();
                        $endTime = strtotime($contest['end_date']);
                        $timeRemaining = $endTime - $now;
                        $daysRemaining = floor($timeRemaining / (60 * 60 * 24));
                        $hoursRemaining = floor(($timeRemaining % (60 * 60 * 24)) / (60 * 60));
                    ?>
                        <div class="bg-indigo-900 bg-opacity-10 border border-indigo-500 rounded-lg overflow-hidden">
                            <div class="p-4 border-b border-indigo-500 bg-indigo-500 bg-opacity-20">
                                <div class="flex justify-between items-start">
                                    <h3 class="text-white font-semibold"><?php echo htmlspecialchars($contest['title']); ?></h3>
                                    <span class="inline-flex items-center px-2 py-1 rounded text-xs font-medium bg-green-900 text-green-300">
                                        Active
                                    </span>
                                </div>
                                <p class="text-sm text-gray-300 mt-1">
                                    Ends in: <span class="text-white"><?php echo $daysRemaining; ?> days, <?php echo $hoursRemaining; ?> hours</span>
                                </p>
                            </div>
                            
                            <div class="p-4">
                                <div class="mb-3">
                                    <label class="block text-sm font-medium text-gray-400 mb-1">Your Referral Link</label>
                                    <div class="flex">
                                        <input type="text" value="<?php echo $referralLinks[$contest['id']]; ?>" 
                                               id="contest-link-<?php echo $contest['id']; ?>" 
                                               class="form-input block w-full rounded-l-md bg-gray-700 border-gray-600 text-white" readonly>
                                        <button onclick="copyToClipboard('<?php echo $referralLinks[$contest['id']]; ?>', 'contest-<?php echo $contest['id']; ?>')" 
                                                class="bg-indigo-600 hover:bg-indigo-700 text-white px-4 py-2 rounded-r-md">
                                            <i class="fas fa-copy"></i>
                                        </button>
                                    </div>
                                </div>
                                
                                <?php if (!empty($contest['group_link'])): ?>
                                    <div class="mb-3">
                                        <a href="<?php echo htmlspecialchars($contest['group_link']); ?>" target="_blank" 
                                           class="inline-flex items-center text-indigo-400 hover:text-indigo-300">
                                            <i class="fas fa-users mr-2"></i> Join Contest Group
                                        </a>
                                    </div>
                                <?php endif; ?>
                                
                                <div class="flex justify-between mb-3">
                                    <span class="text-gray-400">Participants:</span>
                                    <span class="text-white"><?php echo $contest['participants_count']; ?></span>
                                </div>
                                
                                <div class="flex justify-between mb-3">
                                    <span class="text-gray-400">First Prize:</span>
                                    <span class="text-white"><?php echo formatAmount($contest['first_prize']); ?></span>
                                </div>
                                
                                <div class="flex justify-between mb-3">
                                    <span class="text-gray-400">Min. Referrals:</span>
                                    <span class="text-white"><?php echo $contest['min_referrals']; ?></span>
                                </div>
                                
                                <div class="mt-4">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/reward/contest_leaderboard.php?id=<?php echo $contest['id']; ?>" class="block w-full text-center bg-indigo-600 hover:bg-indigo-700 text-white py-2 px-4 rounded-md">
                                        View Leaderboard
                                    </a>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <!-- Available Contests Section -->
        <div class="dashboard-card shadow rounded-lg p-6 mb-6">
            <h2 class="text-xl font-semibold text-white mb-4"><?php echo count($userActiveContests) > 0 ? 'Other Available Contests' : 'Available Contests'; ?></h2>
            
            <?php 
            $availableContests = array_filter($contests, function($contest) use ($userActiveContests) {
                // Filter out contests the user has already joined
                foreach ($userActiveContests as $activeContest) {
                    if ($activeContest['id'] === $contest['id']) {
                        return false;
                    }
                }
                // Only include active and upcoming contests
                return $contest['end_date'] >= date('Y-m-d H:i:s');
            });
            
            if (count($availableContests) === 0): 
            ?>
                <div class="bg-gray-800 rounded-lg p-8 text-center">
                    <div class="w-16 h-16 mx-auto bg-gray-700 rounded-full flex items-center justify-center mb-4">
                        <i class="fas fa-trophy text-gray-500 text-2xl"></i>
                    </div>
                    <h3 class="text-white font-semibold mb-2">No Available Contests</h3>
                    <p class="text-gray-400 max-w-md mx-auto">There are currently no available contests to join. Check back later!</p>
                </div>
            <?php else: ?>
                <div class="grid grid-cols-1 gap-6">
                    <?php foreach ($availableContests as $contest): 
                        $isActive = $contest['start_date'] <= date('Y-m-d H:i:s') && $contest['end_date'] >= date('Y-m-d H:i:s');
                        $isUpcoming = $contest['start_date'] > date('Y-m-d H:i:s');
                        $hasJoined = $contest['has_joined'] ?? false;
                        $isDisqualified = $contest['is_disqualified'] ?? false;
                    ?>
                        <div class="bg-gray-800 border border-gray-700 rounded-lg overflow-hidden">
                            <div class="p-4 border-b border-gray-700">
                                <div class="flex flex-wrap md:flex-nowrap justify-between items-start gap-2">
                                    <div>
                                        <h3 class="text-white font-semibold"><?php echo htmlspecialchars($contest['title']); ?></h3>
                                        <p class="text-sm text-gray-400 mt-1">
                                            <?php if ($isActive): ?>
                                                Ends: <?php echo date('M d, Y', strtotime($contest['end_date'])); ?>
                                            <?php else: ?>
                                                Starts: <?php echo date('M d, Y', strtotime($contest['start_date'])); ?>
                                            <?php endif; ?>
                                        </p>
                                    </div>
                                    
                                    <div class="flex flex-wrap gap-2">
                                        <?php if ($isActive): ?>
                                            <span class="inline-flex items-center px-2 py-1 rounded text-xs font-medium bg-green-900 text-green-300">
                                                Active
                                            </span>
                                        <?php elseif ($isUpcoming): ?>
                                            <span class="inline-flex items-center px-2 py-1 rounded text-xs font-medium bg-blue-900 text-blue-300">
                                                Upcoming
                                            </span>
                                        <?php endif; ?>
                                        
                                        <?php if ($contest['is_elimination']): ?>
                                            <span class="inline-flex items-center px-2 py-1 rounded text-xs font-medium bg-red-900 text-red-300">
                                                <i class="fas fa-fire-alt mr-1"></i> Elimination
                                            </span>
                                        <?php endif; ?>
                                        
                                        <?php if ($hasJoined && $isDisqualified): ?>
                                            <span class="inline-flex items-center px-2 py-1 rounded text-xs font-medium bg-gray-700 text-gray-300">
                                                Disqualified
                                            </span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="p-4">
                                <p class="text-gray-300 mb-4"><?php echo nl2br(htmlspecialchars($contest['description'])); ?></p>
                                
                                <div class="grid grid-cols-1 md:grid-cols-3 gap-4 mb-4">
                                    <div>
                                        <h4 class="text-gray-400 text-sm mb-1">Entry Fee</h4>
                                        <p class="text-white font-semibold">
                                            <?php 
                                                if ($contest['entry_fee'] > 0) {
                                                    echo formatAmount($contest['entry_fee']);
                                                } else {
                                                    echo 'Free';
                                                }
                                            ?>
                                        </p>
                                    </div>
                                    
                                    <div>
                                        <h4 class="text-gray-400 text-sm mb-1">Prize Pool</h4>
                                        <p class="text-white font-semibold"><?php echo formatAmount($contest['prize_pool']); ?></p>
                                    </div>
                                    
                                    <div>
                                        <h4 class="text-gray-400 text-sm mb-1">Participants</h4>
                                        <p class="text-white font-semibold"><?php echo $contest['participants_count']; ?></p>
                                    </div>
                                </div>
                                
                                <div class="mb-4">
                                    <h4 class="text-gray-400 text-sm mb-1">Prizes</h4>
                                    <ul class="text-white">
                                        <li class="flex justify-between">
                                            <span>1st Place:</span>
                                            <span><?php echo formatAmount($contest['first_prize']); ?></span>
                                        </li>
                                        <?php if ($contest['second_prize'] > 0): ?>
                                        <li class="flex justify-between">
                                            <span>2nd Place:</span>
                                            <span><?php echo formatAmount($contest['second_prize']); ?></span>
                                        </li>
                                        <?php endif; ?>
                                        <?php if ($contest['third_prize'] > 0): ?>
                                        <li class="flex justify-between">
                                            <span>3rd Place:</span>
                                            <span><?php echo formatAmount($contest['third_prize']); ?></span>
                                        </li>
                                        <?php endif; ?>
                                        <?php if ($contest['participation_reward'] > 0): ?>
                                        <li class="flex justify-between">
                                            <span>Participation (min <?php echo $contest['min_referrals']; ?> referrals):</span>
                                            <span><?php echo formatAmount($contest['participation_reward']); ?></span>
                                        </li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                                
                                <?php if ($isActive && !$hasJoined): ?>
                                    <form method="POST" action="">
                                        <input type="hidden" name="contest_id" value="<?php echo $contest['id']; ?>">
                                        <button type="submit" name="join_contest" class="w-full bg-indigo-600 hover:bg-indigo-700 text-white py-2 px-4 rounded">
                                            Join Contest <?php echo $contest['entry_fee'] > 0 ? '(' . formatAmount($contest['entry_fee']) . ')' : '(Free)'; ?>
                                        </button>
                                    </form>
                                <?php elseif ($isUpcoming && !$hasJoined): ?>
                                    <button disabled class="w-full bg-gray-600 text-white py-2 px-4 rounded cursor-not-allowed">
                                        Contest Starts on <?php echo date('M d, Y', strtotime($contest['start_date'])); ?>
                                    </button>
                                <?php elseif ($hasJoined && !$isDisqualified): ?>
                                    <a href="<?php echo SITE_URL; ?>/dashboard/reward/contest_leaderboard.php?id=<?php echo $contest['id']; ?>" class="block w-full text-center bg-indigo-600 hover:bg-indigo-700 text-white py-2 px-4 rounded">
                                        View Leaderboard
                                    </a>
                                <?php elseif ($hasJoined && $isDisqualified): ?>
                                    <button disabled class="w-full bg-red-600 text-white py-2 px-4 rounded cursor-not-allowed">
                                        You've Been Disqualified
                                    </button>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Past Contests Section -->
        <?php if (count($pastContests) > 0): ?>
            <div class="dashboard-card shadow rounded-lg p-6">
                <h2 class="text-xl font-semibold text-white mb-4">Your Contest History</h2>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-700">
                        <thead class="bg-gray-800">
                            <tr>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Contest</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Period</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Your Referrals</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Position</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody class="bg-gray-900 divide-y divide-gray-800">
                            <?php foreach ($pastContests as $contest): ?>
                                <tr>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($contest['title']); ?></div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="text-sm text-white"><?php echo date('M d', strtotime($contest['start_date'])); ?> - <?php echo date('M d, Y', strtotime($contest['end_date'])); ?></div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="text-sm font-medium text-white"><?php echo $contest['adjusted_count']; ?></div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php if ($contest['position']): ?>
                                            <div class="text-sm font-medium text-white"><?php echo $contest['position']; ?></div>
                                        <?php else: ?>
                                            <div class="text-sm text-gray-400">-</div>
                                        <?php endif; ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php if ($contest['is_disqualified']): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300">
                                                Disqualified
                                            </span>
                                        <?php else: ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300">
                                                Completed
                                            </span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                        <a href="<?php echo SITE_URL; ?>/dashboard/reward/contest_leaderboard.php?id=<?php echo $contest['id']; ?>" class="text-indigo-400 hover:text-indigo-300">
                                            View Results
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- Toast Notification -->
<div id="toast" class="fixed right-4 top-4 bg-green-500 text-white px-4 py-2 rounded shadow-lg transform transition-transform duration-300 translate-y-[-100px]"></div>

<script>
    function copyToClipboard(text, type = 'code') {
        navigator.clipboard.writeText(text).then(() => {
            showToast(type === 'code' ? 'Referral code copied!' : 'Referral link copied!');
        }).catch(err => {
            showToast('Failed to copy text: ' + err);
        });
    }
    
    function showToast(message) {
        const toast = document.getElementById('toast');
        toast.textContent = message;
        toast.style.transform = 'translateY(0)';
        
        setTimeout(() => {
            toast.style.transform = 'translateY(-100px)';
        }, 3000);
    }
</script>

<?php require_once '../includes/footer.php'; ?>