<?php
// File: dashboard/reward/contest_leaderboard.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get contest ID from URL
$contestId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($contestId <= 0) {
    redirect(SITE_URL . '/dashboard/reward/referral.php');
}

// Get contest details
$stmt = $conn->prepare("
    SELECT * FROM referral_contests 
    WHERE id = ? AND is_active = 1
");
$stmt->bind_param("i", $contestId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    redirect(SITE_URL . '/dashboard/reward/referral.php');
}

$contest = $result->fetch_assoc();

// Check if user has joined this contest
$stmt = $conn->prepare("
    SELECT * FROM contest_entries
    WHERE user_id = ? AND contest_id = ?
");
$stmt->bind_param("ii", $userId, $contestId);
$stmt->execute();
$result = $stmt->get_result();
$userEntry = null;

if ($result->num_rows > 0) {
    $userEntry = $result->fetch_assoc();
    
    // If user is disqualified and tries to view leaderboard, redirect to referrals page
    if ($userEntry['is_disqualified']) {
        redirect(SITE_URL . '/dashboard/reward/referral.php');
    }
} else {
    // User hasn't joined this contest, redirect
    redirect(SITE_URL . '/dashboard/reward/referral.php');
}

// Get leaderboard entries
$stmt = $conn->prepare("
    SELECT ce.*, u.username, u.full_name, 
           (ce.referral_count + ce.manual_adjustment) as adjusted_count
    FROM contest_entries ce
    JOIN users u ON ce.user_id = u.id
    WHERE ce.contest_id = ? AND ce.is_disqualified = 0
    ORDER BY adjusted_count DESC, ce.created_at ASC
");
$stmt->bind_param("i", $contestId);
$stmt->execute();
$result = $stmt->get_result();
$entries = [];

while ($row = $result->fetch_assoc()) {
    $entries[] = $row;
}

// Get recent eliminations
$stmt = $conn->prepare("
    SELECT el.*, ce.user_id, u.username
    FROM contest_elimination_logs el
    LEFT JOIN contest_entries ce ON el.contest_id = ce.contest_id AND ce.is_disqualified = 1
    LEFT JOIN users u ON ce.user_id = u.id
    WHERE el.contest_id = ?
    ORDER BY el.elimination_date DESC
    LIMIT 5
");
$stmt->bind_param("i", $contestId);
$stmt->execute();
$result = $stmt->get_result();
$eliminations = [];

while ($row = $result->fetch_assoc()) {
    $eliminations[] = $row;
}

// Find user's position in the leaderboard
$userPosition = 0;
foreach ($entries as $index => $entry) {
    if ($entry['user_id'] == $userId) {
        $userPosition = $index + 1;
        break;
    }
}

// Calculate time remaining
$now = time();
$endTime = strtotime($contest['end_date']);
$timeRemaining = $endTime - $now;

$contestActive = $timeRemaining > 0;
$daysRemaining = floor($timeRemaining / (60 * 60 * 24));
$hoursRemaining = floor(($timeRemaining % (60 * 60 * 24)) / (60 * 60));

// Calculate total and remaining spots
$totalSpots = count($entries);
$eliminatedCount = 0;

$stmt = $conn->prepare("
    SELECT COUNT(*) as eliminated 
    FROM contest_entries 
    WHERE contest_id = ? AND is_disqualified = 1
");
$stmt->bind_param("i", $contestId);
$stmt->execute();
$result = $stmt->get_result();
$eliminatedCount = $result->fetch_assoc()['eliminated'];

$totalParticipants = $totalSpots + $eliminatedCount;

// Page title
$pageTitle = 'Contest Leaderboard - ' . $contest['title'];
require_once '../includes/header.php';
?>

<div class="container px-4 py-6 mx-auto">
    <div class="dashboard-card shadow rounded-lg p-6 mb-6">
        <div class="mb-6">
            <div class="flex items-center mb-4">
                <a href="<?php echo SITE_URL; ?>/dashboard/reward/referral.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                    <i class="fas fa-arrow-left"></i> Back to Referrals
                </a>
                <h1 class="text-2xl font-bold text-white"><?php echo htmlspecialchars($contest['title']); ?> - Leaderboard</h1>
            </div>
            
            <div class="bg-gray-800 p-4 rounded-lg mb-6">
                <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                    <div class="flex flex-col">
                        <span class="text-gray-400 text-sm">Contest Period:</span>
                        <span class="text-white">
                            <?php echo date('M d', strtotime($contest['start_date'])); ?> - 
                            <?php echo date('M d, Y', strtotime($contest['end_date'])); ?>
                        </span>
                    </div>
                    
                    <div class="flex flex-col">
                        <span class="text-gray-400 text-sm">Status:</span>
                        <?php if ($contestActive): ?>
                            <span class="text-green-400">
                                Active - <?php echo $daysRemaining; ?> days, <?php echo $hoursRemaining; ?> hours left
                            </span>
                        <?php else: ?>
                            <span class="text-red-400">Ended</span>
                        <?php endif; ?>
                    </div>
                    
                    <div class="flex flex-col">
                        <span class="text-gray-400 text-sm">Participants:</span>
                        <span class="text-white">
                            <?php echo $totalSpots; ?> active / <?php echo $totalParticipants; ?> total
                        </span>
                    </div>
                </div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6 mb-6">
                <!-- Contest Description -->
                <div>
                    <h2 class="text-lg font-semibold text-white mb-2">Contest Details</h2>
                    <div class="bg-gray-800 p-4 rounded-lg">
                        <p class="text-gray-300 mb-4"><?php echo nl2br(htmlspecialchars($contest['description'])); ?></p>
                        
                        <div class="text-sm">
                            <div class="flex justify-between mb-1">
                                <span class="text-white text-sm font-semibold">Prizes:</span>
                            </div>
                            <div>
                                <div class="flex justify-between">
                                    <span class="text-gray-400">1st Place:</span>
                                    <span class="text-white"><?php echo formatAmount($contest['first_prize']); ?></span>
                                </div>
                                <?php if ($contest['second_prize'] > 0): ?>
                                <div class="flex justify-between">
                                    <span class="text-gray-400">2nd Place:</span>
                                    <span class="text-white"><?php echo formatAmount($contest['second_prize']); ?></span>
                                </div>
                                <?php endif; ?>
                                <?php if ($contest['third_prize'] > 0): ?>
                                <div class="flex justify-between">
                                    <span class="text-gray-400">3rd Place:</span>
                                    <span class="text-white"><?php echo formatAmount($contest['third_prize']); ?></span>
                                </div>
                                <?php endif; ?>
                                <?php if ($contest['participation_reward'] > 0): ?>
                                <div class="flex justify-between">
                                    <span class="text-gray-400">Participation (min <?php echo $contest['min_referrals']; ?> referrals):</span>
                                    <span class="text-white"><?php echo formatAmount($contest['participation_reward']); ?></span>
                                </div>
                                <?php endif; ?>
                                <?php if ($contest['per_referral_reward'] > 0): ?>
                                <div class="flex justify-between">
                                    <span class="text-gray-400">Per Referral:</span>
                                    <span class="text-white"><?php echo formatAmount($contest['per_referral_reward']); ?></span>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        
                        <?php if (!empty($contest['group_link'])): ?>
                            <div class="mt-4 text-center">
                                <a href="<?php echo htmlspecialchars($contest['group_link']); ?>" target="_blank" class="inline-block py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md">
                                    <i class="fas fa-users mr-2"></i> Join Contest Group
                                </a>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                
                <!-- Your Position -->
                <div>
                    <h2 class="text-lg font-semibold text-white mb-2">Your Position</h2>
                    <div class="bg-gray-800 p-4 rounded-lg">
                        <div class="flex items-center mb-4">
                            <?php if ($userPosition <= 3): ?>
                                <div class="w-12 h-12 rounded-full bg-yellow-500 flex items-center justify-center text-white font-bold text-xl mr-4">
                                    <?php echo $userPosition; ?>
                                </div>
                            <?php else: ?>
                                <div class="w-12 h-12 rounded-full bg-gray-700 flex items-center justify-center text-white font-bold text-xl mr-4">
                                    <?php echo $userPosition; ?>
                                </div>
                            <?php endif; ?>
                            
                            <div>
                                <div class="text-white font-semibold"><?php echo $userPosition; ?> of <?php echo $totalSpots; ?></div>
                                <div class="text-sm text-gray-400">Current position</div>
                            </div>
                        </div>
                        
                        <div class="flex justify-between mb-2">
                            <span class="text-gray-400">Your Referrals:</span>
                            <span class="text-white"><?php echo ($userEntry['referral_count'] + $userEntry['manual_adjustment']); ?></span>
                        </div>
                        
                        <?php if ($userEntry['manual_adjustment'] != 0): ?>
                            <div class="flex justify-between mb-2">
                                <span class="text-gray-400">Includes Adjustment:</span>
                                <span class="text-<?php echo $userEntry['manual_adjustment'] > 0 ? 'green' : 'red'; ?>-400">
                                    <?php echo $userEntry['manual_adjustment'] > 0 ? '+' : ''; ?><?php echo $userEntry['manual_adjustment']; ?>
                                </span>
                            </div>
                        <?php endif; ?>
                        
                        <?php if ($contest['is_elimination']): ?>
                            <div class="mt-4 p-3 bg-red-900 bg-opacity-30 border border-red-500 rounded text-sm text-red-300">
                                <p><i class="fas fa-exclamation-triangle mr-2"></i> This is an elimination contest. The bottom <?php echo $contest['elimination_threshold']; ?> participants will be eliminated <?php echo $contest['elimination_frequency']; ?>.</p>
                            </div>
                        <?php endif; ?>
                        
                        <div class="mt-4">
                            <div class="text-sm text-gray-400 mb-2">Potential reward:</div>
                            <?php 
                                $potentialReward = 0;
                                if ($userPosition === 1) {
                                    $potentialReward = $contest['first_prize'];
                                } elseif ($userPosition === 2 && $contest['second_prize'] > 0) {
                                    $potentialReward = $contest['second_prize'];
                                } elseif ($userPosition === 3 && $contest['third_prize'] > 0) {
                                    $potentialReward = $contest['third_prize'];
                                }
                                
                                // Add participation reward if eligible
                                if ($userEntry['referral_count'] >= $contest['min_referrals'] && $contest['participation_reward'] > 0) {
                                    $potentialReward += $contest['participation_reward'];
                                }
                                
                                // Add per-referral reward
                                if ($contest['per_referral_reward'] > 0) {
                                    $potentialReward += $userEntry['referral_count'] * $contest['per_referral_reward'];
                                }
                            ?>
                            <div class="text-xl text-white font-bold"><?php echo formatAmount($potentialReward); ?></div>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php if (count($eliminations) > 0 && $contest['is_elimination']): ?>
                <div class="mb-6">
                    <h2 class="text-lg font-semibold text-white mb-2">Recent Eliminations</h2>
                    <div class="bg-red-900 bg-opacity-10 border border-red-500 rounded-lg p-4">
                        <ul class="space-y-2">
                            <?php foreach ($eliminations as $elimination): ?>
                                <li class="text-gray-300">
                                    <i class="fas fa-fire text-red-500 mr-2"></i>
                                    <span class="text-white"><?php echo date('M d, Y', strtotime($elimination['elimination_date'])); ?>:</span>
                                    <?php echo $elimination['users_eliminated']; ?> participants were eliminated
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            <?php endif; ?>
            
            <!-- Top 3 Positions -->
            <?php if (count($entries) > 0): ?>
                <div class="mb-8">
                    <h2 class="text-lg font-semibold text-white mb-4">Top Positions</h2>
                    
                    <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                        <?php
                        $topThree = array_slice($entries, 0, min(3, count($entries)));
                        foreach ($topThree as $index => $entry):
                            $position = $index + 1;
                            // Colors for positions
                            $colors = [
                                1 => [
                                    'bg' => 'bg-yellow-500',
                                    'bgOpacity' => 'bg-yellow-900 bg-opacity-30',
                                    'border' => 'border-yellow-500',
                                    'text' => 'text-yellow-300'
                                ],
                                2 => [
                                    'bg' => 'bg-gray-400',
                                    'bgOpacity' => 'bg-gray-700 bg-opacity-70',
                                    'border' => 'border-gray-400',
                                    'text' => 'text-gray-300'
                                ],
                                3 => [
                                    'bg' => 'bg-yellow-700',
                                    'bgOpacity' => 'bg-yellow-900 bg-opacity-30',
                                    'border' => 'border-yellow-700',
                                    'text' => 'text-yellow-600'
                                ]
                            ];
                            $color = $colors[$position] ?? $colors[3];
                        ?>
                            <div class="<?php echo $color['bgOpacity']; ?> border <?php echo $color['border']; ?> rounded-lg p-4">
                                <div class="flex items-center mb-4">
                                    <div class="w-12 h-12 rounded-full <?php echo $color['bg']; ?> flex items-center justify-center text-white font-bold text-xl mr-4">
                                        <?php echo $position; ?>
                                    </div>
                                    <div>
                                        <div class="text-white font-semibold"><?php echo htmlspecialchars($entry['username']); ?></div>
                                        <?php if ($entry['user_id'] == $userId): ?>
                                            <div class="text-sm <?php echo $color['text']; ?>">You</div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                
                                <div class="flex justify-between mb-2">
                                    <span class="text-gray-400">Referrals:</span>
                                    <span class="text-white font-semibold"><?php echo $entry['adjusted_count']; ?></span>
                                </div>
                                
                                <?php if ($entry['manual_adjustment'] != 0): ?>
                                    <div class="flex justify-between mb-2">
                                        <span class="text-gray-400">Includes Adjustment:</span>
                                        <span class="text-<?php echo $entry['manual_adjustment'] > 0 ? 'green' : 'red'; ?>-400">
                                            <?php echo $entry['manual_adjustment'] > 0 ? '+' : ''; ?><?php echo $entry['manual_adjustment']; ?>
                                        </span>
                                    </div>
                                <?php endif; ?>
                                
                                <div class="flex justify-between mt-2">
                                    <span class="text-gray-400">Prize:</span>
                                    <span class="text-white">
                                        <?php 
                                            $reward = 0;
                                            if ($position === 1) {
                                                $reward = $contest['first_prize'];
                                            } elseif ($position === 2) {
                                                $reward = $contest['second_prize'];
                                            } elseif ($position === 3) {
                                                $reward = $contest['third_prize'];
                                            }
                                            echo formatAmount($reward);
                                        ?>
                                    </span>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            <?php endif; ?>
            
            <!-- Full Leaderboard -->
            <div>
                <h2 class="text-lg font-semibold text-white mb-4">Full Leaderboard</h2>
                
                <?php if (count($entries) === 0): ?>
                    <div class="bg-gray-800 rounded-lg p-8 text-center">
                        <div class="w-16 h-16 mx-auto bg-gray-700 rounded-full flex items-center justify-center mb-4">
                            <i class="fas fa-trophy text-gray-500 text-2xl"></i>
                        </div>
                        <h3 class="text-white font-semibold mb-2">No Entries Yet</h3>
                        <p class="text-gray-400 max-w-md mx-auto">Be the first to join this contest! Start referring users to claim the top spot.</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-700">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Rank</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">User</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Referrals</th>
                                    <?php if (!$contestActive): ?>
                                        <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Reward</th>
                                    <?php endif; ?>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-800">
                                <?php foreach ($entries as $index => $entry): 
                                    $position = $index + 1;
                                ?>
                                    <tr class="<?php echo $entry['user_id'] == $userId ? 'bg-indigo-900 bg-opacity-20' : ''; ?>">
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <?php if ($position <= 3): ?>
                                                <span class="inline-flex items-center justify-center w-6 h-6 rounded-full 
                                                         <?php 
                                                             echo $position === 1 ? 'bg-yellow-500' : 
                                                                 ($position === 2 ? 'bg-gray-400' : 'bg-yellow-700'); 
                                                         ?> text-white font-semibold">
                                                    <?php echo $position; ?>
                                                </span>
                                            <?php else: ?>
                                                <span class="text-gray-400"><?php echo $position; ?></span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap">
                                            <div class="flex items-center">
                                                <div class="text-sm font-medium text-white"><?php echo htmlspecialchars($entry['username']); ?></div>
                                                <?php if ($entry['user_id'] == $userId): ?>
                                                    <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-indigo-100 text-indigo-800 dark:bg-indigo-900 dark:text-indigo-300">
                                                        You
                                                    </span>
                                                <?php endif; ?>
                                            </div>
                                        </td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm text-white font-semibold">
                                            <?php echo $entry['adjusted_count']; ?>
                                            <?php if ($entry['manual_adjustment'] != 0): ?>
                                                <span class="text-<?php echo $entry['manual_adjustment'] > 0 ? 'green' : 'red'; ?>-400 text-xs ml-1">
                                                    (<?php echo $entry['manual_adjustment'] > 0 ? '+' : ''; ?><?php echo $entry['manual_adjustment']; ?>)
                                                </span>
                                            <?php endif; ?>
                                        </td>
                                        <?php if (!$contestActive): ?>
                                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                                <?php 
                                                    $reward = 0;
                                                    if ($position === 1) {
                                                        $reward = $contest['first_prize'];
                                                    } elseif ($position === 2 && $contest['second_prize'] > 0) {
                                                        $reward = $contest['second_prize'];
                                                    } elseif ($position === 3 && $contest['third_prize'] > 0) {
                                                        $reward = $contest['third_prize'];
                                                    }
                                                    
                                                    // Add participation reward if eligible
                                                    if ($entry['referral_count'] >= $contest['min_referrals'] && $contest['participation_reward'] > 0) {
                                                        $reward += $contest['participation_reward'];
                                                    }
                                                    
                                                    // Add per-referral reward
                                                    if ($contest['per_referral_reward'] > 0) {
                                                        $reward += $entry['referral_count'] * $contest['per_referral_reward'];
                                                    }
                                                    
                                                    echo formatAmount($reward);
                                                ?>
                                            </td>
                                        <?php endif; ?>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>