<?php
// File: dashboard/reward/referral.php
require_once '../../includes/config.php';
require_once '../../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login');
}

// Process claim request
$success = "";
$error = "";

if (isset($_POST['claim_reward']) && isset($_POST['referral_id'])) {
    $referralId = (int)$_POST['referral_id'];
    
    // Check if this referral belongs to this user and is qualified but not completed
    $stmt = $conn->prepare("
        SELECT r.*, u.username
        FROM referrals r
        JOIN users u ON r.referred_id = u.id
        WHERE r.id = ? AND r.referrer_id = ? AND r.status = 'qualified'
    ");
    $stmt->bind_param("ii", $referralId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = "Invalid referral or you're not authorized to claim this reward.";
    } else {
        $referral = $result->fetch_assoc();
        $referredUsername = $referral['username'];
        
        // Get referral reward amount
        $reward = (float)getSetting('referral_reward', 100);
        
        try {
            // Start transaction
            $conn->begin_transaction();
            
            // Create transaction record
            $txnRef = 'REF_' . time() . '_' . $userId . '_' . generateRandomString(6);
            $description = "Referral reward for " . $referredUsername;
            
            $stmt = $conn->prepare("
                INSERT INTO transactions 
                (user_id, txn_ref, type, amount, description, status)
                VALUES (?, ?, 'bonus', ?, ?, 'successful')
            ");
            $stmt->bind_param("isds", $userId, $txnRef, $reward, $description);
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to create transaction record.");
            }
            
            $transactionId = $conn->insert_id;
            
            // Update referral status
            $stmt = $conn->prepare("
                UPDATE referrals
                SET status = 'completed',
                    reward_amount = ?,
                    reward_transaction_id = ?,
                    completed_at = NOW()
                WHERE id = ?
            ");
            $stmt->bind_param("dii", $reward, $transactionId, $referralId);
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to update referral record.");
            }
            
            // Update user's wallet balance and earnings
            $stmt = $conn->prepare("
                UPDATE users
                SET balance = balance + ?,
                    referral_earnings = referral_earnings + ?
                WHERE id = ?
            ");
            $stmt->bind_param("ddi", $reward, $reward, $userId);
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to update user balance.");
            }
            
            // Create notification
            $stmt = $conn->prepare("
                INSERT INTO notifications
                (user_id, title, message, type, is_read)
                VALUES (?, 'Referral Reward', ?, 'success', 0)
            ");
            $message = "You have received " . formatAmount($reward) . " for referring " . $referredUsername;
            $stmt->bind_param("is", $userId, $message);
            $stmt->execute();
            
            // Commit transaction
            $conn->commit();
            
            $success = "You have successfully claimed " . formatAmount($reward) . " for referring " . $referredUsername . ".";
            
        } catch (Exception $e) {
            $conn->rollback();
            $error = "Failed to process reward: " . $e->getMessage();
        }
    }
}

// Join active contest
if (isset($_POST['join_contest']) && isset($_POST['contest_id'])) {
    $contestId = (int)$_POST['contest_id'];
    
    // Check if contest exists and is active
    $stmt = $conn->prepare("
        SELECT * FROM referral_contests
        WHERE id = ? AND is_active = 1
        AND NOW() BETWEEN start_date AND end_date
    ");
    $stmt->bind_param("i", $contestId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = "Contest not found or not active.";
    } else {
        $contest = $result->fetch_assoc();
        $entryFee = $contest['entry_fee'];
        
        // Check if user already joined
        $stmt = $conn->prepare("
            SELECT * FROM contest_entries
            WHERE user_id = ? AND contest_id = ?
        ");
        $stmt->bind_param("ii", $userId, $contestId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $entry = $result->fetch_assoc();
            
            if ($entry['entry_fee_paid']) {
                $error = "You have already joined this contest.";
            } else {
                // User joined but hasn't paid - check if they have enough balance
                if ($user['balance'] < $entryFee) {
                    $error = "Insufficient balance to join this contest. Required: " . formatAmount($entryFee);
                } else {
                    try {
                        // Start transaction
                        $conn->begin_transaction();
                        
                        // Create transaction for entry fee
                        $txnRef = 'CONTEST_FEE_' . time() . '_' . $userId . '_' . generateRandomString(6);
                        $description = "Entry fee for contest: " . $contest['title'];
                        
                        $stmt = $conn->prepare("
                            INSERT INTO transactions 
                            (user_id, txn_ref, type, amount, fee, description, status)
                            VALUES (?, ?, 'fee', ?, 0, ?, 'successful')
                        ");
                        $stmt->bind_param("isds", $userId, $txnRef, $entryFee, $description);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to create transaction record.");
                        }
                        
                        $transactionId = $conn->insert_id;
                        
                        // Update contest entry
                        $stmt = $conn->prepare("
                            UPDATE contest_entries
                            SET entry_fee_paid = 1,
                                payment_transaction_id = ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("ii", $transactionId, $entry['id']);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update contest entry.");
                        }
                        
                        // Update user's balance
                        $stmt = $conn->prepare("
                            UPDATE users
                            SET balance = balance - ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("di", $entryFee, $userId);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update user balance.");
                        }
                        
                        // Commit transaction
                        $conn->commit();
                        
                        $success = "You have successfully joined the contest: " . $contest['title'];
                        
                    } catch (Exception $e) {
                        $conn->rollback();
                        $error = "Failed to join contest: " . $e->getMessage();
                    }
                }
            }
        } else {
            // New entry - check if they have enough balance
            if ($entryFee > 0 && $user['balance'] < $entryFee) {
                $error = "Insufficient balance to join this contest. Required: " . formatAmount($entryFee);
            } else {
                try {
                    // Start transaction
                    $conn->begin_transaction();
                    
                    if ($entryFee > 0) {
                        // Create transaction for entry fee
                        $txnRef = 'CONTEST_FEE_' . time() . '_' . $userId . '_' . generateRandomString(6);
                        $description = "Entry fee for contest: " . $contest['title'];
                        
                        $stmt = $conn->prepare("
                            INSERT INTO transactions 
                            (user_id, txn_ref, type, amount, fee, description, status)
                            VALUES (?, ?, 'fee', ?, 0, ?, 'successful')
                        ");
                        $stmt->bind_param("isds", $userId, $txnRef, $entryFee, $description);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to create transaction record.");
                        }
                        
                        $transactionId = $conn->insert_id;
                        
                        // Update user's balance
                        $stmt = $conn->prepare("
                            UPDATE users
                            SET balance = balance - ?
                            WHERE id = ?
                        ");
                        $stmt->bind_param("di", $entryFee, $userId);
                        
                        if (!$stmt->execute()) {
                            throw new Exception("Failed to update user balance.");
                        }
                    } else {
                        $transactionId = null;
                    }
                    
                    // Create new contest entry
                    $stmt = $conn->prepare("
                        INSERT INTO contest_entries
                        (user_id, contest_id, entry_fee_paid, payment_transaction_id)
                        VALUES (?, ?, 1, ?)
                    ");
                    $stmt->bind_param("iii", $userId, $contestId, $transactionId);
                    
                    if (!$stmt->execute()) {
                        throw new Exception("Failed to create contest entry.");
                    }
                    
                    // Commit transaction
                    $conn->commit();
                    
                    $success = "You have successfully joined the contest: " . $contest['title'];
                    
                } catch (Exception $e) {
                    $conn->rollback();
                    $error = "Failed to join contest: " . $e->getMessage();
                }
            }
        }
    }
}

// Get user's referrals with qualification details
$stmt = $conn->prepare("
    SELECT r.*, u.username, u.email, u.full_name, u.created_at as joined_date, 
           u.email_verified, c.title as contest_title
    FROM referrals r
    JOIN users u ON r.referred_id = u.id
    LEFT JOIN referral_contests c ON r.contest_id = c.id
    WHERE r.referrer_id = ?
    ORDER BY 
        CASE r.status
            WHEN 'qualified' THEN 0
            WHEN 'pending' THEN 1
            WHEN 'completed' THEN 2
            ELSE 3
        END,
        r.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$referrals = [];

while ($row = $result->fetch_assoc()) {
    $referrals[] = $row;
}

// Get user's referral stats
$pendingCount = 0;
$qualifiedCount = 0;
$completedCount = 0;
$totalEarnings = 0;

foreach ($referrals as $referral) {
    if ($referral['status'] === 'completed') {
        $completedCount++;
        $totalEarnings += $referral['reward_amount'] ?: 0;
    } elseif ($referral['status'] === 'qualified') {
        $qualifiedCount++;
    } elseif ($referral['status'] === 'pending') {
        $pendingCount++;
    }
}

// Get active referral contests
$stmt = $conn->prepare("
    SELECT c.*, 
        ce.referral_count, ce.position, ce.entry_fee_paid, 
        ce.is_disqualified, ce.disqualification_reason
    FROM referral_contests c
    LEFT JOIN contest_entries ce ON c.id = ce.contest_id AND ce.user_id = ?
    WHERE c.is_active = 1 
    AND c.end_date >= NOW()
    ORDER BY c.start_date ASC,
    c.end_date ASC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$activeContests = [];

while ($row = $result->fetch_assoc()) {
    $activeContests[] = $row;
}

// Generate referral links
$referralLink = SITE_URL . '/register?ref=' . urlencode($user['username']);
$referralLinks = [
    'default' => $referralLink
];

// Generate contest referral links
foreach ($activeContests as $contest) {
    $contestLink = $referralLink;
    if (!empty($contest['prefix'])) {
        $contestLink = SITE_URL . '/register?ref=' . urlencode($contest['prefix'] . $user['username']);
    } elseif (!empty($contest['suffix'])) {
        $contestLink = SITE_URL . '/register?ref=' . urlencode($user['username'] . $contest['suffix']);
    }
    $referralLinks['contest_' . $contest['id']] = $contestLink;
}

// Page title
$pageTitle = 'My Referrals';
require_once '../includes/header.php';
?>

<div class="container px-4 py-6 mx-auto">
    <div class="dashboard-card shadow rounded-lg p-6 mb-6">
        <div class="flex justify-between items-center mb-6">
            <h1 class="text-2xl font-bold text-white">My Referrals</h1>
            
            <div class="flex items-center">
                <div class="relative w-10 h-10 rounded-full bg-indigo-900 bg-opacity-20 flex items-center justify-center mr-2">
                    <i class="fas fa-user-plus text-indigo-400"></i>
                </div>
                <span class="text-gray-400 text-sm">Total Referrals: <strong class="text-white"><?php echo $user['referrals_count']; ?></strong></span>
            </div>
        </div>
        
        <?php if ($success): ?>
            <div class="bg-green-900 bg-opacity-20 border border-green-500 text-green-300 p-4 rounded-md mb-4">
                <?php echo $success; ?>
            </div>
        <?php endif; ?>
        
        <?php if ($error): ?>
            <div class="bg-red-900 bg-opacity-20 border border-red-500 text-red-300 p-4 rounded-md mb-4">
                <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <!-- Referral Stats Cards -->
        <div class="grid grid-cols-1 md:grid-cols-3 gap-6 mb-8">
            <!-- Total Referrals Card -->
            <div class="bg-indigo-900 bg-opacity-10 border border-indigo-500 rounded-lg p-4">
                <div class="flex items-center mb-2">
                    <div class="w-10 h-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                        <i class="fas fa-users text-indigo-400"></i>
                    </div>
                    <h3 class="text-white font-semibold">Total Referrals</h3>
                </div>
                <div class="text-3xl font-bold text-white mb-2"><?php echo $user['referrals_count']; ?></div>
                <div class="text-indigo-300 text-sm">
                    <?php echo $completedCount; ?> completed, <?php echo $qualifiedCount; ?> qualified, <?php echo $pendingCount; ?> pending
                </div>
            </div>
            
            <!-- Earnings Card -->
            <div class="bg-green-900 bg-opacity-10 border border-green-500 rounded-lg p-4">
                <div class="flex items-center mb-2">
                    <div class="w-10 h-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                        <i class="fas fa-coins text-green-400"></i>
                    </div>
                    <h3 class="text-white font-semibold">Total Earnings</h3>
                </div>
                <div class="text-3xl font-bold text-white mb-2"><?php echo formatAmount($user['referral_earnings']); ?></div>
                <div class="text-green-300 text-sm">
                    From <?php echo $completedCount; ?> completed referrals
                </div>
            </div>
            
            <!-- Referral Link Card -->
            <div class="bg-purple-900 bg-opacity-10 border border-purple-500 rounded-lg p-4">
                <div class="flex items-center mb-2">
                    <div class="w-10 h-10 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mr-3">
                        <i class="fas fa-link text-purple-400"></i>
                    </div>
                    <h3 class="text-white font-semibold">Your Referral Code</h3>
                </div>
                <div class="flex items-center mb-2">
                    <span class="text-xl font-semibold text-white mr-2"><?php echo htmlspecialchars($user['username']); ?></span>
                    <button onclick="copyToClipboard('<?php echo htmlspecialchars($user['username']); ?>')" class="text-purple-400 hover:text-purple-300">
                        <i class="fas fa-copy"></i>
                    </button>
                </div>
                <div class="text-purple-300 text-sm">
                    Share this code or your referral link
                </div>
            </div>
        </div>
        
        <!-- Referral Requirements Info Box -->
        <div class="bg-blue-900 bg-opacity-10 border border-blue-500 rounded-lg p-4 mb-8">
            <div class="flex items-start">
                <div class="mt-1">
                    <i class="fas fa-info-circle text-blue-400 text-lg"></i>
                </div>
                <div class="ml-4">
                    <h3 class="text-white font-medium mb-2">Referral Reward Requirements</h3>
                    <p class="text-blue-300 text-sm mb-2">For your referrals to qualify for rewards, they must meet one of these requirements:</p>
                    <ul class="list-disc pl-5 text-blue-300 text-sm">
                        <li>Spend or fund their account with at least <?php echo formatAmount(5000); ?>, OR</li>
                        <li>Complete at least 30 transactions</li>
                    </ul>
                    <p class="text-blue-300 text-sm mt-2">Once these requirements are met, you can claim your reward of <?php echo formatAmount(getSetting('referral_reward', 100)); ?> per referral.</p>
                </div>
            </div>
        </div>
        
        <!-- Referral Link Section -->
        <div class="mb-8">
            <h2 class="text-lg font-semibold text-white mb-4">Your Referral Links</h2>
            
            <div class="bg-gray-800 rounded-lg p-4 mb-4">
                <label class="block text-sm font-medium text-gray-400 mb-2">Standard Referral Link</label>
                <div class="flex">
                    <input type="text" value="<?php echo $referralLinks['default']; ?>" id="standard-referral-link" class="form-input block w-full rounded-l-md bg-gray-700 border-gray-600 text-white" readonly>
                    <button onclick="copyToClipboard('<?php echo $referralLinks['default']; ?>', 'standard-referral')" class="bg-indigo-600 hover:bg-indigo-700 text-white px-4 rounded-r-md">
                        <i class="fas fa-copy mr-2"></i> Copy
                    </button>
                </div>
                <p class="mt-2 text-sm text-gray-400">Share this link to invite friends to join. You'll get rewarded for each qualified referral.</p>
            </div>
            
            <!-- Social Sharing Buttons -->
            <div class="flex flex-wrap gap-2 mb-4">
                <button onclick="shareViaWhatsApp('<?php echo $referralLinks['default']; ?>')" class="bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded-md">
                    <i class="fab fa-whatsapp mr-2"></i> WhatsApp
                </button>
                <button onclick="shareViaFacebook('<?php echo $referralLinks['default']; ?>')" class="bg-blue-600 hover:bg-blue-700 text-white py-2 px-4 rounded-md">
                    <i class="fab fa-facebook-f mr-2"></i> Facebook
                </button>
                <button onclick="shareViaTwitter('<?php echo $referralLinks['default']; ?>')" class="bg-blue-400 hover:bg-blue-500 text-white py-2 px-4 rounded-md">
                    <i class="fab fa-twitter mr-2"></i> Twitter
                </button>
                <button onclick="shareViaTelegram('<?php echo $referralLinks['default']; ?>')" class="bg-blue-500 hover:bg-blue-600 text-white py-2 px-4 rounded-md">
                    <i class="fab fa-telegram-plane mr-2"></i> Telegram
                </button>
                <button onclick="shareViaEmail('<?php echo $referralLinks['default']; ?>')" class="bg-gray-600 hover:bg-gray-700 text-white py-2 px-4 rounded-md">
                    <i class="fas fa-envelope mr-2"></i> Email
                </button>
            </div>
            
            <?php if (count($activeContests) > 0): ?>
                <div class="mt-6">
                    <h3 class="text-md font-semibold text-white mb-2">Contest Referral Links</h3>
                    <p class="text-sm text-gray-400 mb-4">Use these special links for active referral contests:</p>
                    
                    <?php foreach ($activeContests as $index => $contest): 
                        // Check if user has joined and paid entry fee
                        $hasJoined = isset($contest['entry_fee_paid']) && $contest['entry_fee_paid'] == 1;
                        $isDisqualified = isset($contest['is_disqualified']) && $contest['is_disqualified'] == 1;
                    ?>
                        <div class="bg-gray-800 rounded-lg p-4 mb-4">
                            <div class="flex justify-between items-start mb-2">
                                <div>
                                    <span class="text-white font-semibold"><?php echo htmlspecialchars($contest['title']); ?></span>
                                    <span class="ml-2 text-xs bg-indigo-900 text-indigo-300 px-2 py-1 rounded">
                                        Ends: <?php echo date('M d, Y', strtotime($contest['end_date'])); ?>
                                    </span>
                                    
                                    <?php if ($isDisqualified): ?>
                                        <span class="ml-2 text-xs bg-red-900 text-red-300 px-2 py-1 rounded">
                                            Disqualified
                                        </span>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="text-sm text-gray-400">
                                    <?php if ($hasJoined): ?>
                                        Your referrals: <span class="text-white font-medium"><?php echo $contest['referral_count'] ?? 0; ?></span>
                                    <?php else: ?>
                                        <form method="POST" action="">
                                            <input type="hidden" name="contest_id" value="<?php echo $contest['id']; ?>">
                                            <button type="submit" name="join_contest" class="text-xs bg-indigo-600 hover:bg-indigo-700 text-white py-1 px-2 rounded">
                                                Join Contest (<?php echo formatAmount($contest['entry_fee']); ?>)
                                            </button>
                                        </form>
                                    <?php endif; ?>
                                </div>
                            </div>
                            
                            <?php if ($hasJoined && !$isDisqualified): ?>
                                <div class="flex mb-2">
                                    <input type="text" value="<?php echo $referralLinks['contest_' . $contest['id']]; ?>" id="contest-referral-link-<?php echo $contest['id']; ?>" class="form-input block w-full rounded-l-md bg-gray-700 border-gray-600 text-white" readonly>
                                    <button onclick="copyToClipboard('<?php echo $referralLinks['contest_' . $contest['id']]; ?>', 'contest-<?php echo $contest['id']; ?>')" class="bg-indigo-600 hover:bg-indigo-700 text-white px-4 rounded-r-md">
                                        <i class="fas fa-copy mr-2"></i> Copy
                                    </button>
                                </div>
                            <?php endif; ?>
                            
                            <?php if (!empty($contest['group_link'])): ?>
                                <div class="mt-2 text-sm text-green-400">
                                    <a href="<?php echo htmlspecialchars($contest['group_link']); ?>" target="_blank" class="flex items-center">
                                        <i class="fas fa-users mr-2"></i> Join Contest Group
                                    </a>
                                </div>
                            <?php endif; ?>
                            
                            <?php if ($isDisqualified && !empty($contest['disqualification_reason'])): ?>
                                <div class="mt-2 text-sm text-red-400">
                                    <p><i class="fas fa-exclamation-circle mr-2"></i> <?php echo htmlspecialchars($contest['disqualification_reason']); ?></p>
                                </div>
                            <?php endif; ?>
                            
                            <?php if ($hasJoined && !$isDisqualified): ?>
                                <div class="mt-2">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/reward/contest_leaderboard.php?id=<?php echo $contest['id']; ?>" class="text-sm text-indigo-400 hover:text-indigo-300">
                                        <i class="fas fa-trophy mr-2"></i> View Contest Leaderboard
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Qualified Referrals Section -->
        <?php if ($qualifiedCount > 0): ?>
            <div class="mb-8">
                <h2 class="text-lg font-semibold text-white mb-4">Qualified Referrals</h2>
                
                <div class="bg-gray-800 rounded-lg p-4 mb-4">
                    <p class="text-green-400 mb-4"><i class="fas fa-check-circle mr-2"></i> These referrals have met the requirements and are ready for you to claim your rewards.</p>
                    
                    <div class="space-y-4">
                        <?php 
                        $qualifiedReferrals = array_filter($referrals, function($ref) {
                            return $ref['status'] === 'qualified';
                        });
                        
                        foreach ($qualifiedReferrals as $referral): 
                        ?>
                            <div class="bg-gray-700 rounded-lg p-4 flex justify-between items-center">
                                <div>
                                    <div class="text-white font-medium"><?php echo htmlspecialchars($referral['username']); ?></div>
                                    <div class="text-sm text-gray-400">
                                        Joined: <?php echo date('M d, Y', strtotime($referral['joined_date'])); ?>
                                        <?php if ($referral['contest_id']): ?>
                                            <span class="ml-2 text-xs bg-indigo-900 text-indigo-300 px-1 py-0.5 rounded">
                                                Contest
                                            </span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <form method="POST" action="">
                                    <input type="hidden" name="referral_id" value="<?php echo $referral['id']; ?>">
                                    <button type="submit" name="claim_reward" class="bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded">
                                        <i class="fas fa-coins mr-2"></i> Claim Reward
                                    </button>
                                </form>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        
        <!-- Referrals Table -->
        <div>
            <h2 class="text-lg font-semibold text-white mb-4">All Referrals</h2>
            
            <?php if (count($referrals) === 0): ?>
                <div class="bg-gray-800 rounded-lg p-8 text-center">
                    <div class="w-16 h-16 mx-auto bg-gray-700 rounded-full flex items-center justify-center mb-4">
                        <i class="fas fa-user-plus text-gray-500 text-2xl"></i>
                    </div>
                    <h3 class="text-white font-semibold mb-2">No Referrals Yet</h3>
                    <p class="text-gray-400 max-w-md mx-auto">You haven't referred anyone yet. Share your referral link or code to start earning rewards!</p>
                </div>
            <?php else: ?>
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-700">
                        <thead class="bg-gray-800">
                            <tr>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">User</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Joined</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Progress</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Type</th>
                                <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Reward</th>
                            </tr>
                        </thead>
                        <tbody class="bg-gray-900 divide-y divide-gray-800">
                            <?php foreach ($referrals as $referral): ?>
                                <tr>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="flex items-center">
                                            <div class="flex-shrink-0 h-10 w-10 rounded-full bg-gray-800 flex items-center justify-center">
                                                <i class="fas fa-user text-gray-400"></i>
                                            </div>
                                            <div class="ml-4">
                                                <div class="text-sm font-medium text-white"><?php echo htmlspecialchars($referral['username']); ?></div>
                                                <div class="text-sm text-gray-400"><?php echo htmlspecialchars($referral['email']); ?></div>
                                            </div>
                                        </div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="text-sm text-white"><?php echo date('M d, Y', strtotime($referral['joined_date'])); ?></div>
                                        <div class="text-sm text-gray-400"><?php echo date('h:i A', strtotime($referral['joined_date'])); ?></div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <div class="text-sm">
                                            <div class="flex items-center text-gray-400">
                                                <span>Transactions: </span>
                                                <span class="ml-2 font-medium <?php echo $referral['transaction_count'] >= 30 ? 'text-green-400' : 'text-white'; ?>">
                                                    <?php echo $referral['transaction_count']; ?>/30
                                                </span>
                                            </div>
                                            <div class="flex items-center text-gray-400">
                                                <span>Total spend: </span>
                                                <span class="ml-2 font-medium <?php echo $referral['total_spend'] >= 5000 ? 'text-green-400' : 'text-white'; ?>">
                                                    <?php echo formatAmount($referral['total_spend']); ?>/<?php echo formatAmount(5000); ?>
                                                </span>
                                            </div>
                                        </div>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php if ($referral['status'] === 'completed'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300">
                                                Completed
                                            </span>
                                        <?php elseif ($referral['status'] === 'qualified'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300">
                                                Ready to Claim
                                            </span>
                                        <?php elseif ($referral['status'] === 'pending'): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-300">
                                                Pending
                                            </span>
                                        <?php else: ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300">
                                                Rejected
                                            </span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <?php if ($referral['contest_id']): ?>
                                            <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-indigo-100 text-indigo-800 dark:bg-indigo-900 dark:text-indigo-300">
                                                <?php echo htmlspecialchars($referral['contest_title'] ?: 'Contest'); ?>
                                            </span>
                                        <?php else: ?>
                                            <span class="text-gray-400 text-sm">Standard</span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php if ($referral['reward_amount'] > 0): ?>
                                            <?php echo formatAmount($referral['reward_amount']); ?>
                                        <?php elseif ($referral['status'] === 'qualified'): ?>
                                            <span class="text-yellow-400"><?php echo formatAmount(getSetting('referral_reward', 100)); ?> (Unclaimed)</span>
                                        <?php elseif ($referral['status'] === 'pending'): ?>
                                            <span class="text-gray-400">Pending qualification</span>
                                        <?php else: ?>
                                            <span class="text-gray-400">-</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Toast Notification -->
<div id="toast" class="fixed right-4 top-4 bg-green-500 text-white px-4 py-2 rounded shadow-lg transform transition-transform duration-300 translate-y-[-100px]"></div>

<script>
    function copyToClipboard(text, type = 'code') {
        navigator.clipboard.writeText(text).then(() => {
            showToast(type === 'code' ? 'Referral code copied!' : 'Referral link copied!');
        }).catch(err => {
            showToast('Failed to copy text: ' + err);
        });
    }
    
    function showToast(message) {
        const toast = document.getElementById('toast');
        toast.textContent = message;
        toast.style.transform = 'translateY(0)';
        
        setTimeout(() => {
            toast.style.transform = 'translateY(-100px)';
        }, 3000);
    }
    
    function shareViaWhatsApp(url) {
        const message = "Join me on <?php echo getSetting('site_name'); ?>! Use my referral link:";
        const whatsappUrl = `https://wa.me/?text=${encodeURIComponent(message + ' ' + url)}`;
        window.open(whatsappUrl, '_blank');
    }
    
    function shareViaFacebook(url) {
        const facebookUrl = `https://www.facebook.com/sharer/sharer.php?u=${encodeURIComponent(url)}`;
        window.open(facebookUrl, '_blank', 'width=600,height=400');
    }
    
    function shareViaTwitter(url) {
        const message = "Join me on <?php echo getSetting('site_name'); ?>! Use my referral link:";
        const twitterUrl = `https://twitter.com/intent/tweet?text=${encodeURIComponent(message)}&url=${encodeURIComponent(url)}`;
        window.open(twitterUrl, '_blank', 'width=600,height=400');
    }
    
    function shareViaTelegram(url) {
        const message = "Join me on <?php echo getSetting('site_name'); ?>! Use my referral link:";
        const telegramUrl = `https://t.me/share/url?url=${encodeURIComponent(url)}&text=${encodeURIComponent(message)}`;
        window.open(telegramUrl, '_blank');
    }
    
    function shareViaEmail(url) {
        const subject = "Join me on <?php echo getSetting('site_name'); ?>";
        const body = `I thought you might be interested in joining ${<?php echo json_encode(getSetting('site_name')); ?>}. Use my referral link: ${url}`;
        window.location.href = `mailto:?subject=${encodeURIComponent(subject)}&body=${encodeURIComponent(body)}`;
    }
</script>

<?php require_once '../includes/footer.php'; ?>