<?php
$pageTitle = 'Saved Beneficiaries';
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Check if beneficiaries table exists
$tableExists = false;
try {
    $result = $conn->query("SHOW TABLES LIKE 'beneficiaries'");
    $tableExists = $result->num_rows > 0;
} catch (Exception $e) {
    // Table doesn't exist
    $tableExists = false;
}

// Create table if it doesn't exist
if (!$tableExists) {
    try {
        $conn->query("
            CREATE TABLE IF NOT EXISTS `beneficiaries` (
              `id` int(11) NOT NULL AUTO_INCREMENT,
              `user_id` int(11) NOT NULL,
              `type` enum('data','airtime','cable','electricity') NOT NULL,
              `name` varchar(100) NOT NULL,
              `identifier` varchar(100) NOT NULL,
              `provider_id` int(11) DEFAULT NULL,
              `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
              `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
              PRIMARY KEY (`id`),
              KEY `user_id` (`user_id`),
              CONSTRAINT `beneficiaries_ibfk_1` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
        ");
        $tableExists = true;
    } catch (Exception $e) {
        // Failed to create table
        error_log("Failed to create beneficiaries table: " . $e->getMessage());
    }
}

// Check for actions (delete)
if ($tableExists && isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $beneficiaryId = (int) $_GET['id'];
    
    // Verify beneficiary belongs to user
    $stmt = $conn->prepare("SELECT * FROM beneficiaries WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $beneficiaryId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Delete beneficiary
        $stmt = $conn->prepare("DELETE FROM beneficiaries WHERE id = ?");
        $stmt->bind_param("i", $beneficiaryId);
        
        if ($stmt->execute()) {
            $successMessage = "Beneficiary deleted successfully.";
        } else {
            $errorMessage = "Failed to delete beneficiary. Please try again.";
        }
    } else {
        $errorMessage = "Beneficiary not found or you don't have permission to delete it.";
    }
}

// Get beneficiaries
$beneficiaries = [
    'data' => [],
    'airtime' => [],
    'cable' => [],
    'electricity' => []
];

if ($tableExists) {
    // Get networks for data and airtime
    $networks = [];
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active'");
    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $networks[$row['id']] = $row['name'];
    }
    
    // Try to get beneficiaries
    try {
        $stmt = $conn->prepare("SELECT * FROM beneficiaries WHERE user_id = ? ORDER BY type, name ASC");
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            // Add provider name for display
            if ($row['type'] == 'data' || $row['type'] == 'airtime') {
                $row['provider_name'] = isset($networks[$row['provider_id']]) ? $networks[$row['provider_id']] : 'Unknown';
            } else if ($row['type'] == 'cable') {
                // Get cable provider name
                $cableProvider = 'Unknown';
                try {
                    $cableStmt = $conn->prepare("SELECT name FROM cable_providers WHERE id = ?");
                    $cableStmt->bind_param("i", $row['provider_id']);
                    $cableStmt->execute();
                    $cableResult = $cableStmt->get_result();
                    if ($cableRow = $cableResult->fetch_assoc()) {
                        $cableProvider = $cableRow['name'];
                    }
                } catch (Exception $e) {
                    // Ignore errors
                }
                $row['provider_name'] = $cableProvider;
            } else if ($row['type'] == 'electricity') {
                // Get electricity provider name
                $elecProvider = 'Unknown';
                try {
                    $elecStmt = $conn->prepare("SELECT name FROM electricity_providers WHERE id = ?");
                    $elecStmt->bind_param("i", $row['provider_id']);
                    $elecStmt->execute();
                    $elecResult = $elecStmt->get_result();
                    if ($elecRow = $elecResult->fetch_assoc()) {
                        $elecProvider = $elecRow['name'];
                    }
                } catch (Exception $e) {
                    // Ignore errors
                }
                $row['provider_name'] = $elecProvider;
            }
            
            $beneficiaries[$row['type']][] = $row;
        }
    } catch (Exception $e) {
        // Failed to get beneficiaries
        error_log("Failed to get beneficiaries: " . $e->getMessage());
    }
}
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex flex-col md:flex-row justify-between items-start md:items-center mb-6">
        <h1 class="text-2xl font-bold text-white mb-4 md:mb-0">Saved Beneficiaries</h1>
        
        <div class="flex space-x-2">
            <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm flex items-center">
                <i class="fas fa-plus mr-2"></i> Add Data Beneficiary
            </a>
            <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php" class="py-2 px-4 bg-green-600 hover:bg-green-700 text-white rounded-md text-sm flex items-center">
                <i class="fas fa-plus mr-2"></i> Add Airtime Beneficiary
            </a>
        </div>
    </div>
    
    <?php if (isset($successMessage)): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4">
            <?php echo $successMessage; ?>
        </div>
    <?php endif; ?>
    
    <?php if (isset($errorMessage)): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4">
            <?php echo $errorMessage; ?>
        </div>
    <?php endif; ?>
    
    <?php if (!$tableExists): ?>
        <div class="bg-yellow-500 bg-opacity-20 border border-yellow-400 text-yellow-300 p-4 rounded-md mb-4">
            <p><i class="fas fa-exclamation-triangle mr-2"></i> The beneficiaries system is currently being set up. Please try again later or contact support if the issue persists.</p>
        </div>
    <?php endif; ?>
    
    <div class="bg-gray-800 rounded-lg overflow-hidden">
        <div class="border-b border-gray-700">
            <nav class="-mb-px flex" aria-label="Tabs">
                <button class="tab-button text-white px-4 py-3 font-medium border-b-2 border-indigo-500" data-tab="data">
                    <i class="fas fa-wifi mr-2"></i> Data
                </button>
                <button class="tab-button text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="airtime">
                    <i class="fas fa-phone mr-2"></i> Airtime
                </button>
                <button class="tab-button text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="cable">
                    <i class="fas fa-tv mr-2"></i> Cable TV
                </button>
                <button class="tab-button text-gray-400 hover:text-white px-4 py-3 font-medium border-b-2 border-transparent hover:border-gray-500" data-tab="electricity">
                    <i class="fas fa-bolt mr-2"></i> Electricity
                </button>
            </nav>
        </div>
        
        <!-- Data Beneficiaries -->
        <div id="data-tab" class="tab-content p-4">
            <?php if (empty($beneficiaries['data'])): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-wifi text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Data Beneficiaries</h3>
                    <p class="text-gray-500 text-sm mb-4">You haven't saved any data beneficiaries yet</p>
                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 text-white rounded-md text-sm inline-block">
                        Add Data Beneficiary
                    </a>
                </div>
            <?php else: ?>
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach($beneficiaries['data'] as $beneficiary): ?>
                        <div class="bg-gray-700 rounded-lg p-4">
                            <div class="flex justify-between mb-2">
                                <div class="flex items-center">
                                    <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-wifi text-indigo-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                        <div class="text-sm text-gray-400"><?php echo htmlspecialchars($beneficiary['provider_name']); ?></div>
                                    </div>
                                </div>
                                <div class="flex items-start">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_data.php?phone=<?php echo urlencode($beneficiary['identifier']); ?>&network=<?php echo $beneficiary['provider_id']; ?>" class="text-indigo-400 hover:text-indigo-300 mr-2" title="Buy Data">
                                        <i class="fas fa-shopping-cart"></i>
                                    </a>
                                    <a href="?action=delete&id=<?php echo $beneficiary['id']; ?>" class="text-red-500 hover:text-red-400" title="Delete" onclick="return confirm('Are you sure you want to delete this beneficiary?')">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="bg-gray-800 p-2 rounded text-gray-300 mt-2 text-sm">
                                <i class="fas fa-phone mr-1"></i> <?php echo formatPhoneNumber($beneficiary['identifier']); ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Airtime Beneficiaries -->
        <div id="airtime-tab" class="tab-content p-4 hidden">
            <?php if (empty($beneficiaries['airtime'])): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-phone text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Airtime Beneficiaries</h3>
                    <p class="text-gray-500 text-sm mb-4">You haven't saved any airtime beneficiaries yet</p>
                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php" class="py-2 px-4 bg-green-600 hover:bg-green-700 text-white rounded-md text-sm inline-block">
                        Add Airtime Beneficiary
                    </a>
                </div>
            <?php else: ?>
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach($beneficiaries['airtime'] as $beneficiary): ?>
                        <div class="bg-gray-700 rounded-lg p-4">
                            <div class="flex justify-between mb-2">
                                <div class="flex items-center">
                                    <div class="h-10 w-10 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-phone text-green-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                        <div class="text-sm text-gray-400"><?php echo htmlspecialchars($beneficiary['provider_name']); ?></div>
                                    </div>
                                </div>
                                <div class="flex items-start">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/buy_airtime.php?phone=<?php echo urlencode($beneficiary['identifier']); ?>&network=<?php echo $beneficiary['provider_id']; ?>" class="text-green-400 hover:text-green-300 mr-2" title="Buy Airtime">
                                        <i class="fas fa-shopping-cart"></i>
                                    </a>
                                    <a href="?action=delete&id=<?php echo $beneficiary['id']; ?>" class="text-red-500 hover:text-red-400" title="Delete" onclick="return confirm('Are you sure you want to delete this beneficiary?')">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="bg-gray-800 p-2 rounded text-gray-300 mt-2 text-sm">
                                <i class="fas fa-phone mr-1"></i> <?php echo formatPhoneNumber($beneficiary['identifier']); ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Cable TV Beneficiaries -->
        <div id="cable-tab" class="tab-content p-4 hidden">
            <?php if (empty($beneficiaries['cable'])): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-tv text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Cable TV Beneficiaries</h3>
                    <p class="text-gray-500 text-sm mb-4">You haven't saved any cable TV beneficiaries yet</p>
                    <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php" class="py-2 px-4 bg-purple-600 hover:bg-purple-700 text-white rounded-md text-sm inline-block">
                        Add Cable TV Beneficiary
                    </a>
                </div>
            <?php else: ?>
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach($beneficiaries['cable'] as $beneficiary): ?>
                        <div class="bg-gray-700 rounded-lg p-4">
                            <div class="flex justify-between mb-2">
                                <div class="flex items-center">
                                    <div class="h-10 w-10 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-tv text-purple-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                        <div class="text-sm text-gray-400"><?php echo htmlspecialchars($beneficiary['provider_name']); ?></div>
                                    </div>
                                </div>
                                <div class="flex items-start">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/cable_tv.php?smart_card=<?php echo urlencode($beneficiary['identifier']); ?>&provider=<?php echo $beneficiary['provider_id']; ?>" class="text-purple-400 hover:text-purple-300 mr-2" title="Pay Cable TV">
                                        <i class="fas fa-shopping-cart"></i>
                                    </a>
                                    <a href="?action=delete&id=<?php echo $beneficiary['id']; ?>" class="text-red-500 hover:text-red-400" title="Delete" onclick="return confirm('Are you sure you want to delete this beneficiary?')">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="bg-gray-800 p-2 rounded text-gray-300 mt-2 text-sm">
                                <i class="fas fa-id-card mr-1"></i> <?php echo htmlspecialchars($beneficiary['identifier']); ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Electricity Beneficiaries -->
        <div id="electricity-tab" class="tab-content p-4 hidden">
            <?php if (empty($beneficiaries['electricity'])): ?>
                <div class="text-center py-10">
                    <div class="h-16 w-16 mx-auto mb-3 rounded-full bg-gray-700 flex items-center justify-center">
                        <i class="fas fa-bolt text-2xl text-gray-500"></i>
                    </div>
                    <h3 class="text-gray-400 mb-1">No Electricity Beneficiaries</h3>
                    <p class="text-gray-500 text-sm mb-4">You haven't saved any electricity beneficiaries yet</p>
                    <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php" class="py-2 px-4 bg-yellow-600 hover:bg-yellow-700 text-white rounded-md text-sm inline-block">
                        Add Electricity Beneficiary
                    </a>
                </div>
            <?php else: ?>
                <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                    <?php foreach($beneficiaries['electricity'] as $beneficiary): ?>
                        <div class="bg-gray-700 rounded-lg p-4">
                            <div class="flex justify-between mb-2">
                                <div class="flex items-center">
                                    <div class="h-10 w-10 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                                        <i class="fas fa-bolt text-yellow-400"></i>
                                    </div>
                                    <div>
                                        <div class="font-medium text-white"><?php echo htmlspecialchars($beneficiary['name']); ?></div>
                                        <div class="text-sm text-gray-400"><?php echo htmlspecialchars($beneficiary['provider_name']); ?></div>
                                    </div>
                                </div>
                                <div class="flex items-start">
                                    <a href="<?php echo SITE_URL; ?>/dashboard/electricity.php?meter_number=<?php echo urlencode($beneficiary['identifier']); ?>&provider=<?php echo $beneficiary['provider_id']; ?>" class="text-yellow-400 hover:text-yellow-300 mr-2" title="Pay Electricity">
                                        <i class="fas fa-shopping-cart"></i>
                                    </a>
                                    <a href="?action=delete&id=<?php echo $beneficiary['id']; ?>" class="text-red-500 hover:text-red-400" title="Delete" onclick="return confirm('Are you sure you want to delete this beneficiary?')">
                                        <i class="fas fa-trash"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="bg-gray-800 p-2 rounded text-gray-300 mt-2 text-sm">
                                <i class="fas fa-tachometer-alt mr-1"></i> <?php echo htmlspecialchars($beneficiary['identifier']); ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Tips & Information Card -->
<div class="dashboard-card shadow rounded-lg p-6">
    <h2 class="text-xl font-bold text-white mb-4">
        <i class="fas fa-info-circle mr-2 text-indigo-400"></i> About Beneficiaries
    </h2>
    <div class="bg-gray-800 rounded-lg p-6">
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">What are Beneficiaries?</h3>
            <p class="text-gray-400">
                Beneficiaries allow you to save frequently used recipients for quick access. Save phone numbers, smart card numbers, and meter numbers to make future transactions faster.
            </p>
        </div>
        
        <div class="mb-4">
            <h3 class="text-white font-semibold mb-2">How to Add a Beneficiary</h3>
            <p class="text-gray-400">
                When making a purchase, check the "Save as beneficiary" option and enter a name for your beneficiary. After completing the transaction, the details will be saved here for future use.
            </p>
        </div>
        
        <div>
            <h3 class="text-white font-semibold mb-2">Managing Beneficiaries</h3>
            <p class="text-gray-400">
                You can delete beneficiaries anytime by clicking the delete icon. To make a quick purchase for a saved beneficiary, click the shopping cart icon next to their name.
            </p>
        </div>
    </div>
</div>

<?php
// Helper function to format phone number
function formatPhoneNumber($phoneNumber) {
    // Basic formatting for Nigerian numbers
    if (strlen($phoneNumber) === 11) {
        return substr($phoneNumber, 0, 4) . ' ' . substr($phoneNumber, 4, 3) . ' ' . substr($phoneNumber, 7);
    }
    return $phoneNumber;
}

$extraScripts = <<<EOT
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Tab switching functionality
        const tabButtons = document.querySelectorAll('.tab-button');
        const tabContents = document.querySelectorAll('.tab-content');
        
        tabButtons.forEach(button => {
            button.addEventListener('click', function() {
                const targetTab = this.getAttribute('data-tab');
                
                // Hide all tab contents
                tabContents.forEach(content => {
                    content.classList.add('hidden');
                });
                
                // Reset all tab buttons
                tabButtons.forEach(btn => {
                    btn.classList.remove('text-white', 'border-indigo-500');
                    btn.classList.add('text-gray-400', 'border-transparent');
                });
                
                // Show selected tab content
                document.getElementById(targetTab + '-tab').classList.remove('hidden');
                
                // Highlight selected tab button
                this.classList.remove('text-gray-400', 'border-transparent');
                this.classList.add('text-white', 'border-indigo-500');
            });
        });
    });
</script>
EOT;
?>

<?php require_once './includes/footer.php'; ?>