<?php
// File: /dashboard/service_ids.php
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once './includes/header.php';

// Add the missing adjustBrightness function if not already in your codebase
if (!function_exists('adjustBrightness')) {
    function adjustBrightness($hex, $steps) {
        // Steps should be between -255 and 255. Negative = darker, positive = lighter
        $steps = max(-255, min(255, $steps));

        // Normalize into a six character long hex string
        $hex = str_replace('#', '', $hex);
        if (strlen($hex) == 3) {
            $hex = str_repeat(substr($hex, 0, 1), 2) . str_repeat(substr($hex, 1, 1), 2) . str_repeat(substr($hex, 2, 1), 2);
        }

        // Split into three parts: R, G and B
        $color_parts = str_split($hex, 2);
        $return = '#';

        foreach ($color_parts as $color) {
            $color = hexdec($color); // Convert to decimal
            $color = max(0, min(255, $color + $steps)); // Adjust color
            $return .= str_pad(dechex($color), 2, '0', STR_PAD_LEFT); // Make two char hex code
        }

        return $return;
    }
}

$db = getDB();
$conn = $db->getConnection();

// Get filter parameters
$networkFilter = isset($_GET['network']) ? (int)$_GET['network'] : 0;
$typeFilter = isset($_GET['type']) ? (int)$_GET['type'] : 0;
$searchQuery = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Get all networks for the filter dropdown
$networksStmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY name");
$networksStmt->execute();
$networksResult = $networksStmt->get_result();
$networks = [];
while ($network = $networksResult->fetch_assoc()) {
    $networks[] = $network;
}

// Get all data types for the filter dropdown
$dataTypesStmt = $conn->prepare("SELECT id, name FROM data_types WHERE status = 'active' ORDER BY name");
$dataTypesStmt->execute();
$dataTypesResult = $dataTypesStmt->get_result();
$dataTypes = [];
while ($type = $dataTypesResult->fetch_assoc()) {
    $dataTypes[] = $type;
}

// Build the query with filters
$query = "
    SELECT 
        dp.plan_id,
        dp.name,
        dp.size,
        dp.validity,
        dp.price,
        dp.status,
        n.id AS network_id,
        n.name AS network_name,
        dt.id AS data_type_id,
        dt.name AS data_type_name
    FROM 
        data_plans dp
    JOIN 
        data_types dt ON dp.data_type_id = dt.id
    JOIN 
        networks n ON dt.network_id = n.id
    WHERE 
        1=1
";

$params = [];
$types = "";

if ($networkFilter > 0) {
    $query .= " AND n.id = ?";
    $params[] = $networkFilter;
    $types .= "i";
}

if ($typeFilter > 0) {
    $query .= " AND dt.id = ?";
    $params[] = $typeFilter;
    $types .= "i";
}

if (!empty($searchQuery)) {
    $query .= " AND (dp.plan_id LIKE ? OR dp.name LIKE ?)";
    $searchParam = "%$searchQuery%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "ss";
}

$query .= " ORDER BY dp.plan_id ASC";

// Prepare and execute the query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();

// Get network ID mapping (for API clients)
function getNetworkIdMapping() {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    $simpleId = 1;
    
    while ($row = $result->fetch_assoc()) {
        $mapping[$row['id']] = $simpleId;
        $simpleId++;
    }
    
    return $mapping;
}

$networkIdMapping = getNetworkIdMapping();

// Fetch all plans
$plans = [];
while ($plan = $result->fetch_assoc()) {
    $plans[] = $plan;
}

// Group plans by network for tab-based display
$networkGroups = [];
foreach ($plans as $plan) {
    $networkId = $plan['network_id'];
    if (!isset($networkGroups[$networkId])) {
        $networkGroups[$networkId] = [
            'name' => $plan['network_name'],
            'id' => $networkId,
            'api_id' => $networkIdMapping[$networkId],
            'plans' => []
        ];
    }
    $networkGroups[$networkId]['plans'][] = $plan;
}

// Page title
$pageTitle = "Service IDs Reference";
?>

<div class="container px-6 py-4 mx-auto">
    <div class="dashboard-card shadow-md rounded-lg p-4 mb-6">
        <h1 class="text-xl font-bold text-white mb-4">
            <i class="fas fa-table mr-2 text-primary"></i> Service IDs Reference
        </h1>
        <p class="text-sm text-gray-400 mb-4">
            This page provides the official service IDs for API integration. Use these IDs when making API requests to our platform.
        </p>
        
        <!-- Search and filter -->
        <form method="GET" action="" class="mb-6">
            <div class="bg-gray-800 rounded-lg p-4 border border-gray-700 mb-6">
                <div class="grid grid-cols-1 md:grid-cols-4 gap-4">
                    <!-- Search bar -->
                    <div class="md:col-span-2">
                        <label for="searchInput" class="block text-sm font-medium text-gray-400 mb-1">Search</label>
                        <div class="relative">
                            <div class="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                                <i class="fas fa-search text-gray-500"></i>
                            </div>
                            <input type="text" name="search" id="searchInput" placeholder="Search by ID or name" class="block w-full pl-10 pr-3 py-2 rounded-md bg-gray-700 border border-gray-600 text-white focus:outline-none focus:ring-2 focus:ring-primary focus:border-primary" 
                                value="<?php echo htmlspecialchars($searchQuery ?? ''); ?>">
                            <?php if (!empty($searchQuery)): ?>
                            <div class="absolute inset-y-0 right-0 pr-3 flex items-center cursor-pointer" id="clearSearch">
                                <i class="fas fa-times text-gray-500 hover:text-white"></i>
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    
                    <!-- Network filter -->
                    <div>
                        <label for="networkSelect" class="block text-sm font-medium text-gray-400 mb-1">Network</label>
                        <select name="network" id="networkSelect" class="block w-full py-2 px-3 rounded-md bg-gray-700 border border-gray-600 text-white focus:outline-none focus:ring-2 focus:ring-primary focus:border-primary">
                            <option value="0">All Networks</option>
                            <?php foreach ($networks as $network): ?>
                            <option value="<?php echo $network['id']; ?>" <?php echo ($networkFilter == $network['id']) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($network['name']); ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <!-- Data type filter -->
                    <div>
                        <label for="typeSelect" class="block text-sm font-medium text-gray-400 mb-1">Data Type</label>
                        <select name="type" id="typeSelect" class="block w-full py-2 px-3 rounded-md bg-gray-700 border border-gray-600 text-white focus:outline-none focus:ring-2 focus:ring-primary focus:border-primary">
                            <option value="0">All Data Types</option>
                            <?php foreach ($dataTypes as $type): ?>
                            <option value="<?php echo $type['id']; ?>" <?php echo ($typeFilter == $type['id']) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($type['name']); ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
                
                <div class="flex items-center justify-between mt-4">
                    <div>
                        <?php if (!empty($searchQuery) || $networkFilter > 0 || $typeFilter > 0): ?>
                        <div class="flex flex-wrap gap-2">
                            <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-primary bg-opacity-20 text-primary">
                                <i class="fas fa-filter mr-1"></i> Filters applied
                            </span>
                            
                            <?php if (!empty($searchQuery)): ?>
                            <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-700 text-gray-300">
                                Search: <?php echo htmlspecialchars($searchQuery); ?>
                            </span>
                            <?php endif; ?>
                            
                            <?php if ($networkFilter > 0): 
                                $selectedNetwork = array_filter($networks, function($n) use ($networkFilter) { return $n['id'] == $networkFilter; });
                                $selectedNetwork = reset($selectedNetwork);
                            ?>
                            <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-700 text-gray-300">
                                Network: <?php echo htmlspecialchars($selectedNetwork['name'] ?? ''); ?>
                            </span>
                            <?php endif; ?>
                            
                            <?php if ($typeFilter > 0): 
                                $selectedType = array_filter($dataTypes, function($t) use ($typeFilter) { return $t['id'] == $typeFilter; });
                                $selectedType = reset($selectedType);
                            ?>
                            <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-700 text-gray-300">
                                Type: <?php echo htmlspecialchars($selectedType['name'] ?? ''); ?>
                            </span>
                            <?php endif; ?>
                        </div>
                        <?php endif; ?>
                    </div>
                    
                    <div class="flex space-x-2">
                        <?php if (!empty($searchQuery) || $networkFilter > 0 || $typeFilter > 0): ?>
                        <a href="service_ids.php" class="inline-flex items-center px-3 py-2 text-sm font-medium rounded-md text-white bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary">
                            <i class="fas fa-times mr-1.5"></i> Clear
                        </a>
                        <?php endif; ?>
                        
                        <button type="submit" class="inline-flex items-center px-3 py-2 text-sm font-medium rounded-md text-white bg-primary hover:bg-primary-dark focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary">
                            <i class="fas fa-filter mr-1.5"></i> Filter
                        </button>
                    </div>
                </div>
            </div>
        </form>

        <?php if (count($plans) === 0): ?>
        <!-- Empty state -->
        <div class="bg-gray-800 rounded-lg p-10 text-center border border-gray-700">
            <div class="py-5">
                <i class="fas fa-search fa-3x mb-3 text-gray-500"></i>
                <h4 class="text-xl font-semibold text-white">No services found</h4>
                <p class="text-gray-400 mt-2">No services match your filter criteria.</p>
                <a href="service_ids.php" class="mt-4 inline-flex items-center px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-primary hover:bg-primary-dark focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary">
                    <i class="fas fa-times mr-2"></i> Clear filters
                </a>
            </div>
        </div>
        <?php else: ?>

        <!-- Network tabs - only show when not filtering -->
        <?php if (empty($searchQuery) && $networkFilter == 0 && $typeFilter == 0): ?>
        <div class="mb-6 border-b border-gray-700">
            <ul class="flex flex-wrap -mb-px text-sm font-medium text-center" id="networkTabs" role="tablist">
                <li class="mr-2" role="presentation">
                    <button class="inline-block p-4 border-b-2 border-primary text-primary rounded-t-lg active" id="all-tab" data-tabs-target="#all-content" type="button" role="tab" aria-controls="all-content" aria-selected="true">
                        <i class="fas fa-layer-group mr-2"></i>All Services
                    </button>
                </li>
                <?php foreach ($networkGroups as $networkId => $network): ?>
                <li class="mr-2" role="presentation">
                    <button class="inline-block p-4 border-b-2 border-transparent hover:text-white hover:border-gray-400 rounded-t-lg" id="network-<?php echo $networkId; ?>-tab" data-tabs-target="#network-<?php echo $networkId; ?>-content" type="button" role="tab">
                        <i class="fas fa-broadcast-tower mr-2"></i><?php echo htmlspecialchars($network['name']); ?>
                    </button>
                </li>
                <?php endforeach; ?>
            </ul>
        </div>
        
        <div id="networkTabsContent">
            <div class="block" id="all-content" role="tabpanel" aria-labelledby="all-tab">
        <?php endif; ?>
        
        <!-- Main data table -->
        <div class="overflow-hidden shadow-md rounded-lg border border-gray-700">
            <div class="bg-gray-800 py-3 px-4 flex justify-between items-center border-b border-gray-700">
                <div class="flex items-center">
                    <i class="fas fa-table text-primary mr-2"></i>
                    <h2 class="text-lg font-semibold text-white">Data Services</h2>
                </div>
                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-primary bg-opacity-20 text-primary">
                    <?php echo count($plans); ?> services
                </span>
            </div>
            <div class="overflow-x-auto">
                <table class="min-w-full divide-y divide-gray-700">
                    <thead class="bg-gray-800">
                        <tr>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan ID</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Network ID</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Name</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Size</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Validity</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Price</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Data Type</th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                        </tr>
                    </thead>
                    <tbody class="bg-gray-900 divide-y divide-gray-800">
                        <?php foreach ($plans as $plan): ?>
                        <tr class="hover:bg-gray-800">
                            <td class="px-6 py-4 whitespace-nowrap">
                                <span class="inline-flex items-center px-2.5 py-1 rounded-md text-sm font-medium bg-primary bg-opacity-20 text-primary">
                                    <?php echo htmlspecialchars($plan['plan_id'] ?? ''); ?>
                                </span>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo htmlspecialchars($plan['network_name'] ?? ''); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <span class="inline-flex items-center px-2.5 py-1 rounded-md text-xs font-medium bg-blue-900 bg-opacity-40 text-blue-400">
                                    <?php echo isset($networkIdMapping[$plan['network_id']]) ? $networkIdMapping[$plan['network_id']] : 'N/A'; ?>
                                </span>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo htmlspecialchars($plan['name'] ?? ''); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo htmlspecialchars($plan['size'] ?? ''); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo htmlspecialchars($plan['validity'] ?? ''); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo $currency . number_format((float)($plan['price'] ?? 0), 2); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                <?php echo htmlspecialchars($plan['data_type_name'] ?? ''); ?>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium <?php echo ($plan['status'] == 'active') ? 'bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300' : 'bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300'; ?>">
                                    <?php echo ucfirst($plan['status'] ?? 'unknown'); ?>
                                </span>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        
        <?php if (empty($searchQuery) && $networkFilter == 0 && $typeFilter == 0): ?>
            </div> <!-- End of all-content tab pane -->
            
            <!-- Individual network tabs -->
            <?php foreach ($networkGroups as $networkId => $network): ?>
            <div class="hidden" id="network-<?php echo $networkId; ?>-content" role="tabpanel">
                <div class="overflow-hidden shadow-md rounded-lg border border-gray-700">
                    <div class="bg-gray-800 py-3 px-4 flex justify-between items-center border-b border-gray-700">
                        <div class="flex items-center">
                            <i class="fas fa-broadcast-tower text-primary mr-2"></i>
                            <h2 class="text-lg font-semibold text-white"><?php echo htmlspecialchars($network['name']); ?> Data Services</h2>
                            <span class="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-blue-900 bg-opacity-40 text-blue-400">
                                Network ID: <?php echo $network['api_id']; ?>
                            </span>
                        </div>
                        <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-primary bg-opacity-20 text-primary">
                            <?php echo count($network['plans']); ?> services
                        </span>
                    </div>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-700">
                            <thead class="bg-gray-800">
                                <tr>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Plan ID</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Name</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Size</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Validity</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Price</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Data Type</th>
                                    <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">Status</th>
                                </tr>
                            </thead>
                            <tbody class="bg-gray-900 divide-y divide-gray-800">
                                <?php foreach ($network['plans'] as $plan): ?>
                                <tr class="hover:bg-gray-800">
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <span class="inline-flex items-center px-2.5 py-1 rounded-md text-sm font-medium bg-primary bg-opacity-20 text-primary">
                                            <?php echo htmlspecialchars($plan['plan_id'] ?? ''); ?>
                                        </span>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php echo htmlspecialchars($plan['name'] ?? ''); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php echo htmlspecialchars($plan['size'] ?? ''); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php echo htmlspecialchars($plan['validity'] ?? ''); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php echo $currency . number_format((float)($plan['price'] ?? 0), 2); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap text-sm text-white">
                                        <?php echo htmlspecialchars($plan['data_type_name'] ?? ''); ?>
                                    </td>
                                    <td class="px-6 py-4 whitespace-nowrap">
                                        <span class="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium <?php echo ($plan['status'] == 'active') ? 'bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300' : 'bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300'; ?>">
                                            <?php echo ucfirst($plan['status'] ?? 'unknown'); ?>
                                        </span>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
            <?php endforeach; ?>
        </div> <!-- End of tab-content -->
        <?php endif; ?>
        <?php endif; ?>

        <!-- API Integration Guide -->
        <div class="mt-6 bg-gray-800 border border-gray-700 rounded-lg shadow-md p-6">
            <h2 class="text-lg font-bold text-white mb-4 flex items-center">
                <i class="fas fa-code text-primary mr-2"></i> API Integration Guide
            </h2>
            <p class="text-sm text-gray-400 mb-4">Use these service IDs to integrate with our API. Below are examples of how to use them in your requests:</p>
            
            <div class="bg-gray-900 border border-gray-700 rounded-lg p-4 mb-4">
                <div class="flex items-start">
                    <div class="flex-shrink-0 mt-0.5">
                        <i class="fas fa-info-circle text-blue-400"></i>
                    </div>
                    <div class="ml-3">
                        <p class="text-sm text-gray-300">
                            <strong class="text-white">Important:</strong> Always use the Plan IDs and Network IDs as shown in the tables above for API requests.
                        </p>
                    </div>
                </div>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mt-4">
                <div>
                    <div class="mb-2 text-white font-medium"><i class="fas fa-code-branch mr-2 text-primary"></i>API v1</div>
                    <div class="relative rounded-md bg-gray-900 border border-gray-700 overflow-hidden">
                        <div class="absolute top-0 right-0 p-1">
                            <button class="copy-code rounded bg-gray-800 hover:bg-gray-700 text-xs text-white px-2 py-1" id="copyV1">Copy</button>
                        </div>
                        <pre class="p-4 text-sm overflow-x-auto text-gray-300"><code>POST /api/v1/buy_data
{
  "plan_id": 5,     // The Plan ID from the table
  "phone": "08012345678",
  "reference": "optional-reference"
}</code></pre>
                    </div>
                </div>
                
                <div>
                    <div class="mb-2 text-white font-medium"><i class="fas fa-code-branch mr-2 text-primary"></i>API v2</div>
                    <div class="relative rounded-md bg-gray-900 border border-gray-700 overflow-hidden">
                        <div class="absolute top-0 right-0 p-1">
                            <button class="copy-code rounded bg-gray-800 hover:bg-gray-700 text-xs text-white px-2 py-1" id="copyV2">Copy</button>
                        </div>
                        <pre class="p-4 text-sm overflow-x-auto text-gray-300"><code>POST /api/v2/data
{
  "network": 1,      // The Network ID from the table
  "mobile_number": "08012345678",
  "plan": 5,         // The Plan ID from the table
  "request_id": "optional-request-id"
}</code></pre>
                    </div>
                </div>
            </div>
            
            <div class="mt-6 text-center">
                <a href="/api/documentation" class="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-primary hover:bg-primary-dark focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary">
                    <i class="fas fa-book mr-2"></i> View Complete API Documentation
                </a>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Tab functionality
    const tabLinks = document.querySelectorAll('[data-tabs-target]');
    const tabContents = document.querySelectorAll('[role="tabpanel"]');
    
    tabLinks.forEach(tabLink => {
        tabLink.addEventListener('click', () => {
            const target = document.querySelector(tabLink.dataset.tabsTarget);
            
            // Hide all tab contents
            tabContents.forEach(content => {
                content.classList.add('hidden');
                content.classList.remove('block');
            });
            
            // Remove active class from all tab links
            tabLinks.forEach(link => {
                link.classList.remove('border-primary', 'text-primary');
                link.classList.add('border-transparent', 'hover:text-white', 'hover:border-gray-400');
                link.setAttribute('aria-selected', 'false');
            });
            
            // Show the selected tab content
            target.classList.remove('hidden');
            target.classList.add('block');
            
            // Add active class to the clicked tab link
            tabLink.classList.remove('border-transparent', 'hover:text-white', 'hover:border-gray-400');
            tabLink.classList.add('border-primary', 'text-primary');
            tabLink.setAttribute('aria-selected', 'true');
        });
    });
    
    // Clear search button
    const clearSearchBtn = document.getElementById('clearSearch');
    if (clearSearchBtn) {
        clearSearchBtn.addEventListener('click', function() {
            document.getElementById('searchInput').value = '';
            
            // Update URL to remove search parameter but keep other parameters
            const url = new URL(window.location.href);
            url.searchParams.delete('search');
            window.location.href = url.toString();
        });
    }
    
    // Copy code buttons
    const copyButtons = document.querySelectorAll('.copy-code');
    copyButtons.forEach(button => {
        button.addEventListener('click', () => {
            const codeElement = button.closest('.relative').querySelector('code');
            const textToCopy = codeElement.textContent;
            
            navigator.clipboard.writeText(textToCopy).then(() => {
                const originalText = button.textContent;
                button.textContent = 'Copied!';
                setTimeout(() => {
                    button.textContent = originalText;
                }, 2000);
            }).catch(err => {
                console.error('Could not copy text: ', err);
                button.textContent = 'Failed!';
                setTimeout(() => {
                    button.textContent = 'Copy';
                }, 2000);
            });
        });
    });
});
</script>

<?php require_once './includes/footer.php'; ?>