<?php
// File: /api/service_id.php
require_once dirname(__DIR__) . '/../includes/config.php';
require_once dirname(__DIR__) . '/../includes/functions.php';

// Check if user is admin, or redirect to login

$db = getDB();
$conn = $db->getConnection();

// Get filter parameters
$networkFilter = isset($_GET['network']) ? (int)$_GET['network'] : 0;
$typeFilter = isset($_GET['type']) ? (int)$_GET['type'] : 0;
$searchQuery = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Get all networks for the filter dropdown
$networksStmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY name");
$networksStmt->execute();
$networksResult = $networksStmt->get_result();
$networks = [];
while ($network = $networksResult->fetch_assoc()) {
    $networks[] = $network;
}

// Get all data types for the filter dropdown
$dataTypesStmt = $conn->prepare("SELECT id, name FROM data_types WHERE status = 'active' ORDER BY name");
$dataTypesStmt->execute();
$dataTypesResult = $dataTypesStmt->get_result();
$dataTypes = [];
while ($type = $dataTypesResult->fetch_assoc()) {
    $dataTypes[] = $type;
}

// Build the query with filters
$query = "
    SELECT 
        dp.id AS internal_id,
        dp.plan_id,
        dp.name,
        dp.size,
        dp.validity,
        dp.price,
        dp.status,
        n.id AS network_id,
        n.name AS network_name,
        dt.id AS data_type_id,
        dt.name AS data_type_name
    FROM 
        data_plans dp
    JOIN 
        data_types dt ON dp.data_type_id = dt.id
    JOIN 
        networks n ON dt.network_id = n.id
    WHERE 
        1=1
";

$params = [];
$types = "";

if ($networkFilter > 0) {
    $query .= " AND n.id = ?";
    $params[] = $networkFilter;
    $types .= "i";
}

if ($typeFilter > 0) {
    $query .= " AND dt.id = ?";
    $params[] = $typeFilter;
    $types .= "i";
}

if (!empty($searchQuery)) {
    $query .= " AND (dp.plan_id LIKE ? OR dp.name LIKE ?)";
    $searchParam = "%$searchQuery%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "ss";
}

$query .= " ORDER BY n.name, dt.name, dp.plan_id, dp.price";

// Prepare and execute the query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();

// Get network ID mapping (for API clients)
function getNetworkIdMapping() {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    $simpleId = 1;
    
    while ($row = $result->fetch_assoc()) {
        $mapping[$row['id']] = $simpleId;
        $simpleId++;
    }
    
    return $mapping;
}

$networkIdMapping = getNetworkIdMapping();

// Page title
$pageTitle = "Service IDs";
include_once dirname(__DIR__) . '/dashboard/includes/header.php';
?>

<div class="container-fluid py-4">
    <div class="row">
        <div class="col-12">
            <div class="card mb-4">
                <div class="card-header pb-0 d-flex justify-content-between align-items-center">
                    <h6 class="mb-0">Service IDs</h6>
                    
                    <div class="d-flex">
                        <form class="d-flex" method="GET" action="">
                            <div class="input-group me-2" style="width: 300px;">
                                <input type="text" class="form-control" placeholder="Search by ID or name" name="search" value="<?php echo htmlspecialchars($searchQuery); ?>">
                                <button class="btn btn-outline-primary" type="submit">
                                    <i class="fas fa-search"></i>
                                </button>
                            </div>
                            
                            <select name="network" class="form-select me-2" onchange="this.form.submit()">
                                <option value="0">All Networks</option>
                                <?php foreach ($networks as $network): ?>
                                <option value="<?php echo $network['id']; ?>" <?php echo ($networkFilter == $network['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($network['name']); ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                            
                            <select name="type" class="form-select me-2" onchange="this.form.submit()">
                                <option value="0">All Data Types</option>
                                <?php foreach ($dataTypes as $type): ?>
                                <option value="<?php echo $type['id']; ?>" <?php echo ($typeFilter == $type['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($type['name']); ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                            
                            <?php if (!empty($searchQuery) || $networkFilter > 0 || $typeFilter > 0): ?>
                            <a href="service_id.php" class="btn btn-outline-secondary">
                                <i class="fas fa-times"></i> Clear
                            </a>
                            <?php endif; ?>
                        </form>
                    </div>
                </div>
                
                <div class="card-body px-0 pt-0 pb-2">
                    <div class="table-responsive p-0">
                        <table class="table align-items-center mb-0">
                            <thead>
                                <tr>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Network</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Network ID</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Plan ID</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Name</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Size</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Validity</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Price</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Data Type</th>
                                    <th class="text-uppercase text-secondary text-xxs font-weight-bolder opacity-7">Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if ($result->num_rows === 0): ?>
                                <tr>
                                    <td colspan="9" class="text-center py-4">No services found</td>
                                </tr>
                                <?php else: ?>
                                <?php while ($plan = $result->fetch_assoc()): ?>
                                <tr>
                                    <td class="ps-4">
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['network_name']); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo isset($networkIdMapping[$plan['network_id']]) ? $networkIdMapping[$plan['network_id']] : 'N/A'; ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['plan_id']); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['name']); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['size']); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['validity']); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo number_format($plan['price'], 2); ?></p>
                                    </td>
                                    <td>
                                        <p class="text-xs font-weight-bold mb-0"><?php echo htmlspecialchars($plan['data_type_name']); ?></p>
                                    </td>
                                    <td>
                                        <span class="badge badge-sm bg-<?php echo ($plan['status'] == 'active') ? 'success' : 'danger'; ?>">
                                            <?php echo ucfirst($plan['status']); ?>
                                        </span>
                                    </td>
                                </tr>
                                <?php endwhile; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <div class="row mt-4">
        <div class="col-12">
            <div class="card">
                <div class="card-header pb-0">
                    <h6>API Documentation</h6>
                </div>
                <div class="card-body">
                    <p>To use these service IDs in your API requests, use the following formats:</p>
                    
                    <div class="mb-3">
                        <h6 class="text-primary">API v1:</h6>
                        <pre><code>POST /api/v1/buy_data
{
    "plan_id": [PLAN_ID],
    "phone": "08012345678",
    "reference": "optional-reference"
}</code></pre>
                    </div>
                    
                    <div>
                        <h6 class="text-primary">API v2:</h6>
                        <pre><code>POST /api/v2/data
{
    "network": [NETWORK_ID],
    "mobile_number": "08012345678",
    "plan": [PLAN_ID],
    "request_id": "optional-request-id"
}</code></pre>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include_once dirname(__DIR__) . '/dashboard/includes/footer.php'; ?>