<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

$db = getDB();
$conn = $db->getConnection();

$errors = [];
$success = '';

// Check if user has an existing PIN
$hasPin = !empty($user['pin']);

// Get pin verification preference (default is enabled)
$pinVerificationEnabled = true;
if (isset($user['pin_verification_enabled'])) {
    $pinVerificationEnabled = (bool)$user['pin_verification_enabled'];
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if this is a PIN toggle request
    if (isset($_POST['toggle_pin_verification'])) {
        $newStatus = isset($_POST['pin_verification_enabled']);
        
        // Update user's PIN verification preference
        $stmt = $conn->prepare("UPDATE users SET pin_verification_enabled = ? WHERE id = ?");
        $statusInt = $newStatus ? 1 : 0;
        $stmt->bind_param("ii", $statusInt, $userId);
        
        if ($stmt->execute()) {
            $success = $newStatus ? 'PIN verification has been enabled.' : 'PIN verification has been disabled.';
            $pinVerificationEnabled = $newStatus;
        } else {
            $errors[] = 'Failed to update PIN verification setting: ' . $conn->error;
        }
    } else {
        // Get form data for setting/changing PIN
        $currentPin = isset($_POST['current_pin']) ? $_POST['current_pin'] : '';
        $newPin = isset($_POST['new_pin']) ? $_POST['new_pin'] : '';
        $confirmPin = isset($_POST['confirm_pin']) ? $_POST['confirm_pin'] : '';
        
        // Validate inputs
        if ($hasPin && empty($currentPin)) {
            $errors[] = 'Current PIN is required';
        } elseif ($hasPin && !password_verify($currentPin, $user['pin'])) {
            $errors[] = 'Current PIN is incorrect';
        }
        
        if (empty($newPin)) {
            $errors[] = 'New PIN is required';
        } elseif (!preg_match('/^[0-9]{4}$/', $newPin)) {
            $errors[] = 'PIN must be exactly 4 digits';
        }
        
        if (empty($confirmPin)) {
            $errors[] = 'Confirm PIN is required';
        } elseif ($newPin !== $confirmPin) {
            $errors[] = 'PINs do not match';
        }
        
        // If no errors, update PIN
        if (empty($errors)) {
            // Hash the new PIN
            $hashedPin = password_hash($newPin, PASSWORD_DEFAULT);
            
            // Update user record
            $stmt = $conn->prepare("UPDATE users SET pin = ? WHERE id = ?");
            $stmt->bind_param("si", $hashedPin, $userId);
            
            if ($stmt->execute()) {
                $success = $hasPin ? 'PIN updated successfully!' : 'PIN set successfully!';
                
                // Refresh user data
                $user = getUserById($userId);
                $hasPin = true;
            } else {
                $errors[] = 'Failed to update PIN: ' . $conn->error;
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $hasPin ? 'Change PIN' : 'Set PIN'; ?> - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .pin-input {
            font-size: 1.875rem;
            letter-spacing: 0.5rem;
            text-align: center;
        }
        
        /* Toggle switch styles */
        .toggle-switch {
            position: relative;
            display: inline-block;
            width: 60px;
            height: 34px;
        }
        
        .toggle-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }
        
        .slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #444;
            transition: .4s;
            border-radius: 34px;
        }
        
        .slider:before {
            position: absolute;
            content: "";
            height: 26px;
            width: 26px;
            left: 4px;
            bottom: 4px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }
        
        input:checked + .slider {
            background-color: var(--accent-color);
        }
        
        input:focus + .slider {
            box-shadow: 0 0 1px var(--accent-color);
        }
        
        input:checked + .slider:before {
            transform: translateX(26px);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <?php echo substr($user['username'], 0, 1); ?>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($user['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="change_password.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Change Password</a>
                        <a href="set_pin.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Set Transaction PIN</a>
                        <a href="api_tokens.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Tokens</a>
                        <a href="../login/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="dashboard-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <ul class="space-y-2">
                    <li>
                        <a href="index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-home mr-3"></i>
                            <span>Dashboard</span>
                        </a>
                    </li>
                    <li>
                        <a href="fund_wallet.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wallet mr-3"></i>
                            <span>Fund Wallet</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_data.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wifi mr-3"></i>
                            <span>Buy Data</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_airtime.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-phone mr-3"></i>
                            <span>Buy Airtime</span>
                        </a>
                    </li>
                    <li>
                        <a href="transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-exchange-alt mr-3"></i>
                            <span>Transactions</span>
                        </a>
                    </li>
                    
                    <!-- Show upgrade option only for smart users -->
                    <?php if ($user['user_type'] === 'smart'): ?>
                    <li>
                        <a href="upgrade.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-arrow-up mr-3"></i>
                            <span>Upgrade Account</span>
                        </a>
                    </li>
                    <?php endif; ?>
                    
                    <!-- Show developer section for API users -->
                    <?php if ($user['user_type'] === 'api'): ?>
                    <li>
                        <a href="api_documentation.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-code mr-3"></i>
                            <span>API Documentation</span>
                        </a>
                    </li>
                    <?php endif; ?>
                </ul>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white"><?php echo $hasPin ? 'Change Transaction PIN' : 'Set Transaction PIN'; ?></h1>
                <div class="text-right">
                    <p class="text-sm text-gray-400">Wallet Balance</p>
                    <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
                </div>
            </div>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if ($hasPin): ?>
            <!-- PIN Verification Toggle -->
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4">PIN Verification Settings</h2>
                
                <form method="POST" action="">
                    <div class="flex items-center justify-between">
                        <div>
                            <h3 class="font-medium text-white">Require PIN for Transactions</h3>
                            <p class="text-sm text-gray-400 mt-1">
                                When enabled, you'll need to enter your PIN for all purchases and sensitive operations.
                                <br>Turn this off if you want to skip PIN verification.
                            </p>
                        </div>
                        <label class="toggle-switch">
                            <input type="checkbox" name="pin_verification_enabled" <?php echo $pinVerificationEnabled ? 'checked' : ''; ?>>
                            <span class="slider"></span>
                        </label>
                    </div>
                    <input type="hidden" name="toggle_pin_verification" value="1">
                    <div class="flex justify-end mt-4">
                        <button type="submit" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Save Settings
                        </button>
                    </div>
                </form>
            </div>
            <?php endif; ?>
            
            <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold text-white mb-4"><?php echo $hasPin ? 'Change Your PIN' : 'Set Your PIN'; ?></h2>
                
                <form method="POST" action="">
                    <?php if ($hasPin): ?>
                        <div class="mb-4">
                            <label for="current_pin" class="block text-sm font-medium text-gray-400 mb-1">Current PIN</label>
                            <input type="password" id="current_pin" name="current_pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                        </div>
                    <?php endif; ?>
                    
                    <div class="mb-4">
                        <label for="new_pin" class="block text-sm font-medium text-gray-400 mb-1">New PIN</label>
                        <input type="password" id="new_pin" name="new_pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                    </div>
                    
                    <div class="mb-6">
                        <label for="confirm_pin" class="block text-sm font-medium text-gray-400 mb-1">Confirm PIN</label>
                        <input type="password" id="confirm_pin" name="confirm_pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                    </div>
                    
                    <div class="mb-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                        <h3 class="font-semibold text-yellow-300 mb-2">Important Notes:</h3>
                        <ul class="list-disc pl-5 space-y-1 text-sm text-yellow-200">
                            <li>Your transaction PIN is used to authorize purchases and sensitive operations.</li>
                            <li>Choose a 4-digit PIN that's easy for you to remember but hard for others to guess.</li>
                            <li>Do not share your PIN with anyone, including our support staff.</li>
                            <li>If you forget your PIN, you will need to reset it using your account password.</li>
                        </ul>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            <?php echo $hasPin ? 'Update PIN' : 'Set PIN'; ?>
                        </button>
                    </div>
                </form>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Numeric input validation
        const pinInputs = document.querySelectorAll('input[type="password"][pattern]');
        pinInputs.forEach(input => {
            input.addEventListener('input', (e) => {
                e.target.value = e.target.value.replace(/[^0-9]/g, '').substring(0, 4);
            });
        });
    </script>
</body>
</html>