<?php
require_once '../includes/config.php';
require_once '../includes/functions.php'; 
require_once './includes/header.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

$db = getDB();
$conn = $db->getConnection();

// Pagination settings
$perPage = 20;
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $perPage;

// Filter settings
$type = isset($_GET['type']) ? sanitizeInput($_GET['type']) : '';
$status = isset($_GET['status']) ? sanitizeInput($_GET['status']) : '';
$startDate = isset($_GET['start_date']) ? sanitizeInput($_GET['start_date']) : '';
$endDate = isset($_GET['end_date']) ? sanitizeInput($_GET['end_date']) : '';

// Build query
$query = "SELECT * FROM transactions WHERE user_id = ?";
$countQuery = "SELECT COUNT(*) as total FROM transactions WHERE user_id = ?";
$params = [$userId];
$types = "i";

if ($type) {
    $query .= " AND type = ?";
    $countQuery .= " AND type = ?";
    $params[] = $type;
    $types .= "s";
}

if ($status) {
    $query .= " AND status = ?";
    $countQuery .= " AND status = ?";
    $params[] = $status;
    $types .= "s";
}

if ($startDate) {
    $query .= " AND DATE(created_at) >= ?";
    $countQuery .= " AND DATE(created_at) >= ?";
    $params[] = $startDate;
    $types .= "s";
}

if ($endDate) {
    $query .= " AND DATE(created_at) <= ?";
    $countQuery .= " AND DATE(created_at) <= ?";
    $params[] = $endDate;
    $types .= "s";
}

// Order by latest first
$query .= " ORDER BY created_at DESC LIMIT ?, ?";
$params[] = $offset;
$params[] = $perPage;
$types .= "ii";

// Prepare and execute query
$stmt = $conn->prepare($query);
$stmt->bind_param($types, ...$params);
$stmt->execute();
$result = $stmt->get_result();
$transactions = [];

while ($row = $result->fetch_assoc()) {
    $transactions[] = $row;
}

// Get total records for pagination
$countStmt = $conn->prepare($countQuery);
$countStmt->bind_param(substr($types, 0, -2), ...array_slice($params, 0, -2));
$countStmt->execute();
$countResult = $countStmt->get_result();
$totalRecords = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $perPage);

// Transaction detail modal
$selectedTransaction = null;
if (isset($_GET['view']) && is_numeric($_GET['view'])) {
    $transactionId = (int)$_GET['view'];
    $stmt = $conn->prepare("SELECT * FROM transactions WHERE id = ? AND user_id = ?");
    $stmt->bind_param("ii", $transactionId, $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $selectedTransaction = $result->fetch_assoc();
    }
}
?>

        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Transaction History</h1>
                <div class="text-right">
                    <p class="text-sm text-gray-400">Wallet Balance</p>
                    <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
                </div>
            </div>
            
            <!-- Filters -->
            <div class="dashboard-card rounded-lg shadow-md p-4 mb-6">
                <form method="GET" action="" class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4">
                    <div>
                        <label for="type" class="block text-sm font-medium text-gray-400 mb-1">Transaction Type</label>
                        <select id="type" name="type" class="form-select block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Types</option>
                            <option value="funding" <?php echo $type === 'funding' ? 'selected' : ''; ?>>Funding</option>
                            <option value="data" <?php echo $type === 'data' ? 'selected' : ''; ?>>Data</option>
                            <option value="airtime" <?php echo $type === 'airtime' ? 'selected' : ''; ?>>Airtime</option>
                            <option value="cable" <?php echo $type === 'cable' ? 'selected' : ''; ?>>Cable</option>
                            <option value="electricity" <?php echo $type === 'electricity' ? 'selected' : ''; ?>>Electricity</option>
                            <option value="withdrawal" <?php echo $type === 'withdrawal' ? 'selected' : ''; ?>>Withdrawal</option>
                            <option value="transfer" <?php echo $type === 'transfer' ? 'selected' : ''; ?>>Transfer</option>
                            <option value="upgrade" <?php echo $type === 'upgrade' ? 'selected' : ''; ?>>Upgrade</option>
                            <option value="bonus" <?php echo $type === 'bonus' ? 'selected' : ''; ?>>Bonus</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="status" class="block text-sm font-medium text-gray-400 mb-1">Status</label>
                        <select id="status" name="status" class="form-select block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                            <option value="">All Statuses</option>
                            <option value="pending" <?php echo $status === 'pending' ? 'selected' : ''; ?>>Pending</option>
                            <option value="successful" <?php echo $status === 'successful' ? 'selected' : ''; ?>>Successful</option>
                            <option value="failed" <?php echo $status === 'failed' ? 'selected' : ''; ?>>Failed</option>
                        </select>
                    </div>
                    
                    <div>
                        <label for="start_date" class="block text-sm font-medium text-gray-400 mb-1">Start Date</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $startDate; ?>" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    </div>
                    
                    <div>
                        <label for="end_date" class="block text-sm font-medium text-gray-400 mb-1">End Date</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $endDate; ?>" class="form-input block w-full rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                    </div>
                    
                    <div class="md:col-span-2 lg:col-span-4 flex justify-end">
                        <button type="submit" class="accent-button py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Filter Results
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Transaction Table -->
            <div class="dashboard-card rounded-lg shadow-md overflow-hidden mb-6">
                <?php if (empty($transactions)): ?>
                    <div class="p-6 text-center text-gray-400">
                        <i class="fas fa-search text-4xl mb-3"></i>
                        <p>No transactions found</p>
                    </div>
                <?php else: ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full">
                            <thead class="table-header">
                                <tr>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">ID</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Type</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Amount</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Status</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Date</th>
                                    <th class="py-3 px-4 text-left text-sm font-medium text-gray-300 uppercase tracking-wider">Action</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($transactions as $transaction): ?>
                                    <tr class="table-row border-t">
                                        <td class="py-3 px-4 text-sm"><?php echo $transaction['id']; ?></td>
                                        <td class="py-3 px-4 text-sm">
                                            <?php 
                                                $typeIcon = '';
                                                switch ($transaction['type']) {
                                                    case 'funding':
                                                        $typeIcon = '<i class="fas fa-money-bill-wave text-green-500 mr-2"></i>';
                                                        break;
                                                    case 'data':
                                                        $typeIcon = '<i class="fas fa-wifi text-blue-500 mr-2"></i>';
                                                        break;
                                                    case 'airtime':
                                                        $typeIcon = '<i class="fas fa-phone text-purple-500 mr-2"></i>';
                                                        break;
                                                    case 'cable':
                                                        $typeIcon = '<i class="fas fa-tv text-red-500 mr-2"></i>';
                                                        break;
                                                    case 'electricity':
                                                        $typeIcon = '<i class="fas fa-bolt text-yellow-500 mr-2"></i>';
                                                        break;
                                                    case 'withdrawal':
                                                        $typeIcon = '<i class="fas fa-hand-holding-usd text-red-500 mr-2"></i>';
                                                        break;
                                                    case 'transfer':
                                                        $typeIcon = '<i class="fas fa-exchange-alt text-blue-500 mr-2"></i>';
                                                        break;
                                                    case 'upgrade':
                                                        $typeIcon = '<i class="fas fa-arrow-up text-indigo-500 mr-2"></i>';
                                                        break;
                                                    case 'bonus':
                                                        $typeIcon = '<i class="fas fa-gift text-pink-500 mr-2"></i>';
                                                        break;
                                                    default:
                                                        $typeIcon = '<i class="fas fa-circle text-gray-500 mr-2"></i>';
                                                }
                                                echo $typeIcon . ucfirst($transaction['type']);
                                            ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm">
                                            <?php echo formatAmount($transaction['amount']); ?>
                                            <?php if ($transaction['fee'] > 0): ?>
                                                <span class="text-xs text-gray-400 block">Fee: <?php echo formatAmount($transaction['fee']); ?></span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="py-3 px-4 text-sm">
                                            <span class="status-badge <?php echo 'status-' . $transaction['status']; ?>">
                                                <?php echo ucfirst($transaction['status']); ?>
                                            </span>
                                        </td>
                                        <td class="py-3 px-4 text-sm">
                                            <?php echo date('M d, Y', strtotime($transaction['created_at'])); ?>
                                            <span class="text-xs text-gray-400 block"><?php echo date('h:i A', strtotime($transaction['created_at'])); ?></span>
                                        </td>
                                        <td class="py-3 px-4 text-sm">
                                            <a href="?view=<?php echo $transaction['id']; ?><?php echo $type ? '&type=' . $type : ''; ?><?php echo $status ? '&status=' . $status : ''; ?><?php echo $startDate ? '&start_date=' . $startDate : ''; ?><?php echo $endDate ? '&end_date=' . $endDate : ''; ?>" class="text-indigo-400 hover:text-indigo-300">
                                                View Details
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <!-- Pagination -->
                    <?php if ($totalPages > 1): ?>
                        <div class="px-4 py-3 flex items-center justify-between border-t border-gray-700">
                            <div class="hidden sm:block">
                                <p class="text-sm text-gray-400">
                                    Showing <span class="font-medium"><?php echo $offset + 1; ?></span> to <span class="font-medium"><?php echo min($offset + $perPage, $totalRecords); ?></span> of <span class="font-medium"><?php echo $totalRecords; ?></span> results
                                </p>
                            </div>
                            <div class="flex-1 flex justify-between sm:justify-end">
                                <?php if ($page > 1): ?>
                                    <a href="?page=<?php echo $page - 1; ?><?php echo $type ? '&type=' . $type : ''; ?><?php echo $status ? '&status=' . $status : ''; ?><?php echo $startDate ? '&start_date=' . $startDate : ''; ?><?php echo $endDate ? '&end_date=' . $endDate : ''; ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Previous
                                    </a>
                                <?php endif; ?>
                                
                                <?php if ($page < $totalPages): ?>
                                    <a href="?page=<?php echo $page + 1; ?><?php echo $type ? '&type=' . $type : ''; ?><?php echo $status ? '&status=' . $status : ''; ?><?php echo $startDate ? '&start_date=' . $startDate : ''; ?><?php echo $endDate ? '&end_date=' . $endDate : ''; ?>" class="ml-3 relative inline-flex items-center px-4 py-2 border border-gray-700 text-sm font-medium rounded-md text-gray-300 bg-gray-800 hover:bg-gray-700">
                                        Next
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Transaction Detail Modal -->
    <?php if ($selectedTransaction): ?>
        <div id="transactionModal" class="fixed inset-0 z-50 overflow-y-auto modal flex items-center justify-center">
            <div class="modal-content relative max-w-lg w-full mx-auto rounded-lg shadow-lg p-6">
                <div class="flex justify-between items-start mb-4">
                    <h3 class="text-xl font-semibold text-white">Transaction Details</h3>
                    <a href="?<?php echo http_build_query(array_filter(['type' => $type, 'status' => $status, 'start_date' => $startDate, 'end_date' => $endDate, 'page' => $page])); ?>" class="text-gray-400 hover:text-white">
                        <i class="fas fa-times"></i>
                    </a>
                </div>
                
                <div class="border-b border-gray-700 pb-4 mb-4">
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Transaction ID:</span>
                        <span class="text-white"><?php echo $selectedTransaction['id']; ?></span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Reference:</span>
                        <span class="text-white"><?php echo $selectedTransaction['txn_ref']; ?></span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Type:</span>
                        <span class="text-white"><?php echo ucfirst($selectedTransaction['type']); ?></span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Amount:</span>
                        <span class="text-white"><?php echo formatAmount($selectedTransaction['amount']); ?></span>
                    </div>
                    <?php if ($selectedTransaction['fee'] > 0): ?>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Fee:</span>
                        <span class="text-white"><?php echo formatAmount($selectedTransaction['fee']); ?></span>
                    </div>
                    <?php endif; ?>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Status:</span>
                        <span class="status-badge <?php echo 'status-' . $selectedTransaction['status']; ?>">
                            <?php echo ucfirst($selectedTransaction['status']); ?>
                        </span>
                    </div>
                    <div class="flex justify-between mb-2">
                        <span class="text-gray-400">Date:</span>
                        <span class="text-white"><?php echo date('M d, Y h:i A', strtotime($selectedTransaction['created_at'])); ?></span>
                    </div>
                </div>
                
                <div class="mb-4">
                    <h4 class="text-lg font-medium text-white mb-2">Description</h4>
                    <p class="text-gray-300"><?php echo $selectedTransaction['description']; ?></p>
                </div>
                
                <?php if ($selectedTransaction['metadata']): ?>
                    <div class="mb-4">
                        <h4 class="text-lg font-medium text-white mb-2">Additional Details</h4>
                        <div class="bg-gray-800 rounded-md p-4 text-sm">
                            <?php 
                                $metadata = json_decode($selectedTransaction['metadata'], true);
                                if ($metadata) {
                                    foreach ($metadata as $key => $value) {
                                        if ($key === 'api_response' || $key === 'error') continue;
                                        echo '<div class="flex justify-between mb-1">';
                                        echo '<span class="text-gray-400">' . ucwords(str_replace('_', ' ', $key)) . ':</span>';
                                        echo '<span class="text-white">' . (is_array($value) ? json_encode($value) : $value) . '</span>';
                                        echo '</div>';
                                    }
                                }
                            ?>
                        </div>
                    </div>
                <?php endif; ?>
                
                <div class="mt-6 flex justify-end">
                    <a href="?<?php echo http_build_query(array_filter(['type' => $type, 'status' => $status, 'start_date' => $startDate, 'end_date' => $endDate, 'page' => $page])); ?>" class="py-2 px-4 border border-gray-600 rounded-md shadow-sm text-sm font-medium text-gray-300 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Close
                    </a>
                </div>
            </div>
        </div>
    <?php endif; ?>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Close modal when clicking outside
        const modal = document.getElementById('transactionModal');
        if (modal) {
            modal.addEventListener('click', (event) => {
                if (event.target === modal) {
                    window.location.href = '?<?php echo http_build_query(array_filter(['type' => $type, 'status' => $status, 'start_date' => $startDate, 'end_date' => $endDate, 'page' => $page])); ?>';
                }
            });
        }
    </script> 
<?php require_once './includes/footer.php'; ?>
</body>
</html>