<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$user = getUserById($userId);

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// If user is not a smart user, redirect to dashboard
if ($user['user_type'] !== 'smart') {
    redirect(SITE_URL . '/dashboard');
}

$db = getDB();
$conn = $db->getConnection();

// Get upgrade fee
$upgradeFee = (float)getSetting('upgrade_fee');

$errors = [];
$success = '';

// Process upgrade request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['upgrade'])) {
    // Get form data
    $pin = isset($_POST['pin']) ? $_POST['pin'] : '';
    
    // Validate inputs
    if (empty($pin)) {
        $errors[] = 'Transaction PIN is required';
    } elseif (empty($user['pin'])) {
        $errors[] = 'You need to set a transaction PIN before upgrading. <a href="set_pin.php" class="text-indigo-400 underline">Set PIN now</a>';
    } elseif (!password_verify($pin, $user['pin'])) {
        $errors[] = 'Invalid transaction PIN';
    }
    
    // Check if user has sufficient balance
    if ($user['balance'] < $upgradeFee) {
        $errors[] = 'Insufficient balance. Please fund your wallet with at least ' . formatAmount($upgradeFee) . '.';
    }
    
    // If no errors, process upgrade
    if (empty($errors)) {
        // Begin transaction
        $conn->begin_transaction();
        
        try {
            // Deduct upgrade fee from user balance
            $deductResult = updateUserBalance($userId, $upgradeFee, 'deduct');
            
            if ($deductResult) {
                // Record transaction
                $description = "Account upgrade from Smart to Vendor";
                $txnRef = recordTransaction($userId, 'upgrade', $upgradeFee, $description, 'pending');
                
                if ($txnRef) {
                    // Update user type
                    $stmt = $conn->prepare("UPDATE users SET user_type = 'vendor' WHERE id = ?");
                    $stmt->bind_param("i", $userId);
                    
                    if ($stmt->execute()) {
                        // Update transaction status to successful
                        updateTransactionStatus($txnRef, 'successful');
                        
                        // Commit transaction
                        $conn->commit();
                        
                        // Set success message and refresh user data
                        $success = 'Congratulations! Your account has been upgraded to Vendor level.';
                        $user = getUserById($userId);
                        
                        // Send email notification
                        $emailSubject = 'Account Upgrade Successful';
                        $emailMessage = "Hello " . $user['full_name'] . ",\n\nYour account has been successfully upgraded to Vendor level. You now have access to discounted rates and additional features.\n\nThank you for choosing " . getSetting('site_name') . "!\n\nBest regards,\n" . getSetting('site_name') . " Team";
                        
                        sendEmail($user['email'], $emailSubject, $emailMessage);
                    } else {
                        // Refund user and rollback transaction
                        updateUserBalance($userId, $upgradeFee, 'add');
                        updateTransactionStatus($txnRef, 'failed');
                        $conn->rollback();
                        
                        $errors[] = 'Failed to upgrade account: ' . $conn->error;
                    }
                } else {
                    // Refund user and rollback transaction
                    updateUserBalance($userId, $upgradeFee, 'add');
                    $conn->rollback();
                    
                    $errors[] = 'Failed to record transaction';
                }
            } else {
                // Rollback transaction
                $conn->rollback();
                
                $errors[] = 'Failed to deduct amount from your balance';
            }
        } catch (Exception $e) {
            // Rollback transaction
            $conn->rollback();
            
            $errors[] = 'An error occurred: ' . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Upgrade Account - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .dashboard-nav {
            background-color: var(--bg-secondary);
        }
        
        .nav-link {
            color: var(--text-secondary);
        }
        
        .nav-link:hover, .nav-link.active {
            color: var(--text-primary);
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 3px solid var(--accent-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
        }
        
        .plan-card {
            border: 2px solid transparent;
            transition: all 0.3s ease;
        }
        
        .plan-card.active {
            border-color: var(--accent-color);
        }
        
        .plan-card.current {
            border-color: #4ADE80;
        }
        
        .check-feature {
            color: #4ADE80;
        }
        
        .pin-input {
            font-size: 1.875rem;
            letter-spacing: 0.5rem;
            text-align: center;
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <div class="flex items-center">
                <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            </div>
            
            <div class="relative inline-block text-left">
                <button id="profileDropdownButton" class="flex items-center text-white focus:outline-none">
                    <div class="w-8 h-8 rounded-full bg-gray-600 flex items-center justify-center mr-2">
                        <?php echo substr($user['username'], 0, 1); ?>
                    </div>
                    <span class="hidden md:inline-block"><?php echo htmlspecialchars($user['username']); ?></span>
                    <svg class="w-4 h-4 ml-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7"></path>
                    </svg>
                </button>
                
                <div id="profileDropdown" class="hidden absolute right-0 mt-2 w-48 bg-gray-700 rounded-md shadow-lg z-10">
                    <div class="py-1">
                        <a href="profile.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Profile</a>
                        <a href="change_password.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Change Password</a>
                        <a href="set_pin.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Set Transaction PIN</a>
                        <a href="api_tokens.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">API Tokens</a>
                        <a href="../login/logout.php" class="block px-4 py-2 text-sm text-gray-200 hover:bg-gray-600">Logout</a>
                    </div>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex flex-col md:flex-row">
        <!-- Sidebar -->
        <aside class="dashboard-nav w-full md:w-64 md:min-h-screen md:flex-shrink-0 border-r border-gray-700">
            <nav class="p-4">
                <ul class="space-y-2">
                    <li>
                        <a href="index.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-home mr-3"></i>
                            <span>Dashboard</span>
                        </a>
                    </li>
                    <li>
                        <a href="fund_wallet.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wallet mr-3"></i>
                            <span>Fund Wallet</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_data.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-wifi mr-3"></i>
                            <span>Buy Data</span>
                        </a>
                    </li>
                    <li>
                        <a href="buy_airtime.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-phone mr-3"></i>
                            <span>Buy Airtime</span>
                        </a>
                    </li>
                    <li>
                        <a href="transactions.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-exchange-alt mr-3"></i>
                            <span>Transactions</span>
                        </a>
                    </li>
                    
                    <!-- Show upgrade option only for smart users -->
                    <?php if ($user['user_type'] === 'smart'): ?>
                    <li>
                        <a href="upgrade.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700 bg-gray-700">
                            <i class="fas fa-arrow-up mr-3"></i>
                            <span>Upgrade Account</span>
                        </a>
                    </li>
                    <?php endif; ?>
                    
                    <!-- Show developer section for API users -->
                    <?php if ($user['user_type'] === 'api'): ?>
                    <li>
                        <a href="api_documentation.php" class="nav-link flex items-center px-4 py-2 rounded-md transition-colors hover:bg-gray-700">
                            <i class="fas fa-code mr-3"></i>
                            <span>API Documentation</span>
                        </a>
                    </li>
                    <?php endif; ?>
                </ul>
            </nav>
        </aside>
        
        <!-- Content Area -->
        <main class="flex-grow p-4">
            <div class="flex justify-between items-center mb-6">
                <h1 class="text-2xl font-bold text-white">Upgrade Your Account</h1>
                <div class="text-right">
                    <p class="text-sm text-gray-400">Wallet Balance</p>
                    <p class="text-lg font-semibold text-white"><?php echo formatAmount($user['balance']); ?></p>
                </div>
            </div>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-4" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="bg-green-500 text-white p-4 rounded-md mb-4" role="alert">
                    <p><?php echo $success; ?></p>
                    <p class="mt-2">
                        <a href="index.php" class="underline font-semibold">Return to Dashboard</a>
                    </p>
                </div>
            <?php else: ?>
                <!-- Pricing Plans -->
                <div class="grid grid-cols-1 md:grid-cols-3 gap-6 mb-6">
                    <!-- Smart Plan -->
                    <div class="dashboard-card rounded-lg shadow-md p-6 plan-card current">
                        <div class="text-center mb-4">
                            <div class="inline-block p-3 bg-blue-500 bg-opacity-20 rounded-full mb-3">
                                <i class="fas fa-user text-blue-400 text-2xl"></i>
                            </div>
                            <h3 class="text-xl font-bold text-white">Smart User</h3>
                            <p class="text-gray-400 text-sm">Your current plan</p>
                        </div>
                        
                        <ul class="space-y-3 mb-6">
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Standard data and airtime rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Basic features access</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-times text-red-400 mt-1 mr-2"></i>
                                <span class="text-gray-400">No discount on purchases</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-times text-red-400 mt-1 mr-2"></i>
                                <span class="text-gray-400">No API access</span>
                            </li>
                        </ul>
                    </div>
                    
                    <!-- Vendor Plan -->
                    <div class="dashboard-card rounded-lg shadow-md p-6 plan-card active">
                        <div class="text-center mb-4">
                            <div class="inline-block p-3 bg-green-500 bg-opacity-20 rounded-full mb-3">
                                <i class="fas fa-store text-green-400 text-2xl"></i>
                            </div>
                            <h3 class="text-xl font-bold text-white">Vendor</h3>
                            <div class="mt-2 text-white font-bold text-xl"><?php echo formatAmount($upgradeFee); ?></div>
                            <p class="text-gray-400 text-sm">One-time payment</p>
                        </div>
                        
                        <ul class="space-y-3 mb-6">
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Discounted data and airtime rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Full features access</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Priority customer support</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-times text-red-400 mt-1 mr-2"></i>
                                <span class="text-gray-400">No API access</span>
                            </li>
                        </ul>
                    </div>
                    
                    <!-- API Plan -->
                    <div class="dashboard-card rounded-lg shadow-md p-6 plan-card bg-gray-800 bg-opacity-70">
                        <div class="text-center mb-4">
                            <div class="inline-block p-3 bg-red-500 bg-opacity-20 rounded-full mb-3">
                                <i class="fas fa-code text-red-400 text-2xl"></i>
                            </div>
                            <h3 class="text-xl font-bold text-white">API User</h3>
                            <p class="text-gray-400 text-sm">Contact admin for upgrade</p>
                        </div>
                        
                        <ul class="space-y-3 mb-6">
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Lowest data and airtime rates</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Full features access</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">API integration</span>
                            </li>
                            <li class="flex items-start">
                                <i class="fas fa-check check-feature mt-1 mr-2"></i>
                                <span class="text-gray-300">Priority support</span>
                            </li>
                        </ul>
                        
                        <div class="text-center">
                            <a href="mailto:<?php echo getSetting('contact_email'); ?>?subject=API%20Account%20Upgrade%20Request&body=Hello%20Admin,%0A%0AI%20would%20like%20to%20upgrade%20my%20account%20to%20API%20User.%0A%0AUsername:%20<?php echo $user['username']; ?>%0AEmail:%20<?php echo $user['email']; ?>%0A%0AThank%20you." class="text-indigo-400 hover:text-indigo-300 text-sm">
                                Contact Admin for API Upgrade
                            </a>
                        </div>
                    </div>
                </div>
                
                <!-- Upgrade Form -->
                <div class="dashboard-card rounded-lg shadow-md p-6 mb-6">
                    <h2 class="text-xl font-semibold text-white mb-4">Upgrade to Vendor</h2>
                    
                    <div class="mb-6 p-4 bg-indigo-500 bg-opacity-10 border border-indigo-500 rounded-md">
                        <p class="text-indigo-300 text-sm">
                            <i class="fas fa-info-circle mr-2"></i> You're about to upgrade to a Vendor account for a one-time fee of <?php echo formatAmount($upgradeFee); ?>. You'll get access to discounted rates and additional features.
                        </p>
                    </div>
                    
                    <form method="POST" action="">
                        <div class="mb-6">
                            <label for="pin" class="block text-sm font-medium text-gray-400 mb-1">Transaction PIN</label>
                            <input type="password" id="pin" name="pin" class="pin-input form-input block w-full md:w-64 rounded-md border-gray-600 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" placeholder="••••" maxlength="4" inputmode="numeric" pattern="[0-9]*" required>
                            <p class="mt-1 text-sm text-gray-500">Enter your 4-digit PIN to confirm the upgrade</p>
                        </div>
                        
                        <div class="flex space-x-4">
                            <a href="index.php" class="py-2 px-6 border border-gray-600 rounded-md shadow-sm text-sm font-medium text-gray-300 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Cancel
                            </a>
                            <button type="submit" name="upgrade" class="accent-button py-2 px-6 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Upgrade Now
                            </button>
                        </div>
                    </form>
                </div>
                
                <!-- More Information -->
                <div class="dashboard-card rounded-lg shadow-md p-6">
                    <h2 class="text-xl font-semibold text-white mb-4">Vendor Account Benefits</h2>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                        <div>
                            <h3 class="font-medium text-white mb-3">What You Get</h3>
                            <ul class="list-disc pl-5 space-y-2 text-gray-300">
                                <li>Discounted rates on all data plans (up to 5% cheaper)</li>
                                <li>Discounted rates on airtime purchases (up to 3% cheaper)</li>
                                <li>Priority processing of your transactions</li>
                                <li>Priority customer support</li>
                                <li>Access to vendor-exclusive promotions</li>
                            </ul>
                        </div>
                        
                        <div>
                            <h3 class="font-medium text-white mb-3">Frequently Asked Questions</h3>
                            <div class="space-y-4">
                                <div>
                                    <h4 class="text-white font-medium">Can I downgrade back to Smart User?</h4>
                                    <p class="text-gray-400 text-sm">No, account upgrades are permanent and cannot be reversed.</p>
                                </div>
                                <div>
                                    <h4 class="text-white font-medium">How do I become an API User?</h4>
                                    <p class="text-gray-400 text-sm">API accounts require admin approval. Please contact our support team to request an API account upgrade.</p>
                                </div>
                                <div>
                                    <h4 class="text-white font-medium">Is the upgrade fee refundable?</h4>
                                    <p class="text-gray-400 text-sm">No, the upgrade fee is non-refundable once the upgrade is completed.</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </main>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- JavaScript -->
    <script>
        // Toggle profile dropdown
        const profileButton = document.getElementById('profileDropdownButton');
        const profileDropdown = document.getElementById('profileDropdown');
        
        profileButton.addEventListener('click', () => {
            profileDropdown.classList.toggle('hidden');
        });
        
        // Close dropdown when clicking outside
        document.addEventListener('click', (event) => {
            if (!profileButton.contains(event.target) && !profileDropdown.contains(event.target)) {
                profileDropdown.classList.add('hidden');
            }
        });
        
        // Numeric input validation for PIN
        const pinInput = document.getElementById('pin');
        if (pinInput) {
            pinInput.addEventListener('input', (e) => {
                e.target.value = e.target.value.replace(/[^0-9]/g, '').substring(0, 4);
            });
        }
    </script>
</body>
</html>