<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get user's reseller panel orders
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro 
    JOIN reseller_panels rp ON ro.panel_id = rp.id 
    WHERE ro.user_id = ? 
    ORDER BY ro.created_at DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$orders = [];

while ($row = $result->fetch_assoc()) {
    $orders[] = $row;
}

// Get currency from settings
$currency = getSetting('currency', '₦');

require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-bold text-white">My Orders</h1>
        <a href="reseller_panel.php" class="py-2 px-4 bg-indigo-600 hover:bg-indigo-700 rounded-md text-white text-sm transition-colors">
            <i class="fas fa-plus mr-2"></i>Order New Panel
        </a>
    </div>
    
    <?php if (empty($orders)): ?>
        <div class="bg-gray-800 p-6 rounded-lg text-center">
            <i class="fas fa-shopping-cart text-gray-600 text-5xl mb-4"></i>
            <h2 class="text-xl font-semibold text-white mb-2">No Orders Yet</h2>
            <p class="text-gray-400 mb-4">You haven't placed any reseller panel orders yet.</p>
            <a href="reseller_panel.php" class="inline-block py-2 px-4 bg-indigo-600 hover:bg-indigo-700 rounded-md text-white text-sm transition-colors">
                Browse Reseller Panels
            </a>
        </div>
    <?php else: ?>
        <div class="bg-gray-800 rounded-lg overflow-hidden">
            <div class="overflow-x-auto">
                <table class="min-w-full divide-y divide-gray-700">
                    <thead class="bg-gray-900">
                        <tr>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Order Ref
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Panel
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Amount
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Domain
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Status
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Date
                            </th>
                            <th scope="col" class="px-6 py-3 text-left text-xs font-medium text-gray-400 uppercase tracking-wider">
                                Actions
                            </th>
                        </tr>
                    </thead>
                    <tbody class="divide-y divide-gray-700">
                        <?php foreach ($orders as $order): ?>
                            <tr>
                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                    <?php echo htmlspecialchars($order['order_ref']); ?>
                                </td>
                                <td class="px-6 py-4 text-sm text-gray-300">
                                    <?php echo htmlspecialchars($order['panel_name']); ?>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                    <?php echo $currency . number_format($order['amount'], 2); ?>
                                </td>
                                <td class="px-6 py-4 text-sm text-gray-300">
                                    <?php echo htmlspecialchars($order['domain_name']); ?>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <?php 
                                    $statusClasses = [
                                        'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-300',
                                        'processing' => 'bg-blue-500 bg-opacity-20 text-blue-300',
                                        'completed' => 'bg-green-500 bg-opacity-20 text-green-300',
                                        'cancelled' => 'bg-red-500 bg-opacity-20 text-red-300',
                                        'failed' => 'bg-red-500 bg-opacity-20 text-red-300'
                                    ];
                                    
                                    $statusClass = $statusClasses[$order['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-300';
                                    ?>
                                    <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full <?php echo $statusClass; ?>">
                                        <?php echo ucfirst($order['status']); ?>
                                    </span>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                    <?php echo date('M d, Y', strtotime($order['created_at'])); ?>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-300">
                                    <button data-order-id="<?php echo $order['id']; ?>" class="view-details text-indigo-400 hover:text-indigo-300">
                                        <i class="fas fa-eye mr-1"></i> Details
                                    </button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    <?php endif; ?>
</div>

<!-- Order Details Modal -->
<div id="orderDetailsModal" class="fixed inset-0 flex items-center justify-center z-50 hidden">
    <div class="absolute inset-0 bg-black bg-opacity-50"></div>
    <div class="relative bg-gray-800 rounded-lg max-w-xl w-full max-h-screen overflow-auto">
        <div class="p-6">
            <div class="flex justify-between items-center mb-4">
                <h2 class="text-xl font-semibold text-white">Order Details</h2>
                <button id="closeModalBtn" class="text-gray-400 hover:text-white">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            
            <div id="orderDetailsContent" class="space-y-6">
                <!-- Content will be loaded here -->
                <div class="flex justify-center">
                    <div class="loader w-8 h-8 border-4 border-blue-500 border-t-transparent rounded-full animate-spin"></div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const modal = document.getElementById('orderDetailsModal');
    const closeModalBtn = document.getElementById('closeModalBtn');
    const orderDetailsContent = document.getElementById('orderDetailsContent');
    const viewDetailsBtns = document.querySelectorAll('.view-details');
    
    // Open modal and load order details
    viewDetailsBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            const orderId = this.getAttribute('data-order-id');
            
            // Show modal
            modal.classList.remove('hidden');
            
            // Show loading state
            orderDetailsContent.innerHTML = `
                <div class="flex justify-center">
                    <div class="w-8 h-8 border-4 border-blue-500 border-t-transparent rounded-full animate-spin"></div>
                </div>
            `;
            
            // Get order details
            fetch(`process/get_order_details.php?id=${orderId}`)
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        let statusClass;
                        switch (data.order.status) {
                            case 'pending':
                                statusClass = 'bg-yellow-500 bg-opacity-20 text-yellow-300';
                                break;
                            case 'processing':
                                statusClass = 'bg-blue-500 bg-opacity-20 text-blue-300';
                                break;
                            case 'completed':
                                statusClass = 'bg-green-500 bg-opacity-20 text-green-300';
                                break;
                            case 'cancelled':
                            case 'failed':
                                statusClass = 'bg-red-500 bg-opacity-20 text-red-300';
                                break;
                            default:
                                statusClass = 'bg-gray-500 bg-opacity-20 text-gray-300';
                        }
                        
                        orderDetailsContent.innerHTML = `
                            <div class="bg-gray-900 rounded-lg p-4 mb-4">
                                <div class="flex justify-between">
                                    <div>
                                        <p class="text-gray-400 text-sm">Order Reference</p>
                                        <p class="text-white font-medium">${data.order.order_ref}</p>
                                    </div>
                                    <div>
                                        <p class="text-gray-400 text-sm">Status</p>
                                        <span class="px-2 py-1 inline-flex text-xs leading-5 font-semibold rounded-full ${statusClass}">
                                            ${data.order.status.charAt(0).toUpperCase() + data.order.status.slice(1)}
                                        </span>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                                <div>
                                    <h3 class="text-white font-medium mb-2">Panel Information</h3>
                                    <p class="text-gray-400 text-sm">Name</p>
                                    <p class="text-white mb-2">${data.order.panel_name}</p>
                                    
                                    <p class="text-gray-400 text-sm">Amount</p>
                                    <p class="text-white mb-2">${data.currency}${parseFloat(data.order.amount).toLocaleString(undefined, {minimumFractionDigits: 2, maximumFractionDigits: 2})}</p>
                                    
                                    <p class="text-gray-400 text-sm">Date Ordered</p>
                                    <p class="text-white">${new Date(data.order.created_at).toLocaleString()}</p>
                                </div>
                                
                                <div>
                                    <h3 class="text-white font-medium mb-2">Company Information</h3>
                                    <p class="text-gray-400 text-sm">Domain Name</p>
                                    <p class="text-white mb-2">${data.order.domain_name}</p>
                                    
                                    <p class="text-gray-400 text-sm">Company Name</p>
                                    <p class="text-white mb-2">${data.order.company_name}</p>
                                    
                                    <p class="text-gray-400 text-sm">Email & Phone</p>
                                    <p class="text-white mb-2">${data.order.company_email} | ${data.order.company_phone}</p>
                                    
                                    ${data.order.company_address ? `
                                        <p class="text-gray-400 text-sm">Address</p>
                                        <p class="text-white">${data.order.company_address}</p>
                                    ` : ''}
                                </div>
                            </div>
                            
                            ${data.order.additional_info ? `
                                <div class="mb-4">
                                    <h3 class="text-white font-medium mb-2">Additional Information</h3>
                                    <p class="text-gray-300">${data.order.additional_info}</p>
                                </div>
                            ` : ''}
                            
                            ${data.order.admin_notes && data.order.status !== 'pending' ? `
                                <div class="mb-4">
                                    <h3 class="text-white font-medium mb-2">Admin Notes</h3>
                                    <div class="bg-gray-900 p-3 rounded-md">
                                        <p class="text-gray-300">${data.order.admin_notes}</p>
                                    </div>
                                </div>
                            ` : ''}
                            
                            ${data.order.status === 'completed' ? `
                                <div class="bg-green-500 bg-opacity-10 border border-green-500 rounded-md p-4">
                                    <h3 class="text-green-300 font-medium mb-2">Panel Access Information</h3>
                                    <p class="text-gray-300 mb-2">
                                        Your panel is now active. You can access it using the information below:
                                    </p>
                                    <div class="flex flex-col space-y-2">
                                        <div class="flex justify-between">
                                            <span class="text-gray-400">URL:</span>
                                            <a href="https://${data.order.domain_name}" target="_blank" class="text-indigo-400 hover:text-indigo-300">
                                                https://${data.order.domain_name}
                                            </a>
                                        </div>
                                        <div class="flex justify-between">
                                            <span class="text-gray-400">Admin URL:</span>
                                            <a href="https://${data.order.domain_name}/admin" target="_blank" class="text-indigo-400 hover:text-indigo-300">
                                                https://${data.order.domain_name}/admin
                                            </a>
                                        </div>
                                    </div>
                                </div>
                            ` : ''}
                        `;
                    } else {
                        orderDetailsContent.innerHTML = `
                            <div class="bg-red-500 bg-opacity-10 border border-red-500 rounded-md p-4 text-center">
                                <p class="text-red-400">${data.message || 'Failed to load order details'}</p>
                            </div>
                        `;
                    }
                })
                .catch(error => {
                    orderDetailsContent.innerHTML = `
                        <div class="bg-red-500 bg-opacity-10 border border-red-500 rounded-md p-4 text-center">
                            <p class="text-red-400">An error occurred. Please try again later.</p>
                        </div>
                    `;
                    console.error('Error:', error);
                });
        });
    });
    
    // Close modal
    closeModalBtn.addEventListener('click', function() {
        modal.classList.add('hidden');
    });
    
    // Close modal when clicking outside
    modal.addEventListener('click', function(e) {
        if (e.target === modal) {
            modal.classList.add('hidden');
        }
    });
});
</script>

<?php require_once './includes/footer.php'; ?>