<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get reference from query parameters
$reference = isset($_GET['reference']) ? sanitizeInput($_GET['reference']) : '';

if (empty($reference)) {
    redirect('fund_wallet.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get Paystack settings
$paystackLive = getSetting('paystack_live', '0');
$paystackLiveSecretKey = getSetting('paystack_live_secret_key', '');
$paystackTestSecretKey = getSetting('paystack_test_secret_key', '');

// Choose the appropriate key based on live mode setting
$secretKey = ($paystackLive == '1') ? $paystackLiveSecretKey : $paystackTestSecretKey;

// Initialize variables
$success = false;
$message = '';
$amount = 0;
$amountToCredit = 0;
$error = '';

try {
    // Verify payment with Paystack
    $curl = curl_init();
    curl_setopt_array($curl, [
        CURLOPT_URL => "https://api.paystack.co/transaction/verify/" . rawurlencode($reference),
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_HTTPHEADER => [
            "Authorization: Bearer " . $secretKey,
            "Cache-Control: no-cache",
        ],
    ]);
    
    $response = curl_exec($curl);
    $err = curl_error($curl);
    curl_close($curl);
    
    if ($err) {
        throw new Exception("Connection error: " . $err);
    }
    
    $paystackResponse = json_decode($response, true);
    
    if (!$paystackResponse['status']) {
        throw new Exception("Payment verification failed: " . $paystackResponse['message']);
    }
    
    // Get transaction details
    $txnStmt = $conn->prepare("SELECT * FROM transactions WHERE txn_ref = ? AND user_id = ?");
    $txnStmt->bind_param("si", $reference, $userId);
    $txnStmt->execute();
    $txnResult = $txnStmt->get_result();
    $transaction = $txnResult->fetch_assoc();
    
    if (!$transaction) {
        throw new Exception("Transaction not found in our records");
    }
    
    if ($transaction['status'] == 'successful') {
        $success = true;
        $amount = $transaction['amount'] + $transaction['fee'];
        $amountToCredit = $transaction['amount'];
        $message = "Transaction already processed. Your wallet has been credited.";
    } else {
        // Check Paystack transaction data
        $paymentData = $paystackResponse['data'];
        $paymentStatus = $paymentData['status'];
        $amount = $paymentData['amount'] / 100; // Convert from kobo to naira
        $amountToCredit = $transaction['amount'];
        
        if ($paymentStatus == 'success') {
            // Begin transaction
            $conn->begin_transaction();
            
            try {
                // Update transaction status to successful
                $updateStmt = $conn->prepare("UPDATE transactions SET status = 'successful' WHERE id = ?");
                $updateStmt->bind_param("i", $transaction['id']);
                $updateStmt->execute();
                
                // Credit user's wallet
                $creditStmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                $creditStmt->bind_param("di", $amountToCredit, $userId);
                $creditStmt->execute();
                
                // Create notification for user
                $notifyTitle = 'Wallet Funding Successful';
                $notifyMessage = 'Your wallet has been credited with ' . $amountToCredit . ' via Paystack payment.';
                
                $notifyStmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, 'success', 0)
                ");
                $notifyStmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
                $notifyStmt->execute();
                
                // Commit transaction
                $conn->commit();
                
                $success = true;
                $message = "Payment successful! Your wallet has been credited with ₦" . number_format($amountToCredit, 2);
                
                // Set success message in session
                $_SESSION['funding_success'] = $message;
                
                // Clean up checkout session
                if (isset($_SESSION['paystack_checkout'])) {
                    unset($_SESSION['paystack_checkout']);
                }
                
                // Redirect to fund wallet page after a short delay
                header("refresh:5;url=fund_wallet.php");
            } catch (Exception $e) {
                // Rollback transaction
                $conn->rollback();
                throw new Exception("Failed to process payment: " . $e->getMessage());
            }
        } else {
            throw new Exception("Payment was not successful. Status: " . $paymentStatus);
        }
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}

// Get currency symbol
$currency = getSetting('currency', '₦');
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Payment Verification - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        :root {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #333;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dashboard-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .checkout-card {
            background-color: #1e1e1e;
            position: relative;
            overflow: hidden;
            z-index: 0;
        }
        
        .checkout-card::before {
            content: '';
            position: absolute;
            top: -50%;
            left: -50%;
            width: 200%;
            height: 200%;
            background: linear-gradient(45deg, transparent, rgba(93, 92, 222, 0.1), transparent);
            transform: rotate(45deg);
            z-index: -1;
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col bg-gray-900">
    <!-- Header -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3">
            <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
        </div>
    </header>
    
    <!-- Main Content -->
    <div class="flex-grow flex items-center justify-center p-4">
        <div class="max-w-md w-full">
            <div class="checkout-card rounded-lg shadow-lg p-6">
                <div class="mb-6 text-center">
                    <h1 class="text-2xl font-bold text-white mb-2">Payment Verification</h1>
                    <?php if ($success): ?>
                        <div class="h-16 w-16 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                            <i class="fas fa-check-circle text-3xl text-green-500"></i>
                        </div>
                        <p class="text-gray-400">Your payment has been verified</p>
                    <?php elseif ($error): ?>
                        <div class="h-16 w-16 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                            <i class="fas fa-times-circle text-3xl text-red-500"></i>
                        </div>
                        <p class="text-gray-400">Payment verification failed</p>
                    <?php else: ?>
                        <div class="h-16 w-16 bg-yellow-500 bg-opacity-20 rounded-full flex items-center justify-center mx-auto mb-4">
                            <i class="fas fa-spinner fa-spin text-3xl text-yellow-500"></i>
                        </div>
                        <p class="text-gray-400">Verifying your payment...</p>
                    <?php endif; ?>
                </div>
                
                <?php if ($success): ?>
                    <div class="mb-6 p-4 bg-green-500 bg-opacity-10 border border-green-500 rounded-md">
                        <p class="text-green-400 text-center">
                            <?php echo $message; ?>
                        </p>
                    </div>
                    
                    <div class="mb-6 p-4 bg-gray-800 rounded-md">
                        <div class="flex justify-between mb-2">
                            <span class="text-gray-400">Reference:</span>
                            <span class="text-white"><?php echo $reference; ?></span>
                        </div>
                        <div class="flex justify-between mb-2">
                            <span class="text-gray-400">Amount Paid:</span>
                            <span class="text-white"><?php echo $currency; ?><?php echo number_format($amount, 2); ?></span>
                        </div>
                        <div class="flex justify-between font-semibold">
                            <span class="text-gray-400">Wallet Credited:</span>
                            <span class="text-white"><?php echo $currency; ?><?php echo number_format($amountToCredit, 2); ?></span>
                        </div>
                    </div>
                    
                    <div class="flex justify-center">
                        <a href="fund_wallet.php" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Return to Wallet
                        </a>
                    </div>
                    
                    <div class="mt-4 text-center">
                        <p class="text-gray-400 text-sm">You will be automatically redirected in 5 seconds...</p>
                    </div>
                <?php elseif ($error): ?>
                    <div class="mb-6 p-4 bg-red-500 bg-opacity-10 border border-red-500 rounded-md">
                        <p class="text-red-400 text-center">
                            <?php echo $error; ?>
                        </p>
                    </div>
                    
                    <div class="flex justify-center">
                        <a href="fund_wallet.php" class="accent-button py-2 px-6 rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Try Again
                        </a>
                    </div>
                <?php else: ?>
                    <div class="mb-6 p-4 bg-yellow-500 bg-opacity-10 border border-yellow-500 rounded-md">
                        <p class="text-yellow-400 text-center">
                            Please wait while we verify your payment...
                        </p>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
</body>
</html>