<?php
// File: /dashboard/view_order.php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is logged in
if (!isLoggedIn()) {
    redirect(SITE_URL . '/login/login.php');
}

// Get user data
$userId = $_SESSION['user_id'];
$db = getDB();
$conn = $db->getConnection();

// Get user info
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    // If user not found, log out
    session_destroy();
    redirect(SITE_URL . '/login/login.php');
}

// Get order ID
$orderId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($orderId <= 0) {
    setFlashMessage('Invalid order ID', 'error');
    redirect('orders.php');
}

// Get order details
$stmt = $conn->prepare("
    SELECT ro.*, rp.name as panel_name 
    FROM reseller_orders ro 
    JOIN reseller_panels rp ON ro.panel_id = rp.id 
    WHERE ro.id = ? AND ro.user_id = ?
");
$stmt->bind_param("ii", $orderId, $userId);
$stmt->execute();
$result = $stmt->get_result();
$order = $result->fetch_assoc();

if (!$order) {
    setFlashMessage('Order not found or you do not have permission to view it', 'error');
    redirect('orders.php');
}

// Get currency from settings
$currency = getSetting('currency', '₦');

require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex flex-col md:flex-row justify-between items-start md:items-center mb-6">
        <div>
            <a href="orders.php" class="text-indigo-400 hover:text-indigo-300 mb-2 inline-flex items-center">
                <i class="fas fa-arrow-left mr-2"></i> Back to Orders
            </a>
            <h1 class="text-2xl font-bold text-white mt-2">Order Details</h1>
        </div>
        <div class="mt-4 md:mt-0 flex items-center">
            <span class="px-3 py-1 rounded-full text-sm font-medium 
                <?php
                switch ($order['status']) {
                    case 'pending':
                        echo 'bg-yellow-500 bg-opacity-20 text-yellow-300';
                        break;
                    case 'processing':
                        echo 'bg-blue-500 bg-opacity-20 text-blue-300';
                        break;
                    case 'completed':
                        echo 'bg-green-500 bg-opacity-20 text-green-300';
                        break;
                    case 'cancelled':
                    case 'failed':
                        echo 'bg-red-500 bg-opacity-20 text-red-300';
                        break;
                    default:
                        echo 'bg-gray-500 bg-opacity-20 text-gray-300';
                }
                ?>">
                <?php echo ucfirst($order['status']); ?>
            </span>
        </div>
    </div>
    
    <div class="bg-gray-800 rounded-lg p-4 mb-6">
        <div class="grid grid-cols-2 md:grid-cols-4 gap-4">
            <div>
                <p class="text-gray-400 text-sm">Order Reference</p>
                <p class="text-white font-medium"><?php echo htmlspecialchars($order['order_ref']); ?></p>
            </div>
            <div>
                <p class="text-gray-400 text-sm">Date Ordered</p>
                <p class="text-white"><?php echo date('M d, Y', strtotime($order['created_at'])); ?></p>
            </div>
            <div>
                <p class="text-gray-400 text-sm">Panel</p>
                <p class="text-white"><?php echo htmlspecialchars($order['panel_name']); ?></p>
            </div>
            <div>
                <p class="text-gray-400 text-sm">Amount</p>
                <p class="text-white"><?php echo $currency . number_format($order['amount'], 2); ?></p>
            </div>
        </div>
    </div>
    
    <div class="grid grid-cols-1 md:grid-cols-2 gap-6 mb-6">
        <div class="bg-gray-800 rounded-lg p-4">
            <h2 class="text-white font-medium mb-3">Domain Information</h2>
            <p class="text-gray-400 text-sm">Domain Name</p>
            <p class="text-white mb-3"><?php echo htmlspecialchars($order['domain_name']); ?></p>
            
            <?php if ($order['status'] === 'completed'): ?>
            <div class="mt-4 p-3 bg-green-500 bg-opacity-10 border border-green-500 rounded-md">
                <p class="text-green-300 text-sm mb-2">Domain is active!</p>
                <div class="flex flex-col space-y-2">
                    <a href="https://<?php echo htmlspecialchars($order['domain_name']); ?>" target="_blank" class="text-indigo-400 hover:text-indigo-300 flex items-center">
                        <i class="fas fa-external-link-alt mr-2"></i>
                        https://<?php echo htmlspecialchars($order['domain_name']); ?>
                    </a>
                    <a href="https://<?php echo htmlspecialchars($order['domain_name']); ?>/admin" target="_blank" class="text-indigo-400 hover:text-indigo-300 flex items-center">
                        <i class="fas fa-external-link-alt mr-2"></i>
                        https://<?php echo htmlspecialchars($order['domain_name']); ?>/admin
                    </a>
                </div>
            </div>
            <?php endif; ?>
        </div>
        
        <div class="bg-gray-800 rounded-lg p-4">
            <h2 class="text-white font-medium mb-3">Company Information</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-400 text-sm">Company Name</p>
                    <p class="text-white mb-2"><?php echo htmlspecialchars($order['company_name']); ?></p>
                </div>
                <div>
                    <p class="text-gray-400 text-sm">Company Email</p>
                    <p class="text-white mb-2"><?php echo htmlspecialchars($order['company_email']); ?></p>
                </div>
                <div>
                    <p class="text-gray-400 text-sm">Company Phone</p>
                    <p class="text-white mb-2"><?php echo htmlspecialchars($order['company_phone']); ?></p>
                </div>
                <?php if (!empty($order['company_address'])): ?>
                <div>
                    <p class="text-gray-400 text-sm">Company Address</p>
                    <p class="text-white mb-2"><?php echo htmlspecialchars($order['company_address']); ?></p>
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <?php if (!empty($order['additional_info'])): ?>
    <div class="bg-gray-800 rounded-lg p-4 mb-6">
        <h2 class="text-white font-medium mb-3">Additional Information</h2>
        <p class="text-gray-300"><?php echo nl2br(htmlspecialchars($order['additional_info'])); ?></p>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($order['admin_notes']) && in_array($order['status'], ['completed', 'processing', 'cancelled', 'failed'])): ?>
    <div class="bg-gray-800 rounded-lg p-4 mb-6">
        <h2 class="text-white font-medium mb-3">Admin Notes</h2>
        <p class="text-gray-300"><?php echo nl2br(htmlspecialchars($order['admin_notes'])); ?></p>
    </div>
    <?php endif; ?>
    
    <?php if ($order['status'] === 'pending'): ?>
    <div class="bg-gray-900 rounded-lg p-4 border border-gray-700">
        <h2 class="text-white font-medium mb-3">Order Status</h2>
        <p class="text-gray-300 mb-4">Your order is being reviewed by our team. We will process it as soon as possible.</p>
        
        <div class="flex items-center">
            <div class="rounded-full h-4 w-4 bg-yellow-500 mr-3"></div>
            <p class="text-gray-300">Pending - Your order has been received and is under review</p>
        </div>
    </div>
    <?php elseif ($order['status'] === 'processing'): ?>
    <div class="bg-gray-900 rounded-lg p-4 border border-gray-700">
        <h2 class="text-white font-medium mb-3">Order Status</h2>
        <p class="text-gray-300 mb-4">Your order is currently being processed by our team.</p>
        
        <div class="flex flex-col space-y-3">
            <div class="flex items-center">
                <div class="rounded-full h-4 w-4 bg-green-500 mr-3"></div>
                <p class="text-gray-300">Pending - Your order has been received</p>
            </div>
            <div class="flex items-center">
                <div class="rounded-full h-4 w-4 bg-blue-500 mr-3"></div>
                <p class="text-gray-300">Processing - We are currently setting up your reseller panel</p>
            </div>
        </div>
    </div>
    <?php endif; ?>
</div>

<?php require_once './includes/footer.php'; ?>