<?php
$pageTitle = 'View Ticket';
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Get ticket ID
$ticketId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($ticketId <= 0) {
    setFlashMessage('Invalid ticket ID', 'error');
    redirect(SITE_URL . '/dashboard/support.php');
}

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// Get the ticket
$stmt = $conn->prepare("
    SELECT * FROM support_tickets 
    WHERE id = ? AND user_id = ?
");
$stmt->bind_param("ii", $ticketId, $userId);
$stmt->execute();
$result = $stmt->get_result();
$ticket = $result->fetch_assoc();

if (!$ticket) {
    setFlashMessage('Ticket not found or access denied', 'error');
    redirect(SITE_URL . '/dashboard/support.php');
}

// Process reply
$success = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['submit_reply'])) {
    $message = sanitizeInput($_POST['message']);
    
    if (empty($message)) {
        $error = 'Please enter a message';
    } else {
        $conn->begin_transaction();
        
        try {
            // Insert reply
            $stmt = $conn->prepare("
                INSERT INTO ticket_replies
                (ticket_id, user_id, message)
                VALUES (?, ?, ?)
            ");
            $stmt->bind_param("iis", $ticketId, $userId, $message);
            $stmt->execute();
            
            // Update ticket status to open
            $status = 'open';
            $stmt = $conn->prepare("UPDATE support_tickets SET status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $ticketId);
            $stmt->execute();
            
            // Commit transaction
            $conn->commit();
            
            $success = 'Your reply has been submitted successfully';
            
            // Send email notification to admin
            $adminEmail = getSetting('admin_email');
            if ($adminEmail) {
                $subject = 'New Reply to Support Ticket #' . $ticketId;
                $emailMsg = "
                    <p>A user has replied to a support ticket:</p>
                    <p><strong>Ticket ID:</strong> #{$ticketId}</p>
                    <p><strong>Subject:</strong> {$ticket['subject']}</p>
                    <p><strong>Message:</strong></p>
                    <p>{$message}</p>
                    <p>Please log in to the admin dashboard to respond.</p>
                ";
                
                sendEmail($adminEmail, $subject, $emailMsg);
            }
        } catch (Exception $e) {
            $conn->rollback();
            $error = 'Failed to submit reply: ' . $e->getMessage();
        }
    }
}

// Get ticket replies
$stmt = $conn->prepare("
    SELECT tr.*, u.username as user_username, a.username as admin_username 
    FROM ticket_replies tr
    LEFT JOIN users u ON tr.user_id = u.id
    LEFT JOIN admins a ON tr.admin_id = a.id
    WHERE tr.ticket_id = ?
    ORDER BY tr.created_at ASC
");
$stmt->bind_param("i", $ticketId);
$stmt->execute();
$result = $stmt->get_result();
$replies = [];

while ($row = $result->fetch_assoc()) {
    $replies[] = $row;
}

// Load header
require_once './includes/header.php';
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <div class="flex flex-col md:flex-row justify-between items-start md:items-center mb-6">
        <div>
            <div class="flex items-center mb-2">
                <a href="<?php echo SITE_URL; ?>/dashboard/support.php" class="text-indigo-400 hover:text-indigo-300 mr-3">
                    <i class="fas fa-arrow-left"></i> Back to Support
                </a>
                <h1 class="text-2xl font-bold text-white">Ticket #<?php echo $ticket['id']; ?></h1>
            </div>
            <div class="text-gray-400 text-sm">
                <?php echo date('F j, Y, g:i a', strtotime($ticket['created_at'])); ?>
            </div>
        </div>
        
        <div>
            <?php
            $statusColors = [
                'open' => 'bg-green-500 bg-opacity-20 text-green-400',
                'pending' => 'bg-yellow-500 bg-opacity-20 text-yellow-400',
                'replied' => 'bg-blue-500 bg-opacity-20 text-blue-400',
                'closed' => 'bg-gray-500 bg-opacity-20 text-gray-400'
            ];
            $statusColor = $statusColors[$ticket['status']] ?? 'bg-gray-500 bg-opacity-20 text-gray-400';
            ?>
            <span class="px-3 py-1 text-sm rounded-full <?php echo $statusColor; ?>">
                <?php echo ucfirst($ticket['status']); ?>
            </span>
        </div>
    </div>
    
    <?php if ($success): ?>
        <div class="bg-green-500 text-white p-4 rounded-md mb-4">
            <?php echo $success; ?>
        </div>
    <?php endif; ?>
    
    <?php if ($error): ?>
        <div class="bg-red-500 text-white p-4 rounded-md mb-4">
            <?php echo $error; ?>
        </div>
    <?php endif; ?>
    
    <!-- Ticket Details -->
    <div class="bg-gray-800 rounded-lg p-6 mb-6">
        <div class="flex justify-between items-start mb-4">
            <h2 class="text-xl font-semibold text-white"><?php echo htmlspecialchars($ticket['subject']); ?></h2>
            <div class="px-3 py-1 text-sm rounded-full bg-indigo-500 bg-opacity-20 text-indigo-400">
                <?php echo ucfirst($ticket['category']); ?>
            </div>
        </div>
        
        <div class="bg-gray-700 rounded-lg p-4 mb-4">
            <div class="flex justify-between items-start mb-2">
                <div class="flex items-center">
                    <div class="h-10 w-10 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                        <i class="fas fa-user text-indigo-400"></i>
                    </div>
                    <div>
                        <div class="font-medium text-white">You</div>
                        <div class="text-xs text-gray-400"><?php echo date('M d, Y, g:i a', strtotime($ticket['created_at'])); ?></div>
                    </div>
                </div>
            </div>
            <div class="mt-3 text-gray-300 whitespace-pre-wrap"><?php echo nl2br(htmlspecialchars($ticket['message'])); ?></div>
            
            <?php if ($ticket['reference']): ?>
                <div class="mt-4 p-3 bg-gray-800 rounded text-sm">
                    <div class="text-gray-400 mb-1">Reference:</div>
                    <div class="text-gray-300"><?php echo htmlspecialchars($ticket['reference']); ?></div>
                </div>
            <?php endif; ?>
        </div>
        
        <!-- Ticket Replies -->
        <?php if (!empty($replies)): ?>
            <div class="space-y-4">
                <?php foreach ($replies as $reply): ?>
                    <div class="bg-gray-700 rounded-lg p-4">
                        <div class="flex justify-between items-start mb-2">
                            <div class="flex items-center">
                                <div class="h-10 w-10 rounded-full <?php echo $reply['admin_id'] ? 'bg-yellow-500 bg-opacity-20' : 'bg-indigo-500 bg-opacity-20'; ?> flex items-center justify-center mr-3">
                                    <i class="fas <?php echo $reply['admin_id'] ? 'fa-user-shield text-yellow-400' : 'fa-user text-indigo-400'; ?>"></i>
                                </div>
                                <div>
                                    <div class="font-medium text-white">
                                        <?php 
                                        if ($reply['admin_id']) {
                                            echo 'Support Team';
                                            if ($reply['admin_username']) {
                                                echo ' (' . htmlspecialchars($reply['admin_username']) . ')';
                                            }
                                        } else {
                                            echo 'You';
                                        }
                                        ?>
                                    </div>
                                    <div class="text-xs text-gray-400"><?php echo date('M d, Y, g:i a', strtotime($reply['created_at'])); ?></div>
                                </div>
                            </div>
                        </div>
                        <div class="mt-3 text-gray-300 whitespace-pre-wrap"><?php echo nl2br(htmlspecialchars($reply['message'])); ?></div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>
    
    <!-- Reply Form -->
    <?php if ($ticket['status'] !== 'closed'): ?>
        <div class="bg-gray-800 rounded-lg p-6">
            <h3 class="text-lg font-semibold text-white mb-4">Add Reply</h3>
            
            <form method="POST" action="">
                <div class="mb-4">
                    <label for="message" class="block text-sm font-medium text-gray-400 mb-2">Your Message</label>
                    <textarea id="message" name="message" rows="5" class="form-input block w-full rounded-md shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required></textarea>
                </div>
                
                <div class="flex justify-end">
                    <button type="submit" name="submit_reply" class="accent-button py-2 px-4 rounded-md text-white">
                        <i class="fas fa-paper-plane mr-2"></i> Send Reply
                    </button>
                </div>
            </form>
        </div>
    <?php else: ?>
        <div class="bg-gray-800 rounded-lg p-6 text-center">
            <div class="h-12 w-12 bg-gray-700 rounded-full flex items-center justify-center mx-auto mb-3">
                <i class="fas fa-lock text-yellow-400 text-xl"></i>
            </div>
            <h3 class="text-white font-medium mb-2">This ticket is closed</h3>
            <p class="text-gray-400 mb-4">You cannot add more replies to this ticket as it has been marked as closed.</p>
            <a href="<?php echo SITE_URL; ?>/dashboard/support.php" class="accent-button py-2 px-4 rounded-md text-white inline-block">
                <i class="fas fa-plus mr-2"></i> Create New Ticket
            </a>
        </div>
    <?php endif; ?>
</div>

<?php require_once './includes/footer.php'; ?>