<?php
// Get transaction statistics
$stmt = $conn->prepare("
    SELECT 
        COUNT(*) as total_transactions,
        SUM(amount) as total_amount,
        COUNT(CASE WHEN status = 'successful' THEN 1 END) as successful_transactions,
        SUM(CASE WHEN status = 'successful' THEN amount ELSE 0 END) as successful_amount,
        COUNT(CASE WHEN status = 'pending' THEN 1 END) as pending_transactions,
        COUNT(CASE WHEN status = 'failed' THEN 1 END) as failed_transactions
    FROM transactions
    WHERE user_id = ?
    AND created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$stats = $result->fetch_assoc();

// Get transaction counts by type for the last 30 days
$stmt = $conn->prepare("
    SELECT 
        type, 
        COUNT(*) as count,
        SUM(CASE WHEN status = 'successful' THEN amount ELSE 0 END) as amount
    FROM transactions
    WHERE user_id = ?
    AND status = 'successful'
    AND created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
    GROUP BY type
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$transactionsByType = [];

while ($row = $result->fetch_assoc()) {
    $transactionsByType[$row['type']] = [
        'count' => $row['count'],
        'amount' => $row['amount']
    ];
}

// Get count and amount for each type
$dataCount = $transactionsByType['data']['count'] ?? 0;
$dataAmount = $transactionsByType['data']['amount'] ?? 0;
$airtimeCount = $transactionsByType['airtime']['count'] ?? 0;
$airtimeAmount = $transactionsByType['airtime']['amount'] ?? 0;
$cableCount = $transactionsByType['cable']['count'] ?? 0;
$cableAmount = $transactionsByType['cable']['amount'] ?? 0;
$electricityCount = $transactionsByType['electricity']['count'] ?? 0;
$electricityAmount = $transactionsByType['electricity']['amount'] ?? 0;

// Get monthly transactions for chart
$stmt = $conn->prepare("
    SELECT 
        DATE_FORMAT(created_at, '%b %d') as date,
        SUM(amount) as amount
    FROM transactions
    WHERE user_id = ?
    AND status = 'successful'
    AND created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
    GROUP BY DATE(created_at)
    ORDER BY DATE(created_at) ASC
    LIMIT 30
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();
$chartData = [];

while ($row = $result->fetch_assoc()) {
    $chartData[] = [
        'date' => $row['date'],
        'amount' => $row['amount']
    ];
}

// Format chart data for JavaScript
$chartLabels = [];
$chartValues = [];

foreach ($chartData as $data) {
    $chartLabels[] = $data['date'];
    $chartValues[] = $data['amount'];
}

$chartLabelsJson = json_encode($chartLabels);
$chartValuesJson = json_encode($chartValues);
?>

<div class="dashboard-card shadow rounded-lg p-6 mb-6">
    <h2 class="text-xl font-bold text-white mb-4">Activity Overview</h2>
    
    <div class="grid grid-cols-2 lg:grid-cols-4 gap-4 mb-6">
        <div class="bg-gray-800 rounded-lg p-4">
            <div class="text-sm text-gray-400 mb-1">Total Transactions</div>
            <div class="text-2xl font-bold text-white"><?php echo number_format($stats['total_transactions']); ?></div>
            <div class="text-xs text-gray-500 mt-1">Last 30 days</div>
        </div>
        
        <div class="bg-gray-800 rounded-lg p-4">
            <div class="text-sm text-gray-400 mb-1">Total Spent</div>
            <div class="text-2xl font-bold text-white"><?php echo $currency . number_format($stats['successful_amount'], 2); ?></div>
            <div class="text-xs text-gray-500 mt-1">Successful transactions</div>
        </div>
        
        <div class="bg-gray-800 rounded-lg p-4">
            <div class="text-sm text-gray-400 mb-1">Success Rate</div>
            <?php 
            $successRate = ($stats['total_transactions'] > 0) 
                ? round(($stats['successful_transactions'] / $stats['total_transactions']) * 100) 
                : 0; 
            ?>
            <div class="text-2xl font-bold text-white"><?php echo $successRate; ?>%</div>
            <div class="text-xs text-gray-500 mt-1">
                <?php echo number_format($stats['successful_transactions']); ?> successful
            </div>
        </div>
        
        <div class="bg-gray-800 rounded-lg p-4">
            <div class="text-sm text-gray-400 mb-1">Current Balance</div>
            <div class="text-2xl font-bold text-white"><?php echo $currency . number_format($user['balance'], 2); ?></div>
            <div class="text-xs text-gray-500 mt-1">
                <a href="<?php echo SITE_URL; ?>/dashboard/fund_wallet.php" class="text-indigo-400 hover:text-indigo-300">
                    <i class="fas fa-plus-circle mr-1"></i> Fund Wallet
                </a>
            </div>
        </div>
    </div>
    
    <div class="grid grid-cols-1 lg:grid-cols-3 gap-6">
        <!-- Services Usage -->
        <div class="col-span-1 lg:col-span-2">
            <h3 class="text-lg font-semibold text-white mb-3">Transaction History</h3>
            <div class="bg-gray-800 rounded-lg p-4 h-60">
                <canvas id="transactionChart"></canvas>
            </div>
        </div>
        
        <!-- Services Breakdown -->
        <div>
            <h3 class="text-lg font-semibold text-white mb-3">Services Usage</h3>
            <div class="bg-gray-800 rounded-lg p-4 space-y-3">
                <div class="flex justify-between items-center">
                    <div class="flex items-center">
                        <div class="w-8 h-8 rounded-full bg-indigo-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-wifi text-indigo-400"></i>
                        </div>
                        <div>
                            <div class="text-sm font-medium text-white">Data</div>
                            <div class="text-xs text-gray-400"><?php echo number_format($dataCount); ?> transactions</div>
                        </div>
                    </div>
                    <div class="text-sm font-medium text-white">
                        <?php echo $currency . number_format($dataAmount, 2); ?>
                    </div>
                </div>
                
                <div class="flex justify-between items-center">
                    <div class="flex items-center">
                        <div class="w-8 h-8 rounded-full bg-green-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-phone text-green-400"></i>
                        </div>
                        <div>
                            <div class="text-sm font-medium text-white">Airtime</div>
                            <div class="text-xs text-gray-400"><?php echo number_format($airtimeCount); ?> transactions</div>
                        </div>
                    </div>
                    <div class="text-sm font-medium text-white">
                        <?php echo $currency . number_format($airtimeAmount, 2); ?>
                    </div>
                </div>
                
                <div class="flex justify-between items-center">
                    <div class="flex items-center">
                        <div class="w-8 h-8 rounded-full bg-purple-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-tv text-purple-400"></i>
                        </div>
                        <div>
                            <div class="text-sm font-medium text-white">Cable TV</div>
                            <div class="text-xs text-gray-400"><?php echo number_format($cableCount); ?> transactions</div>
                        </div>
                    </div>
                    <div class="text-sm font-medium text-white">
                        <?php echo $currency . number_format($cableAmount, 2); ?>
                    </div>
                </div>
                
                <div class="flex justify-between items-center">
                    <div class="flex items-center">
                        <div class="w-8 h-8 rounded-full bg-yellow-500 bg-opacity-20 flex items-center justify-center mr-3">
                            <i class="fas fa-bolt text-yellow-400"></i>
                        </div>
                        <div>
                            <div class="text-sm font-medium text-white">Electricity</div>
                            <div class="text-xs text-gray-400"><?php echo number_format($electricityCount); ?> transactions</div>
                        </div>
                    </div>
                    <div class="text-sm font-medium text-white">
                        <?php echo $currency . number_format($electricityAmount, 2); ?>
                    </div>
                </div>
            </div>
            
            <div class="mt-3 text-right">
                <a href="<?php echo SITE_URL; ?>/dashboard/transactions.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                    View All Transactions <i class="fas fa-arrow-right ml-1"></i>
                </a>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Transaction Chart
        const ctx = document.getElementById('transactionChart').getContext('2d');
        
        const labels = <?php echo $chartLabelsJson; ?>;
        const values = <?php echo $chartValuesJson; ?>;
        
        new Chart(ctx, {
            type: 'line',
            data: {
                labels: labels,
                datasets: [{
                    label: 'Transactions Amount',
                    data: values,
                    backgroundColor: 'rgba(93, 92, 222, 0.1)',
                    borderColor: 'rgba(93, 92, 222, 1)',
                    borderWidth: 2,
                    tension: 0.3,
                    fill: true
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: false
                    },
                    tooltip: {
                        backgroundColor: '#1e1e1e',
                        titleColor: '#e0e0e0',
                        bodyColor: '#e0e0e0',
                        borderColor: '#333',
                        borderWidth: 1,
                        callbacks: {
                            label: function(context) {
                                return `${currency}${context.raw.toFixed(2)}`;
                            }
                        }
                    }
                },
                scales: {
                    x: {
                        grid: {
                            color: 'rgba(255, 255, 255, 0.05)'
                        },
                        ticks: {
                            color: '#a0a0a0'
                        }
                    },
                    y: {
                        grid: {
                            color: 'rgba(255, 255, 255, 0.05)'
                        },
                        ticks: {
                            color: '#a0a0a0',
                            callback: function(value) {
                                return '${currency}' + value;
                            }
                        }
                    }
                }
            }
        });
    });
</script>