<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

// Redirect if already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}
// Get site settings
$siteName = getSetting('site_name') ?: 'SubMall Platform';

$success = false;
$error = false;
$message = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = sanitizeInput($_POST['email']);
    
    // Validate email
    if (empty($email)) {
        $error = true;
        $message = 'Please enter your email address';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = true;
        $message = 'Please enter a valid email address';
    } else {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Check if email exists in database
        $stmt = $conn->prepare("SELECT id, username FROM users WHERE email = ?");
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            $error = true;
            $message = 'No account found with this email address';
        } else {
            $user = $result->fetch_assoc();
            
            // Generate unique token
            $token = bin2hex(random_bytes(32));
            $expires = date('Y-m-d H:i:s', strtotime('+1 hour'));
            
            // Delete any existing tokens for this email
            $stmt = $conn->prepare("DELETE FROM password_reset_tokens WHERE email = ?");
            $stmt->bind_param("s", $email);
            $stmt->execute();
            
            // Save token to database
            $stmt = $conn->prepare("INSERT INTO password_reset_tokens (email, token, expires_at) VALUES (?, ?, ?)");
            $stmt->bind_param("sss", $email, $token, $expires);
            $stmt->execute();
            
            // Send password reset email
            $resetLink = SITE_URL . '/reset_password.php?token=' . $token;
            $subject = 'Password Reset Request';
            $message = "
                <p>Dear {$user['username']},</p>
                <p>We received a request to reset your password. Click the link below to reset your password:</p>
                <p><a href=\"{$resetLink}\">{$resetLink}</a></p>
                <p>This link will expire in 1 hour.</p>
                <p>If you did not request a password reset, please ignore this email.</p>
                <p>Regards,<br>{$siteName} Team</p>
            ";
            
            if (sendEmail($email, $subject, $message)) {
                $success = true;
                $message = 'Password reset instructions have been sent to your email address';
            } else {
                $error = true;
                $message = 'Failed to send password reset email. Please try again later';
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Forgot Password - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
        }
        .dark-card {
            background-color: #1e1e1e;
            border-color: #333;
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
        }
        .primary-button {
            background-color: #5D5CDE;
        }
        .primary-button:hover {
            background-color: #4a49b8;
        }
        a.primary-link {
            color: #5D5CDE;
        }
        a.primary-link:hover {
            color: #4a49b8;
        }
    </style>
</head>
<body class="min-h-screen flex items-center justify-center bg-gray-900 py-12 px-4 sm:px-6 lg:px-8">
    <div class="max-w-md w-full space-y-8">
        <div>
            <h2 class="mt-6 text-center text-3xl font-extrabold text-white">
                Forgot Password
            </h2>
            <p class="mt-2 text-center text-sm text-gray-400">
                Remember your password?
                <a href="login.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Sign in
                </a>
            </p>
        </div>
        
        <?php if ($success): ?>
            <div class="bg-green-900 border-l-4 border-green-500 text-green-200 p-4 mb-4" role="alert">
                <p><?php echo $message; ?></p>
            </div>
            
            <div class="text-center">
                <a href="<?php echo SITE_URL; ?>/login.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Return to Login
                </a>
            </div>
        <?php else: ?>
            <?php if ($error): ?>
                <div class="bg-red-900 border-l-4 border-red-500 text-red-200 p-4 mb-4" role="alert">
                    <p><?php echo $message; ?></p>
                </div>
            <?php endif; ?>
            
            <p class="text-center text-gray-400 mb-4">
                Enter your email address, and we'll send you a link to reset your password.
            </p>
            
            <form class="mt-8 space-y-6" method="POST" action="">
                <div class="rounded-md shadow-sm -space-y-px">
                    <div>
                        <label for="email" class="sr-only">Email Address</label>
                        <input id="email" name="email" type="email" required class="dark-input appearance-none rounded-md relative block w-full px-3 py-2 border focus:outline-none focus:ring-indigo-500 focus:z-10 sm:text-sm" placeholder="Email address">
                    </div>
                </div>
                
                <div>
                    <button type="submit" class="primary-button group relative w-full flex justify-center py-2 px-4 border border-transparent text-sm font-medium rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Send Reset Link
                    </button>
                </div>
            </form>
            
            <div class="flex justify-center mt-4">
                <a href="<?php echo SITE_URL; ?>/register.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Create an Account
                </a>
            </div>
        <?php endif; ?>
    </div>
</body>
</html>