<?php
/**
 * API Manager
 * 
 * Class to manage multiple API providers and route requests to the appropriate provider
 */
class APIManager
{
    private $providers = [];
    private $defaultProvider = null;
    private $db;
    
    /**
     * Constructor
     * 
     * @param object $db Database connection
     */
    public function __construct($db)
    {
        $this->db = $db;
        $this->loadProviders();
    }
    
    /**
     * Load API providers from database
     */
    private function loadProviders()
    {
        // Get all available providers from the database
        $conn = $this->db->getConnection();
        $stmt = $conn->prepare("SELECT * FROM api_providers WHERE status = 'active' ORDER BY priority ASC");
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $providerClass = $row['provider_class'];
            $providerFile = __DIR__ . '/' . $providerClass . '.php';
            
            // Check if provider file exists
            if (file_exists($providerFile)) {
                require_once $providerFile;
                
                // Create provider instance
                if (class_exists($providerClass)) {
                    $provider = new $providerClass($row['api_key'], $row['api_url']);
                    $this->providers[$row['id']] = $provider;
                    
                    // Set default provider if it's primary
                    if ($row['is_primary']) {
                        $this->defaultProvider = $provider;
                    }
                }
            }
        }
    }
    
    /**
     * Get a specific provider
     * 
     * @param int $providerId Provider ID
     * @return object|null Provider instance or null if not found
     */
    public function getProvider($providerId)
    {
        return isset($this->providers[$providerId]) ? $this->providers[$providerId] : null;
    }
    
    /**
     * Get default provider
     * 
     * @return object|null Default provider instance or null if not set
     */
    public function getDefaultProvider()
    {
        return $this->defaultProvider;
    }
    
    /**
     * Get all providers
     * 
     * @return array All provider instances
     */
    public function getAllProviders()
    {
        return $this->providers;
    }
    
    /**
     * Get provider for a specific service
     * 
     * @param string $serviceType Service type (data, airtime, cable, electricity)
     * @param int $networkId Network ID (for data and airtime)
     * @return object|null Provider instance or null if not found
     */
    public function getProviderForService($serviceType, $networkId = null)
    {
        // Try to find a specific provider for this service and network
        $conn = $this->db->getConnection();
        
        if ($networkId) {
            // Look for specific network provider
            $stmt = $conn->prepare("
                SELECT ap.* FROM api_providers ap
                JOIN api_provider_services aps ON ap.id = aps.provider_id
                WHERE ap.status = 'active'
                AND aps.service_type = ?
                AND aps.network_id = ?
                ORDER BY ap.priority ASC
                LIMIT 1
            ");
            $stmt->bind_param("si", $serviceType, $networkId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $row = $result->fetch_assoc();
                return $this->getProvider($row['id']);
            }
        }
        
        // If no specific provider found, look for a general provider for this service
        $stmt = $conn->prepare("
            SELECT ap.* FROM api_providers ap
            JOIN api_provider_services aps ON ap.id = aps.provider_id
            WHERE ap.status = 'active'
            AND aps.service_type = ?
            AND aps.network_id IS NULL
            ORDER BY ap.priority ASC
            LIMIT 1
        ");
        $stmt->bind_param("s", $serviceType);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            return $this->getProvider($row['id']);
        }
        
        // If still no provider found, return default provider
        return $this->defaultProvider;
    }
    
    /**
     * Get network API ID for a specific provider
     * 
     * @param int $networkId Internal network ID
     * @param int $providerId Provider ID
     * @return string|null API network ID for the provider
     */
    public function getNetworkApiId($networkId, $providerId)
    {
        $conn = $this->db->getConnection();
        $stmt = $conn->prepare("
            SELECT api_id FROM network_api_mappings
            WHERE network_id = ? AND provider_id = ?
        ");
        $stmt->bind_param("ii", $networkId, $providerId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            return $row['api_id'];
        }
        
        // If no mapping found, try to get the default API ID from networks table
        $stmt = $conn->prepare("
            SELECT api_id FROM networks
            WHERE id = ?
        ");
        $stmt->bind_param("i", $networkId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            return $row['api_id'];
        }
        
        return null;
    }
    
    /**
     * Log API transaction
     * 
     * @param array $data Transaction data
     * @return int|false New transaction ID or false on failure
     */
    public function logApiTransaction($data)
    {
        $conn = $this->db->getConnection();
        
        // Required fields
        $provider = $data['provider'] ?? null;
        $service = $data['service'] ?? null;
        $request = $data['request'] ?? null;
        $response = $data['response'] ?? null;
        $status = $data['status'] ?? 'pending';
        $reference = $data['reference'] ?? null;
        $user_id = $data['user_id'] ?? null;
        
        // Prepare JSON data
        $requestJson = is_array($request) ? json_encode($request) : $request;
        $responseJson = is_array($response) ? json_encode($response) : $response;
        
        $stmt = $conn->prepare("
            INSERT INTO api_transactions 
            (provider, service, request_data, response_data, status, reference, user_id)
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->bind_param("ssssssi", $provider, $service, $requestJson, $responseJson, $status, $reference, $user_id);
        
        if ($stmt->execute()) {
            return $conn->insert_id;
        }
        
        return false;
    }
    
    /**
     * Update API transaction status
     * 
     * @param int $transactionId Transaction ID
     * @param string $status New status
     * @param array|string $response New response data
     * @return bool Success or failure
     */
    public function updateApiTransaction($transactionId, $status, $response = null)
    {
        $conn = $this->db->getConnection();
        
        // Prepare JSON data
        $responseJson = is_array($response) ? json_encode($response) : $response;
        
        if ($response !== null) {
            $stmt = $conn->prepare("
                UPDATE api_transactions 
                SET status = ?, response_data = ?, updated_at = NOW()
                WHERE id = ?
            ");
            $stmt->bind_param("ssi", $status, $responseJson, $transactionId);
        } else {
            $stmt = $conn->prepare("
                UPDATE api_transactions 
                SET status = ?, updated_at = NOW()
                WHERE id = ?
            ");
            $stmt->bind_param("si", $status, $transactionId);
        }
        
        return $stmt->execute();
    }
}
?>