<?php
/**
 * Base API Provider Class
 * 
 * Abstract class to be extended by all API provider integrations
 */
class BaseAPIProvider
{
    protected $apiKey;
    protected $apiUrl;
    protected $lastError;
    protected $responseData;
    protected $responseCode;
    
    /**
     * Constructor
     * 
     * @param string $apiKey API key for the provider
     * @param string $apiUrl Base URL for the API
     */
    public function __construct($apiKey = null, $apiUrl = null)
    {
        $this->apiKey = $apiKey;
        $this->apiUrl = $apiUrl;
        $this->lastError = null;
        $this->responseData = null;
        $this->responseCode = null;
        
        // Initialize provider-specific settings
        $this->init();
    }
    
    /**
     * Initialize provider-specific settings
     * Can be overridden by child classes
     */
    protected function init()
    {
        // Base implementation does nothing
    }
    
    /**
     * Set API credentials
     * 
     * @param string $apiKey API key for the provider
     * @param string $apiUrl Base URL for the API
     * @return $this For method chaining
     */
    public function setCredentials($apiKey, $apiUrl)
    {
        $this->apiKey = $apiKey;
        $this->apiUrl = $apiUrl;
        return $this;
    }
    
    /**
     * Make a GET request to the API
     * 
     * @param string $endpoint API endpoint
     * @param array $params Query parameters
     * @param array $headers Additional headers
     * @return mixed Response data or false on failure
     */
    protected function get($endpoint, $params = [], $headers = [])
    {
        return $this->request('GET', $endpoint, $params, null, $headers);
    }
    
    /**
     * Make a POST request to the API
     * 
     * @param string $endpoint API endpoint
     * @param array|string $data POST data
     * @param array $headers Additional headers
     * @return mixed Response data or false on failure
     */
    protected function post($endpoint, $data = [], $headers = [])
    {
        return $this->request('POST', $endpoint, [], $data, $headers);
    }
    
    /**
     * Make a request to the API
     * 
     * @param string $method HTTP method
     * @param string $endpoint API endpoint
     * @param array $params Query parameters
     * @param array|string $data POST data
     * @param array $headers Additional headers
     * @return mixed Response data or false on failure
     */
    protected function request($method, $endpoint, $params = [], $data = null, $headers = [])
    {
        // Reset previous response data
        $this->responseData = null;
        $this->responseCode = null;
        $this->lastError = null;
        
        // Build the URL
        $url = rtrim($this->apiUrl, '/') . '/' . ltrim($endpoint, '/');
        
        if (!empty($params)) {
            $url .= (strpos($url, '?') === false ? '?' : '&') . http_build_query($params);
        }
        
        // Initialize cURL
        $ch = curl_init();
        
        // Set common cURL options
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // For development only, should be true in production
        
        // Set method-specific options
        if ($method === 'POST') {
            curl_setopt($ch, CURLOPT_POST, true);
            
            if (!empty($data)) {
                if (is_array($data)) {
                    // JSON data
                    if (isset($headers['Content-Type']) && $headers['Content-Type'] === 'application/json') {
                        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
                    } else {
                        // Form data
                        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
                    }
                } else {
                    // Raw data (already a string)
                    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
                }
            }
        } else {
            curl_setopt($ch, CURLOPT_HTTPGET, true);
        }
        
        // Set headers
        $curlHeaders = [];
        foreach ($headers as $key => $value) {
            $curlHeaders[] = $key . ': ' . $value;
        }
        
        if (!empty($curlHeaders)) {
            curl_setopt($ch, CURLOPT_HTTPHEADER, $curlHeaders);
        }
        
        // Execute the request
        $response = curl_exec($ch);
        $this->responseCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        
        // Check for errors
        if ($response === false) {
            $this->lastError = curl_error($ch);
            curl_close($ch);
            $this->logError('cURL Error: ' . $this->lastError);
            return false;
        }
        
        curl_close($ch);
        
        // Try to decode JSON response
        $decodedResponse = json_decode($response, true);
        if (json_last_error() === JSON_ERROR_NONE) {
            $this->responseData = $decodedResponse;
        } else {
            $this->responseData = $response;
        }
        
        // Check for API error
        if ($this->responseCode >= 400) {
            $this->lastError = 'HTTP Error ' . $this->responseCode . ': ' . (is_string($response) ? $response : json_encode($this->responseData));
            $this->logError($this->lastError);
            return false;
        }
        
        return $this->responseData;
    }
    
    /**
     * Get last error message
     * 
     * @return string|null Last error message or null if no error
     */
    public function getLastError()
    {
        return $this->lastError;
    }
    
    /**
     * Get last response data
     * 
     * @return mixed Last response data
     */
    public function getResponseData()
    {
        return $this->responseData;
    }
    
    /**
     * Get last response code
     * 
     * @return int|null Last HTTP response code
     */
    public function getResponseCode()
    {
        return $this->responseCode;
    }
    
    /**
     * Log an error message
     * 
     * @param string $message Error message to log
     */
    protected function logError($message)
    {
        // Log to error file
        error_log('[' . date('Y-m-d H:i:s') . '] ' . get_class($this) . ': ' . $message . PHP_EOL, 3, __DIR__ . '/../../logs/api_errors.log');
    }
    
    /**
     * Get provider name
     * 
     * @return string Provider name
     */
    public function getProviderName()
    {
        // Get the class name without namespace
        $className = get_class($this);
        if (($pos = strrpos($className, '\\')) !== false) {
            $className = substr($className, $pos + 1);
        }
        
        // Remove "Provider" suffix
        return preg_replace('/Provider$/', '', $className);
    }
    
    /**
     * Check balance
     * 
     * @return array Balance information [success, message, data]
     */
    public function checkBalance()
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
    
    /**
     * Purchase data
     * 
     * @param array $params Purchase parameters
     * @return array Purchase result [success, message, data]
     */
    public function purchaseData($params)
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
    
    /**
     * Purchase airtime
     * 
     * @param array $params Purchase parameters
     * @return array Purchase result [success, message, data]
     */
    public function purchaseAirtime($params)
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
    
    /**
     * Pay cable TV bill
     * 
     * @param array $params Payment parameters
     * @return array Payment result [success, message, data]
     */
    public function payCableTv($params)
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
    
    /**
     * Pay electricity bill
     * 
     * @param array $params Payment parameters
     * @return array Payment result [success, message, data]
     */
    public function payElectricity($params)
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
    
    /**
     * Verify transaction
     * 
     * @param string $reference Transaction reference
     * @return array Verification result [success, message, data]
     */
    public function verifyTransaction($reference)
    {
        return [
            'success' => false,
            'message' => 'Not implemented in base class',
            'data' => null
        ];
    }
}
?>