<?php
require_once __DIR__ . '/BaseAPIProvider.php';

/**
 * LegitDataWay API Provider
 * 
 * Integration with LegitDataWay API for data, airtime, and utility services
 */
class LegitDataWayProvider extends BaseAPIProvider
{
    /**
     * Initialize provider-specific settings
     */
    protected function init()
    {
        // Set default API URL if not provided
        if (empty($this->apiUrl)) {
            $this->apiUrl = 'https://legitdataway.com/api/v2';
        }
    }
    
    /**
     * Get available data plans for a network
     * 
     * @param int $networkId The network ID
     * @return array List of available data plans [success, message, data]
     */
    public function getDataPlans($networkId)
    {
        // Add network ID to params
        $params = [
            'network' => $networkId
        ];
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->get('/data/plans', $params, $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to fetch data plans: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => 'Data plans fetched successfully',
                'data' => $response['data'] ?? []
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => null
        ];
    }
    
    /**
     * Check account balance
     * 
     * @return array Balance information [success, message, data]
     */
    public function checkBalance()
    {
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->get('/account/balance', [], $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to check balance: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => 'Balance fetched successfully',
                'data' => [
                    'balance' => $response['data']['balance'] ?? 0,
                    'currency' => $response['data']['currency'] ?? 'NGN'
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => null
        ];
    }
    
    /**
     * Purchase data bundle
     * 
     * @param array $params Purchase parameters [network_id, plan_id, phone, reference]
     * @return array Purchase result [success, message, data]
     */
    public function purchaseData($params)
    {
        // Required parameters
        $requiredParams = ['network_id', 'plan_id', 'phone', 'reference'];
        
        // Check for required parameters
        foreach ($requiredParams as $param) {
            if (!isset($params[$param]) || empty($params[$param])) {
                return [
                    'success' => false,
                    'message' => "Missing required parameter: {$param}",
                    'data' => null
                ];
            }
        }
        
        // Prepare request data
        $data = [
            'network' => $params['network_id'],
            'plan_id' => $params['plan_id'],
            'recipient' => $params['phone'],
            'reference' => $params['reference']
        ];
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->post('/data/purchase', $data, $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to purchase data: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => $response['message'] ?? 'Data purchased successfully',
                'data' => [
                    'transaction_id' => $response['data']['transaction_id'] ?? null,
                    'reference' => $response['data']['reference'] ?? $params['reference'],
                    'amount' => $response['data']['amount'] ?? 0,
                    'network' => $response['data']['network'] ?? null,
                    'phone' => $response['data']['phone'] ?? $params['phone'],
                    'plan' => $response['data']['plan'] ?? null,
                    'date' => $response['data']['date'] ?? date('Y-m-d H:i:s')
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => $response['data'] ?? null
        ];
    }
    
    /**
     * Purchase airtime
     * 
     * @param array $params Purchase parameters [network_id, amount, phone, reference]
     * @return array Purchase result [success, message, data]
     */
    public function purchaseAirtime($params)
    {
        // Required parameters
        $requiredParams = ['network_id', 'amount', 'phone', 'reference'];
        
        // Check for required parameters
        foreach ($requiredParams as $param) {
            if (!isset($params[$param]) || empty($params[$param])) {
                return [
                    'success' => false,
                    'message' => "Missing required parameter: {$param}",
                    'data' => null
                ];
            }
        }
        
        // Prepare request data
        $data = [
            'network' => $params['network_id'],
            'amount' => $params['amount'],
            'recipient' => $params['phone'],
            'reference' => $params['reference']
        ];
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->post('/airtime/purchase', $data, $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to purchase airtime: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => $response['message'] ?? 'Airtime purchased successfully',
                'data' => [
                    'transaction_id' => $response['data']['transaction_id'] ?? null,
                    'reference' => $response['data']['reference'] ?? $params['reference'],
                    'amount' => $response['data']['amount'] ?? $params['amount'],
                    'network' => $response['data']['network'] ?? null,
                    'phone' => $response['data']['phone'] ?? $params['phone'],
                    'date' => $response['data']['date'] ?? date('Y-m-d H:i:s')
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => $response['data'] ?? null
        ];
    }
    
    /**
     * Pay for cable TV subscription
     * 
     * @param array $params Payment parameters [provider, plan_id, smart_card, reference]
     * @return array Payment result [success, message, data]
     */
    public function payCableTv($params)
    {
        // Required parameters
        $requiredParams = ['provider', 'plan_id', 'smart_card', 'reference'];
        
        // Check for required parameters
        foreach ($requiredParams as $param) {
            if (!isset($params[$param]) || empty($params[$param])) {
                return [
                    'success' => false,
                    'message' => "Missing required parameter: {$param}",
                    'data' => null
                ];
            }
        }
        
        // Prepare request data
        $data = [
            'provider' => $params['provider'],
            'plan_id' => $params['plan_id'],
            'smartcard' => $params['smart_card'],
            'reference' => $params['reference']
        ];
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->post('/tv/purchase', $data, $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to pay for cable TV: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => $response['message'] ?? 'Cable TV subscription successful',
                'data' => [
                    'transaction_id' => $response['data']['transaction_id'] ?? null,
                    'reference' => $response['data']['reference'] ?? $params['reference'],
                    'amount' => $response['data']['amount'] ?? 0,
                    'provider' => $response['data']['provider'] ?? $params['provider'],
                    'smart_card' => $response['data']['smartcard'] ?? $params['smart_card'],
                    'plan' => $response['data']['plan'] ?? null,
                    'date' => $response['data']['date'] ?? date('Y-m-d H:i:s')
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => $response['data'] ?? null
        ];
    }
    
    /**
     * Pay for electricity
     * 
     * @param array $params Payment parameters [provider, meter_number, meter_type, amount, reference]
     * @return array Payment result [success, message, data]
     */
    public function payElectricity($params)
    {
        // Required parameters
        $requiredParams = ['provider', 'meter_number', 'meter_type', 'amount', 'reference'];
        
        // Check for required parameters
        foreach ($requiredParams as $param) {
            if (!isset($params[$param]) || empty($params[$param])) {
                return [
                    'success' => false,
                    'message' => "Missing required parameter: {$param}",
                    'data' => null
                ];
            }
        }
        
        // Validate meter type
        if (!in_array($params['meter_type'], ['prepaid', 'postpaid'])) {
            return [
                'success' => false,
                'message' => "Invalid meter type. Must be 'prepaid' or 'postpaid'",
                'data' => null
            ];
        }
        
        // Prepare request data
        $data = [
            'provider' => $params['provider'],
            'meter_number' => $params['meter_number'],
            'meter_type' => $params['meter_type'],
            'amount' => $params['amount'],
            'reference' => $params['reference']
        ];
        
        // Add phone number if provided
        if (isset($params['phone']) && !empty($params['phone'])) {
            $data['phone'] = $params['phone'];
        }
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->post('/electricity/purchase', $data, $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to pay for electricity: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => $response['message'] ?? 'Electricity payment successful',
                'data' => [
                    'transaction_id' => $response['data']['transaction_id'] ?? null,
                    'reference' => $response['data']['reference'] ?? $params['reference'],
                    'amount' => $response['data']['amount'] ?? $params['amount'],
                    'provider' => $response['data']['provider'] ?? $params['provider'],
                    'meter_number' => $response['data']['meter_number'] ?? $params['meter_number'],
                    'meter_type' => $response['data']['meter_type'] ?? $params['meter_type'],
                    'token' => $response['data']['token'] ?? null,
                    'units' => $response['data']['units'] ?? null,
                    'date' => $response['data']['date'] ?? date('Y-m-d H:i:s')
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => $response['data'] ?? null
        ];
    }
    
    /**
     * Verify transaction status
     * 
     * @param string $reference Transaction reference
     * @return array Verification result [success, message, data]
     */
    public function verifyTransaction($reference)
    {
        if (empty($reference)) {
            return [
                'success' => false,
                'message' => 'Transaction reference is required',
                'data' => null
            ];
        }
        
        // Add authorization header
        $headers = [
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Content-Type' => 'application/json',
            'Accept' => 'application/json'
        ];
        
        // Make the request
        $response = $this->get('/transaction/verify/' . $reference, [], $headers);
        
        if ($response === false) {
            return [
                'success' => false,
                'message' => 'Failed to verify transaction: ' . $this->getLastError(),
                'data' => null
            ];
        }
        
        // Check if the response indicates success
        if (isset($response['status']) && $response['status'] === 'success') {
            return [
                'success' => true,
                'message' => 'Transaction verified successfully',
                'data' => [
                    'transaction_id' => $response['data']['transaction_id'] ?? null,
                    'reference' => $response['data']['reference'] ?? $reference,
                    'status' => $response['data']['status'] ?? null,
                    'amount' => $response['data']['amount'] ?? 0,
                    'type' => $response['data']['type'] ?? null,
                    'date' => $response['data']['date'] ?? null
                ]
            ];
        }
        
        return [
            'success' => false,
            'message' => $response['message'] ?? 'Unknown error occurred',
            'data' => $response['data'] ?? null
        ];
    }
}
?>