<?php
// File: /includes/data_purchase.php
/**
 * Purchase data using the Legit Data Way provider
 * 
 * @param int $planId The internal plan ID from our database
 * @param string $phone The phone number to purchase data for
 * @return array Success status and details
 */
function purchaseDataWithProvider($planId, $phone) {
    // Get a fresh database connection instead of relying on global $conn
    $db = getDB();
    $conn = $db->getConnection();
    
    // Log the purchase attempt for debugging
    error_log("Data purchase attempt - Plan ID: $planId, Phone: $phone");
    
    try {
        // Get plan details including provider settings
        $stmt = $conn->prepare("
            SELECT p.*, dt.name as data_type, dt.id as data_type_id, n.name as network_name, n.id as network_id,
                   dtp.provider_id, dtp.provider_network_id, pr.api_url, pr.api_key, pr.name as provider_name
            FROM data_plans p
            JOIN data_types dt ON p.data_type_id = dt.id
            JOIN networks n ON dt.network_id = n.id
            LEFT JOIN data_type_providers dtp ON dt.id = dtp.data_type_id
            LEFT JOIN providers pr ON dtp.provider_id = pr.id
            WHERE p.id = ? AND p.status = 'active'
        ");
        $stmt->bind_param("i", $planId);
        $stmt->execute();
        $result = $stmt->get_result();
        $plan = $result->fetch_assoc();
        
        if (!$plan) {
            throw new Exception("Plan not found or not active");
        }
        
        if (!$plan['provider_id'] || !$plan['provider_network_id'] || !$plan['api_url'] || !$plan['api_key']) {
            throw new Exception("Provider details not configured for this plan");
        }
        
        // Clean phone number (remove +234 prefix if present and ensure it starts with 0)
        if (substr($phone, 0, 4) === '+234') {
            $phone = '0' . substr($phone, 4);
        } else if (substr($phone, 0, 3) === '234') {
            $phone = '0' . substr($phone, 3);
        }
        
        // Use the plan API ID if available, otherwise use the internal plan ID
        $providerPlanId = !empty($plan['api_plan_id']) ? $plan['api_plan_id'] : $plan['id'];
        
        // Prepare API request data - match the format from your working test
        $requestData = [
            'network' => $plan['provider_network_id'],
            'mobile_number' => $phone,
            'plan' => $providerPlanId,
            'Ported_number' => true
        ];
        
        // Log the API request details
        error_log("API Request to {$plan['api_url']}: " . json_encode($requestData));
        
        // Initialize cURL session
        $ch = curl_init($plan['api_url']);
        
        // Set cURL options
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($requestData));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            "Authorization: Token {$plan['api_key']}",
            'Content-Type: application/json'
        ]);
        
        // Execute cURL request
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        
        // Handle cURL errors
        if (curl_errno($ch)) {
            throw new Exception('API connection error: ' . curl_error($ch));
        }
        
        // Close cURL session
        curl_close($ch);
        
        // Log the raw API response
        error_log("API Response ($httpCode): " . $response);
        
        // Parse API response
        $responseData = json_decode($response, true);
        
        // First check HTTP status - if in 200-299 range, consider potentially successful
        $isHttpSuccess = ($httpCode >= 200 && $httpCode < 300);
        
        // Then check response body for success indicators
        $isResponseSuccess = false;
        $message = 'Unknown API response format';
        
        if (isset($responseData['success']) && $responseData['success'] === true) {
            // Format 1: Direct success flag is true
            $isResponseSuccess = true;
            $message = isset($responseData['message']) ? $responseData['message'] : 'Data purchase successful';
        } 
        elseif (isset($responseData['status']) && ($responseData['status'] === 'success' || $responseData['status'] === true)) {
            // Format 2: Status field indicates success
            $isResponseSuccess = true;
            $message = isset($responseData['message']) ? $responseData['message'] : 'Data purchase successful';
        } 
        // Add this check after the existing status check
        elseif (isset($responseData['Status']) && ($responseData['Status'] === 'success' || $responseData['Status'] === true || $responseData['Status'] === 'successful')) {
    // Format 2.5: Status field with capital S indicates success
    $isResponseSuccess = true;
    $message = isset($responseData['message']) ? $responseData['message'] : 'Data purchase successful';
        }
        
        elseif (isset($responseData['data']) && isset($responseData['data']['status']) && 
                ($responseData['data']['status'] === 'success' || $responseData['data']['status'] === true)) {
            // Format 3: Nested data.status indicates success
            $isResponseSuccess = true;
            $message = isset($responseData['data']['message']) ? $responseData['data']['message'] : 'Data purchase successful';
        }
        elseif ($isHttpSuccess && !isset($responseData['error'])) {
            // Format 4: HTTP success + no error field = assume success
            // This is very important - if the API returns HTTP 200 and there's no explicit error, 
            // we should treat it as success even if we don't recognize the exact response format
            $isResponseSuccess = true;
            $message = 'Data purchase likely successful based on HTTP status';
        }
        
        // Prioritize explicit error messages from API if available
        if (!$isResponseSuccess) {
            if (isset($responseData['message'])) {
                $message = $responseData['message'];
            } elseif (isset($responseData['error'])) {
                $message = $responseData['error'];
            } elseif (isset($responseData['data']['message'])) {
                $message = $responseData['data']['message'];
            }
        }
        
        // If HTTP success but response format is unrecognized, give the benefit of the doubt
        // This is reasonable since the provider is actually delivering the data (as seen in your screenshot)
        if ($isHttpSuccess) {
            // Log this special case for monitoring
            error_log("API returned HTTP success ($httpCode) but unrecognized success format. Treating as success.");
            
            return [
                'success' => true,
                'message' => 'Data purchase likely successful (HTTP Status: ' . $httpCode . ')',
                'details' => $responseData,
                'http_code' => $httpCode,
                'warning' => 'Unrecognized success format but HTTP status indicates success'
            ];
        }
        
        // If we've explicitly determined success from the response format
        if ($isResponseSuccess) {
            return [
                'success' => true,
                'message' => $message,
                'details' => $responseData,
                'http_code' => $httpCode
            ];
        }
        
        // Otherwise, it's an error
       // Otherwise, it's an error
// Ensure $message is a string before passing to Exception
if (is_array($message)) {
    if (isset($message['error']) && is_array($message['error']) && !empty($message['error'])) {
        $message = implode(", ", $message['error']);
    } else {
        $message = json_encode($message);
    }
}
throw new Exception($message);
        
    } catch (Exception $e) {
        // Log the exception
        error_log("Data purchase failed: " . $e->getMessage());
        
        // Return error response
        return [
            'success' => false,
            'message' => $e->getMessage(),
            'error' => $e->getMessage(),
            'plan_id' => $planId,
            'phone' => $phone
        ];
    }
}

/**
 * Check balance with a provider
 * 
 * @param int $providerId The ID of the provider
 * @return array Success status and balance info
 */
function checkProviderBalance($providerId) {
    global $conn;
    
    try {
        // Get provider details
        $stmt = $conn->prepare("SELECT * FROM providers WHERE id = ?");
        $stmt->bind_param("i", $providerId);
        $stmt->execute();
        $result = $stmt->get_result();
        $provider = $result->fetch_assoc();
        
        if (!$provider) {
            throw new Exception("Provider not found");
        }
        
        // Ensure URL ends with /user if needed
        $apiUrl = $provider['api_url'];
        if (strpos($apiUrl, '/user') === false) {
            $apiUrl = rtrim($apiUrl, '/') . '/user';
        }
        
        // Initialize cURL session
        $ch = curl_init($apiUrl);
        
        // Set cURL options
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            "Authorization: Token {$provider['api_key']}",
            'Content-Type: application/json'
        ]);
        
        // Execute cURL request
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        
        // Handle cURL errors
        if (curl_errno($ch)) {
            throw new Exception('API connection error: ' . curl_error($ch));
        }
        
        // Close cURL session
        curl_close($ch);
        
        // Parse API response
        $responseData = json_decode($response, true);
        
        // Check for successful status code (200-299)
        if ($httpCode < 200 || $httpCode >= 300) {
            throw new Exception("API request failed. Status code: $httpCode");
        }
        
        // Extract balance information based on API response structure
        $balance = null;
        if (isset($responseData['balance'])) {
            $balance = $responseData['balance'];
        } elseif (isset($responseData['wallet_balance'])) {
            $balance = $responseData['wallet_balance'];
        } elseif (isset($responseData['data']) && isset($responseData['data']['balance'])) {
            $balance = $responseData['data']['balance'];
        } else {
            throw new Exception('Could not determine balance from API response');
        }
        
        // Return success response
        return [
            'success' => true,
            'balance' => $balance,
            'checked_at' => date('Y-m-d H:i:s'),
            'response' => $responseData
        ];
    } catch (Exception $e) {
        // Return error response
        return [
            'success' => false,
            'message' => $e->getMessage(),
            'error' => $e->getMessage()
        ];
    }
}
?>