<?php
require_once 'db.php';

// Get database instance
function getDB() {
    return Database::getInstance();
}

// Get site settings
function getSetting($settingName) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT setting_value FROM settings WHERE setting_name = ?");
    $stmt->bind_param("s", $settingName);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        return $row['setting_value'];
    }
    
    return null;
}

// Update site settings
function updateSetting($settingName, $settingValue) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("INSERT INTO settings (setting_name, setting_value) VALUES (?, ?) 
                           ON DUPLICATE KEY UPDATE setting_value = ?");
    $stmt->bind_param("sss", $settingName, $settingValue, $settingValue);
    
    return $stmt->execute();
}

// Generate random string
if (!function_exists('generateRandomString')) {
    function generateRandomString($length = 10) {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}


// Generate unique transaction reference
function generateTransactionRef($prefix = 'TRX') {
    return $prefix . '_' . time() . '_' . generateRandomString(8);
}

// Format amount with currency
function formatAmount($amount) {
    $currency = getSetting('currency') ?: '₦';
    // Ensure $amount is a valid number, defaulting to 0 if null
    $amount = is_null($amount) || !is_numeric($amount) ? 0 : $amount;
    return $currency . number_format($amount, 2);
}

// Get User by ID
function getUserById($userId) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, username, email, phone, full_name, balance, user_type, status, api_key, hide_low_balance_warning, created_at, pin, pin_verification_enabled FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    
    $result = $stmt->get_result();
    if ($result->num_rows === 0) {
        return null;
    }
    
    return $result->fetch_assoc();
}

// Get User by ID
function getUserById22($userId) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        return $result->fetch_assoc();
    }
    
    return null;
}

// Update user balance
function updateUserBalance($userId, $amount, $type = 'add') {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Get current balance
    $user = getUserById($userId);
    if (!$user) {
        return false;
    }
    
    $currentBalance = $user['balance'];
    $newBalance = ($type === 'add') ? $currentBalance + $amount : $currentBalance - $amount;
    
    // Ensure balance doesn't go below zero
    if ($newBalance < 0) {
        return false;
    }
    
    $stmt = $conn->prepare("UPDATE users SET balance = ? WHERE id = ?");
    $stmt->bind_param("di", $newBalance, $userId);
    
    return $stmt->execute();
}

// Record a transaction
function recordTransaction($userId, $type, $amount, $description, $status = 'pending', $metadata = null, $fee = 0) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $txnRef = generateTransactionRef();
    
    $stmt = $conn->prepare("INSERT INTO transactions (user_id, txn_ref, type, amount, fee, status, description, metadata) 
                          VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
    
    $metadataJson = $metadata ? json_encode($metadata) : null;
    $stmt->bind_param("issddsss", $userId, $txnRef, $type, $amount, $fee, $status, $description, $metadataJson);
    
    if ($stmt->execute()) {
        return $txnRef;
    }
    
    return false;
}

// Get transaction by reference
function getTransactionByRef($txnRef) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT * FROM transactions WHERE txn_ref = ?");
    $stmt->bind_param("s", $txnRef);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        return $result->fetch_assoc();
    }
    
    return null;
}

// Update transaction status
function updateTransactionStatus($txnRef, $status) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("UPDATE transactions SET status = ? WHERE txn_ref = ?");
    $stmt->bind_param("ss", $status, $txnRef);
    
    return $stmt->execute();
}

// Send API request
function sendApiRequest($url, $method = 'GET', $data = null, $headers = []) {
    $ch = curl_init();
    
    if ($method === 'POST') {
        curl_setopt($ch, CURLOPT_POST, 1);
        if ($data) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        }
    } else if ($method === 'PUT') {
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PUT');
        if ($data) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        }
    } else if ($method !== 'GET') {
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
    }
    
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    
    if (!empty($headers)) {
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    }
    
    $response = curl_exec($ch);
    $error = curl_error($ch);
    $statusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    
    curl_close($ch);
    
    return [
        'status_code' => $statusCode,
        'response' => $response ? json_decode($response, true) : null,
        'error' => $error
    ];
}

// Sanitize input
function sanitizeInput($input) {
    $input = trim($input);
    $input = stripslashes($input);
    $input = htmlspecialchars($input);
    return $input;
}

// Flash messages
function setFlashMessage($type, $message) {
    $_SESSION['flash_message'] = [
        'type' => $type,
        'message' => $message
    ];
}

function getFlashMessage() {
    if (isset($_SESSION['flash_message'])) {
        $message = $_SESSION['flash_message'];
        unset($_SESSION['flash_message']);
        return $message;
    }
    return null;
}

// Check if user is logged in
function isLoggedIn() {
    return isset($_SESSION['user_id']);
}

// Check if admin is logged in
function isAdminLoggedIn() {
    return isset($_SESSION['admin_id']);
}

// Redirect
function redirect($url) {
    header("Location: $url");
    exit;
}

// Get current page URL
function getCurrentUrl() {
    return (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
}

// Generate API token
function generateApiToken() {
    return bin2hex(random_bytes(32));
}

// Log activity
function logActivity($userId, $activity, $details = null) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("INSERT INTO activity_logs (user_id, activity, details) VALUES (?, ?, ?)");
    $stmt->bind_param("iss", $userId, $activity, $details);
    
    return $stmt->execute();
}

/**
 * Send email using PHPMailer
 * 
 * @param string $to Recipient email address
 * @param string $subject Email subject
 * @param string $message Email body content
 * @param array $attachments Optional array of attachments
 * @return bool Whether the email was sent successfully
 */
function sendEmail($to, $subject, $message, $attachments = []) {
    global $conn;
    
    // Get email settings from database
    $emailSettings = [];
    $result = $conn->query("SELECT * FROM email_settings LIMIT 1");
    if ($result && $result->num_rows > 0) {
        $emailSettings = $result->fetch_assoc();
    } else {
        error_log("Email settings not found");
        return false;
    }
    
    // Include PHPMailer
    require_once __DIR__ . '/../vendor/phpmailer/phpmailer/src/Exception.php';
    require_once __DIR__ . '/../vendor/phpmailer/phpmailer/src/PHPMailer.php';
    require_once __DIR__ . '/../vendor/phpmailer/phpmailer/src/SMTP.php';
    
    $mail = new PHPMailer\PHPMailer\PHPMailer(true);
    
    try {
        // Server settings
        $mail->isSMTP();
        $mail->Host = $emailSettings['smtp_host'];
        $mail->SMTPAuth = true;
        $mail->Username = $emailSettings['smtp_username'];
        $mail->Password = $emailSettings['smtp_password'];
        
        // Set encryption type
        switch ($emailSettings['smtp_encryption']) {
            case 'ssl':
                $mail->SMTPSecure = PHPMailer\PHPMailer\PHPMailer::ENCRYPTION_SMTPS;
                break;
            case 'tls':
                $mail->SMTPSecure = PHPMailer\PHPMailer\PHPMailer::ENCRYPTION_STARTTLS;
                break;
            default:
                $mail->SMTPSecure = '';
                $mail->SMTPAutoTLS = false;
        }
        
        $mail->Port = $emailSettings['smtp_port'];
        
        // Set debug level for troubleshooting (0 = off, 1 = client messages, 2 = client and server messages)
        // For production, set to 0
        $mail->SMTPDebug = 0;
        
        // Recipients
        $mail->setFrom($emailSettings['from_email'], $emailSettings['from_name']);
        $mail->addAddress($to);
        
        // Content
        $mail->isHTML(true);
        $mail->Subject = $subject;
        $mail->Body = $message;
        $mail->AltBody = strip_tags(str_replace(['<br>', '<br/>', '<br />'], "\r\n", $message));
        
        // Add attachments
        if (!empty($attachments)) {
            foreach ($attachments as $attachment) {
                if (isset($attachment['path']) && file_exists($attachment['path'])) {
                    $filename = isset($attachment['name']) ? $attachment['name'] : basename($attachment['path']);
                    $mail->addAttachment($attachment['path'], $filename);
                }
            }
        }
        
        $mail->send();
        return true;
    } catch (Exception $e) {
        error_log("Email sending failed: " . $mail->ErrorInfo);
        return false;
    }
}

/**
 * Send email using a template
 * 
 * @param string $to Recipient email address
 * @param string $templateName Name of the template
 * @param array $variables Variables to replace in the template
 * @param array $attachments Optional array of attachments
 * @return bool Whether the email was sent successfully
 */
function sendTemplateEmail($to, $templateName, $variables = [], $attachments = []) {
    global $conn;
    
    // Get template from database
    $stmt = $conn->prepare("SELECT * FROM email_templates WHERE name = ?");
    $stmt->bind_param("s", $templateName);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        error_log("Email template not found: " . $templateName);
        return false;
    }
    
    $template = $result->fetch_assoc();
    
    // Add site_name to variables if not set
    if (!isset($variables['site_name'])) {
        $variables['site_name'] = getSetting('site_name');
    }
    
    // Replace variables in subject and body
    $subject = $template['subject'];
    $body = $template['body'];
    
    foreach ($variables as $key => $value) {
        $subject = str_replace('{{'.$key.'}}', $value, $subject);
        $body = str_replace('{{'.$key.'}}', $value, $body);
    }
    
    // Send the email
    return sendEmail($to, $subject, $body, $attachments);
}

/**
 * Test email configuration
 * 
 * @param string $to Recipient email address
 * @return array Status and message of the test
 */
function testEmailConfig($to) {
    // Get site name
    $siteName = getSetting('site_name');
    
    // Create a simple test email
    $subject = "[Test] Email Configuration Test for {$siteName}";
    $message = "
    <html>
    <head>
        <style>
            body { font-family: Arial, sans-serif; color: #333; }
            .container { padding: 20px; }
            .header { background-color: #5D5CDE; color: white; padding: 10px; text-align: center; }
            .content { padding: 20px; }
            .footer { font-size: 12px; color: #777; text-align: center; margin-top: 20px; }
        </style>
    </head>
    <body>
        <div class='container'>
            <div class='header'>
                <h2>{$siteName}</h2>
            </div>
            <div class='content'>
                <p>This is a test email to verify your email configuration is working correctly.</p>
                <p>If you're receiving this email, it means your SMTP settings are configured properly.</p>
                <p>Time sent: " . date('Y-m-d H:i:s') . "</p>
            </div>
            <div class='footer'>
                This is an automated email, please do not reply directly to this message.
            </div>
        </div>
    </body>
    </html>
    ";
    
    // Send the test email
    $success = sendEmail($to, $subject, $message);
    
    if ($success) {
        return [
            'status' => 'success',
            'message' => 'Test email sent successfully to ' . $to
        ];
    } else {
        return [
            'status' => 'error',
            'message' => 'Failed to send test email. Please check your SMTP settings and logs.'
        ];
    }
} 
/**
 * Generate a random API key
 * 
 * @return string Random API key
 */
function generateApiKey() {
    return bin2hex(random_bytes(32));
}