<?php
// File: /includes/monnify.php

class Monnify {
    private $apiKey;
    private $secretKey;
    private $baseUrl;
    private $contractCode;
    private $accessToken;
    private $tokenExpiry;
    private $conn;
    private $isTest;
    private $webhookSecret;
    
    public function __construct() {
        global $conn;
        $this->conn = $conn;
        
        // Load configuration from the database
        $this->loadConfig();
    }
    
    private function loadConfig() {
        $sql = "SELECT * FROM monnify_configs WHERE is_active = 1 LIMIT 1";
        $result = $this->conn->query($sql);
        
        if ($result && $result->num_rows > 0) {
            $config = $result->fetch_assoc();
            $this->apiKey = $config['api_key'];
            $this->secretKey = $config['secret_key'];
            $this->contractCode = $config['contract_code'];
            $this->baseUrl = $config['base_url'];
            $this->isTest = (bool)$config['is_test'];
            $this->webhookSecret = $config['webhook_secret'];
        } else {
            // Use default values or throw an error
            throw new Exception("Monnify configuration not found");
        }
    }
    
    private function getAccessToken() {
        // Check if we already have a valid token
        if ($this->accessToken && $this->tokenExpiry > time()) {
            return $this->accessToken;
        }
        
        // Get a new token
        $auth = base64_encode($this->apiKey . ":" . $this->secretKey);
        $url = $this->baseUrl . "/api/v1/auth/login";
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            "Authorization: Basic " . $auth,
            "Content-Type: application/json"
        ]);
        
        $response = curl_exec($ch);
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        
        if ($httpcode == 200) {
            $result = json_decode($response, true);
            
            if ($result && isset($result['responseBody']['accessToken'])) {
                $this->accessToken = $result['responseBody']['accessToken'];
                // Set expiry to 45 minutes (Monnify tokens last 1 hour)
                $this->tokenExpiry = time() + (45 * 60);
                return $this->accessToken;
            }
        }
        
        // Log the error
        error_log("Monnify authentication failed: " . $response);
        throw new Exception("Failed to authenticate with Monnify");
    }
    
    public function createReservedAccount($user) {
        try {
            // Check if user already has a reserved account
            if (!empty($user['monnify_reserved_account_number'])) {
                return [
                    'success' => true,
                    'message' => 'Reserved account already exists',
                    'data' => [
                        'accountNumber' => $user['monnify_reserved_account_number'],
                        'bankName' => $user['monnify_bank_name'],
                        'bankCode' => $user['monnify_bank_code'],
                        'accountName' => $user['monnify_account_name'],
                        'moniepoint' => $user['monnify_moniepoint_account_number'],
                        'wema' => $user['monnify_wema_account_number'],
                        'sterling' => $user['monnify_sterling_account_number'],
                        'fidelity' => $user['monnify_fidelity_account_number']
                    ]
                ];
            }
            
            // Generate a unique account reference
            $accountReference = "VTU_" . $user['id'] . "_" . time();
            
            // Prepare account name
            // Prepare account name
$accountName = (isset($user['firstname']) ? $user['firstname'] : '') . ' ' . (isset($user['lastname']) ? $user['lastname'] : '');
if (empty(trim($accountName))) {
    $accountName = $user['username'];
}
            
            // Get contract code for this request
            $contractCode = $this->contractCode;
            
            // Request body
            $data = [
                "accountReference" => $accountReference,
                "accountName" => $accountName,
                "currencyCode" => "NGN",
                "contractCode" => $contractCode,
                "customerEmail" => $user['email'],
                "customerName" => $accountName,
                "getAllAvailableBanks" => true
            ];
            
            // Get an access token
            $token = $this->getAccessToken();
            
            // Make the API request
            $url = $this->baseUrl . "/api/v2/bank-transfer/reserved-accounts";
            
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
            curl_setopt($ch, CURLOPT_HTTPHEADER, [
                "Authorization: Bearer " . $token,
                "Content-Type: application/json"
            ]);
            
            $response = curl_exec($ch);
            $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            curl_close($ch);
            
            $result = json_decode($response, true);
            
            if ($httpcode == 200 && isset($result['responseBody'])) {
                $reservedAccounts = $result['responseBody'];
                
                // Extract main account details (typically first one)
                $mainAccount = $reservedAccounts['accounts'][0];
                $monnifyAccountNumber = $mainAccount['accountNumber'];
                $monnifyBankName = $mainAccount['bankName'];
                $monnifyBankCode = $mainAccount['bankCode'];
                
                // Extract specific bank accounts
                $moniepointAccount = '';
                $wemaAccount = '';
                $sterlingAccount = '';
                $fidelityAccount = '';
                
                foreach ($reservedAccounts['accounts'] as $account) {
                    if ($account['bankCode'] == '50515') { // Moniepoint
                        $moniepointAccount = $account['accountNumber'];
                    } elseif ($account['bankCode'] == '035') { // Wema Bank
                        $wemaAccount = $account['accountNumber'];
                    } elseif ($account['bankCode'] == '232') { // Sterling Bank
                        $sterlingAccount = $account['accountNumber'];
                    } elseif ($account['bankCode'] == '070') { // Fidelity Bank
                        $fidelityAccount = $account['accountNumber'];
                    }
                }
                
                // Save the account details to the database
                $stmt = $this->conn->prepare("
                    UPDATE users SET 
                        monnify_account_reference = ?,
                        monnify_contract_code = ?,
                        monnify_reserved_account_number = ?,
                        monnify_bank_name = ?,
                        monnify_bank_code = ?,
                        monnify_account_name = ?,
                        monnify_moniepoint_account_number = ?,
                        monnify_wema_account_number = ?,
                        monnify_sterling_account_number = ?,
                        monnify_fidelity_account_number = ?
                    WHERE id = ?
                ");
                
                $stmt->bind_param(
                    "ssssssssssi",
                    $accountReference,
                    $contractCode,
                    $monnifyAccountNumber,
                    $monnifyBankName,
                    $monnifyBankCode,
                    $accountName,
                    $moniepointAccount,
                    $wemaAccount,
                    $sterlingAccount,
                    $fidelityAccount,
                    $user['id']
                );
                
                if ($stmt->execute()) {
                    return [
                        'success' => true,
                        'message' => 'Reserved account created successfully',
                        'data' => [
                            'accountNumber' => $monnifyAccountNumber,
                            'bankName' => $monnifyBankName,
                            'bankCode' => $monnifyBankCode,
                            'accountName' => $accountName,
                            'moniepoint' => $moniepointAccount,
                            'wema' => $wemaAccount,
                            'sterling' => $sterlingAccount,
                            'fidelity' => $fidelityAccount
                        ]
                    ];
                } else {
                    // Log the error
                    error_log("Failed to save Monnify account details: " . $stmt->error);
                    throw new Exception("Failed to save account details");
                }
            } else {
                // Log the error
                error_log("Monnify create reserved account failed: " . $response);
                
                if (isset($result['responseMessage'])) {
                    throw new Exception("Monnify Error: " . $result['responseMessage']);
                } else {
                    throw new Exception("Failed to create reserved account");
                }
            }
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => $e->getMessage()
            ];
        }
    }
    
    public function handleWebhook($payload, $signature) {
        try {
            // Verify the signature
            if (!$this->verifyWebhookSignature($payload, $signature)) {
                return [
                    'success' => false,
                    'message' => 'Invalid signature'
                ];
            }
            
            // Parse the payload
            $data = json_decode($payload, true);
            
            // Check if it's a successful transaction
            if ($data['eventType'] != 'SUCCESSFUL_TRANSACTION') {
                return [
                    'success' => true,
                    'message' => 'Not a successful transaction event, no action needed'
                ];
            }
            
            $eventData = $data['eventData'];
            
            // Check if this is a reserved account payment
            if ($eventData['paymentMethod'] != 'ACCOUNT_TRANSFER') {
                return [
                    'success' => true,
                    'message' => 'Not an account transfer payment, no action needed'
                ];
            }
            
            // Get the transaction details
            $transactionReference = $eventData['transactionReference'];
            $paymentReference = $eventData['paymentReference'];
            $amountPaid = $eventData['amountPaid'];
            $totalPayable = $eventData['totalPayable'];
            $settlementAmount = $eventData['settlementAmount'];
            $paidOn = $eventData['paidOn'];
            $paymentStatus = $eventData['paymentStatus'];
            $paymentDescription = $eventData['paymentDescription'] ?? '';
            $transactionId = $eventData['transactionId'] ?? 0;
            
            // Get the customer details
            $accountReference = $eventData['accountReference'] ?? '';
            $accountNumber = $eventData['accountDetails']['accountNumber'] ?? '';
            $bankCode = $eventData['accountDetails']['bankCode'] ?? '';
            $customerName = $eventData['customer']['name'] ?? '';
            $customerEmail = $eventData['customer']['email'] ?? '';
            
            // Find the user by account reference
            $stmt = $this->conn->prepare("SELECT id, username, email, balance FROM users WHERE monnify_account_reference = ?");
            $stmt->bind_param("s", $accountReference);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows == 0) {
                return [
                    'success' => false,
                    'message' => 'User not found for account reference: ' . $accountReference
                ];
            }
            
            $user = $result->fetch_assoc();
            $userId = $user['id'];
            
            // Check if this transaction is already processed
            $stmt = $this->conn->prepare("SELECT id FROM monnify_transactions WHERE transaction_reference = ?");
            $stmt->bind_param("s", $transactionReference);
            $stmt->execute();
            
            if ($stmt->get_result()->num_rows > 0) {
                return [
                    'success' => true,
                    'message' => 'Transaction already processed'
                ];
            }
            
            // Start a transaction
            $this->conn->begin_transaction();
            
            try {
                // Save the transaction details
                $stmt = $this->conn->prepare("
                    INSERT INTO monnify_transactions (
                        user_id, transaction_id, payment_reference, amount_paid, 
                        total_payable, settlement_amount, paid_on, payment_status, 
                        payment_description, transaction_reference, payment_reference_raw,
                        account_number, bank_code, customer_name, customer_email
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");
                
                $stmt->bind_param(
                    "iisdddssssssss",
                    $userId,
                    $transactionId,
                    $paymentReference,
                    $amountPaid,
                    $totalPayable,
                    $settlementAmount,
                    $paidOn,
                    $paymentStatus,
                    $paymentDescription,
                    $transactionReference,
                    $paymentReference,
                    $accountNumber,
                    $bankCode,
                    $customerName,
                    $customerEmail
                );
                
                $stmt->execute();
                
                // Calculate the fee using the funding_charge_percentage from settings
                $fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
                $fee = $amountPaid * ($fundingChargePercentage / 100);
                $amountToCredit = $amountPaid - $fee;
                
                // Create a transaction record
                $txn_ref = 'MNFY_' . time() . '_' . $userId;
                $description = "Wallet funding via Monnify bank transfer";
                
                $stmt = $this->conn->prepare("
                    INSERT INTO transactions (
                        user_id, txn_ref, type, amount, fee, description, status, meta_data
                    ) VALUES (?, ?, 'fund', ?, ?, ?, 'successful', ?)
                ");
                
                $metaData = json_encode([
                    'monnify_reference' => $transactionReference,
                    'payment_reference' => $paymentReference,
                    'amount_paid' => $amountPaid,
                    'fee' => $fee,
                    'amount_to_credit' => $amountToCredit,
                    'account_number' => $accountNumber,
                    'bank_code' => $bankCode
                ]);
                
                $stmt->bind_param(
                    "isddss",
                    $userId,
                    $txn_ref,
                    $amountToCredit,
                    $fee,
                    $description,
                    $metaData
                );
                
                $stmt->execute();
                
                // Update user's balance
                $stmt = $this->conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                $stmt->bind_param("di", $amountToCredit, $userId);
                $stmt->execute();
                
                // Create notification
                $notifyTitle = 'Wallet Funding Successful';
                $notifyMessage = "Your wallet has been credited with " . formatAmount($amountToCredit) . " via bank transfer.";
                
                $stmt = $this->conn->prepare("
                    INSERT INTO notifications (user_id, title, message, type, is_read)
                    VALUES (?, ?, ?, 'success', 0)
                ");
                $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
                $stmt->execute();
                
                // Commit the transaction
                $this->conn->commit();
                
                return [
                    'success' => true,
                    'message' => 'Transaction processed successfully',
                    'data' => [
                        'userId' => $userId,
                        'amount' => $amountToCredit,
                        'transactionReference' => $transactionReference
                    ]
                ];
            } catch (Exception $e) {
                // Rollback the transaction
                $this->conn->rollback();
                
                // Log the error
                error_log("Failed to process Monnify webhook: " . $e->getMessage());
                
                return [
                    'success' => false,
                    'message' => 'Failed to process transaction: ' . $e->getMessage()
                ];
            }
        } catch (Exception $e) {
            // Log the error
            error_log("Monnify webhook error: " . $e->getMessage());
            
            return [
                'success' => false,
                'message' => $e->getMessage()
            ];
        }
    }
    
    private function verifyWebhookSignature($payload, $signature) {
        // If no webhook secret is configured, skip verification
        if (empty($this->webhookSecret)) {
            return true;
        }
        
        // Compute the expected signature
        $expectedSignature = hash_hmac('sha512', $payload, $this->webhookSecret);
        
        // Compare signatures
        return hash_equals($expectedSignature, $signature);
    }
    
    public function getBanks() {
        try {
            // Get an access token
            $token = $this->getAccessToken();
            
            // Make the API request
            $url = $this->baseUrl . "/api/v1/banks";
            
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_HTTPHEADER, [
                "Authorization: Bearer " . $token,
                "Content-Type: application/json"
            ]);
            
            $response = curl_exec($ch);
            $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            curl_close($ch);
            
            $result = json_decode($response, true);
            
            if ($httpcode == 200 && isset($result['responseBody'])) {
                return [
                    'success' => true,
                    'data' => $result['responseBody']
                ];
            } else {
                // Log the error
                error_log("Monnify get banks failed: " . $response);
                throw new Exception("Failed to get banks list");
            }
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => $e->getMessage()
            ];
        }
    }
}

// Helper function to format amount
if (!function_exists('formatAmount')) {
    function formatAmount($amount) {
        global $currency;
        return $currency . number_format($amount, 2);
    }
}
?>