<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}

$errors = [];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $username = sanitizeInput($_POST['username'] ?? '');
    $password = $_POST['password'] ?? '';
    
    // Validate form data
    if (empty($username)) {
        $errors[] = 'Username or Email is required';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    }
    
    // If no errors, attempt to log in
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Check if input is email or username
        $isEmail = filter_var($username, FILTER_VALIDATE_EMAIL);
        
        if ($isEmail) {
            $stmt = $conn->prepare("SELECT * FROM users WHERE email = ?");
        } else {
            $stmt = $conn->prepare("SELECT * FROM users WHERE username = ?");
        }
        
        $stmt->bind_param("s", $username);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();
            
            // Verify password
            if (password_verify($password, $user['password'])) {
                // Check if user is suspended
                if ($user['status'] === 'suspended') {
                    $errors[] = 'Your account has been suspended. Please contact support.';
                } 
                // Check if email is verified
                elseif ($user['email_verified'] == 0) {
                    $errors[] = 'Please verify your email before logging in. <a href="resend_verification.php?email=' . urlencode($user['email']) . '" class="text-indigo-400 hover:text-indigo-300">Resend verification email</a>';
                } 
                else {
                    // Log user in
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $user['username'];
                    $_SESSION['user_type'] = $user['user_type'];
                    
                    // Redirect to dashboard
                    redirect(SITE_URL . '/dashboard');
                }
            } else {
                $errors[] = 'Invalid password';
            }
        } else {
            $errors[] = 'Username or Email not found';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .login-container {
            width: 100%;
            max-width: 450px;
            margin: 0 auto;
            padding: 2.5rem;
            border-radius: 10px;
            background-color: #1e1e1e;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.3);
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
            font-size: 16px; /* Prevent zooming on mobile */
            padding: 0.75rem 1rem;
            width: 100%;
            margin-bottom: 1rem;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
            box-shadow: 0 0 0 2px rgba(93, 92, 222, 0.3);
            outline: none;
        }
        .primary-button {
            background-color: #5D5CDE;
            padding: 0.75rem 1rem;
            font-size: 16px;
            font-weight: 600;
            width: 100%;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .primary-button:hover {
            background-color: #4a49b8;
            transform: translateY(-1px);
        }
        .form-group {
            margin-bottom: 1.5rem;
        }
        .link {
            color: #5D5CDE;
            transition: color 0.3s ease;
        }
        .link:hover {
            color: #4a49b8;
            text-decoration: underline;
        }
        .error-alert {
            background-color: rgba(239, 68, 68, 0.9);
            color: white;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
        }
        .checkbox-custom {
            height: 1rem;
            width: 1rem;
            accent-color: #5D5CDE;
            margin-right: 0.5rem;
        }
        @media (max-width: 640px) {
            .login-container {
                padding: 1.5rem;
                max-width: 90%;
            }
        }
    </style>
</head>
<body>
    <div class="login-container">
        <div class="mb-8">
            <h2 class="text-center text-3xl font-extrabold text-white mb-4">
                Sign in to your account
            </h2>
            <p class="text-center text-gray-400">
                Don't have an account?
                <a href="register.php" class="link font-medium">
                    Sign up
                </a>
            </p>
        </div>
        
        <?php if (!empty($errors)): ?>
            <div class="error-alert" role="alert">
                <ul class="list-disc pl-5">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo $error; ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <form method="POST" action="">
            <div class="form-group">
                <label for="username" class="block text-gray-300 mb-2">Username or Email</label>
                <input id="username" name="username" type="text" autocomplete="username" required class="dark-input" 
                       placeholder="Enter your username or email" 
                       value="<?php echo isset($_POST['username']) ? htmlspecialchars($_POST['username']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="password" class="block text-gray-300 mb-2">Password</label>
                <input id="password" name="password" type="password" autocomplete="current-password" 
                       required class="dark-input" placeholder="Enter your password">
            </div>

            <div class="flex items-center justify-between mb-6">
                <div class="flex items-center">
                    <input id="remember_me" name="remember_me" type="checkbox" class="checkbox-custom">
                    <label for="remember_me" class="text-sm text-gray-300">
                        Remember me
                    </label>
                </div>

                <div>
                    <a href="../forgot-password.php" class="link text-sm font-medium">
                        Forgot password?
                    </a>
                </div>
            </div>

            <div>
                <button type="submit" class="primary-button text-white">
                    Sign in
                </button>
            </div>
        </form>
    </div>
</body>
</html>