<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}

$errors = [];
$successMessage = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $username = sanitizeInput($_POST['username'] ?? '');
    $email = sanitizeInput($_POST['email'] ?? '');
    $password = $_POST['password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';
    $fullName = sanitizeInput($_POST['full_name'] ?? '');
    $phone = sanitizeInput($_POST['phone'] ?? '');
    
    // Validate form data
    if (empty($username)) {
        $errors[] = 'Username is required';
    } elseif (!preg_match('/^[a-zA-Z0-9_]+$/', $username)) {
        $errors[] = 'Username can only contain letters, numbers, and underscores';
    }
    
    if (empty($email)) {
        $errors[] = 'Email is required';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid email format';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    } elseif (strlen($password) < 6) {
        $errors[] = 'Password must be at least 6 characters';
    }
    
    if ($password !== $confirmPassword) {
        $errors[] = 'Passwords do not match';
    }
    
    if (empty($fullName)) {
        $errors[] = 'Full name is required';
    }
    
    if (empty($phone)) {
        $errors[] = 'Phone number is required';
    }
    
    // If no errors, check if username or email already exists
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        $stmt = $conn->prepare("SELECT id FROM users WHERE username = ? OR email = ?");
        $stmt->bind_param("ss", $username, $email);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            $errors[] = 'Username or email already exists';
        }
    }
    
    // If still no errors, create user
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Generate API token, verification token and hash password
        $apiToken = generateApiToken();
        $verificationToken = bin2hex(random_bytes(16));
        $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
        
        $stmt = $conn->prepare("INSERT INTO users (username, email, password, full_name, phone, api_token, verification_token) VALUES (?, ?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("sssssss", $username, $email, $hashedPassword, $fullName, $phone, $apiToken, $verificationToken);
        
        if ($stmt->execute()) {
            $userId = $conn->insert_id;
            
            // Send verification email (placeholder)
            $verificationLink = SITE_URL . '/verify.php?token=' . $verificationToken;
            $emailSubject = 'Verify your account';
            $emailMessage = "Hello $fullName,\n\nThank you for registering. Please click the link below to verify your account:\n\n$verificationLink\n\nRegards,\n" . getSetting('site_name');
            
            if (sendEmail($email, $emailSubject, $emailMessage)) {
                $successMessage = 'Registration successful! Please check your email to verify your account.';
            } else {
                $successMessage = 'Registration successful! However, we could not send the verification email. Please contact support.';
            }
        } else {
            $errors[] = 'Registration failed: ' . $conn->error;
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .register-container {
            width: 100%;
            max-width: 500px;
            margin: 2rem auto;
            padding: 2.5rem;
            border-radius: 10px;
            background-color: #1e1e1e;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.3);
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
            font-size: 16px; /* Prevent zooming on mobile */
            padding: 0.75rem 1rem;
            width: 100%;
            margin-bottom: 1rem;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
            box-shadow: 0 0 0 2px rgba(93, 92, 222, 0.3);
            outline: none;
        }
        .primary-button {
            background-color: #5D5CDE;
            padding: 0.75rem 1rem;
            font-size: 16px;
            font-weight: 600;
            width: 100%;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .primary-button:hover {
            background-color: #4a49b8;
            transform: translateY(-1px);
        }
        .form-group {
            margin-bottom: 1.25rem;
        }
        .link {
            color: #5D5CDE;
            transition: color 0.3s ease;
        }
        .link:hover {
            color: #4a49b8;
            text-decoration: underline;
        }
        .error-alert {
            background-color: rgba(239, 68, 68, 0.1);
            border-left: 4px solid #ef4444;
            color: #fca5a5;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
        }
        .success-alert {
            background-color: rgba(16, 185, 129, 0.1);
            border-left: 4px solid #10b981;
            color: #6ee7b7;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
        }
        @media (max-width: 640px) {
            .register-container {
                padding: 1.5rem;
                max-width: 90%;
                margin: 1rem auto;
            }
        }
    </style>
</head>
<body>
    <div class="register-container">
        <div class="mb-8">
            <h2 class="text-center text-3xl font-extrabold text-white mb-4">
                Create your account
            </h2>
            <p class="text-center text-gray-400">
                Already have an account?
                <a href="index.php" class="link font-medium">
                    Sign in
                </a>
            </p>
        </div>
        
        <?php if (!empty($errors)): ?>
            <div class="error-alert" role="alert">
                <ul class="list-disc pl-5">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo $error; ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <?php if ($successMessage): ?>
            <div class="success-alert" role="alert">
                <p><?php echo $successMessage; ?></p>
            </div>
        <?php endif; ?>
        
        <form method="POST" action="">
            <div class="form-group">
                <label for="full_name" class="block text-gray-300 mb-2">Full Name</label>
                <input id="full_name" name="full_name" type="text" required class="dark-input" 
                       placeholder="Enter your full name" 
                       value="<?php echo isset($_POST['full_name']) ? htmlspecialchars($_POST['full_name']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="username" class="block text-gray-300 mb-2">Username</label>
                <input id="username" name="username" type="text" required class="dark-input" 
                       placeholder="Choose a username" 
                       value="<?php echo isset($_POST['username']) ? htmlspecialchars($_POST['username']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="email" class="block text-gray-300 mb-2">Email address</label>
                <input id="email" name="email" type="email" autocomplete="email" required class="dark-input" 
                       placeholder="Enter your email address" 
                       value="<?php echo isset($_POST['email']) ? htmlspecialchars($_POST['email']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="phone" class="block text-gray-300 mb-2">Phone Number</label>
                <input id="phone" name="phone" type="text" required class="dark-input" 
                       placeholder="Enter your phone number" 
                       value="<?php echo isset($_POST['phone']) ? htmlspecialchars($_POST['phone']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="password" class="block text-gray-300 mb-2">Password</label>
                <input id="password" name="password" type="password" autocomplete="new-password" 
                       required class="dark-input" placeholder="Create a password">
            </div>
            
            <div class="form-group">
                <label for="confirm_password" class="block text-gray-300 mb-2">Confirm Password</label>
                <input id="confirm_password" name="confirm_password" type="password" 
                       autocomplete="new-password" required class="dark-input" 
                       placeholder="Confirm your password">
            </div>

            <div class="mt-6">
                <button type="submit" class="primary-button text-white">
                    Create Account
                </button>
            </div>
        </form>
    </div>
</body>
</html>