<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Initialize variables
$email = isset($_GET['email']) ? sanitizeInput($_GET['email']) : '';
$success = '';
$error = '';

// Get database connection
$db = getDB();
$conn = $db->getConnection();

// If email is provided, look up the account
if (!empty($email)) {
    // Check if user exists and needs verification
    $stmt = $conn->prepare("SELECT id, username, verification_token, email_verified, status FROM users WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
    
    if (!$user) {
        $error = "We couldn't find an account with that email address. Please check your email and try again.";
    } elseif ($user['email_verified'] == 1) {
        $error = "This account is already verified. Please <a href='index.php' class='text-indigo-400 hover:text-indigo-300'>login</a> to continue.";
    } else {
        // Generate new verification token
        $verificationToken = bin2hex(random_bytes(32)); // More secure token
        
        // Update the verification token
        $stmt = $conn->prepare("UPDATE users SET verification_token = ? WHERE id = ?");
        $stmt->bind_param("si", $verificationToken, $user['id']);
        
        if (!$stmt->execute()) {
            $error = "Failed to update verification token. Please try again later.";
        } else {
            // Prepare verification email
            $verificationLink = SITE_URL . '/verify.php?token=' . $verificationToken;
            $subject = "Verify Your Email - " . getSetting('site_name');
            $message = "
            <html>
            <head>
                <title>Verify Your Email</title>
            </head>
            <body>
                <p>Hello " . htmlspecialchars($user['username']) . ",</p>
                <p>Thank you for registering on " . getSetting('site_name') . ". Please click the link below to verify your email address:</p>
                <p><a href='{$verificationLink}'>{$verificationLink}</a></p>
                <p>If you did not create an account, please ignore this email.</p>
                <p>Regards,<br>" . getSetting('site_name') . " Team</p>
            </body>
            </html>
            ";
            
            // Send verification email
            if (sendEmail($email, $subject, $message)) {
                $success = "A new verification email has been sent to <strong>" . htmlspecialchars($email) . "</strong>. Please check your inbox and spam folder.";
            } else {
                $error = "Failed to send verification email. Please try again later or contact support.";
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Resend Verification Email - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        :root {
            --bg-primary: #FFFFFF;
            --bg-secondary: #F9FAFB;
            --bg-card: #FFFFFF;
            --text-primary: #1F2937;
            --text-secondary: #6B7280;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #E5E7EB;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .auth-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
        
        .form-input {
            background-color: var(--bg-secondary);
            border-color: var(--border-color);
            color: var(--text-primary);
        }
        
        .dark .form-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        
        .form-input:focus {
            border-color: var(--accent-color);
            box-shadow: 0 0 0 3px rgba(93, 92, 222, 0.25);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            <div>
                <a href="index.php" class="text-white hover:text-gray-300">Log In</a>
                <span class="mx-2 text-gray-500">|</span>
                <a href="register.php" class="text-white hover:text-gray-300">Register</a>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <main class="flex-grow flex items-center justify-center p-4">
        <div class="max-w-md w-full">
            <div class="auth-card rounded-lg shadow p-6">
                <div class="text-center mb-6">
                    <h1 class="text-2xl font-bold text-white">Resend Verification Email</h1>
                    <p class="text-gray-400 mt-2">Enter your email address to receive a new verification link</p>
                </div>
                
                <?php if ($error): ?>
                    <div class="bg-red-500 bg-opacity-20 border border-red-500 text-red-300 p-4 rounded-md mb-6">
                        <p><?php echo $error; ?></p>
                    </div>
                <?php endif; ?>
                
                <?php if ($success): ?>
                    <div class="bg-green-500 bg-opacity-20 border border-green-500 text-green-300 p-4 rounded-md mb-6">
                        <p><?php echo $success; ?></p>
                    </div>
                <?php endif; ?>
                
                <?php if (empty($success)): ?>
                    <form method="GET" action="">
                        <div class="mb-4">
                            <label for="email" class="block text-sm font-medium text-gray-400 mb-1">Email Address</label>
                            <input type="email" id="email" name="email" value="<?php echo htmlspecialchars($email); ?>" class="form-input block w-full rounded-md shadow-sm focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                        </div>
                        
                        <div class="mt-6">
                            <button type="submit" class="accent-button w-full py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                Send Verification Email
                            </button>
                        </div>
                    </form>
                <?php else: ?>
                    <div class="mt-6">
                        <a href="index.php" class="accent-button w-full py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 inline-block text-center">
                            Back to Login
                        </a>
                    </div>
                <?php endif; ?>
                
                <div class="mt-6 text-center">
                    <a href="index.php" class="text-indigo-400 hover:text-indigo-300 text-sm">
                        <i class="fas fa-arrow-left mr-1"></i> Back to Login
                    </a>
                </div>
            </div>
        </div>
    </main>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
</body>
</html>