<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}

$errors = [];

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $username = sanitizeInput($_POST['username'] ?? '');
    $password = $_POST['password'] ?? '';
    
    // Validate form data
    if (empty($username)) {
        $errors[] = 'Username or Email is required';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    }
    
    // If no errors, attempt to log in
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Check if input is email or username
        $isEmail = filter_var($username, FILTER_VALIDATE_EMAIL);
        
        if ($isEmail) {
            $stmt = $conn->prepare("SELECT * FROM users WHERE email = ?");
        } else {
            $stmt = $conn->prepare("SELECT * FROM users WHERE username = ?");
        }
        
        $stmt->bind_param("s", $username);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();
            
            // Verify password
            if (password_verify($password, $user['password'])) {
                // Check if user is suspended
                if ($user['status'] === 'suspended') {
                    $errors[] = 'Your account has been suspended. Please contact support.';
                } 
                // Check if email is verified
                elseif ($user['email_verified'] == 0) {
                    $errors[] = 'Please verify your email before logging in. <a href="resend_verification.php?email=' . urlencode($user['email']) . '" class="text-indigo-400 hover:text-indigo-300">Resend verification email</a>';
                } 
                else {
                    // Log user in
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $user['username'];
                    $_SESSION['user_type'] = $user['user_type'];
                    
                    // Redirect to dashboard
                    redirect(SITE_URL . '/dashboard');
                }
            } else {
                $errors[] = 'Invalid password';
            }
        } else {
            $errors[] = 'Username or Email not found';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
        }
        .dark-card {
            background-color: #1e1e1e;
            border-color: #333;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.2);
            border-radius: 8px;
            padding: 2rem;
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
            font-size: 16px;
            padding: 14px 16px;
            border-radius: 6px;
            width: 100%;
            margin-bottom: 1rem;
            border-width: 1px;
            transition: all 0.3s ease;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
            box-shadow: 0 0 0 2px rgba(93, 92, 222, 0.2);
            outline: none;
        }
        .primary-button {
            background-color: #5D5CDE;
            font-size: 16px;
            padding: 12px 24px;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .primary-button:hover {
            background-color: #4a49b8;
            transform: translateY(-1px);
        }
        .form-container {
            width: 100%;
            max-width: 450px;
            margin: 0 auto;
            padding: 2rem 1.5rem;
        }
        @media (max-width: 640px) {
            .form-container {
                padding: 1.5rem 1rem;
            }
        }
    </style>
</head>
<body class="min-h-screen flex items-center justify-center bg-gray-900 py-12 px-4 sm:px-6 lg:px-8">
    <div class="form-container">
        <div class="dark-card">
            <div class="text-center mb-8">
                <h2 class="text-center text-3xl font-extrabold text-white mb-4">
                    Sign in to your account
                </h2>
                <p class="text-center text-base text-gray-400">
                    Don't have an account?
                    <a href="register.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                        Sign up
                    </a>
                </p>
            </div>
            
            <?php if (!empty($errors)): ?>
                <div class="bg-red-500 text-white p-4 rounded-md mb-6" role="alert">
                    <ul class="list-disc pl-5">
                        <?php foreach ($errors as $error): ?>
                            <li><?php echo $error; ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
            
            <form class="space-y-6" method="POST" action="">
                <div class="space-y-4">
                    <div>
                        <label for="username" class="block text-sm font-medium text-gray-300 mb-1">Username or Email</label>
                        <input id="username" name="username" type="text" autocomplete="username" required class="dark-input" placeholder="Enter your username or email" value="<?php echo isset($_POST['username']) ? htmlspecialchars($_POST['username']) : ''; ?>">
                    </div>
                    <div>
                        <label for="password" class="block text-sm font-medium text-gray-300 mb-1">Password</label>
                        <input id="password" name="password" type="password" autocomplete="current-password" required class="dark-input" placeholder="Enter your password">
                    </div>
                </div>

                <div class="flex items-center justify-between mt-4 mb-6">
                    <div class="flex items-center">
                        <input id="remember_me" name="remember_me" type="checkbox" class="h-5 w-5 text-indigo-600 focus:ring-indigo-500 border-gray-300 rounded">
                        <label for="remember_me" class="ml-2 block text-base text-gray-300">
                            Remember me
                        </label>
                    </div>

                    <div>
                        <a href="forgot_password.php" class="font-medium text-indigo-400 hover:text-indigo-300 text-base">
                            Forgot password?
                        </a>
                    </div>
                </div>

                <div>
                    <button type="submit" class="primary-button w-full flex justify-center text-base font-medium rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                        Sign in
                    </button>
                </div>
            </form>
        </div>
    </div>
</body>
</html>