<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if token is provided
$token = isset($_GET['token']) ? sanitizeInput($_GET['token']) : '';
$message = '';
$status = '';

if (empty($token)) {
    $message = 'Invalid verification link. No token provided.';
    $status = 'error';
} else {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Check if token exists in the database
    $stmt = $conn->prepare("SELECT * FROM users WHERE verification_token = ? AND status = 'pending'");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $message = 'Invalid or expired token. This account may already be verified.';
        $status = 'error';
    } else {
        $user = $result->fetch_assoc();
        
        // Activate the account
        $stmt = $conn->prepare("UPDATE users SET status = 'active', email_verified = 1, verification_token = NULL WHERE id = ?");
        $stmt->bind_param("i", $user['id']);
        
        if ($stmt->execute()) {
            $message = 'Your account has been successfully verified. You can now login.';
            $status = 'success';
            
            // Create a welcome notification for the user
            $stmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, 'Welcome to " . getSetting('site_name') . "', ?, 'success', 0)
            ");
            $welcomeMsg = "Your account has been verified successfully. Welcome to " . getSetting('site_name') . "! Start by funding your wallet to enjoy our services.";
            $stmt->bind_param("is", $user['id'], $welcomeMsg);
            $stmt->execute();
            
            // Send welcome email
            $subject = 'Welcome to ' . getSetting('site_name');
            $emailMsg = "
                <p>Dear {$user['username']},</p>
                <p>Your account has been successfully verified. Welcome to " . getSetting('site_name') . "!</p>
                <p>You can now login to your account and start using our services.</p>
                <p>To get started, fund your wallet and explore our range of services including:</p>
                <ul>
                    <li>Airtime purchase</li>
                    <li>Data subscription</li>
                    <li>Cable TV subscription</li>
                    <li>Electricity bill payment</li>
                </ul>
                <p>If you have any questions, please don't hesitate to contact our support team.</p>
                <p>Regards,<br>" . getSetting('site_name') . " Team</p>
            ";
            
            sendEmail($user['email'], $subject, $emailMsg);
        } else {
            $message = 'An error occurred while verifying your account. Please try again later.';
            $status = 'error';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Account Verification - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        /* Dark theme styles */
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body.dark {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .dark .form-card {
            background-color: var(--bg-card);
        }
    </style>
</head>
<body class="min-h-screen bg-gray-100 py-6 flex flex-col justify-center sm:py-12 dark:bg-gray-900">
    <div class="relative py-3 sm:max-w-xl sm:mx-auto">
        <div class="absolute inset-0 bg-gradient-to-r from-indigo-500 to-purple-600 shadow-lg transform -skew-y-6 sm:skew-y-0 sm:-rotate-6 sm:rounded-3xl"></div>
        <div class="form-card relative px-4 py-10 bg-white shadow-lg sm:rounded-3xl sm:p-20 dark:bg-gray-800">
            <div class="max-w-md mx-auto">
                <div class="text-center mb-8">
                    <a href="<?php echo SITE_URL; ?>" class="text-3xl font-extrabold text-gray-900 dark:text-white">
                        <?php echo getSetting('site_name'); ?>
                    </a>
                    <h1 class="text-xl font-semibold mt-2 text-gray-900 dark:text-white">Account Verification</h1>
                </div>
                
                <div class="text-center py-8">
                    <?php if ($status === 'success'): ?>
                        <div class="h-16 w-16 mx-auto mb-4 bg-green-100 rounded-full flex items-center justify-center dark:bg-green-900">
                            <i class="fas fa-check-circle text-3xl text-green-500 dark:text-green-400"></i>
                        </div>
                        <h2 class="text-xl font-semibold text-gray-900 dark:text-white mb-2">Verification Successful</h2>
                        <p class="text-gray-600 dark:text-gray-300 mb-8"><?php echo $message; ?></p>
                        
                        <a href="<?php echo SITE_URL; ?>/login.php" class="inline-flex items-center justify-center px-5 py-3 border border-transparent text-base font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700">
                            <i class="fas fa-sign-in-alt mr-2"></i> Proceed to Login
                        </a>
                    <?php else: ?>
                        <div class="h-16 w-16 mx-auto mb-4 bg-red-100 rounded-full flex items-center justify-center dark:bg-red-900">
                            <i class="fas fa-times-circle text-3xl text-red-500 dark:text-red-400"></i>
                        </div>
                        <h2 class="text-xl font-semibold text-gray-900 dark:text-white mb-2">Verification Failed</h2>
                        <p class="text-gray-600 dark:text-gray-300 mb-8"><?php echo $message; ?></p>
                        
                        <div class="flex flex-col sm:flex-row justify-center space-y-3 sm:space-y-0 sm:space-x-4">
                            <a href="login.php" class="inline-flex items-center justify-center px-5 py-3 border border-transparent text-base font-medium rounded-md text-indigo-600 bg-white hover:bg-gray-50 border-indigo-600 dark:text-indigo-400 dark:bg-gray-700 dark:hover:bg-gray-600 dark:border-indigo-700">
                                <i class="fas fa-sign-in-alt mr-2"></i> Login
                            </a>
                            <a href="<?php echo SITE_URL; ?>/contact.php" class="inline-flex items-center justify-center px-5 py-3 border border-transparent text-base font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700">
                                <i class="fas fa-headset mr-2"></i> Contact Support
                            </a>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</body>
</html>