<?php
// File: /register/index.php
require_once '../includes/config.php';
require_once '../includes/functions.php';

// Check if user is already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}

$errors = [];
$successMessage = '';

// Check for referral code in URL
$referralCode = sanitizeInput($_GET['ref'] ?? ''); 
$contestCode = '';

// Check if this is a contest referral
$contestId = 0;
if (!empty($referralCode)) {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Check all active contests to see if this referral has a prefix/suffix matching a contest
    $stmt = $conn->prepare("
        SELECT id, prefix, suffix 
        FROM referral_contests 
        WHERE is_active = 1 
        AND NOW() BETWEEN start_date AND end_date
    ");
    $stmt->execute();
    $result = $stmt->get_result();
    
    while ($contest = $result->fetch_assoc()) {
        $prefix = $contest['prefix'] ?? '';
        $suffix = $contest['suffix'] ?? '';
        
        if (!empty($prefix) && strpos($referralCode, $prefix) === 0) {
            // This is a contest referral with a prefix
            $contestId = $contest['id'];
            $contestCode = $referralCode;
            $referralCode = substr($referralCode, strlen($prefix));
            break;
        } elseif (!empty($suffix) && substr($referralCode, -strlen($suffix)) === $suffix) {
            // This is a contest referral with a suffix
            $contestId = $contest['id'];
            $contestCode = $referralCode;
            $referralCode = substr($referralCode, 0, -strlen($suffix));
            break;
        }
    }
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $username = sanitizeInput($_POST['username'] ?? '');
    $email = sanitizeInput($_POST['email'] ?? '');
    $password = $_POST['password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';
    $fullName = sanitizeInput($_POST['full_name'] ?? '');
    $phone = sanitizeInput($_POST['phone'] ?? '');
    $referralCode = sanitizeInput($_POST['referral_code'] ?? '');
    $contestId = (int)($_POST['contest_id'] ?? 0);
    
    // Validate form data
    if (empty($username)) {
        $errors[] = 'Username is required';
    } elseif (!preg_match('/^[a-zA-Z0-9_]+$/', $username)) {
        $errors[] = 'Username can only contain letters, numbers, and underscores';
    }
    
    if (empty($email)) {
        $errors[] = 'Email is required';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid email format';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    } elseif (strlen($password) < 6) {
        $errors[] = 'Password must be at least 6 characters';
    }
    
    if ($password !== $confirmPassword) {
        $errors[] = 'Passwords do not match';
    }
    
    if (empty($fullName)) {
        $errors[] = 'Full name is required';
    }
    
    if (empty($phone)) {
        $errors[] = 'Phone number is required';
    }
    
    // If no errors, check if username or email already exists
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        $stmt = $conn->prepare("SELECT id FROM users WHERE username = ? OR email = ?");
        $stmt->bind_param("ss", $username, $email);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $errors[] = 'Username or email already exists';
        }
    }
    
    // Check referral code if provided
    $referrerId = null;
    if (!empty($referralCode) && empty($errors)) {
        $stmt = $conn->prepare("SELECT id FROM users WHERE username = ? OR referral_code = ?");
        $stmt->bind_param("ss", $referralCode, $referralCode);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            $errors[] = 'Invalid referral code';
        } else {
            $referrer = $result->fetch_assoc();
            $referrerId = $referrer['id'];
        }
    }
    
    // If still no errors, create user
    if (empty($errors)) {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Start a transaction
        $conn->begin_transaction();
        
        try {
            // Generate API token, verification token and hash password
            $apiToken = generateApiToken();
            $verificationToken = bin2hex(random_bytes(16));
            $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
            
            // The user's referral code is their username by default
            $userReferralCode = $username;
            
            $stmt = $conn->prepare("
                INSERT INTO users (
                    username, email, password, full_name, phone, api_token, 
                    verification_token, referrer_id, referral_code
                ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->bind_param(
                "sssssssss", 
                $username, $email, $hashedPassword, $fullName, $phone, 
                $apiToken, $verificationToken, $referrerId, $userReferralCode
            );
            
            if ($stmt->execute()) {
                $userId = $conn->insert_id;
                
                // If there was a referrer, record the referral
                if ($referrerId) {
                    $stmt = $conn->prepare("
                        INSERT INTO referrals (
                            referrer_id, referred_id, contest_id, status
                        ) VALUES (?, ?, ?, 'pending')
                    ");
                    $stmt->bind_param("iii", $referrerId, $userId, $contestId);
                    $stmt->execute();
                    
                    // If this is a contest referral, add an entry to the contest_entries table
                    if ($contestId > 0) {
                        // First, check if the referrer already has an entry for this contest
                        $stmt = $conn->prepare("
                            SELECT id FROM contest_entries 
                            WHERE user_id = ? AND contest_id = ?
                        ");
                        $stmt->bind_param("ii", $referrerId, $contestId);
                        $stmt->execute();
                        $result = $stmt->get_result();
                        
                        if ($result->num_rows === 0) {
                            // Create a new entry
                            $stmt = $conn->prepare("
                                INSERT INTO contest_entries (
                                    user_id, contest_id, referral_count
                                ) VALUES (?, ?, 1)
                            ");
                            $stmt->bind_param("ii", $referrerId, $contestId);
                            $stmt->execute();
                        } else {
                            // Update existing entry
                            $stmt = $conn->prepare("
                                UPDATE contest_entries
                                SET referral_count = referral_count + 1
                                WHERE user_id = ? AND contest_id = ?
                            ");
                            $stmt->bind_param("ii", $referrerId, $contestId);
                            $stmt->execute();
                        }
                    }
                    
                    // Update referrer's referral count
                    $stmt = $conn->prepare("
                        UPDATE users
                        SET referrals_count = referrals_count + 1
                        WHERE id = ?
                    ");
                    $stmt->bind_param("i", $referrerId);
                    $stmt->execute();
                }
                
                // Send verification email
                $verificationLink = SITE_URL . '/verify.php?token=' . $verificationToken;
                $emailSubject = 'Verify your account';
                $emailMessage = "
                    <p>Hello $fullName,</p>
                    <p>Thank you for registering. Please click the link below to verify your account:</p>
                    <p><a href='$verificationLink'>Verify My Account</a></p>
                    <p>Or copy and paste this link: $verificationLink</p>
                    <p>Regards,<br>" . getSetting('site_name') . " Team</p>
                ";
                
                if (sendEmail($email, $emailSubject, $emailMessage)) {
                    $successMessage = 'Registration successful! Please check your email to verify your account.';
                } else {
                    $successMessage = 'Registration successful! However, we could not send the verification email. Please contact support.';
                }
                
                // Commit the transaction
                $conn->commit();
            } else {
                throw new Exception('Registration failed: ' . $conn->error);
            }
        } catch (Exception $e) {
            // Rollback the transaction in case of error
            $conn->rollback();
            $errors[] = $e->getMessage();
        }
    }
}

// Page title
$pageTitle = "Create Account - " . getSetting('site_name');
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .register-container {
            width: 100%;
            max-width: 500px;
            margin: 2rem auto;
            padding: 2.5rem;
            border-radius: 10px;
            background-color: #1e1e1e;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.3);
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
            font-size: 16px; /* Prevent zooming on mobile */
            padding: 0.75rem 1rem;
            width: 100%;
            margin-bottom: 0.5rem;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
            box-shadow: 0 0 0 2px rgba(93, 92, 222, 0.3);
            outline: none;
        }
        .primary-button {
            background-color: #5D5CDE;
            padding: 0.75rem 1rem;
            font-size: 16px;
            font-weight: 600;
            width: 100%;
            border-radius: 6px;
            transition: all 0.3s ease;
        }
        .primary-button:hover {
            background-color: #4a49b8;
            transform: translateY(-1px);
        }
        .form-group {
            margin-bottom: 1.25rem;
        }
        .link {
            color: #5D5CDE;
            transition: color 0.3s ease;
        }
        .link:hover {
            color: #4a49b8;
            text-decoration: underline;
        }
        .error-alert {
            background-color: rgba(239, 68, 68, 0.1);
            border-left: 4px solid #ef4444;
            color: #fca5a5;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
        }
        .success-alert {
            background-color: rgba(16, 185, 129, 0.1);
            border-left: 4px solid #10b981;
            color: #6ee7b7;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
        }
        .referral-badge {
            background-color: rgba(93, 92, 222, 0.1);
            border-left: 4px solid #5D5CDE;
            color: #c4b5fd;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1.5rem;
            display: flex;
            align-items: center;
        }
        .referral-badge i {
            margin-right: 0.75rem;
            font-size: 1.25rem;
        }
        @media (max-width: 640px) {
            .register-container {
                padding: 1.5rem;
                max-width: 90%;
                margin: 1rem auto;
            }
        }
    </style>
</head>
<body>
    <div class="register-container">
        <div class="mb-8">
            <h2 class="text-center text-3xl font-extrabold text-white mb-4">
                Create your account
            </h2>
            <p class="text-center text-gray-400">
                Already have an account?
                <a href="<?php echo SITE_URL; ?>/login" class="link font-medium">
                    Sign in
                </a>
            </p>
        </div>
        
        <?php if (!empty($referralCode)): ?>
            <div class="referral-badge">
                <i class="fas fa-user-plus"></i>
                <div>
                    <?php if (!empty($contestCode)): ?>
                        <p class="font-medium">You've been invited to join a referral contest!</p>
                        <p class="text-sm">Referred by: <?php echo htmlspecialchars($referralCode); ?></p>
                    <?php else: ?>
                        <p class="font-medium">You've been referred by <?php echo htmlspecialchars($referralCode); ?></p>
                    <?php endif; ?>
                </div>
            </div>
        <?php endif; ?>
        
        <?php if (!empty($errors)): ?>
            <div class="error-alert" role="alert">
                <ul class="list-disc pl-5">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo $error; ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <?php if ($successMessage): ?>
            <div class="success-alert" role="alert">
                <p><?php echo $successMessage; ?></p>
            </div>
        <?php endif; ?>
        
        <form method="POST" action="">
            <!-- Hidden fields for referral tracking -->
            <input type="hidden" name="referral_code" value="<?php echo htmlspecialchars($referralCode); ?>">
            <input type="hidden" name="contest_id" value="<?php echo htmlspecialchars($contestId); ?>">
            
            <div class="form-group">
                <label for="full_name" class="block text-gray-300 mb-2">Full Name</label>
                <input id="full_name" name="full_name" type="text" required class="dark-input" 
                       placeholder="Enter your full name" 
                       value="<?php echo isset($_POST['full_name']) ? htmlspecialchars($_POST['full_name']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="username" class="block text-gray-300 mb-2">Username</label>
                <input id="username" name="username" type="text" required class="dark-input" 
                       placeholder="Choose a username" 
                       value="<?php echo isset($_POST['username']) ? htmlspecialchars($_POST['username']) : ''; ?>">
                <p class="text-sm text-gray-500">This will also be your referral code</p>
            </div>
            
            <div class="form-group">
                <label for="email" class="block text-gray-300 mb-2">Email address</label>
                <input id="email" name="email" type="email" autocomplete="email" required class="dark-input" 
                       placeholder="Enter your email address" 
                       value="<?php echo isset($_POST['email']) ? htmlspecialchars($_POST['email']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="phone" class="block text-gray-300 mb-2">Phone Number</label>
                <input id="phone" name="phone" type="text" required class="dark-input" 
                       placeholder="Enter your phone number" 
                       value="<?php echo isset($_POST['phone']) ? htmlspecialchars($_POST['phone']) : ''; ?>">
            </div>
            
            <div class="form-group">
                <label for="password" class="block text-gray-300 mb-2">Password</label>
                <input id="password" name="password" type="password" autocomplete="new-password" 
                       required class="dark-input" placeholder="Create a password">
            </div>
            
            <div class="form-group">
                <label for="confirm_password" class="block text-gray-300 mb-2">Confirm Password</label>
                <input id="confirm_password" name="confirm_password" type="password" 
                       autocomplete="new-password" required class="dark-input" 
                       placeholder="Confirm your password">
            </div>
            
            <?php if (empty($referralCode)): ?>
            <div class="form-group">
                <label for="manual_referral_code" class="block text-gray-300 mb-2">Referral Code (Optional)</label>
                <input id="manual_referral_code" name="referral_code" type="text" class="dark-input" 
                       placeholder="Enter referral code if you have one">
            </div>
            <?php endif; ?>

            <div class="mt-6">
                <button type="submit" class="primary-button text-white">
                    Create Account
                </button>
            </div>
        </form>
    </div>
</body>
</html>