<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

// Redirect if already logged in
if (isLoggedIn()) {
    redirect(SITE_URL . '/dashboard');
}

$token = isset($_GET['token']) ? sanitizeInput($_GET['token']) : '';
$success = false;
$error = false;
$message = '';
$validToken = false;
$email = '';

// Check if token is valid
if (!empty($token)) {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT email, expires_at FROM password_reset_tokens WHERE token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = true;
        $message = 'Invalid or expired password reset token';
    } else {
        $row = $result->fetch_assoc();
        $email = $row['email'];
        $expiresAt = strtotime($row['expires_at']);
        
        if (time() > $expiresAt) {
            $error = true;
            $message = 'Password reset token has expired. Please request a new one';
            
            // Delete expired token
            $stmt = $conn->prepare("DELETE FROM password_reset_tokens WHERE token = ?");
            $stmt->bind_param("s", $token);
            $stmt->execute();
        } else {
            $validToken = true;
        }
    }
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $validToken) {
    $password = $_POST['password'];
    $confirmPassword = $_POST['confirm_password'];
    
    // Validate passwords
    if (empty($password) || empty($confirmPassword)) {
        $error = true;
        $message = 'Both password fields are required';
    } elseif ($password !== $confirmPassword) {
        $error = true;
        $message = 'Passwords do not match';
    } elseif (strlen($password) < 8) {
        $error = true;
        $message = 'Password must be at least 8 characters long';
    } else {
        $db = getDB();
        $conn = $db->getConnection();
        
        // Hash the new password
        $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
        
        // Update user's password
        $stmt = $conn->prepare("UPDATE users SET password = ? WHERE email = ?");
        $stmt->bind_param("ss", $hashedPassword, $email);
        
        if ($stmt->execute()) {
            // Delete the token
            $stmt = $conn->prepare("DELETE FROM password_reset_tokens WHERE token = ?");
            $stmt->bind_param("s", $token);
            $stmt->execute();
            
            $success = true;
            $message = 'Password has been reset successfully. You can now log in with your new password';
        } else {
            $error = true;
            $message = 'Failed to reset password. Please try again later';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Password - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        /* Dark theme styles */
        body {
            background-color: #121212;
            color: #e0e0e0;
        }
        .dark-card {
            background-color: #1e1e1e;
            border-color: #333;
        }
        .dark-input {
            background-color: #2d2d2d;
            border-color: #444;
            color: #e0e0e0;
        }
        .dark-input:focus {
            border-color: #5D5CDE;
        }
        .primary-button {
            background-color: #5D5CDE;
        }
        .primary-button:hover {
            background-color: #4a49b8;
        }
        a.primary-link {
            color: #5D5CDE;
        }
        a.primary-link:hover {
            color: #4a49b8;
        }
    </style>
</head>
<body class="min-h-screen flex items-center justify-center bg-gray-900 py-12 px-4 sm:px-6 lg:px-8">
    <div class="max-w-md w-full space-y-8">
        <div>
            <h2 class="mt-6 text-center text-3xl font-extrabold text-white">
                Reset Password
            </h2>
            <p class="mt-2 text-center text-sm text-gray-400">
                Remember your password?
                <a href="login.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Sign in
                </a>
            </p>
        </div>
        
        <?php if ($success): ?>
            <div class="bg-green-900 border-l-4 border-green-500 text-green-200 p-4 mb-4" role="alert">
                <p><?php echo $message; ?></p>
            </div>
            
            <div class="text-center">
                <a href="<?php echo SITE_URL; ?>/login.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Go to Login
                </a>
            </div>
        <?php else: ?>
            <?php if ($error): ?>
                <div class="bg-red-900 border-l-4 border-red-500 text-red-200 p-4 mb-4" role="alert">
                    <p><?php echo $message; ?></p>
                </div>
                
                <?php if (!$validToken): ?>
                    <div class="text-center mt-4">
                        <a href="<?php echo SITE_URL; ?>/forgotpassword.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                            Request a new password reset link
                        </a>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
            
            <?php if ($validToken): ?>
                <p class="text-gray-400 text-center mb-4">
                    Enter your new password below.
                </p>
                
                <form class="mt-8 space-y-6" method="POST" action="">
                    <div class="rounded-md shadow-sm -space-y-px">
                        <div>
                            <label for="password" class="sr-only">New Password</label>
                            <input id="password" name="password" type="password" required class="dark-input appearance-none rounded-none relative block w-full px-3 py-2 border rounded-t-md focus:outline-none focus:ring-indigo-500 focus:z-10 sm:text-sm" placeholder="New Password">
                        </div>
                        <div>
                            <label for="confirm_password" class="sr-only">Confirm Password</label>
                            <input id="confirm_password" name="confirm_password" type="password" required class="dark-input appearance-none rounded-none relative block w-full px-3 py-2 border rounded-b-md focus:outline-none focus:ring-indigo-500 focus:z-10 sm:text-sm" placeholder="Confirm Password">
                        </div>
                    </div>
                    
                    <div>
                        <button type="submit" class="primary-button group relative w-full flex justify-center py-2 px-4 border border-transparent text-sm font-medium rounded-md text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                            Reset Password
                        </button>
                    </div>
                </form>
            <?php endif; ?>
            
            <div class="text-center mt-4">
                <a href="<?php echo SITE_URL; ?>/login.php" class="font-medium text-indigo-400 hover:text-indigo-300">
                    Back to Login
                </a>
            </div>
        <?php endif; ?>
    </div>
</body>
</html>