<?php
// File: /service_ids.php (at the root directory)
require_once __DIR__ . '/includes/config.php';
require_once __DIR__ . '/includes/functions.php';

/**
 * Adjust the brightness of a hex color
 * @param string $hex Hex color code
 * @param int $steps Steps to adjust (-255 to 255)
 * @return string Adjusted hex color
 */
function adjustBrightness($hex, $steps) {
    // Steps should be between -255 and 255. Negative = darker, positive = lighter
    $steps = max(-255, min(255, $steps));

    // Normalize into a six character long hex string
    $hex = str_replace('#', '', $hex);
    if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex, 0, 1), 2) . str_repeat(substr($hex, 1, 1), 2) . str_repeat(substr($hex, 2, 1), 2);
    }

    // Split into three parts: R, G and B
    $color_parts = str_split($hex, 2);
    $return = '#';

    foreach ($color_parts as $color) {
        $color = hexdec($color); // Convert to decimal
        $color = max(0, min(255, $color + $steps)); // Adjust color
        $return .= str_pad(dechex($color), 2, '0', STR_PAD_LEFT); // Make two char hex code
    }

    return $return;
}

$db = getDB();
$conn = $db->getConnection();

// Get filter parameters
$networkFilter = isset($_GET['network']) ? (int)$_GET['network'] : 0;
$typeFilter = isset($_GET['type']) ? (int)$_GET['type'] : 0;
$searchQuery = isset($_GET['search']) ? sanitizeInput($_GET['search']) : '';

// Get all networks for the filter dropdown
$networksStmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY name");
$networksStmt->execute();
$networksResult = $networksStmt->get_result();
$networks = [];
while ($network = $networksResult->fetch_assoc()) {
    $networks[] = $network;
}

// Get all data types for the filter dropdown
$dataTypesStmt = $conn->prepare("SELECT id, name FROM data_types WHERE status = 'active' ORDER BY name");
$dataTypesStmt->execute();
$dataTypesResult = $dataTypesStmt->get_result();
$dataTypes = [];
while ($type = $dataTypesResult->fetch_assoc()) {
    $dataTypes[] = $type;
}

// Get network ID mapping (for API clients)
function getNetworkIdMapping() {
    $db = getDB();
    $conn = $db->getConnection();
    
    $stmt = $conn->prepare("SELECT id, name FROM networks WHERE status = 'active' ORDER BY id");
    $stmt->execute();
    $result = $stmt->get_result();
    
    $mapping = [];
    $simpleId = 1;
    
    while ($row = $result->fetch_assoc()) {
        $mapping[$row['id']] = $simpleId;
        $simpleId++;
    }
    
    return $mapping;
}

$networkIdMapping = getNetworkIdMapping();

// Build the network reference data - this will be used for the network reference table
$networkReference = [];
foreach ($networks as $network) {
    $networkReference[] = [
        'id' => $network['id'],
        'name' => $network['name'],
        'api_id' => $networkIdMapping[$network['id']] ?? 'N/A'
    ];
}

// Build the query with filters for data plans
$query = "
    SELECT 
        dp.id,
        dp.plan_id,
        dp.name,
        dp.size,
        dp.validity,
        dp.price,
        dp.amount_api,
        dp.status,
        n.id AS network_id,
        n.name AS network_name,
        dt.id AS data_type_id,
        dt.name AS data_type_name
    FROM 
        data_plans dp
    JOIN 
        data_types dt ON dp.data_type_id = dt.id
    JOIN 
        networks n ON dt.network_id = n.id
    WHERE 
        dp.status = 'active'
";

$params = [];
$types = "";

if ($networkFilter > 0) {
    $query .= " AND n.id = ?";
    $params[] = $networkFilter;
    $types .= "i";
}

if ($typeFilter > 0) {
    $query .= " AND dt.id = ?";
    $params[] = $typeFilter;
    $types .= "i";
}

if (!empty($searchQuery)) {
    $query .= " AND (dp.plan_id LIKE ? OR dp.name LIKE ? OR dp.size LIKE ?)";
    $searchParam = "%$searchQuery%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "sss";
}

$query .= " ORDER BY n.name, dt.name, dp.price";

// Prepare and execute the query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();

// Fetch all plans
$plans = [];
while ($plan = $result->fetch_assoc()) {
    // Use API price if available, otherwise use regular price
    $plan['display_price'] = (!empty($plan['amount_api']) && $plan['amount_api'] > 0) ? $plan['amount_api'] : $plan['price'];
    $plans[] = $plan;
}

// Group plans by network for tab-based display
$networkGroups = [];
foreach ($plans as $plan) {
    $networkId = $plan['network_id'];
    if (!isset($networkGroups[$networkId])) {
        $networkGroups[$networkId] = [
            'name' => $plan['network_name'],
            'id' => $networkId,
            'api_id' => $networkIdMapping[$networkId] ?? 'N/A',
            'plans' => []
        ];
    }
    $networkGroups[$networkId]['plans'][] = $plan;
}

// Page title
$pageTitle = "Service IDs Reference";
$siteName = getSetting('site_name', 'VTU Platform');

// Get primary color from settings or use default
$primaryColor = getSetting('primary_color', '#5D5CDE');
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($pageTitle); ?> - <?php echo htmlspecialchars($siteName); ?></title>
    
    <!-- Favicon -->
    <link rel="icon" href="<?php echo htmlspecialchars(getSetting('favicon_url', '/assets/img/favicon.png')); ?>" type="image/png">
    
    <!-- CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    
    <style>
        :root {
            --primary-color: <?php echo $primaryColor; ?>;
            --primary-darker: <?php echo adjustBrightness($primaryColor, -30); ?>;
            --primary-lighter: <?php echo adjustBrightness($primaryColor, 60); ?>;
            --primary-lightest: <?php echo adjustBrightness($primaryColor, 120); ?>;
            
            /* Light mode colors */
            --bg-light: #f8fafc;
            --card-bg-light: #ffffff;
            --text-light: #2d3748;
            --text-muted-light: #718096;
            --border-light: #e2e8f0;
            --input-bg-light: #f7fafc;
            --hover-light: #f7fafc;
            --table-header-light: #f8fafc;
            --table-stripe-light: #f9fafb;
            
            /* Dark mode colors */
            --bg-dark: #111827;
            --card-bg-dark: #1e293b;
            --text-dark: #f7fafc;
            --text-muted-dark: #a0aec0;
            --border-dark: #334155;
            --input-bg-dark: #1e293b;
            --hover-dark: #1e293b;
            --table-header-dark: #1e293b;
            --table-stripe-dark: #1e1e30;
            
            /* Status colors */
            --success-bg-light: rgba(16, 185, 129, 0.1);
            --success-text-light: #10b981;
            --danger-bg-light: rgba(239, 68, 68, 0.1);
            --danger-text-light: #ef4444;
            
            --success-bg-dark: rgba(16, 185, 129, 0.15);
            --success-text-dark: #34d399;
            --danger-bg-dark: rgba(239, 68, 68, 0.15);
            --danger-text-dark: #f87171;
        }
        
        /* Base styles */
        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, sans-serif;
            background-color: var(--bg-dark);
            color: var(--text-dark);
            transition: background-color 0.3s ease, color 0.3s ease;
        }
        
        body.light-mode {
            background-color: var(--bg-light);
            color: var(--text-light);
        }
        
        /* Card styling */
        .service-card {
            background-color: var(--card-bg-dark);
            border-radius: 0.75rem;
            border: 1px solid var(--border-dark);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            margin-bottom: 1.5rem;
            transition: all 0.2s ease;
            overflow: hidden;
        }
        
        .light-mode .service-card {
            background-color: var(--card-bg-light);
            border: 1px solid var(--border-light);
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.05);
        }
        
        /* Header styling */
        .page-header {
            background: linear-gradient(135deg, var(--primary-color), var(--primary-darker));
            padding: 3rem 0 4rem;
            margin-bottom: -2rem;
            position: relative;
            overflow: hidden;
        }
        
        .page-header::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: url("data:image/svg+xml,%3Csvg width='60' height='60' viewBox='0 0 60 60' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='none' fill-rule='evenodd'%3E%3Cg fill='%23ffffff' fill-opacity='0.05'%3E%3Cpath d='M36 34v-4h-2v4h-4v2h4v4h2v-4h4v-2h-4zm0-30V0h-2v4h-4v2h4v4h2V6h4V4h-4zM6 34v-4H4v4H0v2h4v4h2v-4h4v-2H6zM6 4V0H4v4H0v2h4v4h2V6h4V4H6z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
            z-index: 0;
            opacity: 0.1;
        }
        
        .page-header .container {
            position: relative;
            z-index: 1;
        }
        
        .page-header h1 {
            font-weight: 700;
            color: white;
            margin-bottom: 0.5rem;
        }
        
        .page-header p {
            color: rgba(255, 255, 255, 0.8);
            font-size: 1.1rem;
        }
        
        /* Button styling */
        .btn-primary {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
            color: white;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.15);
            border-radius: 0.5rem;
            font-weight: 600;
            padding: 0.6rem 1.25rem;
            transition: all 0.2s ease;
        }
        
        .btn-primary:hover, .btn-primary:focus {
            background-color: var(--primary-darker);
            border-color: var(--primary-darker);
            color: white;
            transform: translateY(-1px);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.2);
        }
        
        .btn-outline-primary {
            color: var(--primary-color);
            border-color: var(--primary-color);
            background-color: transparent;
        }
        
        .btn-outline-primary:hover, .btn-outline-primary:focus {
            background-color: var(--primary-color);
            color: white;
        }
        
        .light-mode .btn-outline-primary {
            color: var(--primary-color);
            border-color: var(--primary-color);
        }
        
        .light-mode .btn-outline-primary:hover, .light-mode .btn-outline-primary:focus {
            background-color: var(--primary-color);
            color: white;
        }
        
        .btn-light {
            background-color: rgba(255, 255, 255, 0.15);
            border-color: transparent;
            color: white;
            backdrop-filter: blur(10px);
        }
        
        .btn-light:hover, .btn-light:focus {
            background-color: rgba(255, 255, 255, 0.25);
            color: white;
        }
        
        /* Filter styling */
        .filter-container {
            background-color: var(--card-bg-dark);
            border-radius: 1rem;
            padding: 1.5rem;
            margin-bottom: 1.5rem;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.15);
            position: relative;
            margin-top: -1rem;
            border: 1px solid var(--border-dark);
            z-index: 10;
        }
        
        .light-mode .filter-container {
            background-color: var(--card-bg-light);
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.05);
            border: 1px solid var(--border-light);
        }
        
        .form-control, .form-select {
            background-color: var(--input-bg-dark);
            border: 1px solid var(--border-dark);
            color: var(--text-dark);
            border-radius: 0.5rem;
            padding: 0.7rem 1rem;
            font-size: 0.95rem;
            transition: all 0.2s ease;
        }
        
        .light-mode .form-control, .light-mode .form-select {
            background-color: var(--input-bg-light);
            border: 1px solid var(--border-light);
            color: var(--text-light);
        }
        
        .form-control:focus, .form-select:focus {
            box-shadow: 0 0 0 0.25rem rgba(93, 92, 222, 0.25);
            border-color: var(--primary-color);
        }
        
        .light-mode .form-control:focus, .light-mode .form-select:focus {
            box-shadow: 0 0 0 0.25rem rgba(93, 92, 222, 0.15);
        }
        
        .input-group-text {
            background-color: transparent;
            border: none;
            color: var(--text-muted-dark);
        }
        
        .light-mode .input-group-text {
            color: var(--text-muted-light);
        }
        
        .clear-search {
            cursor: pointer;
            color: var(--text-muted-dark);
            transition: color 0.2s ease;
        }
        
        .clear-search:hover {
            color: var(--text-dark);
        }
        
        .light-mode .clear-search {
            color: var(--text-muted-light);
        }
        
        .light-mode .clear-search:hover {
            color: var(--text-light);
        }
        
        /* Tab styling */
        .nav-tabs {
            border-bottom: none;
            gap: 0.5rem;
            margin-bottom: 1.5rem;
            overflow-x: auto;
            flex-wrap: nowrap;
            scrollbar-width: thin;
            scrollbar-color: var(--primary-color) transparent;
            padding-bottom: 0.5rem;
        }
        
        .nav-tabs::-webkit-scrollbar {
            height: 4px;
        }
        
        .nav-tabs::-webkit-scrollbar-thumb {
            background-color: var(--primary-lighter);
            border-radius: 2px;
        }
        
        .nav-tabs .nav-item {
            margin-bottom: 0;
        }
        
        .nav-tabs .nav-link {
            background-color: var(--card-bg-dark);
            color: var(--text-dark);
            border: 1px solid var(--border-dark);
            border-radius: 0.5rem;
            padding: 0.75rem 1.25rem;
            font-weight: 500;
            font-size: 0.9rem;
            transition: all 0.2s ease;
            white-space: nowrap;
        }
        
        .light-mode .nav-tabs .nav-link {
            background-color: var(--input-bg-light);
            color: var(--text-light);
            border: 1px solid var(--border-light);
        }
        
        .nav-tabs .nav-link:hover {
            background-color: var(--hover-dark);
            transform: translateY(-1px);
        }
        
        .light-mode .nav-tabs .nav-link:hover {
            background-color: var(--hover-light);
        }
        
        .nav-tabs .nav-link.active {
            background-color: var(--primary-color);
            color: white;
            border-color: var(--primary-color);
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
        
        .light-mode .nav-tabs .nav-link.active {
            background-color: var(--primary-color);
            color: white;
            border-color: var(--primary-color);
        }
        
        /* Table styling */
        .table-container {
            overflow: auto;
            border-radius: 0.5rem;
            margin: 0 -1px;
        }
        
        .table {
            margin-bottom: 0;
            color: var(--text-dark);
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
        }
        
        .light-mode .table {
            color: var(--text-light);
        }
        
        .table th {
            background-color: var(--table-header-dark);
            color: var(--text-muted-dark);
            font-weight: 500;
            text-transform: uppercase;
            font-size: 0.75rem;
            letter-spacing: 0.5px;
            padding: 1rem 1.25rem;
            border: none;
            border-bottom: 1px solid var(--border-dark);
            position: sticky;
            top: 0;
            z-index: 5;
        }
        
        .light-mode .table th {
            background-color: var(--table-header-light);
            color: var(--text-muted-light);
            border-bottom: 1px solid var(--border-light);
        }
        
        .table td {
            padding: 1rem 1.25rem;
            vertical-align: middle;
            border: none;
            border-bottom: 1px solid var(--border-dark);
        }
        
        .light-mode .table td {
            border-bottom: 1px solid var(--border-light);
        }
        
        .table tr:last-child td {
            border-bottom: none;
        }
        
        .table-striped>tbody>tr:nth-of-type(odd)>* {
            background-color: var(--table-stripe-dark);
            box-shadow: inset 0 0 0 9999px var(--table-stripe-dark);
        }
        
        .light-mode .table-striped>tbody>tr:nth-of-type(odd)>* {
            background-color: var(--table-stripe-light);
            box-shadow: inset 0 0 0 9999px var(--table-stripe-light);
        }
        
        .table-hover>tbody>tr:hover>* {
            background-color: rgba(93, 92, 222, 0.1);
            box-shadow: inset 0 0 0 9999px rgba(93, 92, 222, 0.1);
        }
        
        /* Badge styling */
        .badge-status {
            padding: 0.35em 0.65em;
            font-size: 0.75em;
            font-weight: 500;
            border-radius: 0.375rem;
            display: inline-block;
        }
        
        .badge-active {
            background-color: var(--success-bg-dark);
            color: var(--success-text-dark);
        }
        
        .badge-inactive {
            background-color: var(--danger-bg-dark);
            color: var(--danger-text-dark);
        }
        
        .light-mode .badge-active {
            background-color: var(--success-bg-light);
            color: var(--success-text-light);
        }
        
        .light-mode .badge-inactive {
            background-color: var(--danger-bg-light);
            color: var(--danger-text-light);
        }
        
        /* Card header styling */
        .card-header {
            padding: 1.25rem 1.5rem;
            background-color: var(--card-bg-dark);
            border-bottom: 1px solid var(--border-dark);
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .light-mode .card-header {
            background-color: var(--card-bg-light);
            border-bottom: 1px solid var(--border-light);
        }
        
        .card-header h5 {
            margin: 0;
            font-weight: 600;
            color: var(--text-dark);
            display: flex;
            align-items: center;
        }
        
        .light-mode .card-header h5 {
            color: var(--text-light);
        }
        
        .card-header .header-badge {
            background-color: var(--primary-lighter);
            color: var(--primary-darker);
            font-size: 0.75rem;
            padding: 0.35em 0.65em;
            border-radius: 0.375rem;
            font-weight: 600;
        }
        
        .light-mode .card-header .header-badge {
            background-color: var(--primary-lightest);
            color: var(--primary-color);
        }
        
        /* API Documentation styling */
        .api-doc {
            background-color: var(--card-bg-dark);
            border-radius: 0.75rem;
            padding: 1.5rem;
            margin-top: 2rem;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            border: 1px solid var(--border-dark);
        }
        
        .light-mode .api-doc {
            background-color: var(--card-bg-light);
            border: 1px solid var(--border-light);
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.05);
        }
        
        .api-doc h4 {
            color: var(--text-dark);
            margin-bottom: 1rem;
            font-weight: 700;
            display: flex;
            align-items: center;
        }
        
        .light-mode .api-doc h4 {
            color: var(--text-light);
        }
        
        .api-doc h5 {
            color: var(--primary-color);
            margin-bottom: 0.75rem;
            font-weight: 600;
        }
        
        .code-block {
            background-color: #1e1e2e;
            color: #f8f8f2;
            border-radius: 0.5rem;
            padding: 1.25rem;
            margin: 1rem 0;
            font-family: 'SFMono-Regular', Consolas, 'Liberation Mono', Menlo, monospace;
            overflow-x: auto;
            border: 1px solid #2e2e42;
            position: relative;
        }
        
        .light-mode .code-block {
            background-color: #2d3748;
            border: 1px solid #4a5568;
            color: #f8f8f2;
        }
        
        .code-block pre {
            margin: 0;
            color: #f8f8f2;
        }
        
        .copy-code {
            position: absolute;
            top: 0.5rem;
            right: 0.5rem;
            background: rgba(255, 255, 255, 0.1);
            border: none;
            border-radius: 0.25rem;
            color: #f8f8f2;
            padding: 0.25rem 0.5rem;
            font-size: 0.75rem;
            cursor: pointer;
            transition: all 0.2s ease;
        }
        
        .copy-code:hover {
            background: rgba(255, 255, 255, 0.2);
        }
        
        /* Alert styling */
        .alert {
            border-radius: 0.5rem;
            padding: 1rem 1.25rem;
            margin-bottom: 1.5rem;
            border: none;
            display: flex;
            align-items: flex-start;
            gap: 0.75rem;
        }
        
        .alert-info {
            background-color: rgba(59, 130, 246, 0.1);
            color: #3b82f6;
            border-left: 4px solid #3b82f6;
        }
        
        .light-mode .alert-info {
            background-color: rgba(59, 130, 246, 0.05);
            color: #2563eb;
        }
        
        .alert-warning {
            background-color: rgba(245, 158, 11, 0.1);
            color: #f59e0b;
            border-left: 4px solid #f59e0b;
        }
        
        .light-mode .alert-warning {
            background-color: rgba(245, 158, 11, 0.05);
            color: #d97706;
        }

        /* ID badge styling */
        .id-badge {
            display: inline-block;
            font-family: 'SFMono-Regular', Consolas, 'Liberation Mono', Menlo, monospace;
            font-weight: 600;
            padding: 0.25rem 0.5rem;
            border-radius: 0.25rem;
            background-color: var(--primary-color);
            color: white;
        }
        
        /* Footer styling */
        .footer {
            background-color: var(--card-bg-dark);
            padding: 2.5rem 0;
            margin-top: 3rem;
            border-top: 1px solid var(--border-dark);
        }
        
        .light-mode .footer {
            background-color: var(--card-bg-light);
            border-top: 1px solid var(--border-light);
        }
        
        .footer h5 {
            font-weight: 600;
            margin-bottom: 1rem;
            color: var(--text-dark);
        }
        
        .light-mode .footer h5 {
            color: var(--text-light);
        }
        
        .footer .text-muted {
            color: var(--text-muted-dark) !important;
        }
        
        .light-mode .footer .text-muted {
            color: var(--text-muted-light) !important;
        }
        
        /* Color mode toggle button */
        .color-mode-toggle {
            width: 45px;
            height: 45px;
            border-radius: 50%;
            background-color: var(--primary-color);
            color: white;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            position: fixed;
            bottom: 20px;
            right: 20px;
            z-index: 1000;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.3);
            border: none;
            transition: all 0.3s ease;
        }
        
        .color-mode-toggle:hover {
            transform: scale(1.1);
            background-color: var(--primary-darker);
        }
        
        /* Mobile optimizations */
        @media (max-width: 768px) {
            .page-header {
                padding: 2rem 0 3rem;
            }
            
            .page-header h1 {
                font-size: 1.75rem;
            }
            
            .filter-container {
                padding: 1.25rem;
            }
            
            .service-card, .api-doc {
                padding: 0;
            }
            
            .card-header {
                padding: 1rem;
            }
            
            .table-responsive-mobile {
                display: block;
                width: 100%;
                overflow-x: auto;
                -webkit-overflow-scrolling: touch;
            }
            
            .table-responsive-mobile .table {
                width: 100%;
                max-width: none;
            }
            
            .btn {
                padding: 0.5rem 1rem;
            }
            
            .table th, .table td {
                padding: 0.75rem 1rem;
                white-space: nowrap;
            }
            
            .api-doc {
                padding: 1.25rem;
                margin-top: 1.5rem;
            }
            
            .search-filter-row {
                margin-top: 1rem;
            }
            
            .search-filter-row .btn {
                margin-top: 0.75rem;
                width: 100%;
            }
            
            .search-filter-row .form-control,
            .search-filter-row .form-select {
                margin-bottom: 0.75rem;
            }
        }
        
        /* Extra small screens */
        @media (max-width: 576px) {
            .filter-tabs .nav-link {
                padding: 0.5rem 1rem;
                font-size: 0.8rem;
            }
            
            .card-header {
                flex-direction: column;
                align-items: flex-start;
                gap: 0.5rem;
            }
            
            .card-header .header-badge {
                align-self: flex-start;
            }
        }
        
        /* Custom scrollbar */
        ::-webkit-scrollbar {
            width: 8px;
            height: 8px;
        }
        
        ::-webkit-scrollbar-track {
            background: transparent;
        }
        
        ::-webkit-scrollbar-thumb {
            background: var(--primary-lighter);
            border-radius: 4px;
        }
        
        ::-webkit-scrollbar-thumb:hover {
            background: var(--primary-color);
        }
        
        /* Syntax highlighting for code */
        .highlight-comment { color: #6272a4; }
        .highlight-keyword { color: #ff79c6; }
        .highlight-string { color: #f1fa8c; }
        .highlight-number { color: #bd93f9; }
        .highlight-literal { color: #f1fa8c; }
        .highlight-punctuation { color: #f8f8f2; }
    </style>
</head>
<body class="<?php echo (isset($_COOKIE['lightMode']) && $_COOKIE['lightMode'] === 'true') ? 'light-mode' : ''; ?>">
    <!-- Color mode toggle button -->
    <button class="color-mode-toggle" id="colorModeToggle" aria-label="Toggle dark/light mode">
        <i class="fas <?php echo (isset($_COOKIE['lightMode']) && $_COOKIE['lightMode'] === 'true') ? 'fa-moon' : 'fa-sun'; ?>"></i>
    </button>

    <!-- Header -->
    <div class="page-header">
        <div class="container">
            <div class="row align-items-center">
                <div class="col-lg-7 col-md-8">
                    <h1 class="display-5 fw-bold"><?php echo htmlspecialchars($pageTitle); ?></h1>
                    <p class="lead mb-3">Complete list of service IDs for API integration</p>
                </div>
                <div class="col-lg-5 col-md-4 d-flex justify-content-md-end mt-3 mt-md-0">
                    <a href="/dashboard" class="btn btn-light me-2">
                        <i class="fas fa-tachometer-alt me-2"></i> Dashboard
                    </a>
                    <a href="/api/documentation" class="btn btn-light">
                        <i class="fas fa-book me-2"></i> API Docs
                    </a>
                </div>
            </div>
        </div>
    </div>

    <div class="container">
        <!-- Search and filter -->
        <form method="GET" action="" class="mb-4">
            <div class="filter-container">
                <div class="row g-3">
                    <!-- Search bar -->
                    <div class="col-lg-5 col-md-6">
                        <div class="input-group">
                            <span class="input-group-text">
                                <i class="fas fa-search"></i>
                            </span>
                            <input type="text" name="search" placeholder="Search by ID, name or size" class="form-control" 
                                   value="<?php echo htmlspecialchars($searchQuery ?? ''); ?>" id="searchInput">
                            <?php if (!empty($searchQuery)): ?>
                            <span class="input-group-text clear-search" id="clearSearch">
                                <i class="fas fa-times"></i>
                            </span>
                            <?php endif; ?>
                        </div>
                    </div>
                    
                    <!-- Network filter -->
                    <div class="col-lg-3 col-md-6">
                        <select name="network" class="form-select">
                            <option value="0">All Networks</option>
                            <?php foreach ($networks as $network): ?>
                            <option value="<?php echo $network['id']; ?>" <?php echo ($networkFilter == $network['id']) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($network['name'] ?? ''); ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <!-- Data type filter -->
                    <div class="col-lg-3 col-md-6">
                        <select name="type" class="form-select">
                            <option value="0">All Data Types</option>
                            <?php foreach ($dataTypes as $type): ?>
                            <option value="<?php echo $type['id']; ?>" <?php echo ($typeFilter == $type['id']) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($type['name'] ?? ''); ?>
                            </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <!-- Filter button -->
                    <div class="col-lg-1 col-md-6">
                        <button type="submit" class="btn btn-primary w-100">
                            <i class="fas fa-filter me-md-2"></i><span class="d-none d-xl-inline">Filter</span>
                        </button>
                    </div>
                </div>
                
                <!-- Filter status -->
                <?php if (!empty($searchQuery) || $networkFilter > 0 || $typeFilter > 0): ?>
                <div class="mt-3 d-flex justify-content-between align-items-center">
                    <div>
                        <span class="badge-status badge-active me-2">
                            <i class="fas fa-filter me-1"></i> Filters applied
                        </span>
                        <?php if (!empty($searchQuery)): ?>
                        <span class="badge bg-light text-dark me-2">Search: <?php echo htmlspecialchars($searchQuery); ?></span>
                        <?php endif; ?>
                        <?php if ($networkFilter > 0): 
                            $selectedNetwork = array_filter($networks, function($n) use ($networkFilter) { return $n['id'] == $networkFilter; });
                            $selectedNetwork = reset($selectedNetwork);
                        ?>
                        <span class="badge bg-light text-dark me-2">Network: <?php echo htmlspecialchars($selectedNetwork['name'] ?? ''); ?></span>
                        <?php endif; ?>
                        <?php if ($typeFilter > 0): 
                            $selectedType = array_filter($dataTypes, function($t) use ($typeFilter) { return $t['id'] == $typeFilter; });
                            $selectedType = reset($selectedType);
                        ?>
                        <span class="badge bg-light text-dark">Type: <?php echo htmlspecialchars($selectedType['name'] ?? ''); ?></span>
                        <?php endif; ?>
                    </div>
                    <a href="service_ids.php" class="btn btn-sm btn-outline-primary">
                        <i class="fas fa-times me-1"></i> Clear filters
                    </a>
                </div>
                <?php endif; ?>
            </div>
        </form>

        <!-- Network Reference Guide -->
        <div class="service-card mb-4">
            <div class="card-header">
                <h5>
                    <i class="fas fa-network-wired me-2" style="color: var(--primary-color);"></i>
                    Network Reference
                </h5>
                <span class="header-badge"><?php echo count($networkReference); ?> networks</span>
            </div>
            <div class="table-container">
                <table class="table table-striped table-hover">
                    <thead>
                        <tr>
                            <th>Network ID (API)</th>
                            <th>Internal ID</th>
                            <th>Network Name</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($networkReference as $network): ?>
                        <tr>
                            <td><span class="id-badge"><?php echo htmlspecialchars($network['api_id'] ?? ''); ?></span></td>
                            <td><?php echo htmlspecialchars($network['id'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($network['name'] ?? ''); ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <?php if (count($plans) === 0): ?>
        <!-- Empty state -->
        <div class="service-card p-4 text-center">
            <div class="py-5">
                <i class="fas fa-search fa-3x mb-3 text-muted"></i>
                <h4>No services found</h4>
                <p class="text-muted">No services match your filter criteria.</p>
                <a href="service_ids.php" class="btn btn-outline-primary mt-2">
                    <i class="fas fa-times me-2"></i> Clear filters
                </a>
            </div>
        </div>
        <?php else: ?>

        <!-- Network tabs - only show when not filtering -->
        <?php if (empty($searchQuery) && $networkFilter == 0 && $typeFilter == 0): ?>
        <ul class="nav nav-tabs filter-tabs" id="networkTabs" role="tablist">
            <li class="nav-item" role="presentation">
                <button class="nav-link active" id="all-tab" data-bs-toggle="tab" data-bs-target="#all-content" type="button" role="tab" aria-controls="all-content" aria-selected="true">
                    <i class="fas fa-layer-group me-2"></i>All Services
                </button>
            </li>
            <?php foreach ($networkGroups as $networkId => $network): ?>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="network-<?php echo $networkId; ?>-tab" data-bs-toggle="tab" data-bs-target="#network-<?php echo $networkId; ?>-content" type="button" role="tab">
                    <i class="fas fa-broadcast-tower me-2"></i><?php echo htmlspecialchars($network['name'] ?? ''); ?>
                </button>
            </li>
            <?php endforeach; ?>
        </ul>
        
        <div class="tab-content" id="networkTabsContent">
            <div class="tab-pane fade show active" id="all-content" role="tabpanel" aria-labelledby="all-tab">
        <?php endif; ?>
        
        <!-- Main data table -->
        <div class="service-card">
            <div class="card-header">
                <h5>
                    <i class="fas fa-table me-2" style="color: var(--primary-color);"></i>
                    Data Plan Reference
                </h5>
                <span class="header-badge"><?php echo count($plans); ?> plans</span>
            </div>
            <div class="table-container table-responsive-mobile">
                <table class="table table-striped table-hover">
                    <thead>
                        <tr>
                            <th>Plan ID (API)</th>
                            <th>Network</th>
                            <th>Network ID (API)</th>
                            <th>Name</th>
                            <th>Size</th>
                            <th>Validity</th>
                            <th>API Price (₦)</th>
                            <th>Data Type</th>
                            <th>Status</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($plans as $plan): ?>
                        <tr>
                            <td><span class="id-badge"><?php echo htmlspecialchars($plan['plan_id'] ?? ''); ?></span></td>
                            <td><?php echo htmlspecialchars($plan['network_name'] ?? ''); ?></td>
                            <td><span class="id-badge"><?php echo isset($networkIdMapping[$plan['network_id']]) ? $networkIdMapping[$plan['network_id']] : 'N/A'; ?></span></td>
                            <td><?php echo htmlspecialchars($plan['name'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($plan['size'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($plan['validity'] ?? ''); ?></td>
                            <td><?php echo number_format((float)($plan['display_price'] ?? 0), 2); ?></td>
                            <td><?php echo htmlspecialchars($plan['data_type_name'] ?? ''); ?></td>
                            <td>
                                <span class="badge-status <?php echo ($plan['status'] == 'active') ? 'badge-active' : 'badge-inactive'; ?>">
                                    <?php echo ucfirst($plan['status'] ?? 'unknown'); ?>
                                </span>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        
        <?php if (empty($searchQuery) && $networkFilter == 0 && $typeFilter == 0): ?>
            </div> <!-- End of all-content tab pane -->
            
            <!-- Individual network tabs -->
            <?php foreach ($networkGroups as $networkId => $network): ?>
            <div class="tab-pane fade" id="network-<?php echo $networkId; ?>-content" role="tabpanel">
                <div class="service-card">
                    <div class="card-header">
                        <h5>
                            <i class="fas fa-broadcast-tower me-2" style="color: var(--primary-color);"></i>
                            <?php echo htmlspecialchars($network['name'] ?? ''); ?> Data Plans
                            <span class="ms-2 badge bg-primary">Network ID: <?php echo $network['api_id']; ?></span>
                        </h5>
                        <span class="header-badge"><?php echo count($network['plans']); ?> plans</span>
                    </div>
                    <div class="table-container table-responsive-mobile">
                        <table class="table table-striped table-hover">
                            <thead>
                                <tr>
                                    <th>Plan ID (API)</th>
                                    <th>Name</th>
                                    <th>Size</th>
                                    <th>Validity</th>
                                    <th>API Price (₦)</th>
                                    <th>Data Type</th>
                                    <th>Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($network['plans'] as $plan): ?>
                                <tr>
                                    <td><span class="id-badge"><?php echo htmlspecialchars($plan['plan_id'] ?? ''); ?></span></td>
                                    <td><?php echo htmlspecialchars($plan['name'] ?? ''); ?></td>
                                    <td><?php echo htmlspecialchars($plan['size'] ?? ''); ?></td>
                                    <td><?php echo htmlspecialchars($plan['validity'] ?? ''); ?></td>
                                    <td><?php echo number_format((float)($plan['display_price'] ?? 0), 2); ?></td>
                                    <td><?php echo htmlspecialchars($plan['data_type_name'] ?? ''); ?></td>
                                    <td>
                                        <span class="badge-status <?php echo ($plan['status'] == 'active') ? 'badge-active' : 'badge-inactive'; ?>">
                                            <?php echo ucfirst($plan['status'] ?? 'unknown'); ?>
                                        </span>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
            <?php endforeach; ?>
        </div> <!-- End of tab-content -->
        <?php endif; ?>
        <?php endif; ?>

        <!-- API Integration Guide -->
        <div class="api-doc mt-4">
            <h4><i class="fas fa-code me-2" style="color: var(--primary-color);"></i> API Integration Guide</h4>
            <p class="text-muted mb-4">Use these service IDs to integrate with our API. Below are examples of how to use them in your requests:</p>
            
            <div class="alert alert-info mb-4">
                <i class="fas fa-info-circle fa-lg"></i>
                <div>
                    <strong>ID Reference Guide:</strong> The Plan IDs and Network IDs shown in this reference are the exact values you should use in your API requests. These IDs are unique and stable identifiers for our services.
                </div>
            </div>
            
            <div class="row mt-4">
                <div class="col-lg-6 mb-4 mb-lg-0">
                    <h5><i class="fas fa-code-branch me-2"></i> API v1 (Data Purchase)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV1Data">Copy</button>
<pre><span class="highlight-comment">// API v1 Data Purchase Example</span>
<span class="highlight-keyword">POST</span> /api/v1/data/buy
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"plan_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">5</span><span class="highlight-punctuation">,</span>     <span class="highlight-comment">// The Plan ID from the table above</span>
  <span class="highlight-string">"phone"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"08012345678"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"reference"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"optional-reference-123"</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
                
                <div class="col-lg-6">
                    <h5><i class="fas fa-code-branch me-2"></i> API v2 (Data Purchase)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV2Data">Copy</button>
<pre><span class="highlight-comment">// API v2 Data Purchase Example</span>
<span class="highlight-keyword">POST</span> /api/v2/data
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"network"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>      <span class="highlight-comment">// The Network ID from the table</span>
  <span class="highlight-string">"mobile_number"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"08012345678"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"plan"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">5</span><span class="highlight-punctuation">,</span>        <span class="highlight-comment">// The Plan ID from the table</span>
  <span class="highlight-string">"request_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"optional-request-id-123"</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
            </div>
            
            <div class="row mt-4">
                <div class="col-lg-6 mb-4 mb-lg-0">
                    <h5><i class="fas fa-code-branch me-2"></i> API v1 (Airtime Purchase)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV1Airtime">Copy</button>
<pre><span class="highlight-comment">// API v1 Airtime Purchase Example</span>
<span class="highlight-keyword">POST</span> /api/v1/airtime/buy
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"network_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>    <span class="highlight-comment">// The Network ID from the table</span>
  <span class="highlight-string">"phone"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"08012345678"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"amount"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">500</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"reference"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"optional-reference-456"</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
                
                <div class="col-lg-6">
                    <h5><i class="fas fa-code-branch me-2"></i> API v2 (Airtime Purchase)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV2Airtime">Copy</button>
<pre><span class="highlight-comment">// API v2 Airtime Purchase Example</span>
<span class="highlight-keyword">POST</span> /api/v2/topup <span class="highlight-comment">// or /api/v2/airtime</span>
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"network"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>      <span class="highlight-comment">// The Network ID from the table</span>
  <span class="highlight-string">"mobile_number"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"08012345678"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"amount"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">500</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"request_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"optional-request-id-456"</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
            </div>
            
            <div class="row mt-4">
                <div class="col-lg-6 mb-4 mb-lg-0">
                    <h5><i class="fas fa-list me-2"></i> API v1 (Get Data Plans)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV1GetPlans">Copy</button>
<pre><span class="highlight-comment">// API v1 Get Data Plans Example</span>
<span class="highlight-keyword">GET</span> /api/v1/data_plans<span class="highlight-punctuation">?</span>network_id<span class="highlight-punctuation">=</span><span class="highlight-number">1</span> <span class="highlight-comment">// Optional network filter</span>

<span class="highlight-comment">// Response format</span>
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"status"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"success"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"message"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"Data plans retrieved successfully"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"data"</span><span class="highlight-punctuation">:</span> <span class="highlight-punctuation">[</span>
    <span class="highlight-punctuation">{</span>
      <span class="highlight-string">"id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>             <span class="highlight-comment">// Plan ID to use in purchases</span>
      <span class="highlight-string">"network_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>
      <span class="highlight-comment">// Other plan details...</span>
    <span class="highlight-punctuation">}</span><span class="highlight-punctuation">,</span>
    <span class="highlight-comment">// More plans...</span>
  <span class="highlight-punctuation">]</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
                
                <div class="col-lg-6">
                    <h5><i class="fas fa-list me-2"></i> API v2 (Get Data Plans)</h5>
                    <div class="code-block">
                        <button class="copy-code" id="copyV2GetPlans">Copy</button>
<pre><span class="highlight-comment">// API v2 Get Data Plans Example</span>
<span class="highlight-keyword">GET</span> /api/v2/data-plans<span class="highlight-punctuation">?</span>network<span class="highlight-punctuation">=</span><span class="highlight-number">1</span> <span class="highlight-comment">// Optional network filter</span>

<span class="highlight-comment">// Response format</span>
<span class="highlight-punctuation">{</span>
  <span class="highlight-string">"status"</span><span class="highlight-punctuation">:</span> <span class="highlight-literal">true</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"message"</span><span class="highlight-punctuation">:</span> <span class="highlight-string">"Data plans retrieved successfully"</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"data"</span><span class="highlight-punctuation">:</span> <span class="highlight-punctuation">[</span>
    <span class="highlight-punctuation">{</span>
      <span class="highlight-string">"id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>           <span class="highlight-comment">// Plan ID to use in purchases</span>
      <span class="highlight-string">"network_id"</span><span class="highlight-punctuation">:</span> <span class="highlight-number">1</span><span class="highlight-punctuation">,</span>
      <span class="highlight-comment">// Other plan details...</span>
    <span class="highlight-punctuation">}</span><span class="highlight-punctuation">,</span>
    <span class="highlight-comment">// More plans...</span>
  <span class="highlight-punctuation">]</span><span class="highlight-punctuation">,</span>
  <span class="highlight-string">"user"</span><span class="highlight-punctuation">:</span> <span class="highlight-punctuation">[</span>...same as data...<span class="highlight-punctuation">]</span>
<span class="highlight-punctuation">}</span></pre>
                    </div>
                </div>
            </div>
            
            <div class="alert alert-warning mt-4">
                <i class="fas fa-exclamation-triangle fa-lg"></i>
                <div>
                    <strong>Important Note:</strong> Always use the Plan IDs and Network IDs as shown in the tables above for API requests. The IDs are stable and won't change even if plans are reordered or deleted, ensuring reliable integration.
                </div>
            </div>
            
            <p class="text-center mt-4">
                <a href="/api/documentation" class="btn btn-primary">
                    <i class="fas fa-book me-2"></i> View Complete API Documentation
                </a>
            </p>
        </div>
    </div>

    <!-- Footer -->
    <footer class="footer mt-5">
        <div class="container">
            <div class="row">
                <div class="col-md-6 mb-4 mb-md-0">
                    <h5><?php echo htmlspecialchars($siteName); ?></h5>
                    <p class="text-muted">Your reliable VTU service provider</p>
                </div>
                <div class="col-md-6 text-md-end">
                    <p class="text-muted">&copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($siteName); ?>. All rights reserved.</p>
                </div>
            </div>
        </div>
    </footer>

    <!-- JavaScript -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Color mode toggle
            const colorModeToggle = document.getElementById('colorModeToggle');
            const icon = colorModeToggle.querySelector('i');
            
            // Toggle and save color mode preference
            colorModeToggle.addEventListener('click', function() {
                document.body.classList.toggle('light-mode');
                
                if (document.body.classList.contains('light-mode')) {
                    document.cookie = "lightMode=true; path=/; max-age=31536000"; // 1 year
                    icon.classList.remove('fa-sun');
                    icon.classList.add('fa-moon');
                } else {
                    document.cookie = "lightMode=false; path=/; max-age=31536000";
                    icon.classList.remove('fa-moon');
                    icon.classList.add('fa-sun');
                }
            });
            
            // Clear search
            const clearSearchBtn = document.getElementById('clearSearch');
            if (clearSearchBtn) {
                clearSearchBtn.addEventListener('click', function() {
                    const searchInput = document.getElementById('searchInput');
                    searchInput.value = '';
                    // Update the form to remove just the search parameter
                    const currentUrl = new URL(window.location.href);
                    currentUrl.searchParams.delete('search');
                    window.location.href = currentUrl.toString();
                });
            }
            
            // Copy code blocks
            function setupCopyButton(buttonId) {
                const copyButton = document.getElementById(buttonId);
                if (copyButton) {
                    copyButton.addEventListener('click', function() {
                        const codeBlock = this.nextElementSibling;
                        const range = document.createRange();
                        range.selectNode(codeBlock);
                        window.getSelection().removeAllRanges();
                        window.getSelection().addRange(range);
                        
                        try {
                            document.execCommand('copy');
                            copyButton.textContent = 'Copied!';
                            setTimeout(() => {
                                copyButton.textContent = 'Copy';
                            }, 2000);
                        } catch (err) {
                            copyButton.textContent = 'Failed!';
                            console.error('Copy failed:', err);
                        }
                        
                        window.getSelection().removeAllRanges();
                    });
                }
            }
            
            // Set up all copy buttons
            setupCopyButton('copyV1Data');
            setupCopyButton('copyV2Data');
            setupCopyButton('copyV1Airtime');
            setupCopyButton('copyV2Airtime');
            setupCopyButton('copyV1GetPlans');
            setupCopyButton('copyV2GetPlans');
            
            // Listen for system color scheme changes
            window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', function(e) {
                const cookieValue = document.cookie
                    .split('; ')
                    .find(row => row.startsWith('lightMode='))
                    ?.split('=')[1];
                    
                // Only change if user hasn't set a preference
                if (!cookieValue) {
                    if (e.matches) {
                        document.body.classList.remove('light-mode');
                        icon.classList.remove('fa-moon');
                        icon.classList.add('fa-sun');
                    } else {
                        document.body.classList.add('light-mode');
                        icon.classList.remove('fa-sun');
                        icon.classList.add('fa-moon');
                    }
                }
            });
        });
    </script>
</body>
</html>