<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

$token = isset($_GET['token']) ? sanitizeInput($_GET['token']) : '';
$verified = false;
$error = '';

if (empty($token)) {
    $error = 'No verification token provided';
} else {
    $db = getDB();
    $conn = $db->getConnection();
    
    // Find user with this token
    $stmt = $conn->prepare("SELECT id, email_verified FROM users WHERE verification_token = ? AND status != 'deleted'");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        $error = 'Invalid verification token. The token may be incorrect or already used.';
    } else {
        $user = $result->fetch_assoc();
        
        if ($user['email_verified'] == 1) {
            $error = 'This email address has already been verified.';
        } else {
            // Update user to verified status
            $stmt = $conn->prepare("UPDATE users SET email_verified = 1, verification_token = NULL, status = 'active' WHERE id = ?");
            $stmt->bind_param("i", $user['id']);
            
            if ($stmt->execute()) {
                $verified = true;
                
                // Create notification for user
                $stmt = $conn->prepare("
                    INSERT INTO notifications 
                    (user_id, title, message, type, is_read)
                    VALUES (?, 'Account Verified', 'Your email address has been verified successfully. Welcome to our platform!', 'success', 0)
                ");
                $stmt->bind_param("i", $user['id']);
                $stmt->execute();
            } else {
                $error = 'An error occurred while verifying your account. Please try again later.';
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Account Verification - <?php echo getSetting('site_name'); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <script>
        // Check for dark mode preference
        if (window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
            document.documentElement.classList.add('dark');
        }
        
        // Listen for changes in dark mode preference
        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', event => {
            if (event.matches) {
                document.documentElement.classList.add('dark');
            } else {
                document.documentElement.classList.remove('dark');
            }
        });
    </script>
    <style>
        :root {
            --bg-primary: #FFFFFF;
            --bg-secondary: #F9FAFB;
            --bg-card: #FFFFFF;
            --text-primary: #1F2937;
            --text-secondary: #6B7280;
            --accent-color: #5D5CDE;
            --accent-hover: #4a49b8;
            --border-color: #E5E7EB;
        }
        
        .dark {
            --bg-primary: #121212;
            --bg-secondary: #1e1e1e;
            --bg-card: #252525;
            --text-primary: #e0e0e0;
            --text-secondary: #a0a0a0;
        }
        
        body {
            background-color: var(--bg-primary);
            color: var(--text-primary);
        }
        
        .auth-card {
            background-color: var(--bg-card);
            border-color: var(--border-color);
        }
        
        .accent-button {
            background-color: var(--accent-color);
        }
        
        .accent-button:hover {
            background-color: var(--accent-hover);
        }
    </style>
</head>
<body class="min-h-screen flex flex-col">
    <!-- Header/Navbar -->
    <header class="bg-gray-800 text-white shadow">
        <div class="container mx-auto px-4 py-3 flex justify-between items-center">
            <a href="<?php echo SITE_URL; ?>" class="font-bold text-xl"><?php echo getSetting('site_name'); ?></a>
            <div>
                <a href="<?php echo SITE_URL; ?>/login/login.php" class="text-white hover:text-gray-300">Log In</a>
                <span class="mx-2 text-gray-500">|</span>
                <a href="<?php echo SITE_URL; ?>/login/register.php" class="text-white hover:text-gray-300">Register</a>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <main class="flex-grow flex items-center justify-center p-4">
        <div class="max-w-md w-full">
            <div class="auth-card rounded-lg shadow p-6">
                <div class="text-center mb-6">
                    <h1 class="text-2xl font-bold text-white">Account Verification</h1>
                    
                    <?php if ($verified): ?>
                        <div class="h-20 w-20 mx-auto mt-6 mb-4 bg-green-500 bg-opacity-20 rounded-full flex items-center justify-center">
                            <i class="fas fa-check-circle text-5xl text-green-500"></i>
                        </div>
                        <h2 class="text-xl font-semibold text-white mb-2">Verification Successful</h2>
                        <p class="text-gray-400 mb-6">Your email address has been verified successfully. You can now log in to your account.</p>
                        
                        <a href="<?php echo SITE_URL; ?>/login/login.php" class="accent-button inline-block w-full py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 text-center">
                            Proceed to Login
                        </a>
                    <?php else: ?>
                        <div class="h-20 w-20 mx-auto mt-6 mb-4 bg-red-500 bg-opacity-20 rounded-full flex items-center justify-center">
                            <i class="fas fa-times-circle text-5xl text-red-500"></i>
                        </div>
                        <h2 class="text-xl font-semibold text-white mb-2">Verification Failed</h2>
                        <p class="text-gray-400 mb-6"><?php echo $error; ?></p>
                        
                        <div class="flex flex-col space-y-3">
                            <a href="<?php echo SITE_URL; ?>/login/resend_verification.php" class="accent-button inline-block py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 text-center">
                                Resend Verification Email
                            </a>
                            
                            <a href="<?php echo SITE_URL; ?>/login/login.php" class="bg-gray-700 hover:bg-gray-600 inline-block py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-gray-500 text-center">
                                Return to Login
                            </a>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </main>
    
    <!-- Footer -->
    <footer class="bg-gray-800 text-gray-400 py-4">
        <div class="container mx-auto px-4 text-center">
            <p>&copy; <?php echo date('Y'); ?> <?php echo getSetting('site_name'); ?>. All rights reserved.</p>
        </div>
    </footer>
</body>
</html>