<?php
// File: /webhook/monnify.php

// Load required files
require_once '../includes/config.php';
require_once '../includes/functions.php';
require_once '../includes/monnify.php';

// Debug mode - set to true to see detailed logs
define('DEBUG_MODE', true);

// Create a debugging log function
function debug_log($message, $data = null) {
    if (DEBUG_MODE) {
        $log = '[' . date('Y-m-d H:i:s') . '] ' . $message;
        if ($data !== null) {
            $log .= ': ' . (is_array($data) || is_object($data) ? json_encode($data) : $data);
        }
        error_log($log);
        
        // Also write to a specific debug file
        $debugFile = __DIR__ . '/monnify_debug.log';
        file_put_contents($debugFile, $log . PHP_EOL, FILE_APPEND);
    }
}

// Get the raw POST data
$payload = file_get_contents('php://input');

// Log the full request for debugging
debug_log('Monnify Webhook Request Headers', getallheaders());
debug_log('Monnify Webhook Raw Payload', $payload);

// Skip signature validation in case Monnify didn't provide one
$skipValidation = true;

// Get the signature from the header if it exists
$headers = getallheaders();
$signature = '';

// Check for Monnify signature in various header formats (case-insensitive)
foreach ($headers as $key => $value) {
    if (strtolower($key) === 'x-monnify-signature') {
        $signature = $value;
        $skipValidation = false;
        break;
    }
}

debug_log('Signature Found', $signature ?: 'None');

try {
    // Parse the payload
    $data = json_decode($payload, true);
    
    if (!$data) {
        debug_log('Invalid JSON payload');
        http_response_code(400);
        echo json_encode(['status' => 'error', 'message' => 'Invalid JSON payload']);
        exit;
    }
    
    debug_log('Parsed Webhook Data', $data);
    
    // Process valid transactions even if we can't verify the signature
    if ($skipValidation) {
        debug_log('Skipping signature validation');
    }
    
    // Check for valid transaction data
    if (!isset($data['eventType'])) {
        debug_log('Missing eventType in payload');
        http_response_code(400);
        echo json_encode(['status' => 'error', 'message' => 'Missing eventType']);
        exit;
    }
    
    // Process the transaction manually without using the Monnify class
    if ($data['eventType'] === 'SUCCESSFUL_TRANSACTION') {
        $eventData = $data['eventData'];
        debug_log('Processing successful transaction', $eventData);
        
        // Connect to the database
        $db = getDB();
        $conn = $db->getConnection();
        
        // Extract transaction details - FIXED: now using product.reference for accountReference
        $accountReference = $eventData['product']['reference'] ?? '';
        $amountPaid = $eventData['amountPaid'] ?? 0;
        $paymentReference = $eventData['paymentReference'] ?? '';
        $transactionReference = $eventData['transactionReference'] ?? '';
        $paymentStatus = $eventData['paymentStatus'] ?? '';
        $paidOn = $eventData['paidOn'] ?? date('Y-m-d H:i:s');
        $settlementAmount = $eventData['settlementAmount'] ?? $amountPaid;
        $totalPayable = $eventData['totalPayable'] ?? $amountPaid;
        $paymentDescription = $eventData['paymentDescription'] ?? 'Wallet Funding';
        $transactionId = $eventData['transactionId'] ?? 0;
        
        // Get sender's name from paymentSourceInformation if available
        $senderName = '';
        if (isset($eventData['paymentSourceInformation']) && is_array($eventData['paymentSourceInformation']) && !empty($eventData['paymentSourceInformation'])) {
            $senderName = $eventData['paymentSourceInformation'][0]['accountName'] ?? '';
            $accountNumber = $eventData['paymentSourceInformation'][0]['accountNumber'] ?? '';
            $bankCode = $eventData['paymentSourceInformation'][0]['bankCode'] ?? '';
        }
        
        // Additional details (may be in different locations in the payload)
        if (empty($accountNumber) && isset($eventData['accountDetails'])) {
            $accountNumber = $eventData['accountDetails']['accountNumber'] ?? '';
            $bankCode = $eventData['accountDetails']['bankCode'] ?? '';
        }
        
        $customerName = '';
        $customerEmail = '';
        if (isset($eventData['customer'])) {
            $customerName = $eventData['customer']['name'] ?? '';
            $customerEmail = $eventData['customer']['email'] ?? '';
        }
        
        debug_log('Transaction Details', [
            'accountReference' => $accountReference,
            'amountPaid' => $amountPaid,
            'paymentReference' => $paymentReference,
            'transactionReference' => $transactionReference,
            'senderName' => $senderName
        ]);
        
        // Find the user by account reference
        $stmt = $conn->prepare("SELECT id, username, email, balance FROM users WHERE monnify_account_reference = ?");
        $stmt->bind_param("s", $accountReference);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            debug_log('User not found for account reference: ' . $accountReference);
            http_response_code(404);
            echo json_encode([
                'status' => 'error',
                'message' => 'User not found for account reference: ' . $accountReference
            ]);
            exit;
        }
        
        $user = $result->fetch_assoc();
        $userId = $user['id'];
        
        debug_log('Found user', [
            'userId' => $userId,
            'username' => $user['username'],
            'balance' => $user['balance']
        ]);
        
        // Check if this transaction is already processed
        $stmt = $conn->prepare("SELECT id FROM monnify_transactions WHERE transaction_reference = ?");
        $stmt->bind_param("s", $transactionReference);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            debug_log('Transaction already processed: ' . $transactionReference);
            http_response_code(200);
            echo json_encode([
                'status' => 'success',
                'message' => 'Transaction already processed'
            ]);
            exit;
        }
        
        // Calculate the fee using the funding_charge_percentage from settings
        $fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
        $fee = $amountPaid * ($fundingChargePercentage / 100);
        $amountToCredit = $amountPaid - $fee;
        
        debug_log('Calculated amount', [
            'amountPaid' => $amountPaid,
            'fee' => $fee,
            'amountToCredit' => $amountToCredit
        ]);
        
        // Start a transaction
        $conn->begin_transaction();
        
        try {
            // 1. Save the transaction in monnify_transactions table
            // First, check if the sender_name column exists in the table
            $columnExists = false;
            $checkColumnQuery = "SHOW COLUMNS FROM monnify_transactions LIKE 'sender_name'";
            $columnResult = $conn->query($checkColumnQuery);
            if ($columnResult && $columnResult->num_rows > 0) {
                $columnExists = true;
            }
            
            if ($columnExists) {
                // Use the version with sender_name column
                $stmt = $conn->prepare("
                    INSERT INTO monnify_transactions (
                        user_id, transaction_id, payment_reference, amount_paid, 
                        total_payable, settlement_amount, paid_on, payment_status, 
                        payment_description, transaction_reference, payment_reference_raw,
                        account_number, bank_code, customer_name, customer_email, sender_name
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");
                
                $stmt->bind_param(
                    "iisdddssssssssss",
                    $userId,
                    $transactionId,
                    $paymentReference,
                    $amountPaid,
                    $totalPayable,
                    $settlementAmount,
                    $paidOn,
                    $paymentStatus,
                    $paymentDescription,
                    $transactionReference,
                    $paymentReference,
                    $accountNumber,
                    $bankCode,
                    $customerName,
                    $customerEmail,
                    $senderName
                );
            } else {
                // Use the version without sender_name column
                $stmt = $conn->prepare("
                    INSERT INTO monnify_transactions (
                        user_id, transaction_id, payment_reference, amount_paid, 
                        total_payable, settlement_amount, paid_on, payment_status, 
                        payment_description, transaction_reference, payment_reference_raw,
                        account_number, bank_code, customer_name, customer_email
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");
                
                $stmt->bind_param(
                    "iisdddsssssssss",
                    $userId,
                    $transactionId,
                    $paymentReference,
                    $amountPaid,
                    $totalPayable,
                    $settlementAmount,
                    $paidOn,
                    $paymentStatus,
                    $paymentDescription,
                    $transactionReference,
                    $paymentReference,
                    $accountNumber,
                    $bankCode,
                    $customerName,
                    $customerEmail
                );
            }
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to insert monnify transaction: " . $stmt->error);
            }
            
            debug_log('Inserted transaction into monnify_transactions table');
            
            // 2. Create a transaction record in the main transactions table
            $txn_ref = 'MNFY_' . time() . '_' . $userId;
            $description = "Wallet funding via Monnify bank transfer";
            
            $stmt = $conn->prepare("
                INSERT INTO transactions (
                    user_id, txn_ref, type, amount, fee, description, status, meta_data
                ) VALUES (?, ?, 'fund', ?, ?, ?, 'successful', ?)
            ");
            
            $metaData = json_encode([
                'monnify_reference' => $transactionReference,
                'payment_reference' => $paymentReference,
                'amount_paid' => $amountPaid,
                'fee' => $fee,
                'amount_to_credit' => $amountToCredit,
                'account_number' => $accountNumber,
                'bank_code' => $bankCode,
                'sender_name' => $senderName
            ]);
            
            $stmt->bind_param(
                "isddss",
                $userId,
                $txn_ref,
                $amountToCredit,
                $fee,
                $description,
                $metaData
            );
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to insert transaction: " . $stmt->error);
            }
            
            debug_log('Inserted record into transactions table');
            
            // 3. Update user's balance
            $stmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
            $stmt->bind_param("di", $amountToCredit, $userId);
            
            if (!$stmt->execute()) {
                throw new Exception("Failed to update user balance: " . $stmt->error);
            }
            
            $newBalance = $user['balance'] + $amountToCredit;
            debug_log('Updated user balance', [
                'oldBalance' => $user['balance'],
                'amountCredited' => $amountToCredit,
                'newBalance' => $newBalance
            ]);
            
            // 4. Create notification with sender name if available
            $notifyTitle = 'Wallet Funding Successful';
            
            // Include sender name in notification if available
            if (!empty($senderName)) {
                $notifyMessage = "Your wallet has been credited with " . $GLOBALS['currency'] . number_format($amountToCredit, 2) . 
                    " via bank transfer from " . $senderName . ".";
            } else {
                $notifyMessage = "Your wallet has been credited with " . $GLOBALS['currency'] . number_format($amountToCredit, 2) . 
                    " via bank transfer.";
            }
            
            $stmt = $conn->prepare("
                INSERT INTO notifications (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'success', 0)
            ");
            $stmt->bind_param("iss", $userId, $notifyTitle, $notifyMessage);
            
            if (!$stmt->execute()) {
                debug_log('Failed to create notification: ' . $stmt->error);
                // Not critical, so we'll continue even if notification creation fails
            } else {
                debug_log('Created notification for user');
            }
            
            // Commit the transaction
            $conn->commit();
            debug_log('Transaction committed successfully');
            
            // Return success
            http_response_code(200);
            echo json_encode([
                'status' => 'success',
                'message' => 'Transaction processed successfully',
                'data' => [
                    'userId' => $userId,
                    'amount' => $amountToCredit,
                    'transactionReference' => $transactionReference,
                    'newBalance' => $newBalance
                ]
            ]);
            exit;
        } catch (Exception $e) {
            // Rollback the transaction
            $conn->rollback();
            
            debug_log('Transaction processing failed: ' . $e->getMessage());
            
            http_response_code(500);
            echo json_encode([
                'status' => 'error',
                'message' => 'Transaction processing failed: ' . $e->getMessage()
            ]);
            exit;
        }
    } else {
        // Not a successful transaction event
        debug_log('Ignoring non-successful transaction event: ' . $data['eventType']);
        http_response_code(200);
        echo json_encode([
            'status' => 'success',
            'message' => 'Event type ignored: ' . $data['eventType']
        ]);
        exit;
    }
} catch (Exception $e) {
    debug_log('General webhook error: ' . $e->getMessage());
    http_response_code(500);
    echo json_encode([
        'status' => 'error',
        'message' => 'Webhook processing error: ' . $e->getMessage()
    ]);
    exit;
}
?>