<?php
require_once '../includes/config.php';
require_once '../includes/functions.php';

/**
 * Paystack Webhook Handler
 * 
 * This script handles webhook events from Paystack, particularly for:
 * 1. Successful payments via the checkout system
 * 2. Transfers to dedicated virtual accounts
 */

// Get Paystack settings
$paystackKeys = getPaystackKeys();
$secretKey = $paystackKeys['secret'];

// Initialize variables
$error = '';
$db = getDB();
$conn = $db->getConnection();

// Only process POST requests
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('HTTP/1.0 400 Bad Request');
    exit();
}

// Retrieve the request body
$input = file_get_contents('php://input');

// Validate webhook signature if provided
$signature = isset($_SERVER['HTTP_X_PAYSTACK_SIGNATURE']) ? $_SERVER['HTTP_X_PAYSTACK_SIGNATURE'] : '';

if ($signature) {
    // Validate that this request came from Paystack
    $hash = hash_hmac('sha512', $input, $secretKey);
    
    if ($hash !== $signature) {
        logWebhookError('Invalid signature', $input);
        header('HTTP/1.0 400 Bad Request');
        exit();
    }
}

// Parse the JSON payload
$event = json_decode($input, true);

// Check if event is properly formed
if (!isset($event['event']) || !isset($event['data'])) {
    logWebhookError('Invalid event structure', $input);
    header('HTTP/1.0 400 Bad Request');
    exit();
}

try {
    // Process based on event type
    switch ($event['event']) {
        case 'charge.success':
            // Handle successful payment via checkout
            handleSuccessfulCharge($event['data'], $conn);
            break;
            
        case 'transfer.success':
            // Handle successful transfer
            handleSuccessfulTransfer($event['data'], $conn);
            break;
            
        case 'dedicated_account.successful':
        case 'dedicatedaccount.assign.success':
            // Handle dedicated account creation
            handleDedicatedAccountSuccess($event['data'], $conn);
            break;
            
        case 'transfer.failed':
            // Handle failed transfer
            handleFailedTransfer($event['data'], $conn);
            break;
            
        case 'dedicated_virtual_account.credited':
        case 'dedicatedaccount.payment.success':
            // Handle dedicated account funding
            handleDedicatedAccountFunding($event['data'], $conn);
            break;
            
        default:
            // Log but don't process other events
            logWebhookEvent('Unprocessed event: ' . $event['event'], json_encode($event['data']));
            break;
    }
    
    // Return success response
    http_response_code(200);
    echo json_encode(['status' => 'success']);
} catch (Exception $e) {
    // Log error and return error response
    logWebhookError('Exception: ' . $e->getMessage(), $input);
    http_response_code(500);
    echo json_encode(['status' => 'error', 'message' => $e->getMessage()]);
}

/**
 * Handle successful charge via checkout
 * 
 * @param array $data Charge data from Paystack
 * @param mysqli $conn Database connection
 */
function handleSuccessfulCharge($data, $conn) {
    // Extract transaction details
    $reference = $data['reference'];
    $amountPaid = $data['amount'] / 100; // Convert from kobo to naira
    $paymentStatus = $data['status'];
    
    // Check if reference exists in our transactions table
    $stmt = $conn->prepare("SELECT * FROM transactions WHERE txn_ref = ?");
    $stmt->bind_param("s", $reference);
    $stmt->execute();
    $result = $stmt->get_result();
    $transaction = $result->fetch_assoc();
    
    if (!$transaction) {
        throw new Exception("Transaction not found: " . $reference);
    }
    
    // Skip if already processed
    if ($transaction['status'] === 'successful') {
        logWebhookEvent('Transaction already processed', json_encode($data));
        return;
    }
    
    // Process the payment
    if ($paymentStatus === 'success') {
        // Begin transaction
        $conn->begin_transaction();
        
        try {
            // Update transaction status
            $updateStmt = $conn->prepare("UPDATE transactions SET status = 'successful' WHERE id = ?");
            $updateStmt->bind_param("i", $transaction['id']);
            $updateStmt->execute();
            
            // Credit user's wallet
            $creditStmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
            $creditStmt->bind_param("di", $transaction['amount'], $transaction['user_id']);
            $creditStmt->execute();
            
            // Create notification
            $notifyTitle = 'Wallet Funding Successful';
            $notifyMessage = 'Your wallet has been credited with ' . $transaction['amount'] . ' via Paystack payment.';
            
            $notifyStmt = $conn->prepare("
                INSERT INTO notifications 
                (user_id, title, message, type, is_read)
                VALUES (?, ?, ?, 'success', 0)
            ");
            $notifyStmt->bind_param("iss", $transaction['user_id'], $notifyTitle, $notifyMessage);
            $notifyStmt->execute();
            
            // Log the webhook processing
            logWebhookEvent('Payment processed successfully', json_encode($data));
            
            // Commit transaction
            $conn->commit();
        } catch (Exception $e) {
            // Rollback transaction
            $conn->rollback();
            throw $e;
        }
    } else {
        // Update transaction status to failed
        $updateStmt = $conn->prepare("UPDATE transactions SET status = 'failed' WHERE id = ?");
        $updateStmt->bind_param("i", $transaction['id']);
        $updateStmt->execute();
        
        logWebhookEvent('Payment not successful', json_encode($data));
    }
}

/**
 * Handle successful transfer
 * 
 * @param array $data Transfer data from Paystack
 * @param mysqli $conn Database connection
 */
function handleSuccessfulTransfer($data, $conn) {
    // Extract transfer details
    $reference = $data['reference'];
    $amount = $data['amount'] / 100; // Convert from kobo to naira
    $recipient = $data['recipient'];
    
    // Log the successful transfer
    logWebhookEvent('Transfer successful', json_encode($data));
}

/**
 * Handle dedicated account creation success
 * 
 * @param array $data Account data from Paystack
 * @param mysqli $conn Database connection
 */
function handleDedicatedAccountSuccess($data, $conn) {
    // Extract account details
    $accountNumber = $data['account_number'];
    $bankName = $data['bank']['name'];
    $accountName = $data['account_name'];
    $customer = $data['customer'];
    $email = $customer['email'];
    
    // Find user by email
    $stmt = $conn->prepare("SELECT id FROM users WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
    
    if (!$user) {
        logWebhookError('User not found for dedicated account', json_encode($data));
        return;
    }
    
    // Update user with dedicated account details
    $updateStmt = $conn->prepare("UPDATE users SET 
        paystack_account_number = ?, 
        paystack_account_name = ?, 
        paystack_bank_name = ? 
        WHERE id = ?
    ");
    $updateStmt->bind_param("sssi", $accountNumber, $accountName, $bankName, $user['id']);
    
    if ($updateStmt->execute()) {
        // Create notification for user
        $notifyTitle = 'Dedicated Account Created';
        $notifyMessage = 'Your dedicated account has been created. You can now fund your wallet by transferring to this account.';
        
        $notifyStmt = $conn->prepare("
            INSERT INTO notifications 
            (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $notifyStmt->bind_param("iss", $user['id'], $notifyTitle, $notifyMessage);
        $notifyStmt->execute();
        
        logWebhookEvent('Dedicated account created', json_encode($data));
    } else {
        logWebhookError('Failed to update user with account details', json_encode($data));
    }
}

/**
 * Handle failed transfer
 * 
 * @param array $data Transfer data from Paystack
 * @param mysqli $conn Database connection
 */
function handleFailedTransfer($data, $conn) {
    // Extract transfer details
    $reference = $data['reference'];
    $reason = $data['reason'];
    
    // Log the failed transfer
    logWebhookEvent('Transfer failed: ' . $reason, json_encode($data));
}

/**
 * Handle dedicated account funding
 * 
 * @param array $data Funding data from Paystack
 * @param mysqli $conn Database connection
 */
function handleDedicatedAccountFunding($data, $conn) {
    // Extract funding details
    $amount = $data['amount'] / 100; // Convert from kobo to naira
    $customer = $data['customer'];
    $email = $customer['email'];
    $accountDetails = $data['dedicated_virtual_account'] ?? $data;
    $accountNumber = $accountDetails['account_number'];
    $reference = $data['reference'] ?? generateRandomReference();
    $fundingChargePercentage = (float)getSetting('funding_charge_percentage', 1.5);
    
    // Find user by email or account number
    $stmt = $conn->prepare("SELECT * FROM users WHERE email = ? OR paystack_account_number = ?");
    $stmt->bind_param("ss", $email, $accountNumber);
    $stmt->execute();
    $result = $stmt->get_result();
    $user = $result->fetch_assoc();
    
    if (!$user) {
        logWebhookError('User not found for account funding', json_encode($data));
        return;
    }
    
    // Check if this payment has already been processed (avoid duplicates)
    $checkStmt = $conn->prepare("SELECT id FROM transactions WHERE txn_ref = ? AND status = 'successful'");
    $checkStmt->bind_param("s", $reference);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();
    
    if ($checkResult->num_rows > 0) {
        logWebhookEvent('Transaction already processed', json_encode($data));
        return;
    }
    
    // Calculate charge and amount to credit
    $charge = $amount * ($fundingChargePercentage / 100);
    $amountToCredit = $amount - $charge;
    
    // Begin transaction
    $conn->begin_transaction();
    
    try {
        // Create transaction record
        $description = "Wallet funding via dedicated account transfer";
        $txnStmt = $conn->prepare("
            INSERT INTO transactions 
            (user_id, txn_ref, type, amount, fee, description, status)
            VALUES (?, ?, 'fund', ?, ?, ?, 'successful')
        ");
        $txnStmt->bind_param("isdss", $user['id'], $reference, $amountToCredit, $charge, $description);
        $txnStmt->execute();
        
        // Credit user's wallet
        $creditStmt = $conn->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $creditStmt->bind_param("di", $amountToCredit, $user['id']);
        $creditStmt->execute();
        
        // Create notification for user
        $notifyTitle = 'Wallet Funding Successful';
        $notifyMessage = 'Your wallet has been credited with ' . $amountToCredit . ' via dedicated account transfer.';
        
        $notifyStmt = $conn->prepare("
            INSERT INTO notifications 
            (user_id, title, message, type, is_read)
            VALUES (?, ?, ?, 'success', 0)
        ");
        $notifyStmt->bind_param("iss", $user['id'], $notifyTitle, $notifyMessage);
        $notifyStmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        logWebhookEvent('Account funding processed', json_encode($data));
    } catch (Exception $e) {
        // Rollback transaction
        $conn->rollback();
        logWebhookError('Failed to process account funding: ' . $e->getMessage(), json_encode($data));
        throw $e;
    }
}

/**
 * Log webhook event
 * 
 * @param string $message Event message
 * @param string $data Event data JSON
 */
function logWebhookEvent($message, $data) {
    global $conn;
    
    $stmt = $conn->prepare("
        INSERT INTO webhook_logs 
        (provider, event_type, message, raw_data)
        VALUES ('paystack', 'event', ?, ?)
    ");
    $stmt->bind_param("ss", $message, $data);
    $stmt->execute();
}

/**
 * Log webhook error
 * 
 * @param string $error Error message
 * @param string $data Error data JSON
 */
function logWebhookError($error, $data) {
    global $conn;
    
    $stmt = $conn->prepare("
        INSERT INTO webhook_logs 
        (provider, event_type, message, raw_data)
        VALUES ('paystack', 'error', ?, ?)
    ");
    $stmt->bind_param("ss", $error, $data);
    $stmt->execute();
}

/**
 * Generate a random reference for transactions
 * 
 * @return string Random reference
 */
function generateRandomReference() {
    return 'PS_WEBHOOK_' . time() . '_' . bin2hex(random_bytes(8));
}
?>